-- Partial conversion of GTK+/GDK include files.
--
-- David Cuny, Sept 7, 1999
-- dcuny@lanset.com
--
-- NOTE: Not all the GTK data types in c_struct.e (lines 193-220) have been
-- verified. If you find that any of these are incorrect, please send me a
-- correction to:
--
--      dcuny@lanset.com
--
-- Disclaimer:
-- This program is distributed in the hope that it will be useful, but
-- WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
--

-- GTK - The GIMP Toolkit
-- Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
--
-- This library is free software; you can redistribute it and/or
-- modify it under the terms of the GNU Library General Public
-- License as published by the Free Software Foundation; either
-- version 2 of the License, or (at your option) any later version.
--
-- This library is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-- Library General Public License for more details.
--
-- You should have received a copy of the GNU Library General Public
-- License along with this library; if not, write to the
-- Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-- Boston, MA 02111-1307, USA.

-- Modified by the GTK+ Team and others 1997-1999.  See the AUTHORS
-- file for a list of people on the GTK+ Team.  See the ChangeLog
-- files for a list of changes.  These files are distributed with
-- GTK+ at ftp://ftp.gtk.org/pub/gtk/. 


include c_struct.e
include dll.e
include misc.e

atom GTK, GDK

-- what OS is being run?
if platform() = WIN32 then
    -- link to the Win32 dll
    GTK = open_dll("gtk-1.3.dll")
    GDK = open_dll("gdk-1.3.dll")

else
    -- there's a dependancy on this dll
    GTK = open_dll("libgtkxmhtml.so")
    GTK = open_dll("libgtk.so")
    GDK = open_dll("libgdk.so")

end if

----------------------------------------
----------------------------------------
-- GDK.H
----------------------------------------
----------------------------------------


----------------------------------------
-- gdk_init
----------------------------------------
constant gdk_init_ = link_c_proc( GDK, 
  "gdk_init", {C_INT,C_POINTER} )

global procedure gdk_init(integer argc_, sequence argv_)
    atom string1
    string1 = allocate_string( argv_ )
    c_proc( gdk_init_, {argc_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_init_check
----------------------------------------
constant gdk_init_check_ = link_c_func( GDK, 
  "gdk_init_check", {C_INT,C_POINTER}, C_INT )

global function gdk_init_check(integer argc_, sequence argv_)
    integer result
    atom string1
    string1 = allocate_string( argv_ )
    result = c_func( gdk_init_check_, {argc_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_exit
----------------------------------------
constant gdk_exit_ = link_c_proc( GDK, 
  "gdk_exit", {C_INT} )

global procedure gdk_exit(integer error_code_)
    c_proc( gdk_exit_, {error_code_} )
end procedure

----------------------------------------
-- gdk_set_locale
----------------------------------------
constant gdk_set_locale_ = link_c_func( GDK, 
  "gdk_set_locale", {}, C_POINTER )

global function gdk_set_locale()
    return peek_string( c_func( gdk_set_locale_, {} ) )
end function

----------------------------------------
-- gdk_error_trap_push
----------------------------------------
constant gdk_error_trap_push_ = link_c_proc( GDK, 
  "gdk_error_trap_push", {} )

global procedure gdk_error_trap_push()
    c_proc( gdk_error_trap_push_, {} )
end procedure

----------------------------------------
-- gdk_error_trap_pop
----------------------------------------
constant gdk_error_trap_pop_ = link_c_func( GDK, 
  "gdk_error_trap_pop", {}, C_INT )

global function gdk_error_trap_pop()
    return c_func( gdk_error_trap_pop_, {} )
end function

----------------------------------------
-- gdk_events_pending
----------------------------------------
constant gdk_events_pending_ = link_c_func( GDK, 
  "gdk_events_pending", {}, C_INT )

global function gdk_events_pending()
    return c_func( gdk_events_pending_, {} )
end function

----------------------------------------
-- gdk_event_get
----------------------------------------
constant gdk_event_get_ = link_c_func( GDK, 
  "gdk_event_get", {}, C_POINTER )

global function gdk_event_get()
    return c_func( gdk_event_get_, {} )
end function

----------------------------------------
-- gdk_event_peek
----------------------------------------
constant gdk_event_peek_ = link_c_func( GDK, 
  "gdk_event_peek", {}, C_POINTER )

global function gdk_event_peek()
    return c_func( gdk_event_peek_, {} )
end function

----------------------------------------
-- gdk_event_get_graphics_expose
----------------------------------------
constant gdk_event_get_graphics_expose_ = link_c_func( GDK, 
  "gdk_event_get_graphics_expose", {C_POINTER}, C_POINTER )

global function gdk_event_get_graphics_expose(atom window_)
    return c_func( gdk_event_get_graphics_expose_, {window_} )
end function

----------------------------------------
-- gdk_event_put
----------------------------------------
constant gdk_event_put_ = link_c_proc( GDK, 
  "gdk_event_put", {C_POINTER} )

global procedure gdk_event_put(atom event_)
    c_proc( gdk_event_put_, {event_} )
end procedure

----------------------------------------
-- gdk_event_copy
----------------------------------------
constant gdk_event_copy_ = link_c_func( GDK, 
  "gdk_event_copy", {C_POINTER}, C_POINTER )

global function gdk_event_copy(atom event_)
    return c_func( gdk_event_copy_, {event_} )
end function

----------------------------------------
-- gdk_event_free
----------------------------------------
constant gdk_event_free_ = link_c_proc( GDK, 
  "gdk_event_free", {C_POINTER} )

global procedure gdk_event_free(atom event_)
    c_proc( gdk_event_free_, {event_} )
end procedure

----------------------------------------
-- gdk_event_get_time
----------------------------------------
constant gdk_event_get_time_ = link_c_func( GDK, 
  "gdk_event_get_time", {C_POINTER}, C_UINT )

global function gdk_event_get_time(atom event_)
    return c_func( gdk_event_get_time_, {event_} )
end function

----------------------------------------
-- gdk_event_handler_set
----------------------------------------
constant gdk_event_handler_set_ = link_c_proc( GDK, 
  "gdk_event_handler_set", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gdk_event_handler_set(atom func_, atom data_, atom notify_)
    c_proc( gdk_event_handler_set_, {func_,data_,notify_} )
end procedure

----------------------------------------
-- gdk_set_show_events
----------------------------------------
constant gdk_set_show_events_ = link_c_proc( GDK, 
  "gdk_set_show_events", {C_INT} )

global procedure gdk_set_show_events(integer show_events_)
    c_proc( gdk_set_show_events_, {show_events_} )
end procedure

----------------------------------------
-- gdk_set_use_xshm
----------------------------------------
constant gdk_set_use_xshm_ = link_c_proc( GDK, 
  "gdk_set_use_xshm", {C_INT} )

global procedure gdk_set_use_xshm(integer use_xshm_)
    c_proc( gdk_set_use_xshm_, {use_xshm_} )
end procedure

----------------------------------------
-- gdk_get_show_events
----------------------------------------
constant gdk_get_show_events_ = link_c_func( GDK, 
  "gdk_get_show_events", {}, C_INT )

global function gdk_get_show_events()
    return c_func( gdk_get_show_events_, {} )
end function

----------------------------------------
-- gdk_get_use_xshm
----------------------------------------
constant gdk_get_use_xshm_ = link_c_func( GDK, 
  "gdk_get_use_xshm", {}, C_INT )

global function gdk_get_use_xshm()
    return c_func( gdk_get_use_xshm_, {} )
end function

----------------------------------------
-- gdk_get_display
----------------------------------------
constant gdk_get_display_ = link_c_func( GDK, 
  "gdk_get_display", {}, C_POINTER )

global function gdk_get_display()
    return peek_string( c_func( gdk_get_display_, {} ) )
end function

----------------------------------------
-- gdk_time_get
----------------------------------------
constant gdk_time_get_ = link_c_func( GDK, 
  "gdk_time_get", {}, C_UINT )

global function gdk_time_get()
    return c_func( gdk_time_get_, {} )
end function

----------------------------------------
-- gdk_timer_get
----------------------------------------
constant gdk_timer_get_ = link_c_func( GDK, 
  "gdk_timer_get", {}, C_UINT )

global function gdk_timer_get()
    return c_func( gdk_timer_get_, {} )
end function

----------------------------------------
-- gdk_timer_set
----------------------------------------
constant gdk_timer_set_ = link_c_proc( GDK, 
  "gdk_timer_set", {C_UINT} )

global procedure gdk_timer_set(atom milliseconds_)
    c_proc( gdk_timer_set_, {milliseconds_} )
end procedure

----------------------------------------
-- gdk_timer_enable
----------------------------------------
constant gdk_timer_enable_ = link_c_proc( GDK, 
  "gdk_timer_enable", {} )

global procedure gdk_timer_enable()
    c_proc( gdk_timer_enable_, {} )
end procedure

----------------------------------------
-- gdk_timer_disable
----------------------------------------
constant gdk_timer_disable_ = link_c_proc( GDK, 
  "gdk_timer_disable", {} )

global procedure gdk_timer_disable()
    c_proc( gdk_timer_disable_, {} )
end procedure

----------------------------------------
-- gdk_input_add_full
----------------------------------------
constant gdk_input_add_full_ = link_c_func( GDK, 
  "gdk_input_add_full", {C_INT,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function gdk_input_add_full(integer source_, atom condition_, atom function_, atom data_, atom destroy_)
    return c_func( gdk_input_add_full_, {source_,condition_,function_,data_,destroy_} )
end function

----------------------------------------
-- gdk_input_add
----------------------------------------
constant gdk_input_add_ = link_c_func( GDK, 
  "gdk_input_add", {C_INT,C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function gdk_input_add(integer source_, atom condition_, atom function_, atom data_)
    return c_func( gdk_input_add_, {source_,condition_,function_,data_} )
end function

----------------------------------------
-- gdk_input_remove
----------------------------------------
constant gdk_input_remove_ = link_c_proc( GDK, 
  "gdk_input_remove", {C_INT} )

global procedure gdk_input_remove(integer tag_)
    c_proc( gdk_input_remove_, {tag_} )
end procedure

----------------------------------------
-- gdk_pointer_grab
----------------------------------------
constant gdk_pointer_grab_ = link_c_func( GDK, 
  "gdk_pointer_grab", {C_POINTER,C_INT,C_POINTER,C_POINTER,C_POINTER,C_UINT}, C_INT )

global function gdk_pointer_grab(atom window_, integer owner_events_, atom event_mask_, atom confine_to_, atom cursor_, atom time_)
    return c_func( gdk_pointer_grab_, {window_,owner_events_,event_mask_,confine_to_,cursor_,time_} )
end function

----------------------------------------
-- gdk_pointer_ungrab
----------------------------------------
constant gdk_pointer_ungrab_ = link_c_proc( GDK, 
  "gdk_pointer_ungrab", {C_UINT} )

global procedure gdk_pointer_ungrab(atom time_)
    c_proc( gdk_pointer_ungrab_, {time_} )
end procedure

----------------------------------------
-- gdk_keyboard_grab
----------------------------------------
constant gdk_keyboard_grab_ = link_c_func( GDK, 
  "gdk_keyboard_grab", {C_POINTER,C_INT,C_UINT}, C_INT )

global function gdk_keyboard_grab(atom window_, integer owner_events_, atom time_)
    return c_func( gdk_keyboard_grab_, {window_,owner_events_,time_} )
end function

----------------------------------------
-- gdk_keyboard_ungrab
----------------------------------------
constant gdk_keyboard_ungrab_ = link_c_proc( GDK, 
  "gdk_keyboard_ungrab", {C_UINT} )

global procedure gdk_keyboard_ungrab(atom time_)
    c_proc( gdk_keyboard_ungrab_, {time_} )
end procedure

----------------------------------------
-- gdk_pointer_is_grabbed
----------------------------------------
constant gdk_pointer_is_grabbed_ = link_c_func( GDK, 
  "gdk_pointer_is_grabbed", {}, C_INT )

global function gdk_pointer_is_grabbed()
    return c_func( gdk_pointer_is_grabbed_, {} )
end function

----------------------------------------
-- gdk_screen_width
----------------------------------------
constant gdk_screen_width_ = link_c_func( GDK, 
  "gdk_screen_width", {}, C_INT )

global function gdk_screen_width()
    return c_func( gdk_screen_width_, {} )
end function

----------------------------------------
-- gdk_screen_height
----------------------------------------
constant gdk_screen_height_ = link_c_func( GDK, 
  "gdk_screen_height", {}, C_INT )

global function gdk_screen_height()
    return c_func( gdk_screen_height_, {} )
end function

----------------------------------------
-- gdk_screen_width_mm
----------------------------------------
constant gdk_screen_width_mm_ = link_c_func( GDK, 
  "gdk_screen_width_mm", {}, C_INT )

global function gdk_screen_width_mm()
    return c_func( gdk_screen_width_mm_, {} )
end function

----------------------------------------
-- gdk_screen_height_mm
----------------------------------------
constant gdk_screen_height_mm_ = link_c_func( GDK, 
  "gdk_screen_height_mm", {}, C_INT )

global function gdk_screen_height_mm()
    return c_func( gdk_screen_height_mm_, {} )
end function

----------------------------------------
-- gdk_flush
----------------------------------------
constant gdk_flush_ = link_c_proc( GDK, 
  "gdk_flush", {} )

global procedure gdk_flush()
    c_proc( gdk_flush_, {} )
end procedure

----------------------------------------
-- gdk_beep
----------------------------------------
constant gdk_beep_ = link_c_proc( GDK, 
  "gdk_beep", {} )

global procedure gdk_beep()
    c_proc( gdk_beep_, {} )
end procedure

----------------------------------------
-- gdk_key_repeat_disable
----------------------------------------
constant gdk_key_repeat_disable_ = link_c_proc( GDK, 
  "gdk_key_repeat_disable", {} )

global procedure gdk_key_repeat_disable()
    c_proc( gdk_key_repeat_disable_, {} )
end procedure

----------------------------------------
-- gdk_key_repeat_restore
----------------------------------------
constant gdk_key_repeat_restore_ = link_c_proc( GDK, 
  "gdk_key_repeat_restore", {} )

global procedure gdk_key_repeat_restore()
    c_proc( gdk_key_repeat_restore_, {} )
end procedure

----------------------------------------
-- gdk_visual_get_best_depth
----------------------------------------
constant gdk_visual_get_best_depth_ = link_c_func( GDK, 
  "gdk_visual_get_best_depth", {}, C_INT )

global function gdk_visual_get_best_depth()
    return c_func( gdk_visual_get_best_depth_, {} )
end function

----------------------------------------
-- gdk_visual_get_best_type
----------------------------------------
constant gdk_visual_get_best_type_ = link_c_func( GDK, 
  "gdk_visual_get_best_type", {}, C_POINTER )

global function gdk_visual_get_best_type()
    return c_func( gdk_visual_get_best_type_, {} )
end function

----------------------------------------
-- gdk_visual_get_system
----------------------------------------
constant gdk_visual_get_system_ = link_c_func( GDK, 
  "gdk_visual_get_system", {}, C_POINTER )

global function gdk_visual_get_system()
    return c_func( gdk_visual_get_system_, {} )
end function

----------------------------------------
-- gdk_visual_get_best
----------------------------------------
constant gdk_visual_get_best_ = link_c_func( GDK, 
  "gdk_visual_get_best", {}, C_POINTER )

global function gdk_visual_get_best()
    return c_func( gdk_visual_get_best_, {} )
end function

----------------------------------------
-- gdk_visual_get_best_with_depth
----------------------------------------
constant gdk_visual_get_best_with_depth_ = link_c_func( GDK, 
  "gdk_visual_get_best_with_depth", {C_INT}, C_POINTER )

global function gdk_visual_get_best_with_depth(integer depth_)
    return c_func( gdk_visual_get_best_with_depth_, {depth_} )
end function

----------------------------------------
-- gdk_visual_get_best_with_type
----------------------------------------
constant gdk_visual_get_best_with_type_ = link_c_func( GDK, 
  "gdk_visual_get_best_with_type", {C_POINTER}, C_POINTER )

global function gdk_visual_get_best_with_type(atom visual_type_)
    return c_func( gdk_visual_get_best_with_type_, {visual_type_} )
end function

----------------------------------------
-- gdk_visual_get_best_with_both
----------------------------------------
constant gdk_visual_get_best_with_both_ = link_c_func( GDK, 
  "gdk_visual_get_best_with_both", {C_INT,C_POINTER}, C_POINTER )

global function gdk_visual_get_best_with_both(integer depth_, atom visual_type_)
    return c_func( gdk_visual_get_best_with_both_, {depth_,visual_type_} )
end function

----------------------------------------
-- gdk_visual_ref
----------------------------------------
constant gdk_visual_ref_ = link_c_func( GDK, 
  "gdk_visual_ref", {C_POINTER}, C_POINTER )

global function gdk_visual_ref(atom visual_)
    return c_func( gdk_visual_ref_, {visual_} )
end function

----------------------------------------
-- gdk_visual_unref
----------------------------------------
constant gdk_visual_unref_ = link_c_proc( GDK, 
  "gdk_visual_unref", {C_POINTER} )

global procedure gdk_visual_unref(atom visual_)
    c_proc( gdk_visual_unref_, {visual_} )
end procedure

----------------------------------------
-- gdk_query_depths
----------------------------------------
constant gdk_query_depths_ = link_c_proc( GDK, 
  "gdk_query_depths", {C_INT,C_INT} )

global procedure gdk_query_depths(integer depths_, integer count_)
    c_proc( gdk_query_depths_, {depths_,count_} )
end procedure

----------------------------------------
-- gdk_query_visual_types
----------------------------------------
constant gdk_query_visual_types_ = link_c_proc( GDK, 
  "gdk_query_visual_types", {C_POINTER,C_INT} )

global procedure gdk_query_visual_types(atom visual_types_, integer count_)
    c_proc( gdk_query_visual_types_, {visual_types_,count_} )
end procedure

----------------------------------------
-- gdk_list_visuals
----------------------------------------
constant gdk_list_visuals_ = link_c_func( GDK, 
  "gdk_list_visuals", {}, C_POINTER )

global function gdk_list_visuals()
    return c_func( gdk_list_visuals_, {} )
end function

----------------------------------------
-- gdk_window_new
----------------------------------------
constant gdk_window_new_ = link_c_func( GDK, 
  "gdk_window_new", {C_POINTER,C_POINTER,C_INT}, C_POINTER )

global function gdk_window_new(atom parent_, atom attributes_, integer attributes_mask_)
    return c_func( gdk_window_new_, {parent_,attributes_,attributes_mask_} )
end function

----------------------------------------
-- gdk_window_destroy
----------------------------------------
constant gdk_window_destroy_ = link_c_proc( GDK, 
  "gdk_window_destroy", {C_POINTER} )

global procedure gdk_window_destroy(atom window_)
    c_proc( gdk_window_destroy_, {window_} )
end procedure

----------------------------------------
-- gdk_window_ref
----------------------------------------
constant gdk_window_ref_ = link_c_func( GDK, 
  "gdk_window_ref", {C_POINTER}, C_POINTER )

global function gdk_window_ref(atom window_)
    return c_func( gdk_window_ref_, {window_} )
end function

----------------------------------------
-- gdk_window_unref
----------------------------------------
constant gdk_window_unref_ = link_c_proc( GDK, 
  "gdk_window_unref", {C_POINTER} )

global procedure gdk_window_unref(atom window_)
    c_proc( gdk_window_unref_, {window_} )
end procedure

----------------------------------------
-- gdk_window_at_pointer
----------------------------------------
constant gdk_window_at_pointer_ = link_c_func( GDK, 
  "gdk_window_at_pointer", {C_INT,C_INT}, C_POINTER )

global function gdk_window_at_pointer(integer win_x_, integer win_y_)
    return c_func( gdk_window_at_pointer_, {win_x_,win_y_} )
end function

----------------------------------------
-- gdk_window_show
----------------------------------------
constant gdk_window_show_ = link_c_proc( GDK, 
  "gdk_window_show", {C_POINTER} )

global procedure gdk_window_show(atom window_)
    c_proc( gdk_window_show_, {window_} )
end procedure

----------------------------------------
-- gdk_window_hide
----------------------------------------
constant gdk_window_hide_ = link_c_proc( GDK, 
  "gdk_window_hide", {C_POINTER} )

global procedure gdk_window_hide(atom window_)
    c_proc( gdk_window_hide_, {window_} )
end procedure

----------------------------------------
-- gdk_window_withdraw
----------------------------------------
constant gdk_window_withdraw_ = link_c_proc( GDK, 
  "gdk_window_withdraw", {C_POINTER} )

global procedure gdk_window_withdraw(atom window_)
    c_proc( gdk_window_withdraw_, {window_} )
end procedure

----------------------------------------
-- gdk_window_move
----------------------------------------
constant gdk_window_move_ = link_c_proc( GDK, 
  "gdk_window_move", {C_POINTER,C_INT,C_INT} )

global procedure gdk_window_move(atom window_, integer x_, integer y_)
    c_proc( gdk_window_move_, {window_,x_,y_} )
end procedure

----------------------------------------
-- gdk_window_resize
----------------------------------------
constant gdk_window_resize_ = link_c_proc( GDK, 
  "gdk_window_resize", {C_POINTER,C_INT,C_INT} )

global procedure gdk_window_resize(atom window_, integer width_, integer height_)
    c_proc( gdk_window_resize_, {window_,width_,height_} )
end procedure

----------------------------------------
-- gdk_window_move_resize
----------------------------------------
constant gdk_window_move_resize_ = link_c_proc( GDK, 
  "gdk_window_move_resize", {C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_window_move_resize(atom window_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gdk_window_move_resize_, {window_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gdk_window_reparent
----------------------------------------
constant gdk_window_reparent_ = link_c_proc( GDK, 
  "gdk_window_reparent", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gdk_window_reparent(atom window_, atom new_parent_, integer x_, integer y_)
    c_proc( gdk_window_reparent_, {window_,new_parent_,x_,y_} )
end procedure

----------------------------------------
-- gdk_window_clear
----------------------------------------
constant gdk_window_clear_ = link_c_proc( GDK, 
  "gdk_window_clear", {C_POINTER} )

global procedure gdk_window_clear(atom window_)
    c_proc( gdk_window_clear_, {window_} )
end procedure

----------------------------------------
-- gdk_window_clear_area
----------------------------------------
constant gdk_window_clear_area_ = link_c_proc( GDK, 
  "gdk_window_clear_area", {C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_window_clear_area(atom window_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gdk_window_clear_area_, {window_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gdk_window_clear_area_e
----------------------------------------
constant gdk_window_clear_area_e_ = link_c_proc( GDK, 
  "gdk_window_clear_area_e", {C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_window_clear_area_e(atom window_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gdk_window_clear_area_e_, {window_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gdk_window_copy_area
----------------------------------------
constant gdk_window_copy_area_ = link_c_proc( GDK, 
  "gdk_window_copy_area", {C_POINTER,C_POINTER,C_INT,C_INT,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_window_copy_area(atom window_, atom gc_, integer x_, integer y_, atom source_window_, integer 
 source_x_, integer source_y_, integer width_, integer height_)
    c_proc( gdk_window_copy_area_, {window_,gc_,x_,y_,source_window_,source_x_,source_y_,width_,height_} )
end procedure

----------------------------------------
-- gdk_window_raise
----------------------------------------
constant gdk_window_raise_ = link_c_proc( GDK, 
  "gdk_window_raise", {C_POINTER} )

global procedure gdk_window_raise(atom window_)
    c_proc( gdk_window_raise_, {window_} )
end procedure

----------------------------------------
-- gdk_window_lower
----------------------------------------
constant gdk_window_lower_ = link_c_proc( GDK, 
  "gdk_window_lower", {C_POINTER} )

global procedure gdk_window_lower(atom window_)
    c_proc( gdk_window_lower_, {window_} )
end procedure

----------------------------------------
-- gdk_window_set_user_data
----------------------------------------
constant gdk_window_set_user_data_ = link_c_proc( GDK, 
  "gdk_window_set_user_data", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_user_data(atom window_, atom user_data_)
    c_proc( gdk_window_set_user_data_, {window_,user_data_} )
end procedure

----------------------------------------
-- gdk_window_set_override_redirect
----------------------------------------
constant gdk_window_set_override_redirect_ = link_c_proc( GDK, 
  "gdk_window_set_override_redirect", {C_POINTER,C_INT} )

global procedure gdk_window_set_override_redirect(atom window_, integer override_redirect_)
    c_proc( gdk_window_set_override_redirect_, {window_,override_redirect_} )
end procedure

----------------------------------------
-- gdk_window_add_filter
----------------------------------------
constant gdk_window_add_filter_ = link_c_proc( GDK, 
  "gdk_window_add_filter", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gdk_window_add_filter(atom window_, atom function_, atom data_)
    c_proc( gdk_window_add_filter_, {window_,function_,data_} )
end procedure

----------------------------------------
-- gdk_window_remove_filter
----------------------------------------
constant gdk_window_remove_filter_ = link_c_proc( GDK, 
  "gdk_window_remove_filter", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gdk_window_remove_filter(atom window_, atom function_, atom data_)
    c_proc( gdk_window_remove_filter_, {window_,function_,data_} )
end procedure

----------------------------------------
-- gdk_window_shape_combine_mask
----------------------------------------
constant gdk_window_shape_combine_mask_ = link_c_proc( GDK, 
  "gdk_window_shape_combine_mask", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gdk_window_shape_combine_mask(atom window_, atom shape_mask_, integer offset_x_, integer offset_y_)
    c_proc( gdk_window_shape_combine_mask_, {window_,shape_mask_,offset_x_,offset_y_} )
end procedure

----------------------------------------
-- gdk_window_set_child_shapes
----------------------------------------
constant gdk_window_set_child_shapes_ = link_c_proc( GDK, 
  "gdk_window_set_child_shapes", {C_POINTER} )

global procedure gdk_window_set_child_shapes(atom window_)
    c_proc( gdk_window_set_child_shapes_, {window_} )
end procedure

----------------------------------------
-- gdk_window_merge_child_shapes
----------------------------------------
constant gdk_window_merge_child_shapes_ = link_c_proc( GDK, 
  "gdk_window_merge_child_shapes", {C_POINTER} )

global procedure gdk_window_merge_child_shapes(atom window_)
    c_proc( gdk_window_merge_child_shapes_, {window_} )
end procedure

----------------------------------------
-- gdk_window_is_visible
----------------------------------------
constant gdk_window_is_visible_ = link_c_func( GDK, 
  "gdk_window_is_visible", {C_POINTER}, C_INT )

global function gdk_window_is_visible(atom window_)
    return c_func( gdk_window_is_visible_, {window_} )
end function

----------------------------------------
-- gdk_window_is_viewable
----------------------------------------
constant gdk_window_is_viewable_ = link_c_func( GDK, 
  "gdk_window_is_viewable", {C_POINTER}, C_INT )

global function gdk_window_is_viewable(atom window_)
    return c_func( gdk_window_is_viewable_, {window_} )
end function

----------------------------------------
-- gdk_window_set_static_gravities
----------------------------------------
constant gdk_window_set_static_gravities_ = link_c_func( GDK, 
  "gdk_window_set_static_gravities", {C_POINTER,C_INT}, C_INT )

global function gdk_window_set_static_gravities(atom window_, integer use_static_)
    return c_func( gdk_window_set_static_gravities_, {window_,use_static_} )
end function

----------------------------------------
-- gdk_add_client_message_filter
----------------------------------------
constant gdk_add_client_message_filter_ = link_c_proc( GDK, 
  "gdk_add_client_message_filter", {C_ULONG,C_POINTER,C_POINTER} )

global procedure gdk_add_client_message_filter(atom message_type_, atom func_, atom data_)
    c_proc( gdk_add_client_message_filter_, {message_type_,func_,data_} )
end procedure

----------------------------------------
-- gdk_drag_status
----------------------------------------
constant gdk_drag_status_ = link_c_proc( GDK, 
  "gdk_drag_status", {C_POINTER,C_POINTER,C_UINT} )

global procedure gdk_drag_status(atom context_, atom action_, atom time_)
    c_proc( gdk_drag_status_, {context_,action_,time_} )
end procedure

----------------------------------------
-- gdk_drop_reply
----------------------------------------
constant gdk_drop_reply_ = link_c_proc( GDK, 
  "gdk_drop_reply", {C_POINTER,C_INT,C_UINT} )

global procedure gdk_drop_reply(atom context_, integer ok_, atom time_)
    c_proc( gdk_drop_reply_, {context_,ok_,time_} )
end procedure

----------------------------------------
-- gdk_drop_finish
----------------------------------------
constant gdk_drop_finish_ = link_c_proc( GDK, 
  "gdk_drop_finish", {C_POINTER,C_INT,C_UINT} )

global procedure gdk_drop_finish(atom context_, integer success_, atom time_)
    c_proc( gdk_drop_finish_, {context_,success_,time_} )
end procedure

----------------------------------------
-- gdk_drag_get_selection
----------------------------------------
constant gdk_drag_get_selection_ = link_c_func( GDK, 
  "gdk_drag_get_selection", {C_POINTER}, C_ULONG )

global function gdk_drag_get_selection(atom context_)
    return c_func( gdk_drag_get_selection_, {context_} )
end function

----------------------------------------
-- gdk_window_set_hints
----------------------------------------
constant gdk_window_set_hints_ = link_c_proc( GDK, 
  "gdk_window_set_hints", {C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_window_set_hints(atom window_, integer x_, integer y_, integer min_width_, integer min_height_, 
 integer max_width_, integer max_height_, integer flags_)
    c_proc( gdk_window_set_hints_, {window_,x_,y_,min_width_,min_height_,max_width_,max_height_,flags_} )
end procedure

----------------------------------------
-- gdk_window_set_geometry_hints
----------------------------------------
constant gdk_window_set_geometry_hints_ = link_c_proc( GDK, 
  "gdk_window_set_geometry_hints", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gdk_window_set_geometry_hints(atom window_, atom geometry_, atom flags_)
    c_proc( gdk_window_set_geometry_hints_, {window_,geometry_,flags_} )
end procedure

----------------------------------------
-- gdk_set_sm_client_id
----------------------------------------
constant gdk_set_sm_client_id_ = link_c_proc( GDK, 
  "gdk_set_sm_client_id", {C_POINTER} )

global procedure gdk_set_sm_client_id(sequence const_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gdk_set_sm_client_id_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_window_set_title
----------------------------------------
constant gdk_window_set_title_ = link_c_proc( GDK, 
  "gdk_window_set_title", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_title(atom window_, sequence title_)
    atom string1
    string1 = allocate_string( title_ )
    c_proc( gdk_window_set_title_, {window_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_window_set_role
----------------------------------------
constant gdk_window_set_role_ = link_c_proc( GDK, 
  "gdk_window_set_role", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_role(atom window_, sequence role_)
    atom string1
    string1 = allocate_string( role_ )
    c_proc( gdk_window_set_role_, {window_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_window_set_transient_for
----------------------------------------
constant gdk_window_set_transient_for_ = link_c_proc( GDK, 
  "gdk_window_set_transient_for", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_transient_for(atom window_, atom leader_)
    c_proc( gdk_window_set_transient_for_, {window_,leader_} )
end procedure

----------------------------------------
-- gdk_window_set_background
----------------------------------------
constant gdk_window_set_background_ = link_c_proc( GDK, 
  "gdk_window_set_background", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_background(atom window_, atom color_)
    c_proc( gdk_window_set_background_, {window_,color_} )
end procedure

----------------------------------------
-- gdk_window_set_back_pixmap
----------------------------------------
constant gdk_window_set_back_pixmap_ = link_c_proc( GDK, 
  "gdk_window_set_back_pixmap", {C_POINTER,C_POINTER,C_INT} )

global procedure gdk_window_set_back_pixmap(atom window_, atom pixmap_, integer parent_relative_)
    c_proc( gdk_window_set_back_pixmap_, {window_,pixmap_,parent_relative_} )
end procedure

----------------------------------------
-- gdk_window_set_cursor
----------------------------------------
constant gdk_window_set_cursor_ = link_c_proc( GDK, 
  "gdk_window_set_cursor", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_cursor(atom window_, atom cursor_)
    c_proc( gdk_window_set_cursor_, {window_,cursor_} )
end procedure

----------------------------------------
-- gdk_window_set_colormap
----------------------------------------
constant gdk_window_set_colormap_ = link_c_proc( GDK, 
  "gdk_window_set_colormap", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_colormap(atom window_, atom colormap_)
    c_proc( gdk_window_set_colormap_, {window_,colormap_} )
end procedure

----------------------------------------
-- gdk_window_get_user_data
----------------------------------------
constant gdk_window_get_user_data_ = link_c_proc( GDK, 
  "gdk_window_get_user_data", {C_POINTER,C_POINTER} )

global procedure gdk_window_get_user_data(atom window_, atom data_)
    c_proc( gdk_window_get_user_data_, {window_,data_} )
end procedure

----------------------------------------
-- gdk_window_get_geometry
----------------------------------------
constant gdk_window_get_geometry_ = link_c_proc( GDK, 
  "gdk_window_get_geometry", {C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_window_get_geometry(atom window_, integer x_, integer y_, integer width_, integer height_, integer depth_)
    c_proc( gdk_window_get_geometry_, {window_,x_,y_,width_,height_,depth_} )
end procedure

----------------------------------------
-- gdk_window_get_position
----------------------------------------
constant gdk_window_get_position_ = link_c_proc( GDK, 
  "gdk_window_get_position", {C_POINTER,C_INT,C_INT} )

global procedure gdk_window_get_position(atom window_, integer x_, integer y_)
    c_proc( gdk_window_get_position_, {window_,x_,y_} )
end procedure

----------------------------------------
-- gdk_window_get_size
----------------------------------------
constant gdk_window_get_size_ = link_c_proc( GDK, 
  "gdk_window_get_size", {C_POINTER,C_INT,C_INT} )

global procedure gdk_window_get_size(atom window_, integer width_, integer height_)
    c_proc( gdk_window_get_size_, {window_,width_,height_} )
end procedure

----------------------------------------
-- gdk_window_get_visual
----------------------------------------
constant gdk_window_get_visual_ = link_c_func( GDK, 
  "gdk_window_get_visual", {C_POINTER}, C_POINTER )

global function gdk_window_get_visual(atom window_)
    return c_func( gdk_window_get_visual_, {window_} )
end function

----------------------------------------
-- gdk_window_get_colormap
----------------------------------------
constant gdk_window_get_colormap_ = link_c_func( GDK, 
  "gdk_window_get_colormap", {C_POINTER}, C_POINTER )

global function gdk_window_get_colormap(atom window_)
    return c_func( gdk_window_get_colormap_, {window_} )
end function

----------------------------------------
-- gdk_window_get_type
----------------------------------------
constant gdk_window_get_type_ = link_c_func( GDK, 
  "gdk_window_get_type", {C_POINTER}, C_POINTER )

global function gdk_window_get_type(atom window_)
    return c_func( gdk_window_get_type_, {window_} )
end function

----------------------------------------
-- gdk_window_get_origin
----------------------------------------
constant gdk_window_get_origin_ = link_c_func( GDK, 
  "gdk_window_get_origin", {C_POINTER,C_INT,C_INT}, C_INT )

global function gdk_window_get_origin(atom window_, integer x_, integer y_)
    return c_func( gdk_window_get_origin_, {window_,x_,y_} )
end function

----------------------------------------
-- gdk_window_get_deskrelative_origin
----------------------------------------
constant gdk_window_get_deskrelative_origin_ = link_c_func( GDK, 
  "gdk_window_get_deskrelative_origin", {C_POINTER,C_INT,C_INT}, C_INT )

global function gdk_window_get_deskrelative_origin(atom window_, integer x_, integer y_)
    return c_func( gdk_window_get_deskrelative_origin_, {window_,x_,y_} )
end function

----------------------------------------
-- gdk_window_get_root_origin
----------------------------------------
constant gdk_window_get_root_origin_ = link_c_proc( GDK, 
  "gdk_window_get_root_origin", {C_POINTER,C_INT,C_INT} )

global procedure gdk_window_get_root_origin(atom window_, integer x_, integer y_)
    c_proc( gdk_window_get_root_origin_, {window_,x_,y_} )
end procedure

----------------------------------------
-- gdk_window_get_pointer
----------------------------------------
constant gdk_window_get_pointer_ = link_c_func( GDK, 
  "gdk_window_get_pointer", {C_POINTER,C_INT,C_INT,C_POINTER}, C_POINTER )

global function gdk_window_get_pointer(atom window_, integer x_, integer y_, atom mask_)
    return c_func( gdk_window_get_pointer_, {window_,x_,y_,mask_} )
end function

----------------------------------------
-- gdk_window_get_parent
----------------------------------------
constant gdk_window_get_parent_ = link_c_func( GDK, 
  "gdk_window_get_parent", {C_POINTER}, C_POINTER )

global function gdk_window_get_parent(atom window_)
    return c_func( gdk_window_get_parent_, {window_} )
end function

----------------------------------------
-- gdk_window_get_toplevel
----------------------------------------
constant gdk_window_get_toplevel_ = link_c_func( GDK, 
  "gdk_window_get_toplevel", {C_POINTER}, C_POINTER )

global function gdk_window_get_toplevel(atom window_)
    return c_func( gdk_window_get_toplevel_, {window_} )
end function

----------------------------------------
-- gdk_window_get_children
----------------------------------------
constant gdk_window_get_children_ = link_c_func( GDK, 
  "gdk_window_get_children", {C_POINTER}, C_POINTER )

global function gdk_window_get_children(atom window_)
    return c_func( gdk_window_get_children_, {window_} )
end function

----------------------------------------
-- gdk_window_get_events
----------------------------------------
constant gdk_window_get_events_ = link_c_func( GDK, 
  "gdk_window_get_events", {C_POINTER}, C_POINTER )

global function gdk_window_get_events(atom window_)
    return c_func( gdk_window_get_events_, {window_} )
end function

----------------------------------------
-- gdk_window_set_events
----------------------------------------
constant gdk_window_set_events_ = link_c_proc( GDK, 
  "gdk_window_set_events", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_events(atom window_, atom event_mask_)
    c_proc( gdk_window_set_events_, {window_,event_mask_} )
end procedure

----------------------------------------
-- gdk_window_set_icon
----------------------------------------
constant gdk_window_set_icon_ = link_c_proc( GDK, 
  "gdk_window_set_icon", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gdk_window_set_icon(atom window_, atom icon_window_, atom pixmap_, atom mask_)
    c_proc( gdk_window_set_icon_, {window_,icon_window_,pixmap_,mask_} )
end procedure

----------------------------------------
-- gdk_window_set_icon_name
----------------------------------------
constant gdk_window_set_icon_name_ = link_c_proc( GDK, 
  "gdk_window_set_icon_name", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_icon_name(atom window_, sequence name_)
    atom string1
    string1 = allocate_string( name_ )
    c_proc( gdk_window_set_icon_name_, {window_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_window_set_group
----------------------------------------
constant gdk_window_set_group_ = link_c_proc( GDK, 
  "gdk_window_set_group", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_group(atom window_, atom leader_)
    c_proc( gdk_window_set_group_, {window_,leader_} )
end procedure

----------------------------------------
-- gdk_window_set_decorations
----------------------------------------
constant gdk_window_set_decorations_ = link_c_proc( GDK, 
  "gdk_window_set_decorations", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_decorations(atom window_, atom decorations_)
    c_proc( gdk_window_set_decorations_, {window_,decorations_} )
end procedure

----------------------------------------
-- gdk_window_set_functions
----------------------------------------
constant gdk_window_set_functions_ = link_c_proc( GDK, 
  "gdk_window_set_functions", {C_POINTER,C_POINTER} )

global procedure gdk_window_set_functions(atom window_, atom functions_)
    c_proc( gdk_window_set_functions_, {window_,functions_} )
end procedure

----------------------------------------
-- gdk_cursor_new
----------------------------------------
constant gdk_cursor_new_ = link_c_func( GDK, 
  "gdk_cursor_new", {C_POINTER}, C_POINTER )

global function gdk_cursor_new(atom cursor_type_)
    return c_func( gdk_cursor_new_, {cursor_type_} )
end function

----------------------------------------
-- gdk_cursor_new_from_pixmap
----------------------------------------
constant gdk_cursor_new_from_pixmap_ = link_c_func( GDK, 
  "gdk_cursor_new_from_pixmap", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT}, 
 C_POINTER )

global function gdk_cursor_new_from_pixmap(atom source_, atom mask_, atom fg_, atom bg_, integer x_, integer y_)
    return c_func( gdk_cursor_new_from_pixmap_, {source_,mask_,fg_,bg_,x_,y_} )
end function

----------------------------------------
-- gdk_cursor_destroy
----------------------------------------
constant gdk_cursor_destroy_ = link_c_proc( GDK, 
  "gdk_cursor_destroy", {C_POINTER} )

global procedure gdk_cursor_destroy(atom cursor_)
    c_proc( gdk_cursor_destroy_, {cursor_} )
end procedure

----------------------------------------
-- gdk_gc_new
----------------------------------------
constant gdk_gc_new_ = link_c_func( GDK, 
  "gdk_gc_new", {C_POINTER}, C_POINTER )

global function gdk_gc_new(atom window_)
    return c_func( gdk_gc_new_, {window_} )
end function

----------------------------------------
-- gdk_gc_new_with_values
----------------------------------------
constant gdk_gc_new_with_values_ = link_c_func( GDK, 
  "gdk_gc_new_with_values", {C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gdk_gc_new_with_values(atom window_, atom values_, atom values_mask_)
    return c_func( gdk_gc_new_with_values_, {window_,values_,values_mask_} )
end function

----------------------------------------
-- gdk_gc_ref
----------------------------------------
constant gdk_gc_ref_ = link_c_func( GDK, 
  "gdk_gc_ref", {C_POINTER}, C_POINTER )

global function gdk_gc_ref(atom gc_)
    return c_func( gdk_gc_ref_, {gc_} )
end function

----------------------------------------
-- gdk_gc_unref
----------------------------------------
constant gdk_gc_unref_ = link_c_proc( GDK, 
  "gdk_gc_unref", {C_POINTER} )

global procedure gdk_gc_unref(atom gc_)
    c_proc( gdk_gc_unref_, {gc_} )
end procedure

----------------------------------------
-- gdk_gc_destroy
----------------------------------------
constant gdk_gc_destroy_ = link_c_proc( GDK, 
  "gdk_gc_destroy", {C_POINTER} )

global procedure gdk_gc_destroy(atom gc_)
    c_proc( gdk_gc_destroy_, {gc_} )
end procedure

----------------------------------------
-- gdk_gc_get_values
----------------------------------------
constant gdk_gc_get_values_ = link_c_proc( GDK, 
  "gdk_gc_get_values", {C_POINTER,C_POINTER} )

global procedure gdk_gc_get_values(atom gc_, atom values_)
    c_proc( gdk_gc_get_values_, {gc_,values_} )
end procedure

----------------------------------------
-- gdk_gc_set_foreground
----------------------------------------
constant gdk_gc_set_foreground_ = link_c_proc( GDK, 
  "gdk_gc_set_foreground", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_foreground(atom gc_, atom color_)
    c_proc( gdk_gc_set_foreground_, {gc_,color_} )
end procedure

----------------------------------------
-- gdk_gc_set_background
----------------------------------------
constant gdk_gc_set_background_ = link_c_proc( GDK, 
  "gdk_gc_set_background", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_background(atom gc_, atom color_)
    c_proc( gdk_gc_set_background_, {gc_,color_} )
end procedure

----------------------------------------
-- gdk_gc_set_font
----------------------------------------
constant gdk_gc_set_font_ = link_c_proc( GDK, 
  "gdk_gc_set_font", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_font(atom gc_, atom font_)
    c_proc( gdk_gc_set_font_, {gc_,font_} )
end procedure

----------------------------------------
-- gdk_gc_set_function
----------------------------------------
constant gdk_gc_set_function_ = link_c_proc( GDK, 
  "gdk_gc_set_function", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_function(atom gc_, atom function_)
    c_proc( gdk_gc_set_function_, {gc_,function_} )
end procedure

----------------------------------------
-- gdk_gc_set_fill
----------------------------------------
constant gdk_gc_set_fill_ = link_c_proc( GDK, 
  "gdk_gc_set_fill", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_fill(atom gc_, atom fill_)
    c_proc( gdk_gc_set_fill_, {gc_,fill_} )
end procedure

----------------------------------------
-- gdk_gc_set_tile
----------------------------------------
constant gdk_gc_set_tile_ = link_c_proc( GDK, 
  "gdk_gc_set_tile", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_tile(atom gc_, atom tile_)
    c_proc( gdk_gc_set_tile_, {gc_,tile_} )
end procedure

----------------------------------------
-- gdk_gc_set_stipple
----------------------------------------
constant gdk_gc_set_stipple_ = link_c_proc( GDK, 
  "gdk_gc_set_stipple", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_stipple(atom gc_, atom stipple_)
    c_proc( gdk_gc_set_stipple_, {gc_,stipple_} )
end procedure

----------------------------------------
-- gdk_gc_set_ts_origin
----------------------------------------
constant gdk_gc_set_ts_origin_ = link_c_proc( GDK, 
  "gdk_gc_set_ts_origin", {C_POINTER,C_INT,C_INT} )

global procedure gdk_gc_set_ts_origin(atom gc_, integer x_, integer y_)
    c_proc( gdk_gc_set_ts_origin_, {gc_,x_,y_} )
end procedure

----------------------------------------
-- gdk_gc_set_clip_origin
----------------------------------------
constant gdk_gc_set_clip_origin_ = link_c_proc( GDK, 
  "gdk_gc_set_clip_origin", {C_POINTER,C_INT,C_INT} )

global procedure gdk_gc_set_clip_origin(atom gc_, integer x_, integer y_)
    c_proc( gdk_gc_set_clip_origin_, {gc_,x_,y_} )
end procedure

----------------------------------------
-- gdk_gc_set_clip_mask
----------------------------------------
constant gdk_gc_set_clip_mask_ = link_c_proc( GDK, 
  "gdk_gc_set_clip_mask", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_clip_mask(atom gc_, atom mask_)
    c_proc( gdk_gc_set_clip_mask_, {gc_,mask_} )
end procedure

----------------------------------------
-- gdk_gc_set_clip_rectangle
----------------------------------------
constant gdk_gc_set_clip_rectangle_ = link_c_proc( GDK, 
  "gdk_gc_set_clip_rectangle", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_clip_rectangle(atom gc_, atom rectangle_)
    c_proc( gdk_gc_set_clip_rectangle_, {gc_,rectangle_} )
end procedure

----------------------------------------
-- gdk_gc_set_clip_region
----------------------------------------
constant gdk_gc_set_clip_region_ = link_c_proc( GDK, 
  "gdk_gc_set_clip_region", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_clip_region(atom gc_, atom region_)
    c_proc( gdk_gc_set_clip_region_, {gc_,region_} )
end procedure

----------------------------------------
-- gdk_gc_set_subwindow
----------------------------------------
constant gdk_gc_set_subwindow_ = link_c_proc( GDK, 
  "gdk_gc_set_subwindow", {C_POINTER,C_POINTER} )

global procedure gdk_gc_set_subwindow(atom gc_, atom mode_)
    c_proc( gdk_gc_set_subwindow_, {gc_,mode_} )
end procedure

----------------------------------------
-- gdk_gc_set_exposures
----------------------------------------
constant gdk_gc_set_exposures_ = link_c_proc( GDK, 
  "gdk_gc_set_exposures", {C_POINTER,C_INT} )

global procedure gdk_gc_set_exposures(atom gc_, integer exposures_)
    c_proc( gdk_gc_set_exposures_, {gc_,exposures_} )
end procedure

----------------------------------------
-- gdk_gc_set_line_attributes
----------------------------------------
constant gdk_gc_set_line_attributes_ = link_c_proc( GDK, 
  "gdk_gc_set_line_attributes", {C_POINTER,C_INT,C_POINTER,C_POINTER,C_POINTER} )

global procedure gdk_gc_set_line_attributes(atom gc_, integer line_width_, atom line_style_, atom cap_style_, atom join_style_)
    c_proc( gdk_gc_set_line_attributes_, {gc_,line_width_,line_style_,cap_style_,join_style_} )
end procedure

----------------------------------------
-- gdk_gc_set_dashes
----------------------------------------
constant gdk_gc_set_dashes_ = link_c_proc( GDK, 
  "gdk_gc_set_dashes", {C_POINTER,C_INT,C_POINTER,C_INT} )

global procedure gdk_gc_set_dashes(atom gc_, integer dash_offset_, sequence dash_list_, integer n_)
    atom strArray1
    strArray1 = allot_string_array( dash_list_ )
    c_proc( gdk_gc_set_dashes_, {gc_,dash_offset_,strArray1,n_} )
    free_string_array( strArray1 )
end procedure

----------------------------------------
-- gdk_gc_copy
----------------------------------------
constant gdk_gc_copy_ = link_c_proc( GDK, 
  "gdk_gc_copy", {C_POINTER,C_POINTER} )

global procedure gdk_gc_copy(atom dst_gc_, atom src_gc_)
    c_proc( gdk_gc_copy_, {dst_gc_,src_gc_} )
end procedure

----------------------------------------
-- gdk_pixmap_new
----------------------------------------
constant gdk_pixmap_new_ = link_c_func( GDK, 
  "gdk_pixmap_new", {C_POINTER,C_INT,C_INT,C_INT}, C_POINTER )

global function gdk_pixmap_new(atom window_, integer width_, integer height_, integer depth_)
    return c_func( gdk_pixmap_new_, {window_,width_,height_,depth_} )
end function

----------------------------------------
-- gdk_bitmap_create_from_data
----------------------------------------
constant gdk_bitmap_create_from_data_ = link_c_func( GDK, 
  "gdk_bitmap_create_from_data", {C_POINTER,C_POINTER,C_INT,C_INT}, C_POINTER )

global function gdk_bitmap_create_from_data(atom window_, sequence data_, integer width_, integer height_)
    atom result
    atom string1
    string1 = allocate_string( data_ )
    result = c_func( gdk_bitmap_create_from_data_, {window_,string1,width_,height_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_pixmap_create_from_data
----------------------------------------
constant gdk_pixmap_create_from_data_ = link_c_func( GDK, 
  "gdk_pixmap_create_from_data", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_POINTER,C_POINTER}, 
 C_POINTER )

global function gdk_pixmap_create_from_data(atom window_, sequence data_, integer width_, integer height_, integer depth_, atom fg_, atom bg_)
    atom result
    atom string1
    string1 = allocate_string( data_ )
    result = c_func( gdk_pixmap_create_from_data_, {window_,string1,width_,height_,depth_,fg_,bg_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_pixmap_create_from_xpm
----------------------------------------
constant gdk_pixmap_create_from_xpm_ = link_c_func( GDK, 
  "gdk_pixmap_create_from_xpm", {C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gdk_pixmap_create_from_xpm(atom window_, atom mask_, atom transparent_color_, sequence filename_)
    atom result
    atom string1
    string1 = allocate_string( filename_ )
    result = c_func( gdk_pixmap_create_from_xpm_, {window_,mask_,transparent_color_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_pixmap_create_from_xpm_d
----------------------------------------
constant gdk_pixmap_create_from_xpm_d_ = link_c_func( GDK, 
  "gdk_pixmap_create_from_xpm_d", {C_POINTER,C_POINTER,C_POINTER,C_POINTER}, 
 C_POINTER )

global function gdk_pixmap_create_from_xpm_d(atom window_, atom mask_, atom transparent_color_, sequence data_)
    atom result
    atom string1
    string1 = allocate_string( data_ )
    result = c_func( gdk_pixmap_create_from_xpm_d_, {window_,mask_,transparent_color_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_pixmap_ref
----------------------------------------
constant gdk_pixmap_ref_ = link_c_func( GDK, 
  "gdk_pixmap_ref", {C_POINTER}, C_POINTER )

global function gdk_pixmap_ref(atom pixmap_)
    return c_func( gdk_pixmap_ref_, {pixmap_} )
end function

----------------------------------------
-- gdk_pixmap_unref
----------------------------------------
constant gdk_pixmap_unref_ = link_c_proc( GDK, 
  "gdk_pixmap_unref", {C_POINTER} )

global procedure gdk_pixmap_unref(atom pixmap_)
    c_proc( gdk_pixmap_unref_, {pixmap_} )
end procedure

----------------------------------------
-- gdk_bitmap_ref
----------------------------------------
constant gdk_bitmap_ref_ = link_c_func( GDK, 
  "gdk_bitmap_ref", {C_POINTER}, C_POINTER )

global function gdk_bitmap_ref(atom pixmap_)
    return c_func( gdk_bitmap_ref_, {pixmap_} )
end function

----------------------------------------
-- gdk_bitmap_unref
----------------------------------------
constant gdk_bitmap_unref_ = link_c_proc( GDK, 
  "gdk_bitmap_unref", {C_POINTER} )

global procedure gdk_bitmap_unref(atom pixmap_)
    c_proc( gdk_bitmap_unref_, {pixmap_} )
end procedure

----------------------------------------
-- gdk_image_new_bitmap
----------------------------------------
constant gdk_image_new_bitmap_ = link_c_func( GDK, 
  "gdk_image_new_bitmap", {C_POINTER,C_POINTER,C_INT,C_INT}, C_POINTER )

global function gdk_image_new_bitmap(atom visual_, atom data_, integer width_, integer height_)
    return c_func( gdk_image_new_bitmap_, {visual_,data_,width_,height_} )
end function

----------------------------------------
-- gdk_image_new
----------------------------------------
constant gdk_image_new_ = link_c_func( GDK, 
  "gdk_image_new", {C_POINTER,C_POINTER,C_INT,C_INT}, C_POINTER )

global function gdk_image_new(atom type_, atom visual_, integer width_, integer height_)
    return c_func( gdk_image_new_, {type_,visual_,width_,height_} )
end function

----------------------------------------
-- gdk_image_bitmap_new
----------------------------------------
constant gdk_image_bitmap_new_ = link_c_func( GDK, 
  "gdk_image_bitmap_new", {C_POINTER,C_POINTER,C_INT,C_INT}, C_POINTER )

global function gdk_image_bitmap_new(atom type_, atom visual_, integer width_, integer height_)
    return c_func( gdk_image_bitmap_new_, {type_,visual_,width_,height_} )
end function

----------------------------------------
-- gdk_image_get
----------------------------------------
constant gdk_image_get_ = link_c_func( GDK, 
  "gdk_image_get", {C_POINTER,C_INT,C_INT,C_INT,C_INT}, C_POINTER )

global function gdk_image_get(atom window_, integer x_, integer y_, integer width_, integer height_)
    return c_func( gdk_image_get_, {window_,x_,y_,width_,height_} )
end function

----------------------------------------
-- gdk_image_put_pixel
----------------------------------------
constant gdk_image_put_pixel_ = link_c_proc( GDK, 
  "gdk_image_put_pixel", {C_POINTER,C_INT,C_INT,C_UINT} )

global procedure gdk_image_put_pixel(atom image_, integer x_, integer y_, atom pixel_)
    c_proc( gdk_image_put_pixel_, {image_,x_,y_,pixel_} )
end procedure

----------------------------------------
-- gdk_image_get_pixel
----------------------------------------
constant gdk_image_get_pixel_ = link_c_func( GDK, 
  "gdk_image_get_pixel", {C_POINTER,C_INT,C_INT}, C_UINT )

global function gdk_image_get_pixel(atom image_, integer x_, integer y_)
    return c_func( gdk_image_get_pixel_, {image_,x_,y_} )
end function

----------------------------------------
-- gdk_image_destroy
----------------------------------------
constant gdk_image_destroy_ = link_c_proc( GDK, 
  "gdk_image_destroy", {C_POINTER} )

global procedure gdk_image_destroy(atom image_)
    c_proc( gdk_image_destroy_, {image_} )
end procedure

----------------------------------------
-- gdk_colormap_new
----------------------------------------
constant gdk_colormap_new_ = link_c_func( GDK, 
  "gdk_colormap_new", {C_POINTER,C_INT}, C_POINTER )

global function gdk_colormap_new(atom visual_, integer allocate_)
    return c_func( gdk_colormap_new_, {visual_,allocate_} )
end function

----------------------------------------
-- gdk_colormap_ref
----------------------------------------
constant gdk_colormap_ref_ = link_c_func( GDK, 
  "gdk_colormap_ref", {C_POINTER}, C_POINTER )

global function gdk_colormap_ref(atom cmap_)
    return c_func( gdk_colormap_ref_, {cmap_} )
end function

----------------------------------------
-- gdk_colormap_unref
----------------------------------------
constant gdk_colormap_unref_ = link_c_proc( GDK, 
  "gdk_colormap_unref", {C_POINTER} )

global procedure gdk_colormap_unref(atom cmap_)
    c_proc( gdk_colormap_unref_, {cmap_} )
end procedure

----------------------------------------
-- gdk_colormap_get_system
----------------------------------------
constant gdk_colormap_get_system_ = link_c_func( GDK, 
  "gdk_colormap_get_system", {}, C_POINTER )

global function gdk_colormap_get_system()
    return c_func( gdk_colormap_get_system_, {} )
end function

----------------------------------------
-- gdk_colormap_get_system_size
----------------------------------------
constant gdk_colormap_get_system_size_ = link_c_func( GDK, 
  "gdk_colormap_get_system_size", {}, C_INT )

global function gdk_colormap_get_system_size()
    return c_func( gdk_colormap_get_system_size_, {} )
end function

----------------------------------------
-- gdk_colormap_change
----------------------------------------
constant gdk_colormap_change_ = link_c_proc( GDK, 
  "gdk_colormap_change", {C_POINTER,C_INT} )

global procedure gdk_colormap_change(atom colormap_, integer ncolors_)
    c_proc( gdk_colormap_change_, {colormap_,ncolors_} )
end procedure

----------------------------------------
-- gdk_colormap_alloc_colors
----------------------------------------
constant gdk_colormap_alloc_colors_ = link_c_func( GDK, 
  "gdk_colormap_alloc_colors", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT}, C_INT )

global function gdk_colormap_alloc_colors(atom colormap_, atom colors_, integer ncolors_, integer writeable_, integer best_match_, integer success_)
    return c_func( gdk_colormap_alloc_colors_, {colormap_,colors_,ncolors_,writeable_,best_match_,success_} )
end function

----------------------------------------
-- gdk_colormap_alloc_color
----------------------------------------
constant gdk_colormap_alloc_color_ = link_c_func( GDK, 
  "gdk_colormap_alloc_color", {C_POINTER,C_POINTER,C_INT,C_INT}, C_INT )

global function gdk_colormap_alloc_color(atom colormap_, atom color_, integer writeable_, integer best_match_)
    return c_func( gdk_colormap_alloc_color_, {colormap_,color_,writeable_,best_match_} )
end function

----------------------------------------
-- gdk_colormap_free_colors
----------------------------------------
constant gdk_colormap_free_colors_ = link_c_proc( GDK, 
  "gdk_colormap_free_colors", {C_POINTER,C_POINTER,C_INT} )

global procedure gdk_colormap_free_colors(atom colormap_, atom colors_, integer ncolors_)
    c_proc( gdk_colormap_free_colors_, {colormap_,colors_,ncolors_} )
end procedure

----------------------------------------
-- gdk_colormap_get_visual
----------------------------------------
constant gdk_colormap_get_visual_ = link_c_func( GDK, 
  "gdk_colormap_get_visual", {C_POINTER}, C_POINTER )

global function gdk_colormap_get_visual(atom colormap_)
    return c_func( gdk_colormap_get_visual_, {colormap_} )
end function

----------------------------------------
-- gdk_color_copy
----------------------------------------
constant gdk_color_copy_ = link_c_func( GDK, 
  "gdk_color_copy", {C_POINTER}, C_POINTER )

global function gdk_color_copy(atom color_)
    return c_func( gdk_color_copy_, {color_} )
end function

----------------------------------------
-- gdk_color_free
----------------------------------------
constant gdk_color_free_ = link_c_proc( GDK, 
  "gdk_color_free", {C_POINTER} )

global procedure gdk_color_free(atom color_)
    c_proc( gdk_color_free_, {color_} )
end procedure

----------------------------------------
-- gdk_color_parse
----------------------------------------
constant gdk_color_parse_ = link_c_func( GDK, 
  "gdk_color_parse", {C_POINTER,C_POINTER}, C_INT )

global function gdk_color_parse(sequence const_, atom color_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gdk_color_parse_, {string1,color_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_color_hash
----------------------------------------
constant gdk_color_hash_ = link_c_func( GDK, 
  "gdk_color_hash", {C_POINTER}, C_UINT )

global function gdk_color_hash(atom const_)
    return c_func( gdk_color_hash_, {const_} )
end function

----------------------------------------
-- gdk_color_equal
----------------------------------------
constant gdk_color_equal_ = link_c_func( GDK, 
  "gdk_color_equal", {C_POINTER,C_POINTER}, C_INT )

global function gdk_color_equal(atom const_, atom colorb_)
    return c_func( gdk_color_equal_, {const_,colorb_} )
end function

----------------------------------------
-- gdk_colors_store
----------------------------------------
constant gdk_colors_store_ = link_c_proc( GDK, 
  "gdk_colors_store", {C_POINTER,C_POINTER,C_INT} )

global procedure gdk_colors_store(atom colormap_, atom colors_, integer ncolors_)
    c_proc( gdk_colors_store_, {colormap_,colors_,ncolors_} )
end procedure

----------------------------------------
-- gdk_colors_alloc
----------------------------------------
constant gdk_colors_alloc_ = link_c_func( GDK, 
  "gdk_colors_alloc", {C_POINTER,C_INT,C_ULONG,C_INT,C_ULONG,C_INT}, C_INT )

global function gdk_colors_alloc(atom colormap_, integer contiguous_, atom planes_, integer nplanes_, atom pixels_, integer npixels_)
    return c_func( gdk_colors_alloc_, {colormap_,contiguous_,planes_,nplanes_,pixels_,npixels_} )
end function

----------------------------------------
-- gdk_colors_free
----------------------------------------
constant gdk_colors_free_ = link_c_proc( GDK, 
  "gdk_colors_free", {C_POINTER,C_ULONG,C_INT,C_ULONG} )

global procedure gdk_colors_free(atom colormap_, atom pixels_, integer npixels_, atom planes_)
    c_proc( gdk_colors_free_, {colormap_,pixels_,npixels_,planes_} )
end procedure

----------------------------------------
-- gdk_color_white
----------------------------------------
constant gdk_color_white_ = link_c_func( GDK, 
  "gdk_color_white", {C_POINTER,C_POINTER}, C_INT )

global function gdk_color_white(atom colormap_, atom color_)
    return c_func( gdk_color_white_, {colormap_,color_} )
end function

----------------------------------------
-- gdk_color_black
----------------------------------------
constant gdk_color_black_ = link_c_func( GDK, 
  "gdk_color_black", {C_POINTER,C_POINTER}, C_INT )

global function gdk_color_black(atom colormap_, atom color_)
    return c_func( gdk_color_black_, {colormap_,color_} )
end function

----------------------------------------
-- gdk_color_alloc
----------------------------------------
constant gdk_color_alloc_ = link_c_func( GDK, 
  "gdk_color_alloc", {C_POINTER,C_POINTER}, C_INT )

global function gdk_color_alloc(atom colormap_, atom color_)
    return c_func( gdk_color_alloc_, {colormap_,color_} )
end function

----------------------------------------
-- gdk_color_change
----------------------------------------
constant gdk_color_change_ = link_c_func( GDK, 
  "gdk_color_change", {C_POINTER,C_POINTER}, C_INT )

global function gdk_color_change(atom colormap_, atom color_)
    return c_func( gdk_color_change_, {colormap_,color_} )
end function

----------------------------------------
-- gdk_font_load
----------------------------------------
constant gdk_font_load_ = link_c_func( GDK, 
  "gdk_font_load", {C_POINTER}, C_POINTER )

global function gdk_font_load(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gdk_font_load_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_fontset_load
----------------------------------------
constant gdk_fontset_load_ = link_c_func( GDK, 
  "gdk_fontset_load", {C_POINTER}, C_POINTER )

global function gdk_fontset_load(sequence fontset_name_)
    atom result
    atom string1
    string1 = allocate_string( fontset_name_ )
    result = c_func( gdk_fontset_load_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_font_ref
----------------------------------------
constant gdk_font_ref_ = link_c_func( GDK, 
  "gdk_font_ref", {C_POINTER}, C_POINTER )

global function gdk_font_ref(atom font_)
    return c_func( gdk_font_ref_, {font_} )
end function

----------------------------------------
-- gdk_font_unref
----------------------------------------
constant gdk_font_unref_ = link_c_proc( GDK, 
  "gdk_font_unref", {C_POINTER} )

global procedure gdk_font_unref(atom font_)
    c_proc( gdk_font_unref_, {font_} )
end procedure

----------------------------------------
-- gdk_font_id
----------------------------------------
constant gdk_font_id_ = link_c_func( GDK, 
  "gdk_font_id", {C_POINTER}, C_INT )

global function gdk_font_id(atom const_)
    return c_func( gdk_font_id_, {const_} )
end function

----------------------------------------
-- gdk_font_equal
----------------------------------------
constant gdk_font_equal_ = link_c_func( GDK, 
  "gdk_font_equal", {C_POINTER,C_POINTER}, C_INT )

global function gdk_font_equal(atom const_, atom fontb_)
    return c_func( gdk_font_equal_, {const_,fontb_} )
end function

----------------------------------------
-- gdk_string_width
----------------------------------------
constant gdk_string_width_ = link_c_func( GDK, 
  "gdk_string_width", {C_POINTER,C_POINTER}, C_INT )

global function gdk_string_width(atom font_, sequence string_)
    integer result
    atom string1
    string1 = allocate_string( string_ )
    result = c_func( gdk_string_width_, {font_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_text_width
----------------------------------------
constant gdk_text_width_ = link_c_func( GDK, 
  "gdk_text_width", {C_POINTER,C_POINTER,C_INT}, C_INT )

global function gdk_text_width(atom font_, sequence text_, integer text_length_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gdk_text_width_, {font_,string1,text_length_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_text_width_wc
----------------------------------------
constant gdk_text_width_wc_ = link_c_func( GDK, 
  "gdk_text_width_wc", {C_POINTER,C_UINT,C_INT}, C_INT )

global function gdk_text_width_wc(atom font_, atom text_, integer text_length_)
    return c_func( gdk_text_width_wc_, {font_,text_,text_length_} )
end function

----------------------------------------
-- gdk_char_width
----------------------------------------
constant gdk_char_width_ = link_c_func( GDK, 
  "gdk_char_width", {C_POINTER,C_POINTER}, C_INT )

global function gdk_char_width(atom font_, sequence character_)
    integer result
    atom string1
    string1 = allocate_string( character_ )
    result = c_func( gdk_char_width_, {font_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_char_width_wc
----------------------------------------
constant gdk_char_width_wc_ = link_c_func( GDK, 
  "gdk_char_width_wc", {C_POINTER,C_UINT}, C_INT )

global function gdk_char_width_wc(atom font_, atom character_)
    return c_func( gdk_char_width_wc_, {font_,character_} )
end function

----------------------------------------
-- gdk_string_measure
----------------------------------------
constant gdk_string_measure_ = link_c_func( GDK, 
  "gdk_string_measure", {C_POINTER,C_POINTER}, C_INT )

global function gdk_string_measure(atom font_, sequence string_)
    integer result
    atom string1
    string1 = allocate_string( string_ )
    result = c_func( gdk_string_measure_, {font_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_text_measure
----------------------------------------
constant gdk_text_measure_ = link_c_func( GDK, 
  "gdk_text_measure", {C_POINTER,C_POINTER,C_INT}, C_INT )

global function gdk_text_measure(atom font_, sequence text_, integer text_length_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gdk_text_measure_, {font_,string1,text_length_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_char_measure
----------------------------------------
constant gdk_char_measure_ = link_c_func( GDK, 
  "gdk_char_measure", {C_POINTER,C_POINTER}, C_INT )

global function gdk_char_measure(atom font_, sequence character_)
    integer result
    atom string1
    string1 = allocate_string( character_ )
    result = c_func( gdk_char_measure_, {font_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_string_height
----------------------------------------
constant gdk_string_height_ = link_c_func( GDK, 
  "gdk_string_height", {C_POINTER,C_POINTER}, C_INT )

global function gdk_string_height(atom font_, sequence string_)
    integer result
    atom string1
    string1 = allocate_string( string_ )
    result = c_func( gdk_string_height_, {font_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_text_height
----------------------------------------
constant gdk_text_height_ = link_c_func( GDK, 
  "gdk_text_height", {C_POINTER,C_POINTER,C_INT}, C_INT )

global function gdk_text_height(atom font_, sequence text_, integer text_length_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gdk_text_height_, {font_,string1,text_length_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_char_height
----------------------------------------
constant gdk_char_height_ = link_c_func( GDK, 
  "gdk_char_height", {C_POINTER,C_POINTER}, C_INT )

global function gdk_char_height(atom font_, sequence character_)
    integer result
    atom string1
    string1 = allocate_string( character_ )
    result = c_func( gdk_char_height_, {font_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_text_extents
----------------------------------------
constant gdk_text_extents_ = link_c_proc( GDK, 
  "gdk_text_extents", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_text_extents(atom font_, sequence text_, integer text_length_, integer lbearing_, integer 
 rbearing_, integer width_, integer ascent_, integer descent_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gdk_text_extents_, {font_,string1,text_length_,lbearing_,rbearing_,width_,ascent_,descent_} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_text_extents_wc
----------------------------------------
constant gdk_text_extents_wc_ = link_c_proc( GDK, 
  "gdk_text_extents_wc", {C_POINTER,C_UINT,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_text_extents_wc(atom font_, atom text_, integer text_length_, integer lbearing_, integer 
 rbearing_, integer width_, integer ascent_, integer descent_)
    c_proc( gdk_text_extents_wc_, {font_,text_,text_length_,lbearing_,rbearing_,width_,ascent_,descent_} )
end procedure

----------------------------------------
-- gdk_string_extents
----------------------------------------
constant gdk_string_extents_ = link_c_proc( GDK, 
  "gdk_string_extents", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_string_extents(atom font_, sequence string_, integer lbearing_, integer rbearing_, integer 
 width_, integer ascent_, integer descent_)
    atom string1
    string1 = allocate_string( string_ )
    c_proc( gdk_string_extents_, {font_,string1,lbearing_,rbearing_,width_,ascent_,descent_} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_draw_point
----------------------------------------
constant gdk_draw_point_ = link_c_proc( GDK, 
  "gdk_draw_point", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gdk_draw_point(atom drawable_, atom gc_, integer x_, integer y_)
    c_proc( gdk_draw_point_, {drawable_,gc_,x_,y_} )
end procedure

----------------------------------------
-- gdk_draw_line
----------------------------------------
constant gdk_draw_line_ = link_c_proc( GDK, 
  "gdk_draw_line", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_draw_line(atom drawable_, atom gc_, integer x1_, integer y1_, integer x2_, integer y2_)
    c_proc( gdk_draw_line_, {drawable_,gc_,x1_,y1_,x2_,y2_} )
end procedure

----------------------------------------
-- gdk_draw_rectangle
----------------------------------------
constant gdk_draw_rectangle_ = link_c_proc( GDK, 
  "gdk_draw_rectangle", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_draw_rectangle(atom drawable_, atom gc_, integer filled_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gdk_draw_rectangle_, {drawable_,gc_,filled_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gdk_draw_arc
----------------------------------------
constant gdk_draw_arc_ = link_c_proc( GDK, 
  "gdk_draw_arc", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_draw_arc(atom drawable_, atom gc_, integer filled_, integer x_, integer y_, integer width_, 
 integer height_, integer angle1_, integer angle2_)
    c_proc( gdk_draw_arc_, {drawable_,gc_,filled_,x_,y_,width_,height_,angle1_,angle2_} )
end procedure

----------------------------------------
-- gdk_draw_polygon
----------------------------------------
constant gdk_draw_polygon_ = link_c_proc( GDK, 
  "gdk_draw_polygon", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_INT} )

global procedure gdk_draw_polygon(atom drawable_, atom gc_, integer filled_, atom points_, integer npoints_)
    c_proc( gdk_draw_polygon_, {drawable_,gc_,filled_,points_,npoints_} )
end procedure

----------------------------------------
-- gdk_draw_string
----------------------------------------
constant gdk_draw_string_ = link_c_proc( GDK, 
  "gdk_draw_string", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_POINTER} )

global procedure gdk_draw_string(atom drawable_, atom font_, atom gc_, integer x_, integer y_, sequence string_)
    atom string1
    string1 = allocate_string( string_ )
    c_proc( gdk_draw_string_, {drawable_,font_,gc_,x_,y_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_draw_text
----------------------------------------
constant gdk_draw_text_ = link_c_proc( GDK, 
  "gdk_draw_text", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_POINTER,C_INT} )

global procedure gdk_draw_text(atom drawable_, atom font_, atom gc_, integer x_, integer y_, sequence text_, integer text_length_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gdk_draw_text_, {drawable_,font_,gc_,x_,y_,string1,text_length_} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_draw_text_wc
----------------------------------------
constant gdk_draw_text_wc_ = link_c_proc( GDK, 
  "gdk_draw_text_wc", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_UINT,C_INT} )

global procedure gdk_draw_text_wc(atom drawable_, atom font_, atom gc_, integer x_, integer y_, atom text_, integer text_length_)
    c_proc( gdk_draw_text_wc_, {drawable_,font_,gc_,x_,y_,text_,text_length_} )
end procedure

----------------------------------------
-- gdk_draw_pixmap
----------------------------------------
constant gdk_draw_pixmap_ = link_c_proc( GDK, 
  "gdk_draw_pixmap", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_draw_pixmap(atom drawable_, atom gc_, atom src_, integer xsrc_, integer ysrc_, integer xdest_, 
 integer ydest_, integer width_, integer height_)
    c_proc( gdk_draw_pixmap_, {drawable_,gc_,src_,xsrc_,ysrc_,xdest_,ydest_,width_,height_} )
end procedure

----------------------------------------
-- gdk_draw_bitmap
----------------------------------------
constant gdk_draw_bitmap_ = link_c_proc( GDK, 
  "gdk_draw_bitmap", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_draw_bitmap(atom drawable_, atom gc_, atom src_, integer xsrc_, integer ysrc_, integer xdest_, 
 integer ydest_, integer width_, integer height_)
    c_proc( gdk_draw_bitmap_, {drawable_,gc_,src_,xsrc_,ysrc_,xdest_,ydest_,width_,height_} )
end procedure

----------------------------------------
-- gdk_draw_image
----------------------------------------
constant gdk_draw_image_ = link_c_proc( GDK, 
  "gdk_draw_image", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gdk_draw_image(atom drawable_, atom gc_, atom image_, integer xsrc_, integer ysrc_, integer xdest_, 
 integer ydest_, integer width_, integer height_)
    c_proc( gdk_draw_image_, {drawable_,gc_,image_,xsrc_,ysrc_,xdest_,ydest_,width_,height_} )
end procedure

----------------------------------------
-- gdk_draw_points
----------------------------------------
constant gdk_draw_points_ = link_c_proc( GDK, 
  "gdk_draw_points", {C_POINTER,C_POINTER,C_POINTER,C_INT} )

global procedure gdk_draw_points(atom drawable_, atom gc_, atom points_, integer npoints_)
    c_proc( gdk_draw_points_, {drawable_,gc_,points_,npoints_} )
end procedure

----------------------------------------
-- gdk_draw_segments
----------------------------------------
constant gdk_draw_segments_ = link_c_proc( GDK, 
  "gdk_draw_segments", {C_POINTER,C_POINTER,C_POINTER,C_INT} )

global procedure gdk_draw_segments(atom drawable_, atom gc_, atom segs_, integer nsegs_)
    c_proc( gdk_draw_segments_, {drawable_,gc_,segs_,nsegs_} )
end procedure

----------------------------------------
-- gdk_draw_lines
----------------------------------------
constant gdk_draw_lines_ = link_c_proc( GDK, 
  "gdk_draw_lines", {C_POINTER,C_POINTER,C_POINTER,C_INT} )

global procedure gdk_draw_lines(atom drawable_, atom gc_, atom points_, integer npoints_)
    c_proc( gdk_draw_lines_, {drawable_,gc_,points_,npoints_} )
end procedure

----------------------------------------
-- gdk_selection_owner_set
----------------------------------------
constant gdk_selection_owner_set_ = link_c_func( GDK, 
  "gdk_selection_owner_set", {C_POINTER,C_ULONG,C_UINT,C_INT}, C_INT )

global function gdk_selection_owner_set(atom owner_, atom selection_, atom time_, integer send_event_)
    return c_func( gdk_selection_owner_set_, {owner_,selection_,time_,send_event_} )
end function

----------------------------------------
-- gdk_selection_owner_get
----------------------------------------
constant gdk_selection_owner_get_ = link_c_func( GDK, 
  "gdk_selection_owner_get", {C_ULONG}, C_POINTER )

global function gdk_selection_owner_get(atom selection_)
    return c_func( gdk_selection_owner_get_, {selection_} )
end function

----------------------------------------
-- gdk_selection_convert
----------------------------------------
constant gdk_selection_convert_ = link_c_proc( GDK, 
  "gdk_selection_convert", {C_POINTER,C_ULONG,C_ULONG,C_UINT} )

global procedure gdk_selection_convert(atom requestor_, atom selection_, atom target_, atom time_)
    c_proc( gdk_selection_convert_, {requestor_,selection_,target_,time_} )
end procedure

----------------------------------------
-- gdk_selection_property_get
----------------------------------------
constant gdk_selection_property_get_ = link_c_func( GDK, 
  "gdk_selection_property_get", {C_POINTER,C_UINT,C_ULONG,C_INT}, C_INT )

global function gdk_selection_property_get(atom requestor_, integer data_, atom prop_type_, integer prop_format_)
    return c_func( gdk_selection_property_get_, {requestor_,data_,prop_type_,prop_format_} )
end function

----------------------------------------
-- gdk_selection_send_notify
----------------------------------------
constant gdk_selection_send_notify_ = link_c_proc( GDK, 
  "gdk_selection_send_notify", {C_UINT,C_ULONG,C_ULONG,C_ULONG,C_UINT} )

global procedure gdk_selection_send_notify(atom requestor_, atom selection_, atom target_, atom property_, atom time_)
    c_proc( gdk_selection_send_notify_, {requestor_,selection_,target_,property_,time_} )
end procedure

----------------------------------------
-- gdk_text_property_to_text_list
----------------------------------------
constant gdk_text_property_to_text_list_ = link_c_func( GDK, 
  "gdk_text_property_to_text_list", {C_ULONG,C_UINT,C_POINTER}, C_INT )

global function gdk_text_property_to_text_list(atom encoding_, integer text_, sequence list_)
    integer result
    atom string1
    string1 = allocate_string( list_ )
    result = c_func( gdk_text_property_to_text_list_, {encoding_,text_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_free_text_list
----------------------------------------
constant gdk_free_text_list_ = link_c_proc( GDK, 
  "gdk_free_text_list", {C_POINTER} )

global procedure gdk_free_text_list(sequence list_)
    atom string1
    string1 = allocate_string( list_ )
    c_proc( gdk_free_text_list_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gdk_string_to_compound_text
----------------------------------------
constant gdk_string_to_compound_text_ = link_c_func( GDK, 
  "gdk_string_to_compound_text", {C_POINTER,C_ULONG,C_UINT}, C_INT )

global function gdk_string_to_compound_text(sequence str_, atom encoding_, integer ctext_)
    integer result
    atom string1
    string1 = allocate_string( str_ )
    result = c_func( gdk_string_to_compound_text_, {string1,encoding_,ctext_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_free_compound_text
----------------------------------------
constant gdk_free_compound_text_ = link_c_proc( GDK, 
  "gdk_free_compound_text", {C_UINT} )

global procedure gdk_free_compound_text(integer ctext_)
    c_proc( gdk_free_compound_text_, {ctext_} )
end procedure

----------------------------------------
-- gdk_atom_intern
----------------------------------------
constant gdk_atom_intern_ = link_c_func( GDK, 
  "gdk_atom_intern", {C_POINTER,C_INT}, C_ULONG )

global function gdk_atom_intern(sequence const_, integer only_if_exists_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gdk_atom_intern_, {string1,only_if_exists_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_atom_name
----------------------------------------
constant gdk_atom_name_ = link_c_func( GDK, 
  "gdk_atom_name", {C_ULONG}, C_POINTER )

global function gdk_atom_name(atom atom_)
    return peek_string( c_func( gdk_atom_name_, {atom_} ) )
end function

----------------------------------------
-- gdk_property_get
----------------------------------------
constant gdk_property_get_ = link_c_func( GDK, 
  "gdk_property_get", {C_POINTER,C_ULONG,C_ULONG,C_ULONG,C_ULONG,C_INT,C_ULONG,C_INT,C_INT,C_UINT}, 
 C_INT )

global function gdk_property_get(atom window_, atom property_, atom type_, atom offset_, atom length_, integer 
 pdelete_, atom actual_property_type_, integer actual_format_, integer actual_length_, integer data_)
    return c_func( gdk_property_get_, {window_,property_,type_,offset_,length_,pdelete_,actual_property_type_,actual_format_,actual_length_,data_} )
end function

----------------------------------------
-- gdk_property_change
----------------------------------------
constant gdk_property_change_ = link_c_proc( GDK, 
  "gdk_property_change", {C_POINTER,C_ULONG,C_ULONG,C_INT,C_POINTER,C_UINT,C_INT} )

global procedure gdk_property_change(atom window_, atom property_, atom type_, integer format_, atom mode_, integer data_, integer nelements_)
    c_proc( gdk_property_change_, {window_,property_,type_,format_,mode_,data_,nelements_} )
end procedure

----------------------------------------
-- gdk_property_delete
----------------------------------------
constant gdk_property_delete_ = link_c_proc( GDK, 
  "gdk_property_delete", {C_POINTER,C_ULONG} )

global procedure gdk_property_delete(atom window_, atom property_)
    c_proc( gdk_property_delete_, {window_,property_} )
end procedure

----------------------------------------
-- gdk_rectangle_intersect
----------------------------------------
constant gdk_rectangle_intersect_ = link_c_func( GDK, 
  "gdk_rectangle_intersect", {C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function gdk_rectangle_intersect(atom src1_, atom src2_, atom dest_)
    return c_func( gdk_rectangle_intersect_, {src1_,src2_,dest_} )
end function

----------------------------------------
-- gdk_rectangle_union
----------------------------------------
constant gdk_rectangle_union_ = link_c_proc( GDK, 
  "gdk_rectangle_union", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gdk_rectangle_union(atom src1_, atom src2_, atom dest_)
    c_proc( gdk_rectangle_union_, {src1_,src2_,dest_} )
end procedure

----------------------------------------
-- gdk_input_init
----------------------------------------
constant gdk_input_init_ = link_c_proc( GDK, 
  "gdk_input_init", {} )

global procedure gdk_input_init()
    c_proc( gdk_input_init_, {} )
end procedure

----------------------------------------
-- gdk_input_exit
----------------------------------------
constant gdk_input_exit_ = link_c_proc( GDK, 
  "gdk_input_exit", {} )

global procedure gdk_input_exit()
    c_proc( gdk_input_exit_, {} )
end procedure

----------------------------------------
-- gdk_input_list_devices
----------------------------------------
constant gdk_input_list_devices_ = link_c_func( GDK, 
  "gdk_input_list_devices", {}, C_POINTER )

global function gdk_input_list_devices()
    return c_func( gdk_input_list_devices_, {} )
end function

----------------------------------------
-- gdk_input_set_extension_events
----------------------------------------
constant gdk_input_set_extension_events_ = link_c_proc( GDK, 
  "gdk_input_set_extension_events", {C_POINTER,C_INT,C_POINTER} )

global procedure gdk_input_set_extension_events(atom window_, integer mask_, atom mode_)
    c_proc( gdk_input_set_extension_events_, {window_,mask_,mode_} )
end procedure

----------------------------------------
-- gdk_input_set_source
----------------------------------------
constant gdk_input_set_source_ = link_c_proc( GDK, 
  "gdk_input_set_source", {C_UINT,C_POINTER} )

global procedure gdk_input_set_source(atom deviceid_, atom source_)
    c_proc( gdk_input_set_source_, {deviceid_,source_} )
end procedure

----------------------------------------
-- gdk_input_set_mode
----------------------------------------
constant gdk_input_set_mode_ = link_c_func( GDK, 
  "gdk_input_set_mode", {C_UINT,C_POINTER}, C_INT )

global function gdk_input_set_mode(atom deviceid_, atom mode_)
    return c_func( gdk_input_set_mode_, {deviceid_,mode_} )
end function

----------------------------------------
-- gdk_input_set_axes
----------------------------------------
constant gdk_input_set_axes_ = link_c_proc( GDK, 
  "gdk_input_set_axes", {C_UINT,C_POINTER} )

global procedure gdk_input_set_axes(atom deviceid_, atom axes_)
    c_proc( gdk_input_set_axes_, {deviceid_,axes_} )
end procedure

----------------------------------------
-- gdk_input_set_key
----------------------------------------
constant gdk_input_set_key_ = link_c_proc( GDK, 
  "gdk_input_set_key", {C_UINT,C_UINT,C_UINT,C_POINTER} )

global procedure gdk_input_set_key(atom deviceid_, integer index_, integer keyval_, atom modifiers_)
    c_proc( gdk_input_set_key_, {deviceid_,index_,keyval_,modifiers_} )
end procedure

----------------------------------------
-- gdk_input_window_get_pointer
----------------------------------------
constant gdk_input_window_get_pointer_ = link_c_proc( GDK, 
  "gdk_input_window_get_pointer", {C_POINTER,C_UINT,C_LONG,C_LONG,C_LONG,C_LONG,C_LONG,C_POINTER} 
 )

global procedure gdk_input_window_get_pointer(atom window_, atom deviceid_, atom x_, atom y_, atom pressure_, atom xtilt_, atom ytilt_, atom mask_)
    c_proc( gdk_input_window_get_pointer_, {window_,deviceid_,x_,y_,pressure_,xtilt_,ytilt_,mask_} )
end procedure

----------------------------------------
-- gdk_input_motion_events
----------------------------------------
constant gdk_input_motion_events_ = link_c_func( GDK, 
  "gdk_input_motion_events", {C_POINTER,C_UINT,C_UINT,C_UINT,C_INT}, C_POINTER )

global function gdk_input_motion_events(atom window_, atom deviceid_, atom start_, atom stop_, integer nevents_return_)
    return c_func( gdk_input_motion_events_, {window_,deviceid_,start_,stop_,nevents_return_} )
end function

----------------------------------------
-- gdk_im_ready
----------------------------------------
constant gdk_im_ready_ = link_c_func( GDK, 
  "gdk_im_ready", {}, C_INT )

global function gdk_im_ready()
    return c_func( gdk_im_ready_, {} )
end function

----------------------------------------
-- gdk_im_begin
----------------------------------------
constant gdk_im_begin_ = link_c_proc( GDK, 
  "gdk_im_begin", {C_POINTER,C_POINTER} )

global procedure gdk_im_begin(atom ic_, atom window_)
    c_proc( gdk_im_begin_, {ic_,window_} )
end procedure

----------------------------------------
-- gdk_im_end
----------------------------------------
constant gdk_im_end_ = link_c_proc( GDK, 
  "gdk_im_end", {} )

global procedure gdk_im_end()
    c_proc( gdk_im_end_, {} )
end procedure

----------------------------------------
-- gdk_im_decide_style
----------------------------------------
constant gdk_im_decide_style_ = link_c_func( GDK, 
  "gdk_im_decide_style", {C_POINTER}, C_POINTER )

global function gdk_im_decide_style(atom supported_style_)
    return c_func( gdk_im_decide_style_, {supported_style_} )
end function

----------------------------------------
-- gdk_im_set_best_style
----------------------------------------
constant gdk_im_set_best_style_ = link_c_func( GDK, 
  "gdk_im_set_best_style", {C_POINTER}, C_POINTER )

global function gdk_im_set_best_style(atom best_allowed_style_)
    return c_func( gdk_im_set_best_style_, {best_allowed_style_} )
end function

----------------------------------------
-- gdk_ic_new
----------------------------------------
constant gdk_ic_new_ = link_c_func( GDK, 
  "gdk_ic_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_ic_new(atom attr_, atom mask_)
    return c_func( gdk_ic_new_, {attr_,mask_} )
end function

----------------------------------------
-- gdk_ic_destroy
----------------------------------------
constant gdk_ic_destroy_ = link_c_proc( GDK, 
  "gdk_ic_destroy", {C_POINTER} )

global procedure gdk_ic_destroy(atom ic_)
    c_proc( gdk_ic_destroy_, {ic_} )
end procedure

----------------------------------------
-- gdk_ic_get_style
----------------------------------------
constant gdk_ic_get_style_ = link_c_func( GDK, 
  "gdk_ic_get_style", {C_POINTER}, C_POINTER )

global function gdk_ic_get_style(atom ic_)
    return c_func( gdk_ic_get_style_, {ic_} )
end function

----------------------------------------
-- gdk_ic_get_events
----------------------------------------
constant gdk_ic_get_events_ = link_c_func( GDK, 
  "gdk_ic_get_events", {C_POINTER}, C_POINTER )

global function gdk_ic_get_events(atom ic_)
    return c_func( gdk_ic_get_events_, {ic_} )
end function

----------------------------------------
-- gdk_ic_attr_new
----------------------------------------
constant gdk_ic_attr_new_ = link_c_func( GDK, 
  "gdk_ic_attr_new", {}, C_POINTER )

global function gdk_ic_attr_new()
    return c_func( gdk_ic_attr_new_, {} )
end function

----------------------------------------
-- gdk_ic_attr_destroy
----------------------------------------
constant gdk_ic_attr_destroy_ = link_c_proc( GDK, 
  "gdk_ic_attr_destroy", {C_POINTER} )

global procedure gdk_ic_attr_destroy(atom attr_)
    c_proc( gdk_ic_attr_destroy_, {attr_} )
end procedure

----------------------------------------
-- gdk_ic_set_attr
----------------------------------------
constant gdk_ic_set_attr_ = link_c_func( GDK, 
  "gdk_ic_set_attr", {C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gdk_ic_set_attr(atom ic_, atom attr_, atom mask_)
    return c_func( gdk_ic_set_attr_, {ic_,attr_,mask_} )
end function

----------------------------------------
-- gdk_ic_get_attr
----------------------------------------
constant gdk_ic_get_attr_ = link_c_func( GDK, 
  "gdk_ic_get_attr", {C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gdk_ic_get_attr(atom ic_, atom attr_, atom mask_)
    return c_func( gdk_ic_get_attr_, {ic_,attr_,mask_} )
end function

----------------------------------------
-- gdk_wcstombs
----------------------------------------
constant gdk_wcstombs_ = link_c_func( GDK, 
  "gdk_wcstombs", {C_UINT}, C_POINTER )

global function gdk_wcstombs(atom const_)
    return peek_string( c_func( gdk_wcstombs_, {const_} ) )
end function

----------------------------------------
-- gdk_mbstowcs
----------------------------------------
constant gdk_mbstowcs_ = link_c_func( GDK, 
  "gdk_mbstowcs", {C_UINT,C_POINTER,C_INT}, C_INT )

global function gdk_mbstowcs(atom dest_, sequence src_, integer dest_max_)
    integer result
    atom string1
    string1 = allocate_string( src_ )
    result = c_func( gdk_mbstowcs_, {dest_,string1,dest_max_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_color_context_new
----------------------------------------
constant gdk_color_context_new_ = link_c_func( GDK, 
  "gdk_color_context_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_color_context_new(atom visual_, atom colormap_)
    return c_func( gdk_color_context_new_, {visual_,colormap_} )
end function

----------------------------------------
-- gdk_color_context_new_mono
----------------------------------------
constant gdk_color_context_new_mono_ = link_c_func( GDK, 
  "gdk_color_context_new_mono", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_color_context_new_mono(atom visual_, atom colormap_)
    return c_func( gdk_color_context_new_mono_, {visual_,colormap_} )
end function

----------------------------------------
-- gdk_color_context_free
----------------------------------------
constant gdk_color_context_free_ = link_c_proc( GDK, 
  "gdk_color_context_free", {C_POINTER} )

global procedure gdk_color_context_free(atom cc_)
    c_proc( gdk_color_context_free_, {cc_} )
end procedure

----------------------------------------
-- gdk_color_context_get_pixel
----------------------------------------
constant gdk_color_context_get_pixel_ = link_c_func( GDK, 
  "gdk_color_context_get_pixel", {C_POINTER,C_UINT,C_UINT,C_UINT,C_INT}, C_ULONG )

global function gdk_color_context_get_pixel(atom cc_, integer red_, integer green_, integer blue_, integer failed_)
    return c_func( gdk_color_context_get_pixel_, {cc_,red_,green_,blue_,failed_} )
end function

----------------------------------------
-- gdk_color_context_get_pixels
----------------------------------------
constant gdk_color_context_get_pixels_ = link_c_proc( GDK, 
  "gdk_color_context_get_pixels", {C_POINTER,C_UINT,C_UINT,C_UINT,C_INT,C_ULONG,C_INT} 
 )

global procedure gdk_color_context_get_pixels(atom cc_, integer reds_, integer greens_, integer blues_, integer 
 ncolors_, atom colors_, integer nallocated_)
    c_proc( gdk_color_context_get_pixels_, {cc_,reds_,greens_,blues_,ncolors_,colors_,nallocated_} )
end procedure

----------------------------------------
-- gdk_color_context_get_pixels_incremental
----------------------------------------
constant gdk_color_context_get_pixels_incremental_ = link_c_proc( GDK, 
  "gdk_color_context_get_pixels_incremental", 
 {C_POINTER,C_UINT,C_UINT,C_UINT,C_INT,C_INT,C_ULONG,C_INT} )

global procedure gdk_color_context_get_pixels_incremental(atom cc_, integer reds_, integer greens_, integer blues_, 
 integer ncolors_, integer used_, atom colors_, integer nallocated_)
    c_proc( gdk_color_context_get_pixels_incremental_, {cc_,reds_,greens_,blues_,ncolors_,used_,colors_,nallocated_} )
end procedure

----------------------------------------
-- gdk_color_context_query_color
----------------------------------------
constant gdk_color_context_query_color_ = link_c_func( GDK, 
  "gdk_color_context_query_color", {C_POINTER,C_POINTER}, C_INT )

global function gdk_color_context_query_color(atom cc_, atom color_)
    return c_func( gdk_color_context_query_color_, {cc_,color_} )
end function

----------------------------------------
-- gdk_color_context_query_colors
----------------------------------------
constant gdk_color_context_query_colors_ = link_c_func( GDK, 
  "gdk_color_context_query_colors", {C_POINTER,C_POINTER,C_INT}, C_INT )

global function gdk_color_context_query_colors(atom cc_, atom colors_, integer num_colors_)
    return c_func( gdk_color_context_query_colors_, {cc_,colors_,num_colors_} )
end function

----------------------------------------
-- gdk_color_context_add_palette
----------------------------------------
constant gdk_color_context_add_palette_ = link_c_func( GDK, 
  "gdk_color_context_add_palette", {C_POINTER,C_POINTER,C_INT}, C_INT )

global function gdk_color_context_add_palette(atom cc_, atom palette_, integer num_palette_)
    return c_func( gdk_color_context_add_palette_, {cc_,palette_,num_palette_} )
end function

----------------------------------------
-- gdk_color_context_init_dither
----------------------------------------
constant gdk_color_context_init_dither_ = link_c_proc( GDK, 
  "gdk_color_context_init_dither", {C_POINTER} )

global procedure gdk_color_context_init_dither(atom cc_)
    c_proc( gdk_color_context_init_dither_, {cc_} )
end procedure

----------------------------------------
-- gdk_color_context_free_dither
----------------------------------------
constant gdk_color_context_free_dither_ = link_c_proc( GDK, 
  "gdk_color_context_free_dither", {C_POINTER} )

global procedure gdk_color_context_free_dither(atom cc_)
    c_proc( gdk_color_context_free_dither_, {cc_} )
end procedure

----------------------------------------
-- gdk_color_context_get_pixel_from_palette
----------------------------------------
constant gdk_color_context_get_pixel_from_palette_ = link_c_func( GDK, 
  "gdk_color_context_get_pixel_from_palette", 
 {C_POINTER,C_UINT,C_UINT,C_UINT,C_INT}, C_ULONG )

global function gdk_color_context_get_pixel_from_palette(atom cc_, integer red_, integer green_, integer blue_, integer failed_)
    return c_func( gdk_color_context_get_pixel_from_palette_, {cc_,red_,green_,blue_,failed_} )
end function

----------------------------------------
-- gdk_color_context_get_index_from_palette
----------------------------------------
constant gdk_color_context_get_index_from_palette_ = link_c_func( GDK, 
  "gdk_color_context_get_index_from_palette", 
 {C_POINTER,C_INT,C_INT,C_INT,C_INT}, C_UINT )

global function gdk_color_context_get_index_from_palette(atom cc_, integer red_, integer green_, integer blue_, integer failed_)
    return c_func( gdk_color_context_get_index_from_palette_, {cc_,red_,green_,blue_,failed_} )
end function

----------------------------------------
-- gdk_region_new
----------------------------------------
constant gdk_region_new_ = link_c_func( GDK, 
  "gdk_region_new", {}, C_POINTER )

global function gdk_region_new()
    return c_func( gdk_region_new_, {} )
end function

----------------------------------------
-- gdk_region_destroy
----------------------------------------
constant gdk_region_destroy_ = link_c_proc( GDK, 
  "gdk_region_destroy", {C_POINTER} )

global procedure gdk_region_destroy(atom region_)
    c_proc( gdk_region_destroy_, {region_} )
end procedure

----------------------------------------
-- gdk_region_get_clipbox
----------------------------------------
constant gdk_region_get_clipbox_ = link_c_proc( GDK, 
  "gdk_region_get_clipbox", {C_POINTER,C_POINTER} )

global procedure gdk_region_get_clipbox(atom region_, atom rectangle_)
    c_proc( gdk_region_get_clipbox_, {region_,rectangle_} )
end procedure

----------------------------------------
-- gdk_region_empty
----------------------------------------
constant gdk_region_empty_ = link_c_func( GDK, 
  "gdk_region_empty", {C_POINTER}, C_INT )

global function gdk_region_empty(atom region_)
    return c_func( gdk_region_empty_, {region_} )
end function

----------------------------------------
-- gdk_region_equal
----------------------------------------
constant gdk_region_equal_ = link_c_func( GDK, 
  "gdk_region_equal", {C_POINTER,C_POINTER}, C_INT )

global function gdk_region_equal(atom region1_, atom region2_)
    return c_func( gdk_region_equal_, {region1_,region2_} )
end function

----------------------------------------
-- gdk_region_point_in
----------------------------------------
constant gdk_region_point_in_ = link_c_func( GDK, 
  "gdk_region_point_in", {C_POINTER,C_INT,C_INT}, C_INT )

global function gdk_region_point_in(atom region_, integer x_, integer y_)
    return c_func( gdk_region_point_in_, {region_,x_,y_} )
end function

----------------------------------------
-- gdk_region_rect_in
----------------------------------------
constant gdk_region_rect_in_ = link_c_func( GDK, 
  "gdk_region_rect_in", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_region_rect_in(atom region_, atom rect_)
    return c_func( gdk_region_rect_in_, {region_,rect_} )
end function

----------------------------------------
-- gdk_region_polygon
----------------------------------------
constant gdk_region_polygon_ = link_c_func( GDK, 
  "gdk_region_polygon", {C_POINTER,C_INT,C_POINTER}, C_POINTER )

global function gdk_region_polygon(atom points_, integer npoints_, atom fill_rule_)
    return c_func( gdk_region_polygon_, {points_,npoints_,fill_rule_} )
end function

----------------------------------------
-- gdk_region_offset
----------------------------------------
constant gdk_region_offset_ = link_c_proc( GDK, 
  "gdk_region_offset", {C_POINTER,C_INT,C_INT} )

global procedure gdk_region_offset(atom region_, integer dx_, integer dy_)
    c_proc( gdk_region_offset_, {region_,dx_,dy_} )
end procedure

----------------------------------------
-- gdk_region_shrink
----------------------------------------
constant gdk_region_shrink_ = link_c_proc( GDK, 
  "gdk_region_shrink", {C_POINTER,C_INT,C_INT} )

global procedure gdk_region_shrink(atom region_, integer dx_, integer dy_)
    c_proc( gdk_region_shrink_, {region_,dx_,dy_} )
end procedure

----------------------------------------
-- gdk_region_union_with_rect
----------------------------------------
constant gdk_region_union_with_rect_ = link_c_func( GDK, 
  "gdk_region_union_with_rect", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_region_union_with_rect(atom region_, atom rect_)
    return c_func( gdk_region_union_with_rect_, {region_,rect_} )
end function

----------------------------------------
-- gdk_regions_intersect
----------------------------------------
constant gdk_regions_intersect_ = link_c_func( GDK, 
  "gdk_regions_intersect", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_regions_intersect(atom source1_, atom source2_)
    return c_func( gdk_regions_intersect_, {source1_,source2_} )
end function

----------------------------------------
-- gdk_regions_union
----------------------------------------
constant gdk_regions_union_ = link_c_func( GDK, 
  "gdk_regions_union", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_regions_union(atom source1_, atom source2_)
    return c_func( gdk_regions_union_, {source1_,source2_} )
end function

----------------------------------------
-- gdk_regions_subtract
----------------------------------------
constant gdk_regions_subtract_ = link_c_func( GDK, 
  "gdk_regions_subtract", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_regions_subtract(atom source1_, atom source2_)
    return c_func( gdk_regions_subtract_, {source1_,source2_} )
end function

----------------------------------------
-- gdk_regions_xor
----------------------------------------
constant gdk_regions_xor_ = link_c_func( GDK, 
  "gdk_regions_xor", {C_POINTER,C_POINTER}, C_POINTER )

global function gdk_regions_xor(atom source1_, atom source2_)
    return c_func( gdk_regions_xor_, {source1_,source2_} )
end function

----------------------------------------
-- gdk_event_send_clientmessage_toall
----------------------------------------
constant gdk_event_send_clientmessage_toall_ = link_c_proc( GDK, 
  "gdk_event_send_clientmessage_toall", {C_POINTER} )

global procedure gdk_event_send_clientmessage_toall(atom event_)
    c_proc( gdk_event_send_clientmessage_toall_, {event_} )
end procedure

----------------------------------------
-- gdk_event_send_client_message
----------------------------------------
constant gdk_event_send_client_message_ = link_c_func( GDK, 
  "gdk_event_send_client_message", {C_POINTER,C_UINT}, C_INT )

global function gdk_event_send_client_message(atom event_, atom xid_)
    return c_func( gdk_event_send_client_message_, {event_,xid_} )
end function

----------------------------------------
-- gdk_keyval_name
----------------------------------------
constant gdk_keyval_name_ = link_c_func( GDK, 
  "gdk_keyval_name", {C_UINT}, C_POINTER )

global function gdk_keyval_name(integer keyval_)
    return peek_string( c_func( gdk_keyval_name_, {keyval_} ) )
end function

----------------------------------------
-- gdk_keyval_from_name
----------------------------------------
constant gdk_keyval_from_name_ = link_c_func( GDK, 
  "gdk_keyval_from_name", {C_POINTER}, C_UINT )

global function gdk_keyval_from_name(sequence const_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gdk_keyval_from_name_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gdk_keyval_to_upper
----------------------------------------
constant gdk_keyval_to_upper_ = link_c_func( GDK, 
  "gdk_keyval_to_upper", {C_UINT}, C_UINT )

global function gdk_keyval_to_upper(integer keyval_)
    return c_func( gdk_keyval_to_upper_, {keyval_} )
end function

----------------------------------------
-- gdk_keyval_to_lower
----------------------------------------
constant gdk_keyval_to_lower_ = link_c_func( GDK, 
  "gdk_keyval_to_lower", {C_UINT}, C_UINT )

global function gdk_keyval_to_lower(integer keyval_)
    return c_func( gdk_keyval_to_lower_, {keyval_} )
end function

----------------------------------------
-- gdk_keyval_is_upper
----------------------------------------
constant gdk_keyval_is_upper_ = link_c_func( GDK, 
  "gdk_keyval_is_upper", {C_UINT}, C_INT )

global function gdk_keyval_is_upper(integer keyval_)
    return c_func( gdk_keyval_is_upper_, {keyval_} )
end function

----------------------------------------
-- gdk_keyval_is_lower
----------------------------------------
constant gdk_keyval_is_lower_ = link_c_func( GDK, 
  "gdk_keyval_is_lower", {C_UINT}, C_INT )

global function gdk_keyval_is_lower(integer keyval_)
    return c_func( gdk_keyval_is_lower_, {keyval_} )
end function

----------------------------------------
-- gdk_threads_enter
----------------------------------------
constant gdk_threads_enter_ = link_c_proc( GDK, 
  "gdk_threads_enter", {} )

global procedure gdk_threads_enter()
    c_proc( gdk_threads_enter_, {} )
end procedure

----------------------------------------
-- gdk_threads_leave
----------------------------------------
constant gdk_threads_leave_ = link_c_proc( GDK, 
  "gdk_threads_leave", {} )

global procedure gdk_threads_leave()
    c_proc( gdk_threads_leave_, {} )
end procedure



----------------------------------------
----------------------------------------
-- GDKTYPES.H
----------------------------------------
----------------------------------------


global constant GDK_WINDOWING_X11 = 1
global constant GDK_WINDOWING_WIN32 = 2
global constant GDK_WINDOWING_BEOS = 3
global constant GDK_WINDOWING_MACOS = 4
global constant GDK_WINDOWING_GGI = 5
global constant GDK_NONE = 0
global constant GDK_CURRENT_TIME = 0
global constant GDK_PARENT_RELATIVE = 1
global constant GDK_CORE_POINTER = #FEDC
----------------------------------------
-- GdkEventFunc
----------------------------------------
constant GdkEventFunc_ = link_c_proc( GDK, 
  "GdkEventFunc", {C_POINTER,C_POINTER} )

global procedure GdkEventFunc(atom event_, atom data_)
    c_proc( GdkEventFunc_, {event_,data_} )
end procedure

global constant
    GDK_WINDOW_ROOT                     = 1,
    GDK_WINDOW_TOPLEVEL                 = 2,
    GDK_WINDOW_CHILD                    = 3,
    GDK_WINDOW_DIALOG                   = 4,
    GDK_WINDOW_TEMP                     = 5,
    GDK_WINDOW_PIXMAP                   = 6,
    GDK_WINDOW_FOREIGN                  = 7
global constant SIZEOF_GdkWindowType = SIZEOF_ENUM

global constant
    GDK_INPUT_OUTPUT                    = 1,
    GDK_INPUT_ONLY                      = 2
global constant SIZEOF_GdkWindowClass = SIZEOF_ENUM

global constant
    GDK_IMAGE_NORMAL                    = 1,
    GDK_IMAGE_SHARED                    = 2,
    GDK_IMAGE_FASTEST                   = 3,
    GDK_IMAGE_SHARED_PIXMAP             = 4
global constant SIZEOF_GdkImageType = SIZEOF_ENUM

global constant
    GDK_VISUAL_STATIC_GRAY              = 1,
    GDK_VISUAL_GRAYSCALE                = 2,
    GDK_VISUAL_STATIC_COLOR             = 3,
    GDK_VISUAL_PSEUDO_COLOR             = 4,
    GDK_VISUAL_TRUE_COLOR               = 5,
    GDK_VISUAL_DIRECT_COLOR             = 6
global constant SIZEOF_GdkVisualType = SIZEOF_ENUM

global constant
    GDK_FONT_FONT                       = 1,
    GDK_FONT_FONTSET                    = 2
global constant SIZEOF_GdkFontType = SIZEOF_ENUM

global constant
    GDK_WA_TITLE                        = power(2,1),
    GDK_WA_X                            = power(2,2),
    GDK_WA_Y                            = power(2,3),
    GDK_WA_CURSOR                       = power(2,4),
    GDK_WA_COLORMAP                     = power(2,5),
    GDK_WA_VISUAL                       = power(2,6),
    GDK_WA_WMCLASS                      = power(2,7),
    GDK_WA_NOREDIR                      = power(2,8)
global constant SIZEOF_GdkWindowAttributesType = SIZEOF_ENUM

global constant
    GDK_HINT_POS                        = power(2,0),
    GDK_HINT_MIN_SIZE                   = power(2,1),
    GDK_HINT_MAX_SIZE                   = power(2,2),
    GDK_HINT_BASE_SIZE                  = power(2,3),
    GDK_HINT_ASPECT                     = power(2,4),
    GDK_HINT_RESIZE_INC                 = power(2,5)
global constant SIZEOF_GdkWindowHints = SIZEOF_ENUM

global constant
    GDK_COPY                            = 1,
    GDK_INVERT                          = 2,
    GDK_XOR                             = 3,
    GDK_CLEAR                           = 4,
    GDK_AND                             = 5,
    GDK_AND_REVERSE                     = 6,
    GDK_AND_INVERT                      = 7,
    GDK_NOOP                            = 8,
    GDK_OR                              = 9,
    GDK_EQUIV                           = 10,
    GDK_OR_REVERSE                      = 11,
    GDK_COPY_INVERT                     = 12,
    GDK_OR_INVERT                       = 13,
    GDK_NAND                            = 14,
    GDK_SET                             = 15
global constant SIZEOF_GdkFunction = SIZEOF_ENUM

global constant
    GDK_SOLID                           = 1,
    GDK_TILED                           = 2,
    GDK_STIPPLED                        = 3,
    GDK_OPAQUE_STIPPLED                 = 4
global constant SIZEOF_GdkFill = SIZEOF_ENUM

global constant
    GDK_EVEN_ODD_RULE                   = 1,
    GDK_WINDING_RULE                    = 2
global constant SIZEOF_GdkFillRule = SIZEOF_ENUM

global constant
    GDK_LINE_SOLID                      = 1,
    GDK_LINE_ON_OFF_DASH                = 2,
    GDK_LINE_DOUBLE_DASH                = 3
global constant SIZEOF_GdkLineStyle = SIZEOF_ENUM

global constant
    GDK_CAP_NOT_LAST                    = 1,
    GDK_CAP_BUTT                        = 2,
    GDK_CAP_ROUND                       = 3,
    GDK_CAP_PROJECTING                  = 4
global constant SIZEOF_GdkCapStyle = SIZEOF_ENUM

global constant
    GDK_JOIN_MITER                      = 1,
    GDK_JOIN_ROUND                      = 2,
    GDK_JOIN_BEVEL                      = 3
global constant SIZEOF_GdkJoinStyle = SIZEOF_ENUM

global constant
    -- #include                            = 1
    GDK_LAST_CURSOR                     = 2,
    GDK_CURSOR_IS_PIXMAP                = -1
global constant SIZEOF_GdkCursorType = SIZEOF_ENUM

global constant
    GDK_FILTER_CONTINUE                 = 1,
    GDK_FILTER_TRANSLATE                = 2,
    GDK_FILTER_REMOVE                   = 3
global constant SIZEOF_GdkFilterReturn = SIZEOF_ENUM

global constant
    GDK_VISIBILITY_UNOBSCURED           = 1,
    GDK_VISIBILITY_PARTIAL              = 2,
    GDK_VISIBILITY_FULLY_OBSCURED       = 3
global constant SIZEOF_GdkVisibilityState = SIZEOF_ENUM

global constant
    GDK_NOTHING                         = -1,
    GDK_DELETE                          = 0,
    GDK_DESTROY                         = 1,
    GDK_EXPOSE                          = 2,
    GDK_MOTION_NOTIFY                   = 3,
    GDK_BUTTON_PRESS                    = 4,
    GDK_2BUTTON_PRESS                   = 5,
    GDK_3BUTTON_PRESS                   = 6,
    GDK_BUTTON_RELEASE                  = 7,
    GDK_KEY_PRESS                       = 8,
    GDK_KEY_RELEASE                     = 9,
    GDK_ENTER_NOTIFY                    = 10,
    GDK_LEAVE_NOTIFY                    = 11,
    GDK_FOCUS_CHANGE                    = 12,
    GDK_CONFIGURE                       = 13,
    GDK_MAP                             = 14,
    GDK_UNMAP                           = 15,
    GDK_PROPERTY_NOTIFY                 = 16,
    GDK_SELECTION_CLEAR                 = 17,
    GDK_SELECTION_REQUEST               = 18,
    GDK_SELECTION_NOTIFY                = 19,
    GDK_PROXIMITY_IN                    = 20,
    GDK_PROXIMITY_OUT                   = 21,
    GDK_DRAG_ENTER                      = 22,
    GDK_DRAG_LEAVE                      = 23,
    GDK_DRAG_MOTION                     = 24,
    GDK_DRAG_STATUS                     = 25,
    GDK_DROP_START                      = 26,
    GDK_DROP_FINISHED                   = 27,
    GDK_CLIENT_EVENT                    = 28,
    GDK_VISIBILITY_NOTIFY               = 29,
    GDK_NO_EXPOSE                       = 30
global constant SIZEOF_GdkEventType = SIZEOF_ENUM

global constant
    GDK_EXPOSURE_MASK                   = power(2,1),
    GDK_POINTER_MOTION_MASK             = power(2,2),
    GDK_POINTER_MOTION_HINT_MASK        = power(2,3),
    GDK_BUTTON_MOTION_MASK              = power(2,4),
    GDK_BUTTON1_MOTION_MASK             = power(2,5),
    GDK_BUTTON2_MOTION_MASK             = power(2,6),
    GDK_BUTTON3_MOTION_MASK             = power(2,7),
    GDK_BUTTON_PRESS_MASK               = power(2,8),
    GDK_BUTTON_RELEASE_MASK             = power(2,9),
    GDK_KEY_PRESS_MASK                  = power(2,10),
    GDK_KEY_RELEASE_MASK                = power(2,11),
    GDK_ENTER_NOTIFY_MASK               = power(2,12),
    GDK_LEAVE_NOTIFY_MASK               = power(2,13),
    GDK_FOCUS_CHANGE_MASK               = power(2,14),
    GDK_STRUCTURE_MASK                  = power(2,15),
    GDK_PROPERTY_CHANGE_MASK            = power(2,16),
    GDK_VISIBILITY_NOTIFY_MASK          = power(2,17),
    GDK_PROXIMITY_IN_MASK               = power(2,18),
    GDK_PROXIMITY_OUT_MASK              = power(2,19),
    GDK_SUBSTRUCTURE_MASK               = power(2,20),
    GDK_ALL_EVENTS_MASK                 = #0FFFFF
global constant SIZEOF_GdkEventMask = SIZEOF_ENUM

global constant
    GDK_NOTIFY_ANCESTOR                 = 0,
    GDK_NOTIFY_VIRTUAL                  = 1,
    GDK_NOTIFY_INFERIOR                 = 2,
    GDK_NOTIFY_NONLINEAR                = 3,
    GDK_NOTIFY_NONLINEAR_VIRTUAL        = 4,
    GDK_NOTIFY_UNKNOWN                  = 5
global constant SIZEOF_GdkNotifyType = SIZEOF_ENUM

global constant
    GDK_CROSSING_NORMAL                 = 1,
    GDK_CROSSING_GRAB                   = 2,
    GDK_CROSSING_UNGRAB                 = 3
global constant SIZEOF_GdkCrossingMode = SIZEOF_ENUM

global constant
    GDK_SHIFT_MASK                      = power(2,0),
    GDK_LOCK_MASK                       = power(2,1),
    GDK_CONTROL_MASK                    = power(2,2),
    GDK_MOD1_MASK                       = power(2,3),
    GDK_MOD2_MASK                       = power(2,4),
    GDK_MOD3_MASK                       = power(2,5),
    GDK_MOD4_MASK                       = power(2,6),
    GDK_MOD5_MASK                       = power(2,7),
    GDK_BUTTON1_MASK                    = power(2,8),
    GDK_BUTTON2_MASK                    = power(2,9),
    GDK_BUTTON3_MASK                    = power(2,10),
    GDK_BUTTON4_MASK                    = power(2,11),
    GDK_BUTTON5_MASK                    = power(2,12),
    GDK_RELEASE_MASK                    = power(2,13),
    GDK_MODIFIER_MASK                   = #3FFF
global constant SIZEOF_GdkModifierType = SIZEOF_ENUM

global constant
    GDK_CLIP_BY_CHILDREN                = 0,
    GDK_INCLUDE_INFERIORS               = 1
global constant SIZEOF_GdkSubwindowMode = SIZEOF_ENUM

global constant
    GDK_INPUT_READ                      = power(2,0),
    GDK_INPUT_WRITE                     = power(2,1),
    GDK_INPUT_EXCEPTION                 = power(2,2)
global constant SIZEOF_GdkInputCondition = SIZEOF_ENUM

global constant
    GDK_OK                              = 0,
    GDK_ERROR                           = -1,
    GDK_ERROR_PARAM                     = -2,
    GDK_ERROR_FILE                      = -3,
    GDK_ERROR_MEM                       = -4
global constant SIZEOF_GdkStatus = SIZEOF_ENUM

global constant
    GDK_LSB_FIRST                       = 1,
    GDK_MSB_FIRST                       = 2
global constant SIZEOF_GdkByteOrder = SIZEOF_ENUM

global constant
    GDK_GC_FOREGROUND                   = power(2,0),
    GDK_GC_BACKGROUND                   = power(2,1),
    GDK_GC_FONT                         = power(2,2),
    GDK_GC_FUNCTION                     = power(2,3),
    GDK_GC_FILL                         = power(2,4),
    GDK_GC_TILE                         = power(2,5),
    GDK_GC_STIPPLE                      = power(2,6),
    GDK_GC_CLIP_MASK                    = power(2,7),
    GDK_GC_SUBWINDOW                    = power(2,8),
    GDK_GC_TS_X_ORIGIN                  = power(2,9),
    GDK_GC_TS_Y_ORIGIN                  = power(2,10),
    GDK_GC_CLIP_X_ORIGIN                = power(2,11),
    GDK_GC_CLIP_Y_ORIGIN                = power(2,12),
    GDK_GC_EXPOSURES                    = power(2,13),
    GDK_GC_LINE_WIDTH                   = power(2,14),
    GDK_GC_LINE_STYLE                   = power(2,15),
    GDK_GC_CAP_STYLE                    = power(2,16),
    GDK_GC_JOIN_STYLE                   = power(2,17)
global constant SIZEOF_GdkGCValuesMask = SIZEOF_ENUM

global constant
    GDK_SELECTION_PRIMARY               = 1,
    GDK_SELECTION_SECONDARY             = 2
global constant SIZEOF_GdkSelection = SIZEOF_ENUM

global constant
    GDK_PROPERTY_NEW_VALUE              = 1,
    GDK_PROPERTY_DELETE                 = 2
global constant SIZEOF_GdkPropertyState = SIZEOF_ENUM

global constant
    GDK_PROP_MODE_REPLACE               = 1,
    GDK_PROP_MODE_PREPEND               = 2,
    GDK_PROP_MODE_APPEND                = 3
global constant SIZEOF_GdkPropMode = SIZEOF_ENUM

global constant
    GDK_SOURCE_MOUSE                    = 1,
    GDK_SOURCE_PEN                      = 2,
    GDK_SOURCE_ERASER                   = 3,
    GDK_SOURCE_CURSOR                   = 4
global constant SIZEOF_GdkInputSource = SIZEOF_ENUM

global constant
    GDK_MODE_DISABLED                   = 1,
    GDK_MODE_SCREEN                     = 2,
    GDK_MODE_WINDOW                     = 3
global constant SIZEOF_GdkInputMode = SIZEOF_ENUM

global constant
    GDK_AXIS_IGNORE                     = 1,
    GDK_AXIS_X                          = 2,
    GDK_AXIS_Y                          = 3,
    GDK_AXIS_PRESSURE                   = 4,
    GDK_AXIS_XTILT                      = 5,
    GDK_AXIS_YTILT                      = 6,
    GDK_AXIS_LAST                       = 7
global constant SIZEOF_GdkAxisUse = SIZEOF_ENUM

global constant
    GDK_TARGET_BITMAP                   = 5,
    GDK_TARGET_COLORMAP                 = 7,
    GDK_TARGET_DRAWABLE                 = 17,
    GDK_TARGET_PIXMAP                   = 20,
    GDK_TARGET_STRING                   = 31
global constant SIZEOF_GdkTarget = SIZEOF_ENUM

global constant
    GDK_SELECTION_TYPE_ATOM             = 4,
    GDK_SELECTION_TYPE_BITMAP           = 5,
    GDK_SELECTION_TYPE_COLORMAP         = 7,
    GDK_SELECTION_TYPE_DRAWABLE         = 17,
    GDK_SELECTION_TYPE_INTEGER          = 19,
    GDK_SELECTION_TYPE_PIXMAP           = 20,
    GDK_SELECTION_TYPE_WINDOW           = 33,
    GDK_SELECTION_TYPE_STRING           = 31
global constant SIZEOF_GdkSelectionType = SIZEOF_ENUM

global constant
    GDK_EXTENSION_EVENTS_NONE           = 1,
    GDK_EXTENSION_EVENTS_ALL            = 2,
    GDK_EXTENSION_EVENTS_CURSOR         = 3
global constant SIZEOF_GdkExtensionMode = SIZEOF_ENUM

global constant
    GDK_IM_PREEDIT_AREA                 = #0001,
    GDK_IM_PREEDIT_CALLBACKS            = #0002,
    GDK_IM_PREEDIT_POSITION             = #0004,
    GDK_IM_PREEDIT_NOTHING              = #0008,
    GDK_IM_PREEDIT_NONE                 = #0010,
    GDK_IM_PREEDIT_MASK                 = #001F,
    GDK_IM_STATUS_AREA                  = #0100,
    GDK_IM_STATUS_CALLBACKS             = #0200,
    GDK_IM_STATUS_NOTHING               = #0400,
    GDK_IM_STATUS_NONE                  = #0800,
    GDK_IM_STATUS_MASK                  = #0F00
global constant SIZEOF_GdkIMStyle = SIZEOF_ENUM

global constant
    GDK_IC_STYLE                        = power(2,0),
    GDK_IC_CLIENT_WINDOW                = power(2,1),
    GDK_IC_FOCUS_WINDOW                 = power(2,2),
    GDK_IC_FILTER_EVENTS                = power(2,3),
    GDK_IC_SPOT_LOCATION                = power(2,4),
    GDK_IC_LINE_SPACING                 = power(2,5),
    GDK_IC_CURSOR                       = power(2,6),
    GDK_IC_PREEDIT_FONTSET              = power(2,10),
    GDK_IC_PREEDIT_AREA                 = power(2,11),
    GDK_IC_PREEDIT_AREA_NEEDED          = power(2,12),
    GDK_IC_PREEDIT_FOREGROUND           = power(2,13),
    GDK_IC_PREEDIT_BACKGROUND           = power(2,14),
    GDK_IC_PREEDIT_PIXMAP               = power(2,15),
    GDK_IC_PREEDIT_COLORMAP             = power(2,16),
    GDK_IC_STATUS_FONTSET               = power(2,21),
    GDK_IC_STATUS_AREA                  = power(2,22),
    GDK_IC_STATUS_AREA_NEEDED           = power(2,23),
    GDK_IC_STATUS_FOREGROUND            = power(2,24),
    GDK_IC_STATUS_BACKGROUND            = power(2,25),
    GDK_IC_STATUS_PIXMAP                = power(2,26),
    GDK_IC_STATUS_COLORMAP              = power(2,27),
    GDK_IC_ALL_REQ                      = or_all( { GDK_IC_STYLE,
                                                    GDK_IC_CLIENT_WINDOW} ),

    GDK_IC_PREEDIT_AREA_REQ             = or_all( { GDK_IC_PREEDIT_AREA,
                                                    GDK_IC_PREEDIT_FONTSET} ),
                                                    
    GDK_IC_PREEDIT_POSITION_REQ         = or_all( { GDK_IC_PREEDIT_AREA,
                                                    GDK_IC_SPOT_LOCATION,
                                                    GDK_IC_PREEDIT_FONTSET} ),

    GDK_IC_STATUS_AREA_REQ              = or_all( { GDK_IC_STATUS_AREA,
                                                    GDK_IC_STATUS_FONTSET} )
global constant SIZEOF_GdkICAttributesType = SIZEOF_ENUM

global constant
    GDK_DECOR_ALL                       = power(2,0),
    GDK_DECOR_BORDER                    = power(2,1),
    GDK_DECOR_RESIZEH                   = power(2,2),
    GDK_DECOR_TITLE                     = power(2,3),
    GDK_DECOR_MENU                      = power(2,4),
    GDK_DECOR_MINIMIZE                  = power(2,5),
    GDK_DECOR_MAXIMIZE                  = power(2,6)
global constant SIZEOF_GdkWMDecoration = SIZEOF_ENUM

global constant
    GDK_FUNC_ALL                        = power(2,0),
    GDK_FUNC_RESIZE                     = power(2,1),
    GDK_FUNC_MOVE                       = power(2,2),
    GDK_FUNC_MINIMIZE                   = power(2,3),
    GDK_FUNC_MAXIMIZE                   = power(2,4),
    GDK_FUNC_CLOSE                      = power(2,5)
global constant SIZEOF_GdkWMFunction = SIZEOF_ENUM

----------------------------------------
-- GdkInputFunction
----------------------------------------
constant GdkInputFunction_ = link_c_proc( GDK, 
  "GdkInputFunction", {C_POINTER,C_INT,C_POINTER} )

global procedure GdkInputFunction(atom data_, integer source_, atom condition_)
    c_proc( GdkInputFunction_, {data_,source_,condition_} )
end procedure

----------------------------------------
-- GdkDestroyNotify
----------------------------------------
constant GdkDestroyNotify_ = link_c_proc( GDK, 
  "GdkDestroyNotify", {C_POINTER} )

global procedure GdkDestroyNotify(atom data_)
    c_proc( GdkDestroyNotify_, {data_} )
end procedure

global constant
    GDK_CC_MODE_UNDEFINED               = 1,
    GDK_CC_MODE_BW                      = 2,
    GDK_CC_MODE_STD_CMAP                = 3,
    GDK_CC_MODE_TRUE                    = 4,
    GDK_CC_MODE_MY_GRAY                 = 5,
    GDK_CC_MODE_PALETTE                 = 6
global constant SIZEOF_GdkColorContextMode = SIZEOF_ENUM

global constant
    GDK_OVERLAP_RECTANGLE_IN            = 1,
    GDK_OVERLAP_RECTANGLE_OUT           = 2,
    GDK_OVERLAP_RECTANGLE_PART          = 3
global constant SIZEOF_GdkOverlapType = SIZEOF_ENUM

global constant
    GDK_ACTION_DEFAULT                  = power(2,0),
    GDK_ACTION_COPY                     = power(2,1),
    GDK_ACTION_MOVE                     = power(2,2),
    GDK_ACTION_LINK                     = power(2,3),
    GDK_ACTION_PRIVATE                  = power(2,4),
    GDK_ACTION_ASK                      = power(2,5)
global constant SIZEOF_GdkDragAction = SIZEOF_ENUM

global constant
    GDK_DRAG_PROTO_MOTIF                = 1,
    GDK_DRAG_PROTO_XDND                 = 2,
    GDK_DRAG_PROTO_ROOTWIN              = 3,
    GDK_DRAG_PROTO_NONE                 = 4,
    GDK_DRAG_PROTO_WIN32_DROPFILES      = 5,
    GDK_DRAG_PROTO_OLE2                 = 6
global constant SIZEOF_GdkDragProtocol = SIZEOF_ENUM


----------------------------------------
-- GdkColor
----------------------------------------
global constant
    GdkColor_pixel                      = allot(TYPE_GULONG),
    GdkColor_red                        = allot(TYPE_GUSHORT),
    GdkColor_green                      = allot(TYPE_GUSHORT),
    GdkColor_blue                       = allot(TYPE_GUSHORT),
    SIZEOF_GdkColor                     = allotted_size()

----------------------------------------
-- GdkColormap
----------------------------------------
global constant
    GdkColormap_size                    = allot(TYPE_GINT),
    GdkColormap_colors                  = allot(TYPE_POINTER),
    SIZEOF_GdkColormap                  = allotted_size()

----------------------------------------
-- GdkVisual
----------------------------------------
global constant
    GdkVisual_type                      = allot(SIZEOF_GdkVisualType),
    GdkVisual_depth                     = allot(TYPE_GINT),
    GdkVisual_byte_order                = allot(SIZEOF_GdkByteOrder),
    GdkVisual_colormap_size             = allot(TYPE_GINT),
    GdkVisual_bits_per_rgb              = allot(TYPE_GINT),
    GdkVisual_red_mask                  = allot(TYPE_GUINT32),
    GdkVisual_red_shift                 = allot(TYPE_GINT),
    GdkVisual_red_prec                  = allot(TYPE_GINT),
    GdkVisual_green_mask                = allot(TYPE_GUINT32),
    GdkVisual_green_shift               = allot(TYPE_GINT),
    GdkVisual_green_prec                = allot(TYPE_GINT),
    GdkVisual_blue_mask                 = allot(TYPE_GUINT32),
    GdkVisual_blue_shift                = allot(TYPE_GINT),
    GdkVisual_blue_prec                 = allot(TYPE_GINT),
    SIZEOF_GdkVisual                    = allotted_size()

----------------------------------------
-- GdkWindowAttr
----------------------------------------
global constant
    GdkWindowAttr_title                 = allot(TYPE_POINTER),
    GdkWindowAttr_event_mask            = allot(TYPE_GINT),
    GdkWindowAttr_x                     = allot(TYPE_GINT16),
    GdkWindowAttr_y                     = allot(TYPE_GINT16),
    GdkWindowAttr_width                 = allot(TYPE_GINT16),
    GdkWindowAttr_height                = allot(TYPE_GINT16),
    GdkWindowAttr_wclass                = allot(SIZEOF_GdkWindowClass),
    GdkWindowAttr_visual                = allot(TYPE_POINTER),
    GdkWindowAttr_colormap              = allot(TYPE_POINTER),
    GdkWindowAttr_window_type           = allot(SIZEOF_GdkWindowType),
    GdkWindowAttr_cursor                = allot(TYPE_POINTER),
    GdkWindowAttr_wmclass_name          = allot(TYPE_POINTER),
    GdkWindowAttr_wmclass_class         = allot(TYPE_POINTER),
    GdkWindowAttr_override_redirect     = allot(TYPE_GBOOLEAN),
    SIZEOF_GdkWindowAttr                = allotted_size()

----------------------------------------
-- GdkWindow
----------------------------------------
global constant
    GdkWindow_user_data                 = allot(TYPE_GPOINTER),
    SIZEOF_GdkWindow                    = allotted_size()

----------------------------------------
-- GdkGeometry
----------------------------------------
global constant
    GdkGeometry_min_width               = allot(TYPE_GINT),
    GdkGeometry_min_height              = allot(TYPE_GINT),
    GdkGeometry_max_width               = allot(TYPE_GINT),
    GdkGeometry_max_height              = allot(TYPE_GINT),
    GdkGeometry_base_width              = allot(TYPE_GINT),
    GdkGeometry_base_height             = allot(TYPE_GINT),
    GdkGeometry_width_inc               = allot(TYPE_GINT),
    GdkGeometry_height_inc              = allot(TYPE_GINT),
    GdkGeometry_min_aspect              = allot(TYPE_GDOUBLE),
    GdkGeometry_max_aspect              = allot(TYPE_GDOUBLE),
    SIZEOF_GdkGeometry                  = allotted_size()

----------------------------------------
-- GdkImage
----------------------------------------
global constant
    GdkImage_type                       = allot(SIZEOF_GdkImageType),
    GdkImage_visual                     = allot(TYPE_POINTER),
    GdkImage_byte_order                 = allot(SIZEOF_GdkByteOrder),
    GdkImage_width                      = allot(TYPE_GUINT16),
    GdkImage_height                     = allot(TYPE_GUINT16),
    GdkImage_depth                      = allot(TYPE_GUINT16),
    GdkImage_bpp                        = allot(TYPE_GUINT16),
    GdkImage_bpl                        = allot(TYPE_GUINT16),
    GdkImage_mem                        = allot(TYPE_GPOINTER),
    SIZEOF_GdkImage                     = allotted_size()

----------------------------------------
-- GdkGCValues
----------------------------------------
global constant
    GdkGCValues_foreground              = allot(SIZEOF_GdkColor),
    GdkGCValues_background              = allot(SIZEOF_GdkColor),
    GdkGCValues_font                    = allot(TYPE_POINTER),
    GdkGCValues_function                = allot(SIZEOF_GdkFunction),
    GdkGCValues_fill                    = allot(SIZEOF_GdkFill),
    GdkGCValues_tile                    = allot(TYPE_POINTER),
    GdkGCValues_stipple                 = allot(TYPE_POINTER),
    GdkGCValues_clip_mask               = allot(TYPE_POINTER),
    GdkGCValues_subwindow_mode          = allot(SIZEOF_GdkSubwindowMode),
    GdkGCValues_ts_x_origin             = allot(TYPE_GINT),
    GdkGCValues_ts_y_origin             = allot(TYPE_GINT),
    GdkGCValues_clip_x_origin           = allot(TYPE_GINT),
    GdkGCValues_clip_y_origin           = allot(TYPE_GINT),
    GdkGCValues_graphics_exposures      = allot(TYPE_GINT),
    GdkGCValues_line_width              = allot(TYPE_GINT),
    GdkGCValues_line_style              = allot(SIZEOF_GdkLineStyle),
    GdkGCValues_cap_style               = allot(SIZEOF_GdkCapStyle),
    GdkGCValues_join_style              = allot(SIZEOF_GdkJoinStyle),
    SIZEOF_GdkGCValues                  = allotted_size()

----------------------------------------
-- GdkGC
----------------------------------------
global constant
    GdkGC_dummy_var                     = allot(TYPE_GINT),
    SIZEOF_GdkGC                        = allotted_size()

----------------------------------------
-- GdkPoint
----------------------------------------
global constant
    GdkPoint_x                          = allot(TYPE_GINT16),
    GdkPoint_y                          = allot(TYPE_GINT16),
    SIZEOF_GdkPoint                     = allotted_size()

----------------------------------------
-- GdkRectangle
----------------------------------------
global constant
    GdkRectangle_x                      = allot(TYPE_GINT16),
    GdkRectangle_y                      = allot(TYPE_GINT16),
    GdkRectangle_width                  = allot(TYPE_GUINT16),
    GdkRectangle_height                 = allot(TYPE_GUINT16),
    SIZEOF_GdkRectangle                 = allotted_size()

----------------------------------------
-- GdkSegment
----------------------------------------
global constant
    GdkSegment_x1                       = allot(TYPE_GINT16),
    GdkSegment_y1                       = allot(TYPE_GINT16),
    GdkSegment_x2                       = allot(TYPE_GINT16),
    GdkSegment_y2                       = allot(TYPE_GINT16),
    SIZEOF_GdkSegment                   = allotted_size()

----------------------------------------
-- GdkFont
----------------------------------------
global constant
    GdkFont_type                        = allot(SIZEOF_GdkFontType),
    GdkFont_ascent                      = allot(TYPE_GINT),
    GdkFont_descent                     = allot(TYPE_GINT),
    SIZEOF_GdkFont                      = allotted_size()

----------------------------------------
-- GdkCursor
----------------------------------------
global constant
    GdkCursor_type                      = allot(SIZEOF_GdkCursorType),
    SIZEOF_GdkCursor                    = allotted_size()

----------------------------------------
-- GdkColorContextDither
----------------------------------------
-- fixed manually
global constant
    GdkColorContextDither_fast_rgb      = allot(32*32*32*INT_BYTES),
    GdkColorContextDither_fast_err      = allot(32*32*32*INT_BYTES),
    GdkColorContextDither_fast_erg      = allot(32*32*32*INT_BYTES),
    GdkColorContextDither_fast_erb      = allot(32*32*32*INT_BYTES),
    SIZEOF_GdkColorContextDither        = allotted_size()

----------------------------------------
-- GdkColorContext
----------------------------------------

-- added
global constant
    GdkColorContext_shifts_red          = allot(TYPE_INT),
    GdkColorContext_shifts_green        = allot(TYPE_INT),
    GdkColorContext_shifts_blue         = allot(TYPE_INT),
    SIZEOF_GdkColorContext_shifts       = allotted_size()
                                 
-- added
global constant
    GdkColorContext_masks_red           = allot(TYPE_ULONG),
    GdkColorContext_masks_green         = allot(TYPE_ULONG),
    GdkColorContext_masks_blue          = allot(TYPE_ULONG),
    SIZEOF_GdkColorContext_masks        = allotted_size()

-- added
global constant
    GdkColorContext_bits_red          = allot(TYPE_INT),
    GdkColorContext_bits_green        = allot(TYPE_INT),
    GdkColorContext_bits_blue         = allot(TYPE_INT),
    SIZEOF_GdkColorContext_bits       = allotted_size()

-- fixed manually    
global constant
    GdkColorContext_visual              = allot(TYPE_POINTER),
    GdkColorContext_colormap            = allot(TYPE_POINTER),
    GdkColorContext_num_colors          = allot(TYPE_INT),
    GdkColorContext_max_colors          = allot(TYPE_INT),
    GdkColorContext_num_allocated       = allot(TYPE_INT),
    GdkColorContext_mode                = allot(SIZEOF_GdkColorContextMode),
    GdkColorContext_need_to_free_colormap= allot(TYPE_INT),
    GdkColorContext_std_cmap_atom       = allot(TYPE_ULONG),
    GdkColorContext_clut                = allot(TYPE_POINTER),
    GdkColorContext_cmap                = allot(TYPE_POINTER),
    GdkColorContext_color_hash          = allot(TYPE_POINTER),
    GdkColorContext_palette             = allot(TYPE_POINTER),
    GdkColorContext_num_palette         = allot(TYPE_INT),
    GdkColorContext_fast_dither         = allot(TYPE_POINTER),
    GdkColorContext_shifts              = allot(SIZEOF_GdkColorContext_shifts),
    GdkColorContext_masks               = allot(SIZEOF_GdkColorContext_masks),
    GdkColorContext_bits                = allot(SIZEOF_GdkColorContext_shifts),
    GdkColorContext_max_entry           = allot(TYPE_ULONG),
    GdkColorContext_black_pixel         = allot(TYPE_ULONG),
    GdkColorContext_white_pixel         = allot(TYPE_ULONG),
    SIZEOF_GdkColorContext              = allotted_size()

----------------------------------------
-- GdkDeviceKey
----------------------------------------
global constant
    GdkDeviceKey_keyval                 = allot(TYPE_GUINT),
    GdkDeviceKey_modifiers              = allot(SIZEOF_GdkModifierType),
    SIZEOF_GdkDeviceKey                 = allotted_size()

----------------------------------------
-- GdkDeviceInfo
----------------------------------------
global constant
    GdkDeviceInfo_deviceid              = allot(TYPE_GUINT32),
    GdkDeviceInfo_name                  = allot(TYPE_POINTER),
    GdkDeviceInfo_source                = allot(SIZEOF_GdkInputSource),
    GdkDeviceInfo_mode                  = allot(SIZEOF_GdkInputMode),
    GdkDeviceInfo_has_cursor            = allot(TYPE_GINT),
    GdkDeviceInfo_num_axes              = allot(TYPE_GINT),
    GdkDeviceInfo_axes                  = allot(TYPE_POINTER),
    GdkDeviceInfo_num_keys              = allot(TYPE_GINT),
    GdkDeviceInfo_keys                  = allot(TYPE_POINTER),
    SIZEOF_GdkDeviceInfo                = allotted_size()

----------------------------------------
-- GdkTimeCoord
----------------------------------------
global constant
    GdkTimeCoord_time                   = allot(TYPE_GUINT32),
    GdkTimeCoord_x                      = allot(TYPE_GDOUBLE),
    GdkTimeCoord_y                      = allot(TYPE_GDOUBLE),
    GdkTimeCoord_pressure               = allot(TYPE_GDOUBLE),
    GdkTimeCoord_xtilt                  = allot(TYPE_GDOUBLE),
    GdkTimeCoord_ytilt                  = allot(TYPE_GDOUBLE),
    SIZEOF_GdkTimeCoord                 = allotted_size()

----------------------------------------
-- GdkDragContext
----------------------------------------
global constant
    GdkDragContext_protocol             = allot(SIZEOF_GdkDragProtocol),
    GdkDragContext_is_source            = allot(TYPE_GBOOLEAN),
    GdkDragContext_source_window        = allot(TYPE_POINTER),
    GdkDragContext_dest_window          = allot(TYPE_POINTER),
    GdkDragContext_targets              = allot(TYPE_POINTER),
    GdkDragContext_actions              = allot(SIZEOF_GdkDragAction),
    GdkDragContext_suggested_action     = allot(SIZEOF_GdkDragAction),
    GdkDragContext_action               = allot(SIZEOF_GdkDragAction),
    GdkDragContext_start_time           = allot(TYPE_GUINT32),
    SIZEOF_GdkDragContext               = allotted_size()
----------------------------------------
-- GdkFilterFunc
----------------------------------------
constant GdkFilterFunc_ = link_c_func( GDK, 
  "GdkFilterFunc", {C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function GdkFilterFunc(atom xevent_, atom event_, atom data_)
    return c_func( GdkFilterFunc_, {xevent_,event_,data_} )
end function


----------------------------------------
-- GdkEventAny
----------------------------------------
global constant
    GdkEventAny_type                    = allot(SIZEOF_GdkEventType),
    GdkEventAny_window                  = allot(TYPE_POINTER),
    GdkEventAny_send_event              = allot(TYPE_GINT8),
    SIZEOF_GdkEventAny                  = allotted_size()

----------------------------------------
-- GdkEventExpose
----------------------------------------
global constant
    GdkEventExpose_type                 = allot(SIZEOF_GdkEventType),
    GdkEventExpose_window               = allot(TYPE_POINTER),
    GdkEventExpose_send_event           = allot(TYPE_GINT8),
    GdkEventExpose_area                 = allot(SIZEOF_GdkRectangle),
    GdkEventExpose_count                = allot(TYPE_GINT),
    SIZEOF_GdkEventExpose               = allotted_size()

----------------------------------------
-- GdkEventNoExpose
----------------------------------------
global constant
    GdkEventNoExpose_type               = allot(SIZEOF_GdkEventType),
    GdkEventNoExpose_window             = allot(TYPE_POINTER),
    GdkEventNoExpose_send_event         = allot(TYPE_GINT8),
    SIZEOF_GdkEventNoExpose             = allotted_size()

----------------------------------------
-- GdkEventVisibility
----------------------------------------
global constant
    GdkEventVisibility_type             = allot(SIZEOF_GdkEventType),
    GdkEventVisibility_window           = allot(TYPE_POINTER),
    GdkEventVisibility_send_event       = allot(TYPE_GINT8),
    GdkEventVisibility_state            = allot(SIZEOF_GdkVisibilityState),
    SIZEOF_GdkEventVisibility           = allotted_size()

----------------------------------------
-- GdkEventMotion
----------------------------------------
global constant
    GdkEventMotion_type                 = allot(SIZEOF_GdkEventType),
    GdkEventMotion_window               = allot(TYPE_POINTER),
    GdkEventMotion_send_event           = allot(TYPE_GINT8),
    GdkEventMotion_time                 = allot(TYPE_GUINT32),
    GdkEventMotion_x                    = allot(TYPE_GDOUBLE),
    GdkEventMotion_y                    = allot(TYPE_GDOUBLE),
    GdkEventMotion_pressure             = allot(TYPE_GDOUBLE),
    GdkEventMotion_xtilt                = allot(TYPE_GDOUBLE),
    GdkEventMotion_ytilt                = allot(TYPE_GDOUBLE),
    GdkEventMotion_state                = allot(TYPE_GUINT),
    GdkEventMotion_is_hint              = allot(TYPE_GINT16),
    GdkEventMotion_source               = allot(SIZEOF_GdkInputSource),
    GdkEventMotion_deviceid             = allot(TYPE_GUINT32),
    GdkEventMotion_x_root               = allot(TYPE_GDOUBLE),
    GdkEventMotion_y_root               = allot(TYPE_GDOUBLE),
    SIZEOF_GdkEventMotion               = allotted_size()

----------------------------------------
-- GdkEventButton
----------------------------------------
global constant
    GdkEventButton_type                 = allot(SIZEOF_GdkEventType),
    GdkEventButton_window               = allot(TYPE_POINTER),
    GdkEventButton_send_event           = allot(TYPE_GINT8),
    GdkEventButton_time                 = allot(TYPE_GUINT32),
    GdkEventButton_x                    = allot(TYPE_GDOUBLE),
    GdkEventButton_y                    = allot(TYPE_GDOUBLE),
    GdkEventButton_pressure             = allot(TYPE_GDOUBLE),
    GdkEventButton_xtilt                = allot(TYPE_GDOUBLE),
    GdkEventButton_ytilt                = allot(TYPE_GDOUBLE),
    GdkEventButton_state                = allot(TYPE_GUINT),
    GdkEventButton_button               = allot(TYPE_GUINT),
    GdkEventButton_source               = allot(SIZEOF_GdkInputSource),
    GdkEventButton_deviceid             = allot(TYPE_GUINT32),
    GdkEventButton_x_root               = allot(TYPE_GDOUBLE),
    GdkEventButton_y_root               = allot(TYPE_GDOUBLE),
    SIZEOF_GdkEventButton               = allotted_size()

----------------------------------------
-- GdkEventKey
----------------------------------------
global constant
    GdkEventKey_type                    = allot(SIZEOF_GdkEventType),
    GdkEventKey_window                  = allot(TYPE_POINTER),
    GdkEventKey_send_event              = allot(TYPE_GINT8),
    GdkEventKey_time                    = allot(TYPE_GUINT32),
    GdkEventKey_state                   = allot(TYPE_GUINT),
    GdkEventKey_keyval                  = allot(TYPE_GUINT),
    GdkEventKey_length                  = allot(TYPE_GINT),
    GdkEventKey_string                  = allot(TYPE_POINTER),
    SIZEOF_GdkEventKey                  = allotted_size()

----------------------------------------
-- GdkEventCrossing
----------------------------------------
global constant
    GdkEventCrossing_type               = allot(SIZEOF_GdkEventType),
    GdkEventCrossing_window             = allot(TYPE_POINTER),
    GdkEventCrossing_send_event         = allot(TYPE_GINT8),
    GdkEventCrossing_subwindow          = allot(TYPE_POINTER),
    GdkEventCrossing_time               = allot(TYPE_GUINT32),
    GdkEventCrossing_x                  = allot(TYPE_GDOUBLE),
    GdkEventCrossing_y                  = allot(TYPE_GDOUBLE),
    GdkEventCrossing_x_root             = allot(TYPE_GDOUBLE),
    GdkEventCrossing_y_root             = allot(TYPE_GDOUBLE),
    GdkEventCrossing_mode               = allot(SIZEOF_GdkCrossingMode),
    GdkEventCrossing_detail             = allot(SIZEOF_GdkNotifyType),
    GdkEventCrossing_focus              = allot(TYPE_GBOOLEAN),
    GdkEventCrossing_state              = allot(TYPE_GUINT),
    SIZEOF_GdkEventCrossing             = allotted_size()

----------------------------------------
-- GdkEventFocus
----------------------------------------
global constant
    GdkEventFocus_type                  = allot(SIZEOF_GdkEventType),
    GdkEventFocus_window                = allot(TYPE_POINTER),
    GdkEventFocus_send_event            = allot(TYPE_GINT8),
    GdkEventFocus_in                    = allot(TYPE_GINT16),
    SIZEOF_GdkEventFocus                = allotted_size()

----------------------------------------
-- GdkEventConfigure
----------------------------------------
global constant
    GdkEventConfigure_type              = allot(SIZEOF_GdkEventType),
    GdkEventConfigure_window            = allot(TYPE_POINTER),
    GdkEventConfigure_send_event        = allot(TYPE_GINT8),
    GdkEventConfigure_x                 = allot(TYPE_GINT16),
    GdkEventConfigure_y                 = allot(TYPE_GINT16),
    GdkEventConfigure_width             = allot(TYPE_GINT16),
    GdkEventConfigure_height            = allot(TYPE_GINT16),
    SIZEOF_GdkEventConfigure            = allotted_size()

----------------------------------------
-- GdkEventProperty
----------------------------------------
global constant
    GdkEventProperty_type               = allot(SIZEOF_GdkEventType),
    GdkEventProperty_window             = allot(TYPE_POINTER),
    GdkEventProperty_send_event         = allot(TYPE_GINT8),
    GdkEventProperty_atom               = allot(TYPE_GULONG),
    GdkEventProperty_time               = allot(TYPE_GUINT32),
    GdkEventProperty_state              = allot(TYPE_GUINT),
    SIZEOF_GdkEventProperty             = allotted_size()

----------------------------------------
-- GdkEventSelection
----------------------------------------
global constant
    GdkEventSelection_type              = allot(SIZEOF_GdkEventType),
    GdkEventSelection_window            = allot(TYPE_POINTER),
    GdkEventSelection_send_event        = allot(TYPE_GINT8),
    GdkEventSelection_selection         = allot(TYPE_GULONG),
    GdkEventSelection_target            = allot(TYPE_GULONG),
    GdkEventSelection_property          = allot(TYPE_GULONG),
    GdkEventSelection_requestor         = allot(TYPE_GUINT32),
    GdkEventSelection_time              = allot(TYPE_GUINT32),
    SIZEOF_GdkEventSelection            = allotted_size()

----------------------------------------
-- GdkEventProximity
----------------------------------------
global constant
    GdkEventProximity_type              = allot(SIZEOF_GdkEventType),
    GdkEventProximity_window            = allot(TYPE_POINTER),
    GdkEventProximity_send_event        = allot(TYPE_GINT8),
    GdkEventProximity_time              = allot(TYPE_GUINT32),
    GdkEventProximity_source            = allot(SIZEOF_GdkInputSource),
    GdkEventProximity_deviceid          = allot(TYPE_GUINT32),
    SIZEOF_GdkEventProximity            = allotted_size()

----------------------------------------
-- GdkEventClient
----------------------------------------
global constant
    GdkEventClient_type                 = allot(SIZEOF_GdkEventType),
    GdkEventClient_window               = allot(TYPE_POINTER),
    GdkEventClient_send_event           = allot(TYPE_GINT8),
    GdkEventClient_message_type         = allot(TYPE_GULONG),
    GdkEventClient_data_format          = allot(TYPE_GUSHORT),
    GdkEventClient_data                 = allot(TYPE_LONG), -- union,
    SIZEOF_GdkEventClient               = allotted_size()

----------------------------------------
-- GdkEventDND
----------------------------------------
global constant
    GdkEventDND_type                    = allot(SIZEOF_GdkEventType),
    GdkEventDND_window                  = allot(TYPE_POINTER),
    GdkEventDND_send_event              = allot(TYPE_GINT8),
    GdkEventDND_context                 = allot(TYPE_POINTER),
    GdkEventDND_time                    = allot(TYPE_GUINT32),
    GdkEventDND_x_root                  = allot(TYPE_GSHORT),
    GdkEventDND_y_root                  = allot(TYPE_GSHORT),
    SIZEOF_GdkEventDND                  = allotted_size()

----------------------------------------
-- GdkRegion
----------------------------------------
global constant
    GdkRegion_user_data                 = allot(TYPE_GPOINTER),
    SIZEOF_GdkRegion                    = allotted_size()

----------------------------------------
-- GdkICAttr
----------------------------------------
global constant
    GdkICAttr_style                     = allot(SIZEOF_GdkIMStyle),
    GdkICAttr_client_window             = allot(TYPE_POINTER),
    GdkICAttr_focus_window              = allot(TYPE_POINTER),
    GdkICAttr_filter_events             = allot(SIZEOF_GdkEventMask),
    GdkICAttr_spot_location             = allot(SIZEOF_GdkPoint),
    GdkICAttr_line_spacing              = allot(TYPE_GINT),
    GdkICAttr_cursor                    = allot(TYPE_POINTER),
    GdkICAttr_preedit_fontset           = allot(TYPE_POINTER),
    GdkICAttr_preedit_area              = allot(SIZEOF_GdkRectangle),
    GdkICAttr_preedit_area_needed       = allot(SIZEOF_GdkRectangle),
    GdkICAttr_preedit_foreground        = allot(SIZEOF_GdkColor),
    GdkICAttr_preedit_background        = allot(SIZEOF_GdkColor),
    GdkICAttr_preedit_pixmap            = allot(TYPE_POINTER),
    GdkICAttr_preedit_colormap          = allot(TYPE_POINTER),
    GdkICAttr_status_fontset            = allot(TYPE_POINTER),
    GdkICAttr_status_area               = allot(SIZEOF_GdkRectangle),
    GdkICAttr_status_area_needed        = allot(SIZEOF_GdkRectangle),
    GdkICAttr_status_foreground         = allot(SIZEOF_GdkColor),
    GdkICAttr_status_background         = allot(SIZEOF_GdkColor),
    GdkICAttr_status_pixmap             = allot(TYPE_POINTER),
    GdkICAttr_status_colormap           = allot(TYPE_POINTER),
    SIZEOF_GdkICAttr                    = allotted_size()


----------------------------------------
----------------------------------------
-- GDKRGB.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GdkRgbCmap
----------------------------------------
-- manually corrected
-- colors[256] and lut[256] now allocate correctly
global constant
    GdkRgbCmap_colors                   = allot(256*LONG_BYTES),
    GdkRgbCmap_lut                      = allot(256*INT_BYTES),
    SIZEOF_GdkRgbCmap                   = allotted_size()
    
----------------------------------------
-- gdk_rgb_init
----------------------------------------
constant gdk_rgb_init_ = link_c_proc( GDK, 
  "gdk_rgb_init", {} )

global procedure gdk_rgb_init()
    c_proc( gdk_rgb_init_, {} )
end procedure

----------------------------------------
-- gdk_rgb_xpixel_from_rgb
----------------------------------------
constant gdk_rgb_xpixel_from_rgb_ = link_c_func( GDK, 
  "gdk_rgb_xpixel_from_rgb", {C_UINT}, C_ULONG )

global function gdk_rgb_xpixel_from_rgb(atom rgb_)
    return c_func( gdk_rgb_xpixel_from_rgb_, {rgb_} )
end function

----------------------------------------
-- gdk_rgb_gc_set_foreground
----------------------------------------
constant gdk_rgb_gc_set_foreground_ = link_c_proc( GDK, 
  "gdk_rgb_gc_set_foreground", {C_POINTER} )

global procedure gdk_rgb_gc_set_foreground(atom gc_)
    c_proc( gdk_rgb_gc_set_foreground_, {gc_} )
end procedure

----------------------------------------
-- gdk_rgb_gc_set_background
----------------------------------------
constant gdk_rgb_gc_set_background_ = link_c_proc( GDK, 
  "gdk_rgb_gc_set_background", {C_POINTER} )

global procedure gdk_rgb_gc_set_background(atom gc_)
    c_proc( gdk_rgb_gc_set_background_, {gc_} )
end procedure

global constant
    GDK_RGB_DITHER_NONE                 = 1,
    GDK_RGB_DITHER_NORMAL               = 2,
    GDK_RGB_DITHER_MAX                  = 3
global constant SIZEOF_GdkRgbDither = SIZEOF_ENUM

----------------------------------------
-- gdk_draw_rgb_image
----------------------------------------
constant gdk_draw_rgb_image_ = link_c_proc( GDK, 
  "gdk_draw_rgb_image", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_UINT,C_INT} )

global procedure gdk_draw_rgb_image(atom drawable_, atom gc_, integer x_, integer y_, integer width_, integer 
 height_, atom dith_, integer rgb_buf_, integer rowstride_)
    c_proc( gdk_draw_rgb_image_, {drawable_,gc_,x_,y_,width_,height_,dith_,rgb_buf_,rowstride_} )
end procedure

----------------------------------------
-- gdk_draw_rgb_image_dithalign
----------------------------------------
constant gdk_draw_rgb_image_dithalign_ = link_c_proc( GDK, 
  "gdk_draw_rgb_image_dithalign", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_UINT,C_INT,C_INT,C_INT} 
 )

global procedure gdk_draw_rgb_image_dithalign(atom drawable_, atom gc_, integer x_, integer y_, integer width_, 
 integer height_, atom dith_, integer rgb_buf_, integer rowstride_, integer xdith_, integer ydith_)
    c_proc( gdk_draw_rgb_image_dithalign_, {drawable_,gc_,x_,y_,width_,height_,dith_,rgb_buf_,rowstride_,xdith_,ydith_} )
end procedure

----------------------------------------
-- gdk_draw_rgb_32_image
----------------------------------------
constant gdk_draw_rgb_32_image_ = link_c_proc( GDK, 
  "gdk_draw_rgb_32_image", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_UINT,C_INT} 
 )

global procedure gdk_draw_rgb_32_image(atom drawable_, atom gc_, integer x_, integer y_, integer width_, integer 
 height_, atom dith_, integer buf_, integer rowstride_)
    c_proc( gdk_draw_rgb_32_image_, {drawable_,gc_,x_,y_,width_,height_,dith_,buf_,rowstride_} )
end procedure

----------------------------------------
-- gdk_draw_gray_image
----------------------------------------
constant gdk_draw_gray_image_ = link_c_proc( GDK, 
  "gdk_draw_gray_image", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_UINT,C_INT} )

global procedure gdk_draw_gray_image(atom drawable_, atom gc_, integer x_, integer y_, integer width_, integer 
 height_, atom dith_, integer buf_, integer rowstride_)
    c_proc( gdk_draw_gray_image_, {drawable_,gc_,x_,y_,width_,height_,dith_,buf_,rowstride_} )
end procedure

----------------------------------------
-- gdk_rgb_cmap_new
----------------------------------------
constant gdk_rgb_cmap_new_ = link_c_func( GDK, 
  "gdk_rgb_cmap_new", {C_UINT}, C_POINTER )

global function gdk_rgb_cmap_new(atom colors_)
    return c_func( gdk_rgb_cmap_new_, {colors_} )
end function

----------------------------------------
-- gdk_rgb_cmap_free
----------------------------------------
constant gdk_rgb_cmap_free_ = link_c_proc( GDK, 
  "gdk_rgb_cmap_free", {C_POINTER} )

global procedure gdk_rgb_cmap_free(atom cmap_)
    c_proc( gdk_rgb_cmap_free_, {cmap_} )
end procedure

----------------------------------------
-- gdk_draw_indexed_image
----------------------------------------
constant gdk_draw_indexed_image_ = link_c_proc( GDK, 
  "gdk_draw_indexed_image", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_UINT,C_INT,C_POINTER} 
 )

global procedure gdk_draw_indexed_image(atom drawable_, atom gc_, integer x_, integer y_, integer width_, integer 
 height_, atom dith_, integer buf_, integer rowstride_, atom cmap_)
    c_proc( gdk_draw_indexed_image_, {drawable_,gc_,x_,y_,width_,height_,dith_,buf_,rowstride_,cmap_} )
end procedure

----------------------------------------
-- gdk_rgb_ditherable
----------------------------------------
constant gdk_rgb_ditherable_ = link_c_func( GDK, 
  "gdk_rgb_ditherable", {}, C_INT )

global function gdk_rgb_ditherable()
    return c_func( gdk_rgb_ditherable_, {} )
end function

----------------------------------------
-- gdk_rgb_set_verbose
----------------------------------------
constant gdk_rgb_set_verbose_ = link_c_proc( GDK, 
  "gdk_rgb_set_verbose", {C_INT} )

global procedure gdk_rgb_set_verbose(integer verbose_)
    c_proc( gdk_rgb_set_verbose_, {verbose_} )
end procedure

----------------------------------------
-- gdk_rgb_set_install
----------------------------------------
constant gdk_rgb_set_install_ = link_c_proc( GDK, 
  "gdk_rgb_set_install", {C_INT} )

global procedure gdk_rgb_set_install(integer install_)
    c_proc( gdk_rgb_set_install_, {install_} )
end procedure

----------------------------------------
-- gdk_rgb_set_min_colors
----------------------------------------
constant gdk_rgb_set_min_colors_ = link_c_proc( GDK, 
  "gdk_rgb_set_min_colors", {C_INT} )

global procedure gdk_rgb_set_min_colors(integer min_colors_)
    c_proc( gdk_rgb_set_min_colors_, {min_colors_} )
end procedure

----------------------------------------
-- gdk_rgb_get_cmap
----------------------------------------
constant gdk_rgb_get_cmap_ = link_c_func( GDK, 
  "gdk_rgb_get_cmap", {}, C_POINTER )

global function gdk_rgb_get_cmap()
    return c_func( gdk_rgb_get_cmap_, {} )
end function

----------------------------------------
-- gdk_rgb_get_visual
----------------------------------------
constant gdk_rgb_get_visual_ = link_c_func( GDK, 
  "gdk_rgb_get_visual", {}, C_POINTER )

global function gdk_rgb_get_visual()
    return c_func( gdk_rgb_get_visual_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKACCELGROUP.H
----------------------------------------
----------------------------------------


global constant
    GTK_ACCEL_VISIBLE                   = power(2,0),
    GTK_ACCEL_SIGNAL_VISIBLE            = power(2,1),
    GTK_ACCEL_LOCKED                    = power(2,2),
    GTK_ACCEL_MASK                      = #07
global constant SIZEOF_GtkAccelFlags = SIZEOF_ENUM


----------------------------------------
-- GtkAccelGroup
----------------------------------------
global constant
    GtkAccelGroup_ref_count             = allot(TYPE_GUINT),
    GtkAccelGroup_lock_count            = allot(TYPE_GUINT),
    GtkAccelGroup_modifier_mask         = allot(SIZEOF_GdkModifierType),
    GtkAccelGroup_attach_objects        = allot(TYPE_POINTER),
    SIZEOF_GtkAccelGroup                = allotted_size()

----------------------------------------
-- GtkAccelEntry
----------------------------------------
global constant
    GtkAccelEntry_accel_group           = allot(TYPE_POINTER),
    GtkAccelEntry_accelerator_key       = allot(TYPE_GUINT),
    GtkAccelEntry_accelerator_mods      = allot(SIZEOF_GdkModifierType),
    GtkAccelEntry_accel_flags           = allot(SIZEOF_GtkAccelFlags),
    GtkAccelEntry_object                = allot(TYPE_POINTER),
    GtkAccelEntry_signal_id             = allot(TYPE_GUINT),
    SIZEOF_GtkAccelEntry                = allotted_size()
----------------------------------------
-- gtk_accel_group_new
----------------------------------------
constant gtk_accel_group_new_ = link_c_func( GTK, 
  "gtk_accel_group_new", {}, C_POINTER )

global function gtk_accel_group_new()
    return c_func( gtk_accel_group_new_, {} )
end function

----------------------------------------
-- gtk_accel_group_get_default
----------------------------------------
constant gtk_accel_group_get_default_ = link_c_func( GTK, 
  "gtk_accel_group_get_default", {}, C_POINTER )

global function gtk_accel_group_get_default()
    return c_func( gtk_accel_group_get_default_, {} )
end function

----------------------------------------
-- gtk_accel_group_ref
----------------------------------------
constant gtk_accel_group_ref_ = link_c_func( GTK, 
  "gtk_accel_group_ref", {C_POINTER}, C_POINTER )

global function gtk_accel_group_ref(atom accel_group_)
    return c_func( gtk_accel_group_ref_, {accel_group_} )
end function

----------------------------------------
-- gtk_accel_group_unref
----------------------------------------
constant gtk_accel_group_unref_ = link_c_proc( GTK, 
  "gtk_accel_group_unref", {C_POINTER} )

global procedure gtk_accel_group_unref(atom accel_group_)
    c_proc( gtk_accel_group_unref_, {accel_group_} )
end procedure

----------------------------------------
-- gtk_accel_group_activate
----------------------------------------
constant gtk_accel_group_activate_ = link_c_func( GTK, 
  "gtk_accel_group_activate", {C_POINTER,C_UINT,C_POINTER}, C_INT )

global function gtk_accel_group_activate(atom accel_group_, integer accel_key_, atom accel_mods_)
    return c_func( gtk_accel_group_activate_, {accel_group_,accel_key_,accel_mods_} )
end function

----------------------------------------
-- gtk_accel_groups_activate
----------------------------------------
constant gtk_accel_groups_activate_ = link_c_func( GTK, 
  "gtk_accel_groups_activate", {C_POINTER,C_UINT,C_POINTER}, C_INT )

global function gtk_accel_groups_activate(atom object_, integer accel_key_, atom accel_mods_)
    return c_func( gtk_accel_groups_activate_, {object_,accel_key_,accel_mods_} )
end function

----------------------------------------
-- gtk_accel_group_attach
----------------------------------------
constant gtk_accel_group_attach_ = link_c_proc( GTK, 
  "gtk_accel_group_attach", {C_POINTER,C_POINTER} )

global procedure gtk_accel_group_attach(atom accel_group_, atom object_)
    c_proc( gtk_accel_group_attach_, {accel_group_,object_} )
end procedure

----------------------------------------
-- gtk_accel_group_detach
----------------------------------------
constant gtk_accel_group_detach_ = link_c_proc( GTK, 
  "gtk_accel_group_detach", {C_POINTER,C_POINTER} )

global procedure gtk_accel_group_detach(atom accel_group_, atom object_)
    c_proc( gtk_accel_group_detach_, {accel_group_,object_} )
end procedure

----------------------------------------
-- gtk_accel_group_lock
----------------------------------------
constant gtk_accel_group_lock_ = link_c_proc( GTK, 
  "gtk_accel_group_lock", {C_POINTER} )

global procedure gtk_accel_group_lock(atom accel_group_)
    c_proc( gtk_accel_group_lock_, {accel_group_} )
end procedure

----------------------------------------
-- gtk_accel_group_unlock
----------------------------------------
constant gtk_accel_group_unlock_ = link_c_proc( GTK, 
  "gtk_accel_group_unlock", {C_POINTER} )

global procedure gtk_accel_group_unlock(atom accel_group_)
    c_proc( gtk_accel_group_unlock_, {accel_group_} )
end procedure

----------------------------------------
-- gtk_accel_group_get_entry
----------------------------------------
constant gtk_accel_group_get_entry_ = link_c_func( GTK, 
  "gtk_accel_group_get_entry", {C_POINTER,C_UINT,C_POINTER}, C_POINTER )

global function gtk_accel_group_get_entry(atom accel_group_, integer accel_key_, atom accel_mods_)
    return c_func( gtk_accel_group_get_entry_, {accel_group_,accel_key_,accel_mods_} )
end function

----------------------------------------
-- gtk_accel_group_lock_entry
----------------------------------------
constant gtk_accel_group_lock_entry_ = link_c_proc( GTK, 
  "gtk_accel_group_lock_entry", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_accel_group_lock_entry(atom accel_group_, integer accel_key_, atom accel_mods_)
    c_proc( gtk_accel_group_lock_entry_, {accel_group_,accel_key_,accel_mods_} )
end procedure

----------------------------------------
-- gtk_accel_group_unlock_entry
----------------------------------------
constant gtk_accel_group_unlock_entry_ = link_c_proc( GTK, 
  "gtk_accel_group_unlock_entry", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_accel_group_unlock_entry(atom accel_group_, integer accel_key_, atom accel_mods_)
    c_proc( gtk_accel_group_unlock_entry_, {accel_group_,accel_key_,accel_mods_} )
end procedure

----------------------------------------
-- gtk_accel_group_add
----------------------------------------
constant gtk_accel_group_add_ = link_c_proc( GTK, 
  "gtk_accel_group_add", {C_POINTER,C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_accel_group_add(atom accel_group_, integer accel_key_, atom accel_mods_, atom accel_flags_, 
 atom object_, sequence accel_signal_)
    atom string1
    string1 = allocate_string( accel_signal_ )
    c_proc( gtk_accel_group_add_, {accel_group_,accel_key_,accel_mods_,accel_flags_,object_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_accel_group_remove
----------------------------------------
constant gtk_accel_group_remove_ = link_c_proc( GTK, 
  "gtk_accel_group_remove", {C_POINTER,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_accel_group_remove(atom accel_group_, integer accel_key_, atom accel_mods_, atom object_)
    c_proc( gtk_accel_group_remove_, {accel_group_,accel_key_,accel_mods_,object_} )
end procedure

----------------------------------------
-- gtk_accel_group_handle_add
----------------------------------------
constant gtk_accel_group_handle_add_ = link_c_proc( GTK, 
  "gtk_accel_group_handle_add", {C_POINTER,C_UINT,C_POINTER,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_accel_group_handle_add(atom object_, integer accel_signal_id_, atom accel_group_, integer 
 accel_key_, atom accel_mods_, atom accel_flags_)
    c_proc( gtk_accel_group_handle_add_, {object_,accel_signal_id_,accel_group_,accel_key_,accel_mods_,accel_flags_} )
end procedure

----------------------------------------
-- gtk_accel_group_handle_remove
----------------------------------------
constant gtk_accel_group_handle_remove_ = link_c_proc( GTK, 
  "gtk_accel_group_handle_remove", {C_POINTER,C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_accel_group_handle_remove(atom object_, atom accel_group_, integer accel_key_, atom accel_mods_)
    c_proc( gtk_accel_group_handle_remove_, {object_,accel_group_,accel_key_,accel_mods_} )
end procedure

----------------------------------------
-- gtk_accel_group_create_add
----------------------------------------
constant gtk_accel_group_create_add_ = link_c_func( GTK, 
  "gtk_accel_group_create_add", {C_UINT,C_POINTER,C_UINT}, C_UINT )

global function gtk_accel_group_create_add(integer class_type_, atom signal_flags_, integer handler_offset_)
    return c_func( gtk_accel_group_create_add_, {class_type_,signal_flags_,handler_offset_} )
end function

----------------------------------------
-- gtk_accel_group_create_remove
----------------------------------------
constant gtk_accel_group_create_remove_ = link_c_func( GTK, 
  "gtk_accel_group_create_remove", {C_UINT,C_POINTER,C_UINT}, C_UINT )

global function gtk_accel_group_create_remove(integer class_type_, atom signal_flags_, integer handler_offset_)
    return c_func( gtk_accel_group_create_remove_, {class_type_,signal_flags_,handler_offset_} )
end function

----------------------------------------
-- gtk_accel_group_marshal_add
----------------------------------------
constant gtk_accel_group_marshal_add_ = link_c_proc( GTK, 
  "gtk_accel_group_marshal_add", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_accel_group_marshal_add(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_accel_group_marshal_add_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_accel_group_marshal_remove
----------------------------------------
constant gtk_accel_group_marshal_remove_ = link_c_proc( GTK, 
  "gtk_accel_group_marshal_remove", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_accel_group_marshal_remove(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_accel_group_marshal_remove_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_accel_groups_from_object
----------------------------------------
constant gtk_accel_groups_from_object_ = link_c_func( GTK, 
  "gtk_accel_groups_from_object", {C_POINTER}, C_POINTER )

global function gtk_accel_groups_from_object(atom object_)
    return c_func( gtk_accel_groups_from_object_, {object_} )
end function

----------------------------------------
-- gtk_accel_group_entries_from_object
----------------------------------------
constant gtk_accel_group_entries_from_object_ = link_c_func( GTK, 
  "gtk_accel_group_entries_from_object", {C_POINTER}, C_POINTER )

global function gtk_accel_group_entries_from_object(atom object_)
    return c_func( gtk_accel_group_entries_from_object_, {object_} )
end function

----------------------------------------
-- gtk_accelerator_valid
----------------------------------------
constant gtk_accelerator_valid_ = link_c_func( GTK, 
  "gtk_accelerator_valid", {C_UINT,C_POINTER}, C_INT )

global function gtk_accelerator_valid(integer keyval_, atom modifiers_)
    return c_func( gtk_accelerator_valid_, {keyval_,modifiers_} )
end function

----------------------------------------
-- gtk_accelerator_parse
----------------------------------------
constant gtk_accelerator_parse_ = link_c_proc( GTK, 
  "gtk_accelerator_parse", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_accelerator_parse(sequence const_, integer accelerator_key_, atom accelerator_mods_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_accelerator_parse_, {string1,accelerator_key_,accelerator_mods_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_accelerator_name
----------------------------------------
constant gtk_accelerator_name_ = link_c_func( GTK, 
  "gtk_accelerator_name", {C_UINT,C_POINTER}, C_POINTER )

global function gtk_accelerator_name(integer accelerator_key_, atom accelerator_mods_)
    return peek_string( c_func( gtk_accelerator_name_, {accelerator_key_,accelerator_mods_} ) )
end function

----------------------------------------
-- gtk_accelerator_set_default_mod_mask
----------------------------------------
constant gtk_accelerator_set_default_mod_mask_ = link_c_proc( GTK, 
  "gtk_accelerator_set_default_mod_mask", {C_POINTER} )

global procedure gtk_accelerator_set_default_mod_mask(atom default_mod_mask_)
    c_proc( gtk_accelerator_set_default_mod_mask_, {default_mod_mask_} )
end procedure

----------------------------------------
-- gtk_accelerator_get_default_mod_mask
----------------------------------------
constant gtk_accelerator_get_default_mod_mask_ = link_c_func( GTK, 
  "gtk_accelerator_get_default_mod_mask", {}, C_UINT )

global function gtk_accelerator_get_default_mod_mask()
    return c_func( gtk_accelerator_get_default_mod_mask_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKOBJECT.H
----------------------------------------
----------------------------------------


global constant
    GTK_DESTROYED                       = power(2,0),
    GTK_FLOATING                        = power(2,1),
    GTK_CONNECTED                       = power(2,2),
    GTK_CONSTRUCTED                     = power(2,3)
global constant SIZEOF_GtkObjectFlags = SIZEOF_ENUM

global constant
    GTK_ARG_READABLE                    = power(2,0),
    GTK_ARG_WRITABLE                    = power(2,1),
    GTK_ARG_CONSTRUCT                   = power(2,2),
    GTK_ARG_CONSTRUCT_ONLY              = power(2,3),
    GTK_ARG_CHILD_ARG                   = power(2,4),
    GTK_ARG_MASK                        = #1F,
    GTK_ARG_READWRITE                   = GTK_ARG_READABLE
global constant SIZEOF_GtkArgFlags = SIZEOF_ENUM


----------------------------------------
-- GtkObject
----------------------------------------
global constant
    GtkObject_klass                     = allot(TYPE_POINTER),
    GtkObject_flags                     = allot(TYPE_GUINT32),
    GtkObject_ref_count                 = allot(TYPE_GUINT),
    GtkObject_object_data               = allot(TYPE_POINTER),
    SIZEOF_GtkObject                    = allotted_size()

----------------------------------------
-- GtkObjectClass
----------------------------------------
-- manually corrected
-- set_arg and get_arg are set to pointers
global constant
    GtkObjectClass_type                 = allot(TYPE_GUINT),
    GtkObjectClass_signals              = allot(TYPE_POINTER),
    GtkObjectClass_nsignals             = allot(TYPE_UINT),
    GtkObjectClass_n_args               = allot(TYPE_UINT),
    GtkObjectClass_contstruct_args      = allot(TYPE_POINTER),  -- function
    GtkObjectClass_set_arg              = allot(TYPE_POINTER),  -- pointers...
    GtkObjectClass_get_arg              = allot(TYPE_POINTER),
    GtkObjectClass_shutdown             = allot(TYPE_POINTER),
    GtkObjectClass_destroy              = allot(TYPE_POINTER),
    GtkObjectClass_finalize             = allot(TYPE_POINTER),
    SIZEOF_GtkObjectClass               = allotted_size()
    
----------------------------------------
-- gtk_object_get_type
----------------------------------------
constant gtk_object_get_type_ = link_c_func( GTK, 
  "gtk_object_get_type", {}, C_UINT )

global function gtk_object_get_type()
    return c_func( gtk_object_get_type_, {} )
end function

----------------------------------------
-- gtk_object_class_user_signal_new
----------------------------------------
constant gtk_object_class_user_signal_new_ = link_c_func( GTK, 
  "gtk_object_class_user_signal_new", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_UINT,C_UINT}, 
 C_UINT )

global function gtk_object_class_user_signal_new(atom klass_, sequence name_, atom signal_flags_, atom marshaller_, 
 integer return_val_, integer nparams_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_object_class_user_signal_new_, {klass_,string1,signal_flags_,marshaller_,return_val_,nparams_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_object_class_user_signal_newv
----------------------------------------
constant gtk_object_class_user_signal_newv_ = link_c_func( GTK, 
  "gtk_object_class_user_signal_newv", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_UINT,C_UINT,C_UINT}, 
 C_UINT )

global function gtk_object_class_user_signal_newv(atom klass_, sequence name_, atom signal_flags_, atom marshaller_, 
 integer return_val_, integer nparams_, integer params_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_object_class_user_signal_newv_, {klass_,string1,signal_flags_,marshaller_,return_val_,nparams_,params_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_object_new
----------------------------------------
constant gtk_object_new_ = link_c_func( GTK, 
  "gtk_object_new", {C_UINT,C_POINTER}, C_POINTER )

global function gtk_object_new(integer type_, sequence first_arg_name_)
    atom result
    atom string1
    string1 = allocate_string( first_arg_name_ )
    result = c_func( gtk_object_new_, {type_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_object_newv
----------------------------------------
constant gtk_object_newv_ = link_c_func( GTK, 
  "gtk_object_newv", {C_UINT,C_UINT,C_POINTER}, C_POINTER )

global function gtk_object_newv(integer object_type_, integer n_args_, atom args_)
    return c_func( gtk_object_newv_, {object_type_,n_args_,args_} )
end function

----------------------------------------
-- gtk_object_default_construct
----------------------------------------
constant gtk_object_default_construct_ = link_c_proc( GTK, 
  "gtk_object_default_construct", {C_POINTER} )

global procedure gtk_object_default_construct(atom object_)
    c_proc( gtk_object_default_construct_, {object_} )
end procedure

----------------------------------------
-- gtk_object_constructed
----------------------------------------
constant gtk_object_constructed_ = link_c_proc( GTK, 
  "gtk_object_constructed", {C_POINTER} )

global procedure gtk_object_constructed(atom object_)
    c_proc( gtk_object_constructed_, {object_} )
end procedure

----------------------------------------
-- gtk_object_sink
----------------------------------------
constant gtk_object_sink_ = link_c_proc( GTK, 
  "gtk_object_sink", {C_POINTER} )

global procedure gtk_object_sink(atom object_)
    c_proc( gtk_object_sink_, {object_} )
end procedure

----------------------------------------
-- gtk_object_ref
----------------------------------------
constant gtk_object_ref_ = link_c_proc( GTK, 
  "gtk_object_ref", {C_POINTER} )

global procedure gtk_object_ref(atom object_)
    c_proc( gtk_object_ref_, {object_} )
end procedure

----------------------------------------
-- gtk_object_unref
----------------------------------------
constant gtk_object_unref_ = link_c_proc( GTK, 
  "gtk_object_unref", {C_POINTER} )

global procedure gtk_object_unref(atom object_)
    c_proc( gtk_object_unref_, {object_} )
end procedure

----------------------------------------
-- gtk_object_weakref
----------------------------------------
constant gtk_object_weakref_ = link_c_proc( GTK, 
  "gtk_object_weakref", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_weakref(atom object_, atom notify_, atom data_)
    c_proc( gtk_object_weakref_, {object_,notify_,data_} )
end procedure

----------------------------------------
-- gtk_object_weakunref
----------------------------------------
constant gtk_object_weakunref_ = link_c_proc( GTK, 
  "gtk_object_weakunref", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_weakunref(atom object_, atom notify_, atom data_)
    c_proc( gtk_object_weakunref_, {object_,notify_,data_} )
end procedure

----------------------------------------
-- gtk_object_destroy
----------------------------------------
constant gtk_object_destroy_ = link_c_proc( GTK, 
  "gtk_object_destroy", {C_POINTER} )

global procedure gtk_object_destroy(atom object_)
    c_proc( gtk_object_destroy_, {object_} )
end procedure

----------------------------------------
-- gtk_object_getv
----------------------------------------
constant gtk_object_getv_ = link_c_proc( GTK, 
  "gtk_object_getv", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_object_getv(atom object_, integer n_args_, atom args_)
    c_proc( gtk_object_getv_, {object_,n_args_,args_} )
end procedure

----------------------------------------
-- gtk_object_set
----------------------------------------
constant gtk_object_set_ = link_c_proc( GTK, 
  "gtk_object_set", {C_POINTER,C_POINTER} )

global procedure gtk_object_set(atom object_, sequence first_arg_name_)
    atom string1
    string1 = allocate_string( first_arg_name_ )
    c_proc( gtk_object_set_, {object_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_object_setv
----------------------------------------
constant gtk_object_setv_ = link_c_proc( GTK, 
  "gtk_object_setv", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_object_setv(atom object_, integer n_args_, atom args_)
    c_proc( gtk_object_setv_, {object_,n_args_,args_} )
end procedure

----------------------------------------
-- gtk_object_query_args
----------------------------------------
constant gtk_object_query_args_ = link_c_func( GTK, 
  "gtk_object_query_args", {C_UINT,C_UINT,C_UINT}, C_POINTER )

global function gtk_object_query_args(integer class_type_, atom arg_flags_, integer n_args_)
    return c_func( gtk_object_query_args_, {class_type_,arg_flags_,n_args_} )
end function

----------------------------------------
-- gtk_object_set_data
----------------------------------------
constant gtk_object_set_data_ = link_c_proc( GTK, 
  "gtk_object_set_data", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_set_data(atom object_, sequence key_, atom data_)
    atom string1
    string1 = allocate_string( key_ )
    c_proc( gtk_object_set_data_, {object_,string1,data_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_object_set_data_full
----------------------------------------
constant gtk_object_set_data_full_ = link_c_proc( GTK, 
  "gtk_object_set_data_full", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_set_data_full(atom object_, sequence key_, atom data_, atom destroy_)
    atom string1
    string1 = allocate_string( key_ )
    c_proc( gtk_object_set_data_full_, {object_,string1,data_,destroy_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_object_remove_data
----------------------------------------
constant gtk_object_remove_data_ = link_c_proc( GTK, 
  "gtk_object_remove_data", {C_POINTER,C_POINTER} )

global procedure gtk_object_remove_data(atom object_, sequence key_)
    atom string1
    string1 = allocate_string( key_ )
    c_proc( gtk_object_remove_data_, {object_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_object_get_data
----------------------------------------
constant gtk_object_get_data_ = link_c_func( GTK, 
  "gtk_object_get_data", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_object_get_data(atom object_, sequence key_)
    atom result
    atom string1
    string1 = allocate_string( key_ )
    result = c_func( gtk_object_get_data_, {object_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_object_remove_no_notify
----------------------------------------
constant gtk_object_remove_no_notify_ = link_c_proc( GTK, 
  "gtk_object_remove_no_notify", {C_POINTER,C_POINTER} )

global procedure gtk_object_remove_no_notify(atom object_, sequence key_)
    atom string1
    string1 = allocate_string( key_ )
    c_proc( gtk_object_remove_no_notify_, {object_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_object_set_user_data
----------------------------------------
constant gtk_object_set_user_data_ = link_c_proc( GTK, 
  "gtk_object_set_user_data", {C_POINTER,C_POINTER} )

global procedure gtk_object_set_user_data(atom object_, atom data_)
    c_proc( gtk_object_set_user_data_, {object_,data_} )
end procedure

----------------------------------------
-- gtk_object_get_user_data
----------------------------------------
constant gtk_object_get_user_data_ = link_c_func( GTK, 
  "gtk_object_get_user_data", {C_POINTER}, C_POINTER )

global function gtk_object_get_user_data(atom object_)
    return c_func( gtk_object_get_user_data_, {object_} )
end function

----------------------------------------
-- gtk_object_class_add_signals
----------------------------------------
constant gtk_object_class_add_signals_ = link_c_proc( GTK, 
  "gtk_object_class_add_signals", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_object_class_add_signals(atom klass_, integer signals_, integer nsignals_)
    c_proc( gtk_object_class_add_signals_, {klass_,signals_,nsignals_} )
end procedure

----------------------------------------
-- gtk_object_add_arg_type
----------------------------------------
constant gtk_object_add_arg_type_ = link_c_proc( GTK, 
  "gtk_object_add_arg_type", {C_POINTER,C_UINT,C_UINT,C_UINT} )

global procedure gtk_object_add_arg_type(sequence const_, integer arg_type_, integer arg_flags_, integer arg_id_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_object_add_arg_type_, {string1,arg_type_,arg_flags_,arg_id_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_object_set_data_by_id
----------------------------------------
constant gtk_object_set_data_by_id_ = link_c_proc( GTK, 
  "gtk_object_set_data_by_id", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_set_data_by_id(atom object_, atom data_id_, atom data_)
    c_proc( gtk_object_set_data_by_id_, {object_,data_id_,data_} )
end procedure

----------------------------------------
-- gtk_object_set_data_by_id_full
----------------------------------------
constant gtk_object_set_data_by_id_full_ = link_c_proc( GTK, 
  "gtk_object_set_data_by_id_full", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_set_data_by_id_full(atom object_, atom data_id_, atom data_, atom destroy_)
    c_proc( gtk_object_set_data_by_id_full_, {object_,data_id_,data_,destroy_} )
end procedure

----------------------------------------
-- gtk_object_get_data_by_id
----------------------------------------
constant gtk_object_get_data_by_id_ = link_c_func( GTK, 
  "gtk_object_get_data_by_id", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_object_get_data_by_id(atom object_, atom data_id_)
    return c_func( gtk_object_get_data_by_id_, {object_,data_id_} )
end function

----------------------------------------
-- gtk_object_remove_data_by_id
----------------------------------------
constant gtk_object_remove_data_by_id_ = link_c_proc( GTK, 
  "gtk_object_remove_data_by_id", {C_POINTER,C_POINTER} )

global procedure gtk_object_remove_data_by_id(atom object_, atom data_id_)
    c_proc( gtk_object_remove_data_by_id_, {object_,data_id_} )
end procedure

----------------------------------------
-- gtk_object_remove_no_notify_by_id
----------------------------------------
constant gtk_object_remove_no_notify_by_id_ = link_c_proc( GTK, 
  "gtk_object_remove_no_notify_by_id", {C_POINTER,C_POINTER} )

global procedure gtk_object_remove_no_notify_by_id(atom object_, atom key_id_)
    c_proc( gtk_object_remove_no_notify_by_id_, {object_,key_id_} )
end procedure

----------------------------------------
-- gtk_object_arg_set
----------------------------------------
constant gtk_object_arg_set_ = link_c_proc( GTK, 
  "gtk_object_arg_set", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_arg_set(atom object_, atom arg_, atom info_)
    c_proc( gtk_object_arg_set_, {object_,arg_,info_} )
end procedure

----------------------------------------
-- gtk_object_arg_get
----------------------------------------
constant gtk_object_arg_get_ = link_c_proc( GTK, 
  "gtk_object_arg_get", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_object_arg_get(atom object_, atom arg_, atom info_)
    c_proc( gtk_object_arg_get_, {object_,arg_,info_} )
end procedure

----------------------------------------
-- gtk_object_args_collect
----------------------------------------
constant gtk_object_args_collect_ = link_c_func( GTK, 
  "gtk_object_args_collect", {C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_object_args_collect(integer object_type_, atom arg_list_p_, atom info_list_p_, sequence first_arg_name_, atom var_args_)
    atom result
    atom string1
    string1 = allocate_string( first_arg_name_ )
    result = c_func( gtk_object_args_collect_, {object_type_,arg_list_p_,info_list_p_,string1,var_args_} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_object_arg_get_info
----------------------------------------
constant gtk_object_arg_get_info_ = link_c_func( GTK, 
  "gtk_object_arg_get_info", {C_UINT,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_object_arg_get_info(integer object_type_, sequence arg_name_, atom info_p_)
    atom result
    atom string1
    string1 = allocate_string( arg_name_ )
    result = c_func( gtk_object_arg_get_info_, {object_type_,string1,info_p_} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_trace_referencing
----------------------------------------
constant gtk_trace_referencing_ = link_c_proc( GTK, 
  "gtk_trace_referencing", {C_POINTER,C_POINTER,C_UINT,C_UINT,C_INT} )

global procedure gtk_trace_referencing(atom object_, sequence func_, integer dummy_, integer line_, integer do_ref_)
    atom string1
    string1 = allocate_string( func_ )
    c_proc( gtk_trace_referencing_, {object_,string1,dummy_,line_,do_ref_} )
    free( string1 )
end procedure



----------------------------------------
----------------------------------------
-- GTKARG.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkArgInfo
----------------------------------------
global constant
    GtkArgInfo_class_type               = allot(TYPE_GUINT),
    GtkArgInfo_name                     = allot(TYPE_POINTER),
    GtkArgInfo_type                     = allot(TYPE_GUINT),
    GtkArgInfo_arg_flags                = allot(TYPE_GUINT),
    GtkArgInfo_full_name                = allot(TYPE_POINTER),
    GtkArgInfo_arg_id                   = allot(TYPE_GUINT),
    GtkArgInfo_seq_id                   = allot(TYPE_GUINT),
    SIZEOF_GtkArgInfo                   = allotted_size()
----------------------------------------
-- gtk_arg_new
----------------------------------------
constant gtk_arg_new_ = link_c_func( GTK, 
  "gtk_arg_new", {C_UINT}, C_POINTER )

global function gtk_arg_new(integer arg_type_)
    return c_func( gtk_arg_new_, {arg_type_} )
end function

----------------------------------------
-- gtk_arg_copy
----------------------------------------
constant gtk_arg_copy_ = link_c_func( GTK, 
  "gtk_arg_copy", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_arg_copy(atom src_arg_, atom dest_arg_)
    return c_func( gtk_arg_copy_, {src_arg_,dest_arg_} )
end function

----------------------------------------
-- gtk_arg_free
----------------------------------------
constant gtk_arg_free_ = link_c_proc( GTK, 
  "gtk_arg_free", {C_POINTER,C_INT} )

global procedure gtk_arg_free(atom arg_, integer free_contents_)
    c_proc( gtk_arg_free_, {arg_,free_contents_} )
end procedure

----------------------------------------
-- gtk_args_collect
----------------------------------------
constant gtk_args_collect_ = link_c_func( GTK, 
  "gtk_args_collect", {C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_args_collect(integer object_type_, atom arg_info_hash_table_, atom arg_list_p_, atom info_list_p_, 
 sequence first_arg_name_, atom var_args_)
    atom result
    atom string1
    string1 = allocate_string( first_arg_name_ )
    result = c_func( gtk_args_collect_, {object_type_,arg_info_hash_table_,arg_list_p_,info_list_p_,string1,var_args_} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_args_collect_cleanup
----------------------------------------
constant gtk_args_collect_cleanup_ = link_c_proc( GTK, 
  "gtk_args_collect_cleanup", {C_POINTER,C_POINTER} )

global procedure gtk_args_collect_cleanup(atom arg_list_, atom info_list_)
    c_proc( gtk_args_collect_cleanup_, {arg_list_,info_list_} )
end procedure

----------------------------------------
-- gtk_arg_get_info
----------------------------------------
constant gtk_arg_get_info_ = link_c_func( GTK, 
  "gtk_arg_get_info", {C_UINT,C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_arg_get_info(integer object_type_, atom arg_info_hash_table_, sequence arg_name_, atom info_p_)
    atom result
    atom string1
    string1 = allocate_string( arg_name_ )
    result = c_func( gtk_arg_get_info_, {object_type_,arg_info_hash_table_,string1,info_p_} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_arg_type_new_static
----------------------------------------
constant gtk_arg_type_new_static_ = link_c_func( GTK, 
  "gtk_arg_type_new_static", {C_UINT,C_POINTER,C_UINT,C_POINTER,C_UINT,C_UINT,C_UINT}, 
 C_POINTER )

global function gtk_arg_type_new_static(integer base_class_type_, sequence arg_name_, integer class_n_args_offset_, 
 atom arg_info_hash_table_, integer arg_type_, integer arg_flags_, integer arg_id_)
    atom result
    atom string1
    string1 = allocate_string( arg_name_ )
    result = c_func( gtk_arg_type_new_static_, {base_class_type_,string1,class_n_args_offset_,arg_info_hash_table_,arg_type_,arg_flags_,arg_id_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_args_query
----------------------------------------
constant gtk_args_query_ = link_c_func( GTK, 
  "gtk_args_query", {C_UINT,C_POINTER,C_UINT,C_UINT}, C_POINTER )

global function gtk_args_query(integer class_type_, atom arg_info_hash_table_, atom arg_flags_, integer n_args_p_)
    return c_func( gtk_args_query_, {class_type_,arg_info_hash_table_,arg_flags_,n_args_p_} )
end function

----------------------------------------
-- gtk_arg_name_strip_type
----------------------------------------
constant gtk_arg_name_strip_type_ = link_c_func( GTK, 
  "gtk_arg_name_strip_type", {C_POINTER}, C_POINTER )

global function gtk_arg_name_strip_type(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_arg_name_strip_type_, {string1} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_arg_info_equal
----------------------------------------
constant gtk_arg_info_equal_ = link_c_func( GTK, 
  "gtk_arg_info_equal", {C_POINTER,C_POINTER}, C_INT )

global function gtk_arg_info_equal(atom arg_info_1_, atom arg_info_2_)
    return c_func( gtk_arg_info_equal_, {arg_info_1_,arg_info_2_} )
end function

----------------------------------------
-- gtk_arg_info_hash
----------------------------------------
constant gtk_arg_info_hash_ = link_c_func( GTK, 
  "gtk_arg_info_hash", {C_POINTER}, C_UINT )

global function gtk_arg_info_hash(atom arg_info_)
    return c_func( gtk_arg_info_hash_, {arg_info_} )
end function



----------------------------------------
----------------------------------------
-- GTKTYPEUTILS.H
----------------------------------------
----------------------------------------


global constant
    GTK_TYPE_INVALID                    = 1,
    GTK_TYPE_NONE                       = 2,
    GTK_TYPE_CHAR                       = 3,
    GTK_TYPE_UCHAR                      = 4,
    GTK_TYPE_BOOL                       = 5,
    GTK_TYPE_INT                        = 6,
    GTK_TYPE_UINT                       = 7,
    GTK_TYPE_LONG                       = 8,
    GTK_TYPE_ULONG                      = 9,
    GTK_TYPE_FLOAT                      = 10,
    GTK_TYPE_DOUBLE                     = 11,
    GTK_TYPE_STRING                     = 12,
    GTK_TYPE_ENUM                       = 13,
    GTK_TYPE_FLAGS                      = 14,
    GTK_TYPE_BOXED                      = 15,
    GTK_TYPE_POINTER                    = 16,
    GTK_TYPE_SIGNAL                     = 17,
    GTK_TYPE_ARGS                       = 18,
    GTK_TYPE_CALLBACK                   = 19,
    GTK_TYPE_C_CALLBACK                 = 20,
    GTK_TYPE_FOREIGN                    = 21,
    GTK_TYPE_OBJECT                     = 22
global constant SIZEOF_GtkFundamentalType = SIZEOF_ENUM

global constant GTK_TYPE_FLAT_FIRST = GTK_TYPE_CHAR
global constant GTK_TYPE_FLAT_LAST = GTK_TYPE_POINTER
global constant GTK_TYPE_STRUCTURED_FIRST = GTK_TYPE_SIGNAL
global constant GTK_TYPE_STRUCTURED_LAST = GTK_TYPE_FOREIGN
global constant GTK_TYPE_FUNDAMENTAL_LAST = GTK_TYPE_OBJECT
----------------------------------------
-- gtk_identifier_get_type
----------------------------------------
constant gtk_identifier_get_type_ = link_c_func( GTK, 
  "gtk_identifier_get_type", {}, C_UINT )

global function gtk_identifier_get_type()
    return c_func( gtk_identifier_get_type_, {} )
end function

----------------------------------------
-- GtkClassInitFunc
----------------------------------------
constant GtkClassInitFunc_ = link_c_proc( GTK, 
  "GtkClassInitFunc", {C_POINTER} )

global procedure GtkClassInitFunc(atom klass_)
    c_proc( GtkClassInitFunc_, {klass_} )
end procedure

----------------------------------------
-- GtkObjectInitFunc
----------------------------------------
constant GtkObjectInitFunc_ = link_c_proc( GTK, 
  "GtkObjectInitFunc", {C_POINTER,C_POINTER} )

global procedure GtkObjectInitFunc(atom object_, atom klass_)
    c_proc( GtkObjectInitFunc_, {object_,klass_} )
end procedure

----------------------------------------
-- GtkSignalFunc
----------------------------------------
constant GtkSignalFunc_ = link_c_proc( GTK, 
  "GtkSignalFunc", {C_POINTER} )

global procedure GtkSignalFunc(atom void_)
    c_proc( GtkSignalFunc_, {void_} )
end procedure

----------------------------------------
-- GtkFunction
----------------------------------------
constant GtkFunction_ = link_c_func( GTK, 
  "GtkFunction", {C_POINTER}, C_INT )

global function GtkFunction(atom data_)
    return c_func( GtkFunction_, {data_} )
end function

----------------------------------------
-- GtkDestroyNotify
----------------------------------------
constant GtkDestroyNotify_ = link_c_proc( GTK, 
  "GtkDestroyNotify", {C_POINTER} )

global procedure GtkDestroyNotify(atom data_)
    c_proc( GtkDestroyNotify_, {data_} )
end procedure

----------------------------------------
-- GtkCallbackMarshal
----------------------------------------
constant GtkCallbackMarshal_ = link_c_proc( GTK, 
  "GtkCallbackMarshal", {C_POINTER,C_POINTER,C_UINT,C_POINTER} )

global procedure GtkCallbackMarshal(atom object_, atom data_, integer n_args_, atom args_)
    c_proc( GtkCallbackMarshal_, {object_,data_,n_args_,args_} )
end procedure

----------------------------------------
-- GtkSignalMarshaller
----------------------------------------
constant GtkSignalMarshaller_ = link_c_proc( GTK, 
  "GtkSignalMarshaller", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure GtkSignalMarshaller(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( GtkSignalMarshaller_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- GtkTypeObject
----------------------------------------
global constant
    GtkTypeObject_klass                 = allot(TYPE_POINTER),
    SIZEOF_GtkTypeObject                = allotted_size()

----------------------------------------
-- GtkTypeClass
----------------------------------------
global constant
    GtkTypeClass_type                   = allot(TYPE_GUINT),
    SIZEOF_GtkTypeClass                 = allotted_size()

----------------------------------------
-- GtkArg
----------------------------------------
global constant
    GtkArg_type                         = allot(TYPE_GUINT),
    GtkArg_name                         = allot(TYPE_POINTER),
    GtkArg_d                            = allot(TYPE_LONG), -- union,
    SIZEOF_GtkArg                       = allotted_size()

----------------------------------------
-- GtkTypeInfo
----------------------------------------
-- manually corrected
-- the func's have been set to pointers
global constant
    GtkTypeInfo_type_name               = allot(TYPE_POINTER),
    GtkTypeInfo_object_size             = allot(TYPE_UINT),
    GtkTypeInfo_class_size              = allot(TYPE_UINT),
    GtkTypeInfo_class_init_func         = allot(TYPE_POINTER),
    GtkTypeInfo_object_init_func        = allot(TYPE_POINTER),
    GtkTypeInfo_reserved_1              = allot(TYPE_POINTER),
    GtkTypeInfo_reserved_2              = allot(TYPE_POINTER),
    GtkTypeInfo_base_class_init_func    = allot(TYPE_POINTER),
    SIZEOF_GtkTypeInfo                  = allotted_size()

----------------------------------------
-- GtkTypeQuery
----------------------------------------
global constant
    GtkTypeQuery_type                   = allot(TYPE_GUINT),
    GtkTypeQuery_type_name              = allot(TYPE_POINTER),
    GtkTypeQuery_object_size            = allot(TYPE_GUINT),
    GtkTypeQuery_class_size             = allot(TYPE_GUINT),
    SIZEOF_GtkTypeQuery                 = allotted_size()

----------------------------------------
-- GtkEnumValue
----------------------------------------
global constant
    GtkEnumValue_value                  = allot(TYPE_GUINT),
    GtkEnumValue_value_name             = allot(TYPE_POINTER),
    GtkEnumValue_value_nick             = allot(TYPE_POINTER),
    SIZEOF_GtkEnumValue                 = allotted_size()
----------------------------------------
-- gtk_type_init
----------------------------------------
constant gtk_type_init_ = link_c_proc( GTK, 
  "gtk_type_init", {} )

global procedure gtk_type_init()
    c_proc( gtk_type_init_, {} )
end procedure

----------------------------------------
-- gtk_type_unique
----------------------------------------
constant gtk_type_unique_ = link_c_func( GTK, 
  "gtk_type_unique", {C_UINT,C_POINTER}, C_UINT )

global function gtk_type_unique(integer parent_type_, atom type_info_)
    return c_func( gtk_type_unique_, {parent_type_,type_info_} )
end function

----------------------------------------
-- gtk_type_set_chunk_alloc
----------------------------------------
constant gtk_type_set_chunk_alloc_ = link_c_proc( GTK, 
  "gtk_type_set_chunk_alloc", {C_UINT,C_UINT} )

global procedure gtk_type_set_chunk_alloc(integer type_, integer n_chunks_)
    c_proc( gtk_type_set_chunk_alloc_, {type_,n_chunks_} )
end procedure

----------------------------------------
-- gtk_type_name
----------------------------------------
constant gtk_type_name_ = link_c_func( GTK, 
  "gtk_type_name", {C_UINT}, C_POINTER )

global function gtk_type_name(integer type_)
    return peek_string( c_func( gtk_type_name_, {type_} ) )
end function

----------------------------------------
-- gtk_type_from_name
----------------------------------------
constant gtk_type_from_name_ = link_c_func( GTK, 
  "gtk_type_from_name", {C_POINTER}, C_UINT )

global function gtk_type_from_name(sequence const_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_type_from_name_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_type_parent
----------------------------------------
constant gtk_type_parent_ = link_c_func( GTK, 
  "gtk_type_parent", {C_UINT}, C_UINT )

global function gtk_type_parent(integer type_)
    return c_func( gtk_type_parent_, {type_} )
end function

----------------------------------------
-- gtk_type_class
----------------------------------------
constant gtk_type_class_ = link_c_func( GTK, 
  "gtk_type_class", {C_UINT}, C_POINTER )

global function gtk_type_class(integer type_)
    return c_func( gtk_type_class_, {type_} )
end function

----------------------------------------
-- gtk_type_parent_class
----------------------------------------
constant gtk_type_parent_class_ = link_c_func( GTK, 
  "gtk_type_parent_class", {C_UINT}, C_POINTER )

global function gtk_type_parent_class(integer type_)
    return c_func( gtk_type_parent_class_, {type_} )
end function

----------------------------------------
-- gtk_type_children_types
----------------------------------------
constant gtk_type_children_types_ = link_c_func( GTK, 
  "gtk_type_children_types", {C_UINT}, C_POINTER )

global function gtk_type_children_types(integer type_)
    return c_func( gtk_type_children_types_, {type_} )
end function

----------------------------------------
-- gtk_type_new
----------------------------------------
constant gtk_type_new_ = link_c_func( GTK, 
  "gtk_type_new", {C_UINT}, C_POINTER )

global function gtk_type_new(integer type_)
    return c_func( gtk_type_new_, {type_} )
end function

----------------------------------------
-- gtk_type_free
----------------------------------------
constant gtk_type_free_ = link_c_proc( GTK, 
  "gtk_type_free", {C_UINT,C_POINTER} )

global procedure gtk_type_free(integer type_, atom mem_)
    c_proc( gtk_type_free_, {type_,mem_} )
end procedure

----------------------------------------
-- gtk_type_describe_heritage
----------------------------------------
constant gtk_type_describe_heritage_ = link_c_proc( GTK, 
  "gtk_type_describe_heritage", {C_UINT} )

global procedure gtk_type_describe_heritage(integer type_)
    c_proc( gtk_type_describe_heritage_, {type_} )
end procedure

----------------------------------------
-- gtk_type_describe_tree
----------------------------------------
constant gtk_type_describe_tree_ = link_c_proc( GTK, 
  "gtk_type_describe_tree", {C_UINT,C_INT} )

global procedure gtk_type_describe_tree(integer type_, integer show_size_)
    c_proc( gtk_type_describe_tree_, {type_,show_size_} )
end procedure

----------------------------------------
-- gtk_type_is_a
----------------------------------------
constant gtk_type_is_a_ = link_c_func( GTK, 
  "gtk_type_is_a", {C_UINT,C_UINT}, C_INT )

global function gtk_type_is_a(integer type_, integer is_a_type_)
    return c_func( gtk_type_is_a_, {type_,is_a_type_} )
end function

----------------------------------------
-- gtk_type_check_object_cast
----------------------------------------
constant gtk_type_check_object_cast_ = link_c_func( GTK, 
  "gtk_type_check_object_cast", {C_POINTER,C_UINT}, C_POINTER )

global function gtk_type_check_object_cast(atom type_object_, integer cast_type_)
    return c_func( gtk_type_check_object_cast_, {type_object_,cast_type_} )
end function

----------------------------------------
-- gtk_type_check_class_cast
----------------------------------------
constant gtk_type_check_class_cast_ = link_c_func( GTK, 
  "gtk_type_check_class_cast", {C_POINTER,C_UINT}, C_POINTER )

global function gtk_type_check_class_cast(atom klass_, integer cast_type_)
    return c_func( gtk_type_check_class_cast_, {klass_,cast_type_} )
end function

----------------------------------------
-- gtk_type_register_enum
----------------------------------------
constant gtk_type_register_enum_ = link_c_func( GTK, 
  "gtk_type_register_enum", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_type_register_enum(sequence const_, atom values_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_type_register_enum_, {string1,values_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_type_register_flags
----------------------------------------
constant gtk_type_register_flags_ = link_c_func( GTK, 
  "gtk_type_register_flags", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_type_register_flags(sequence const_, atom values_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_type_register_flags_, {string1,values_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_type_enum_get_values
----------------------------------------
constant gtk_type_enum_get_values_ = link_c_func( GTK, 
  "gtk_type_enum_get_values", {C_UINT}, C_POINTER )

global function gtk_type_enum_get_values(integer enum_type_)
    return c_func( gtk_type_enum_get_values_, {enum_type_} )
end function

----------------------------------------
-- gtk_type_flags_get_values
----------------------------------------
constant gtk_type_flags_get_values_ = link_c_func( GTK, 
  "gtk_type_flags_get_values", {C_UINT}, C_POINTER )

global function gtk_type_flags_get_values(integer flags_type_)
    return c_func( gtk_type_flags_get_values_, {flags_type_} )
end function

----------------------------------------
-- gtk_type_enum_find_value
----------------------------------------
constant gtk_type_enum_find_value_ = link_c_func( GTK, 
  "gtk_type_enum_find_value", {C_UINT,C_POINTER}, C_POINTER )

global function gtk_type_enum_find_value(integer enum_type_, sequence value_name_)
    atom result
    atom string1
    string1 = allocate_string( value_name_ )
    result = c_func( gtk_type_enum_find_value_, {enum_type_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_type_flags_find_value
----------------------------------------
constant gtk_type_flags_find_value_ = link_c_func( GTK, 
  "gtk_type_flags_find_value", {C_UINT,C_POINTER}, C_POINTER )

global function gtk_type_flags_find_value(integer flag_type_, sequence value_name_)
    atom result
    atom string1
    string1 = allocate_string( value_name_ )
    result = c_func( gtk_type_flags_find_value_, {flag_type_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_type_set_varargs_type
----------------------------------------
constant gtk_type_set_varargs_type_ = link_c_proc( GTK, 
  "gtk_type_set_varargs_type", {C_UINT,C_UINT} )

global procedure gtk_type_set_varargs_type(integer foreign_type_, integer varargs_type_)
    c_proc( gtk_type_set_varargs_type_, {foreign_type_,varargs_type_} )
end procedure

----------------------------------------
-- gtk_type_get_varargs_type
----------------------------------------
constant gtk_type_get_varargs_type_ = link_c_func( GTK, 
  "gtk_type_get_varargs_type", {C_UINT}, C_UINT )

global function gtk_type_get_varargs_type(integer foreign_type_)
    return c_func( gtk_type_get_varargs_type_, {foreign_type_} )
end function

----------------------------------------
-- gtk_type_query
----------------------------------------
constant gtk_type_query_ = link_c_func( GTK, 
  "gtk_type_query", {C_UINT}, C_POINTER )

global function gtk_type_query(integer type_)
    return c_func( gtk_type_query_, {type_} )
end function



----------------------------------------
----------------------------------------
-- GTKTYPEBUILTINS.H
----------------------------------------
----------------------------------------




----------------------------------------
----------------------------------------
-- GTKENUMS.H
----------------------------------------
----------------------------------------


global constant
    GTK_ARROW_UP                        = 1,
    GTK_ARROW_DOWN                      = 2,
    GTK_ARROW_LEFT                      = 3,
    GTK_ARROW_RIGHT                     = 4
global constant SIZEOF_GtkArrowType = SIZEOF_ENUM

global constant
    GTK_EXPAND                          = power(2,0),
    GTK_SHRINK                          = power(2,1),
    GTK_FILL                            = power(2,2)
global constant SIZEOF_GtkAttachOptions = SIZEOF_ENUM

global constant
    GTK_BUTTONBOX_DEFAULT_STYLE         = 1,
    GTK_BUTTONBOX_SPREAD                = 2,
    GTK_BUTTONBOX_EDGE                  = 3,
    GTK_BUTTONBOX_START                 = 4,
    GTK_BUTTONBOX_END                   = 5
global constant SIZEOF_GtkButtonBoxStyle = SIZEOF_ENUM

global constant
    GTK_CURVE_TYPE_LINEAR               = 1,
    GTK_CURVE_TYPE_SPLINE               = 2,
    GTK_CURVE_TYPE_FREE                 = 3
global constant SIZEOF_GtkCurveType = SIZEOF_ENUM

global constant
    GTK_DIR_TAB_FORWARD                 = 1,
    GTK_DIR_TAB_BACKWARD                = 2,
    GTK_DIR_UP                          = 3,
    GTK_DIR_DOWN                        = 4,
    GTK_DIR_LEFT                        = 5,
    GTK_DIR_RIGHT                       = 6
global constant SIZEOF_GtkDirectionType = SIZEOF_ENUM

global constant
    GTK_JUSTIFY_LEFT                    = 1,
    GTK_JUSTIFY_RIGHT                   = 2,
    GTK_JUSTIFY_CENTER                  = 3,
    GTK_JUSTIFY_FILL                    = 4
global constant SIZEOF_GtkJustification = SIZEOF_ENUM

global constant
    GTK_MATCH_ALL                       = 1,
    GTK_MATCH_ALL_TAIL                  = 2,
    GTK_MATCH_HEAD                      = 3,
    GTK_MATCH_TAIL                      = 4,
    GTK_MATCH_EXACT                     = 5,
    GTK_MATCH_LAST                      = 6
global constant SIZEOF_GtkMatchType = SIZEOF_ENUM

global constant
    GTK_MENU_DIR_PARENT                 = 1,
    GTK_MENU_DIR_CHILD                  = 2,
    GTK_MENU_DIR_NEXT                   = 3,
    GTK_MENU_DIR_PREV                   = 4
global constant SIZEOF_GtkMenuDirectionType = SIZEOF_ENUM

global constant
    GTK_MENU_FACTORY_MENU               = 1,
    GTK_MENU_FACTORY_MENU_BAR           = 2,
    GTK_MENU_FACTORY_OPTION_MENU        = 3
global constant SIZEOF_GtkMenuFactoryType = SIZEOF_ENUM

global constant
    GTK_PIXELS                          = 1,
    GTK_INCHES                          = 2,
    GTK_CENTIMETERS                     = 3
global constant SIZEOF_GtkMetricType = SIZEOF_ENUM

global constant
    GTK_ORIENTATION_HORIZONTAL          = 1,
    GTK_ORIENTATION_VERTICAL            = 2
global constant SIZEOF_GtkOrientation = SIZEOF_ENUM

global constant
    GTK_CORNER_TOP_LEFT                 = 1,
    GTK_CORNER_BOTTOM_LEFT              = 2,
    GTK_CORNER_TOP_RIGHT                = 3,
    GTK_CORNER_BOTTOM_RIGHT             = 4
global constant SIZEOF_GtkCornerType = SIZEOF_ENUM

global constant
    GTK_PACK_START                      = 1,
    GTK_PACK_END                        = 2
global constant SIZEOF_GtkPackType = SIZEOF_ENUM

global constant
    GTK_PATH_PRIO_LOWEST                = 0,
    GTK_PATH_PRIO_GTK                   = 4,
    GTK_PATH_PRIO_APPLICATION           = 8,
    GTK_PATH_PRIO_RC                    = 12,
    GTK_PATH_PRIO_HIGHEST               = 15,
    GTK_PATH_PRIO_MASK                  = #0F
global constant SIZEOF_GtkPathPriorityType = SIZEOF_ENUM

global constant
    GTK_PATH_WIDGET                     = 1,
    GTK_PATH_WIDGET_CLASS               = 2,
    GTK_PATH_CLASS                      = 3
global constant SIZEOF_GtkPathType = SIZEOF_ENUM

global constant
    GTK_POLICY_ALWAYS                   = 1,
    GTK_POLICY_AUTOMATIC                = 2,
    GTK_POLICY_NEVER                    = 3
global constant SIZEOF_GtkPolicyType = SIZEOF_ENUM

global constant
    GTK_POS_LEFT                        = 1,
    GTK_POS_RIGHT                       = 2,
    GTK_POS_TOP                         = 3,
    GTK_POS_BOTTOM                      = 4
global constant SIZEOF_GtkPositionType = SIZEOF_ENUM

global constant
    GTK_PREVIEW_COLOR                   = 1,
    GTK_PREVIEW_GRAYSCALE               = 2
global constant SIZEOF_GtkPreviewType = SIZEOF_ENUM

global constant
    GTK_RELIEF_NORMAL                   = 1,
    GTK_RELIEF_HALF                     = 2,
    GTK_RELIEF_NONE                     = 3
global constant SIZEOF_GtkReliefStyle = SIZEOF_ENUM

global constant
    GTK_RESIZE_PARENT                   = 1,
    GTK_RESIZE_QUEUE                    = 2,
    GTK_RESIZE_IMMEDIATE                = 3
global constant SIZEOF_GtkResizeMode = SIZEOF_ENUM

global constant
    GTK_RUN_FIRST                       = power(2,0),
    GTK_RUN_LAST                        = power(2,1),
    GTK_RUN_BOTH                        = GTK_RUN_FIRST,
    GTK_RUN_NO_RECURSE                  = power(2,2),
    GTK_RUN_ACTION                      = power(2,3),
    GTK_RUN_NO_HOOKS                    = power(2,4)
global constant SIZEOF_GtkSignalRunType = SIZEOF_ENUM

global constant
    GTK_SCROLL_NONE                     = 1,
    GTK_SCROLL_STEP_BACKWARD            = 2,
    GTK_SCROLL_STEP_FORWARD             = 3,
    GTK_SCROLL_PAGE_BACKWARD            = 4,
    GTK_SCROLL_PAGE_FORWARD             = 5,
    GTK_SCROLL_JUMP                     = 6
global constant SIZEOF_GtkScrollType = SIZEOF_ENUM

global constant
    GTK_SELECTION_SINGLE                = 1,
    GTK_SELECTION_BROWSE                = 2,
    GTK_SELECTION_MULTIPLE              = 3,
    GTK_SELECTION_EXTENDED              = 4
global constant SIZEOF_GtkSelectionMode = SIZEOF_ENUM

global constant
    GTK_SHADOW_NONE                     = 1,
    GTK_SHADOW_IN                       = 2,
    GTK_SHADOW_OUT                      = 3,
    GTK_SHADOW_ETCHED_IN                = 4,
    GTK_SHADOW_ETCHED_OUT               = 5
global constant SIZEOF_GtkShadowType = SIZEOF_ENUM

global constant
    GTK_STATE_NORMAL                    = 1,
    GTK_STATE_ACTIVE                    = 2,
    GTK_STATE_PRELIGHT                  = 3,
    GTK_STATE_SELECTED                  = 4,
    GTK_STATE_INSENSITIVE               = 5
global constant SIZEOF_GtkStateType = SIZEOF_ENUM

global constant
    GTK_DIRECTION_LEFT                  = 1,
    GTK_DIRECTION_RIGHT                 = 2
global constant SIZEOF_GtkSubmenuDirection = SIZEOF_ENUM

global constant
    GTK_TOP_BOTTOM                      = 1,
    GTK_LEFT_RIGHT                      = 2
global constant SIZEOF_GtkSubmenuPlacement = SIZEOF_ENUM

global constant
    GTK_TOOLBAR_ICONS                   = 1,
    GTK_TOOLBAR_TEXT                    = 2,
    GTK_TOOLBAR_BOTH                    = 3
global constant SIZEOF_GtkToolbarStyle = SIZEOF_ENUM

global constant
    GTK_TROUGH_NONE                     = 1,
    GTK_TROUGH_START                    = 2,
    GTK_TROUGH_END                      = 3,
    GTK_TROUGH_JUMP                     = 4
global constant SIZEOF_GtkTroughType = SIZEOF_ENUM

global constant
    GTK_UPDATE_CONTINUOUS               = 1,
    GTK_UPDATE_DISCONTINUOUS            = 2,
    GTK_UPDATE_DELAYED                  = 3
global constant SIZEOF_GtkUpdateType = SIZEOF_ENUM

global constant
    GTK_VISIBILITY_NONE                 = 1,
    GTK_VISIBILITY_PARTIAL              = 2,
    GTK_VISIBILITY_FULL                 = 3
global constant SIZEOF_GtkVisibility = SIZEOF_ENUM

global constant
    GTK_WIN_POS_NONE                    = 1,
    GTK_WIN_POS_CENTER                  = 2,
    GTK_WIN_POS_MOUSE                   = 3
global constant SIZEOF_GtkWindowPosition = SIZEOF_ENUM

global constant
    GTK_WINDOW_TOPLEVEL                 = 1,
    GTK_WINDOW_DIALOG                   = 2,
    GTK_WINDOW_POPUP                    = 3
global constant SIZEOF_GtkWindowType = SIZEOF_ENUM

global constant
    GTK_SORT_ASCENDING                  = 1,
    GTK_SORT_DESCENDING                 = 2
global constant SIZEOF_GtkSortType = SIZEOF_ENUM



----------------------------------------
----------------------------------------
-- GTKDEBUG.H
----------------------------------------
----------------------------------------


global constant
    GTK_DEBUG_OBJECTS                   = power(2,0),
    GTK_DEBUG_MISC                      = power(2,1),
    GTK_DEBUG_SIGNALS                   = power(2,2),
    GTK_DEBUG_DND                       = power(2,3),
    GTK_DEBUG_PLUGSOCKET                = power(2,4)
global constant SIZEOF_GtkDebugFlag = SIZEOF_ENUM



----------------------------------------
----------------------------------------
-- GTKWIDGET.H
----------------------------------------
----------------------------------------


global constant
    GTK_TOPLEVEL                        = power(2,4),
    GTK_NO_WINDOW                       = power(2,5),
    GTK_REALIZED                        = power(2,6),
    GTK_MAPPED                          = power(2,7),
    GTK_VISIBLE                         = power(2,8),
    GTK_SENSITIVE                       = power(2,9),
    GTK_PARENT_SENSITIVE                = power(2,10),
    GTK_CAN_FOCUS                       = power(2,11),
    GTK_HAS_FOCUS                       = power(2,12),
    GTK_CAN_DEFAULT                     = power(2,13),
    GTK_HAS_DEFAULT                     = power(2,14),
    GTK_HAS_GRAB                        = power(2,15),
    GTK_RC_STYLE                        = power(2,16),
    GTK_COMPOSITE_CHILD                 = power(2,17),
    GTK_NO_REPARENT                     = power(2,18),
    GTK_APP_PAINTABLE                   = power(2,19),
    GTK_RECEIVES_DEFAULT                = power(2,20)
global constant SIZEOF_GtkWidgetFlags = SIZEOF_ENUM

----------------------------------------
-- GtkCallback
----------------------------------------
constant GtkCallback_ = link_c_proc( GTK, 
  "GtkCallback", {C_POINTER,C_POINTER} )

global procedure GtkCallback(atom widget_, atom data_)
    c_proc( GtkCallback_, {widget_,data_} )
end procedure


----------------------------------------
-- GtkRequisition
----------------------------------------
global constant
    GtkRequisition_width                = allot(TYPE_GINT16),
    GtkRequisition_height               = allot(TYPE_GINT16),
    SIZEOF_GtkRequisition               = allotted_size()

----------------------------------------
-- GtkAllocation
----------------------------------------
global constant
    GtkAllocation_x                     = allot(TYPE_GINT16),
    GtkAllocation_y                     = allot(TYPE_GINT16),
    GtkAllocation_width                 = allot(TYPE_GUINT16),
    GtkAllocation_height                = allot(TYPE_GUINT16),
    SIZEOF_GtkAllocation                = allotted_size()

----------------------------------------
-- GtkSelectionData
----------------------------------------
global constant
    GtkSelectionData_selection          = allot(TYPE_GULONG),
    GtkSelectionData_target             = allot(TYPE_GULONG),
    GtkSelectionData_type               = allot(TYPE_GULONG),
    GtkSelectionData_format             = allot(TYPE_GINT),
    GtkSelectionData_data               = allot(TYPE_POINTER),
    GtkSelectionData_length             = allot(TYPE_GINT),
    SIZEOF_GtkSelectionData             = allotted_size()

----------------------------------------
-- GtkWidget
----------------------------------------
global constant
    GtkWidget_object                    = allot(SIZEOF_GtkObject),
    GtkWidget_private_flags             = allot(TYPE_GUINT16),
    GtkWidget_state                     = allot(TYPE_GUINT8),
    GtkWidget_saved_state               = allot(TYPE_GUINT8),
    GtkWidget_name                      = allot(TYPE_POINTER),
    GtkWidget_style                     = allot(TYPE_POINTER),
    GtkWidget_requisition               = allot(SIZEOF_GtkRequisition),
    GtkWidget_allocation                = allot(SIZEOF_GtkAllocation),
    GtkWidget_window                    = allot(TYPE_POINTER),
    GtkWidget_parent                    = allot(TYPE_POINTER),
    SIZEOF_GtkWidget                    = allotted_size()

----------------------------------------
-- GtkWidgetClass
----------------------------------------
global constant
    GtkWidgetClass_parent_class         = allot(SIZEOF_GtkObjectClass),
    GtkWidgetClass_activate_signal      = allot(TYPE_GUINT),
    GtkWidgetClass_set_scroll_adjustments_signal= allot(TYPE_GUINT),
    GtkWidgetClass_show                 = allot(TYPE_GPOINTER),
    GtkWidgetClass_show_all             = allot(TYPE_GPOINTER),
    GtkWidgetClass_hide                 = allot(TYPE_GPOINTER),
    GtkWidgetClass_hide_all             = allot(TYPE_GPOINTER),
    GtkWidgetClass_map                  = allot(TYPE_GPOINTER),
    GtkWidgetClass_unmap                = allot(TYPE_GPOINTER),
    GtkWidgetClass_realize              = allot(TYPE_GPOINTER),
    GtkWidgetClass_unrealize            = allot(TYPE_GPOINTER),
    GtkWidgetClass_draw                 = allot(TYPE_GPOINTER),
    GtkWidgetClass_draw_focus           = allot(TYPE_GPOINTER),
    GtkWidgetClass_draw_default         = allot(TYPE_GPOINTER),
    GtkWidgetClass_size_request         = allot(TYPE_GPOINTER),
    GtkWidgetClass_size_allocate        = allot(TYPE_GPOINTER),
    GtkWidgetClass_state_changed        = allot(TYPE_GPOINTER),
    GtkWidgetClass_parent_set           = allot(TYPE_GPOINTER),
    GtkWidgetClass_style_set            = allot(TYPE_GPOINTER),
    GtkWidgetClass_add_accelerator      = allot(TYPE_GPOINTER),
    GtkWidgetClass_remove_accelerator   = allot(TYPE_GPOINTER),
    GtkWidgetClass_grab_focus           = allot(TYPE_GPOINTER),
    GtkWidgetClass_event                = allot(TYPE_GPOINTER),
    GtkWidgetClass_button_press_event   = allot(TYPE_GPOINTER),
    GtkWidgetClass_button_release_event = allot(TYPE_GPOINTER),
    GtkWidgetClass_motion_notify_event  = allot(TYPE_GPOINTER),
    GtkWidgetClass_delete_event         = allot(TYPE_GPOINTER),
    GtkWidgetClass_destroy_event        = allot(TYPE_GPOINTER),
    GtkWidgetClass_expose_event         = allot(TYPE_GPOINTER),
    GtkWidgetClass_key_press_event      = allot(TYPE_GPOINTER),
    GtkWidgetClass_key_release_event    = allot(TYPE_GPOINTER),
    GtkWidgetClass_enter_notify_event   = allot(TYPE_GPOINTER),
    GtkWidgetClass_leave_notify_event   = allot(TYPE_GPOINTER),
    GtkWidgetClass_configure_event      = allot(TYPE_GPOINTER),
    GtkWidgetClass_focus_in_event       = allot(TYPE_GPOINTER),
    GtkWidgetClass_focus_out_event      = allot(TYPE_GPOINTER),
    GtkWidgetClass_map_event            = allot(TYPE_GPOINTER),
    GtkWidgetClass_unmap_event          = allot(TYPE_GPOINTER),
    GtkWidgetClass_property_notify_event= allot(TYPE_GPOINTER),
    GtkWidgetClass_selection_clear_event= allot(TYPE_GPOINTER),
    GtkWidgetClass_selection_request_event= allot(TYPE_GPOINTER),
    GtkWidgetClass_selection_notify_event= allot(TYPE_GPOINTER),
    GtkWidgetClass_proximity_in_event   = allot(TYPE_GPOINTER),
    GtkWidgetClass_proximity_out_event  = allot(TYPE_GPOINTER),
    GtkWidgetClass_visibility_notify_event= allot(TYPE_GPOINTER),
    GtkWidgetClass_client_event         = allot(TYPE_GPOINTER),
    GtkWidgetClass_no_expose_event      = allot(TYPE_GPOINTER),
    GtkWidgetClass_selection_get        = allot(TYPE_GPOINTER),
    GtkWidgetClass_selection_received   = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_begin           = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_end             = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_data_get        = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_data_delete     = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_leave           = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_motion          = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_drop            = allot(TYPE_GPOINTER),
    GtkWidgetClass_drag_data_received   = allot(TYPE_GPOINTER),
    GtkWidgetClass_debug_msg            = allot(TYPE_GPOINTER),
    GtkWidgetClass_pad1                 = allot(TYPE_GPOINTER),
    GtkWidgetClass_pad2                 = allot(TYPE_GPOINTER),
    GtkWidgetClass_pad3                 = allot(TYPE_GPOINTER),
    GtkWidgetClass_pad4                 = allot(TYPE_GPOINTER),
    SIZEOF_GtkWidgetClass               = allotted_size()

----------------------------------------
-- GtkWidgetAuxInfo
----------------------------------------
global constant
    GtkWidgetAuxInfo_x                  = allot(TYPE_GINT16),
    GtkWidgetAuxInfo_y                  = allot(TYPE_GINT16),
    GtkWidgetAuxInfo_width              = allot(TYPE_GINT16),
    GtkWidgetAuxInfo_height             = allot(TYPE_GINT16),
    SIZEOF_GtkWidgetAuxInfo             = allotted_size()

----------------------------------------
-- GtkWidgetShapeInfo
----------------------------------------
global constant
    GtkWidgetShapeInfo_offset_x         = allot(TYPE_GINT16),
    GtkWidgetShapeInfo_offset_y         = allot(TYPE_GINT16),
    GtkWidgetShapeInfo_shape_mask       = allot(TYPE_POINTER),
    SIZEOF_GtkWidgetShapeInfo           = allotted_size()
----------------------------------------
-- gtk_widget_get_type
----------------------------------------
constant gtk_widget_get_type_ = link_c_func( GTK, 
  "gtk_widget_get_type", {}, C_UINT )

global function gtk_widget_get_type()
    return c_func( gtk_widget_get_type_, {} )
end function

----------------------------------------
-- gtk_widget_new
----------------------------------------
constant gtk_widget_new_ = link_c_func( GTK, 
  "gtk_widget_new", {C_UINT,C_POINTER}, C_POINTER )

global function gtk_widget_new(integer type_, sequence first_arg_name_)
    atom result
    atom string1
    string1 = allocate_string( first_arg_name_ )
    result = c_func( gtk_widget_new_, {type_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_widget_newv
----------------------------------------
constant gtk_widget_newv_ = link_c_func( GTK, 
  "gtk_widget_newv", {C_UINT,C_UINT,C_POINTER}, C_POINTER )

global function gtk_widget_newv(integer type_, integer nargs_, atom args_)
    return c_func( gtk_widget_newv_, {type_,nargs_,args_} )
end function

----------------------------------------
-- gtk_widget_ref
----------------------------------------
constant gtk_widget_ref_ = link_c_proc( GTK, 
  "gtk_widget_ref", {C_POINTER} )

global procedure gtk_widget_ref(atom widget_)
    c_proc( gtk_widget_ref_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_unref
----------------------------------------
constant gtk_widget_unref_ = link_c_proc( GTK, 
  "gtk_widget_unref", {C_POINTER} )

global procedure gtk_widget_unref(atom widget_)
    c_proc( gtk_widget_unref_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_destroy
----------------------------------------
constant gtk_widget_destroy_ = link_c_proc( GTK, 
  "gtk_widget_destroy", {C_POINTER} )

global procedure gtk_widget_destroy(atom widget_)
    c_proc( gtk_widget_destroy_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_destroyed
----------------------------------------
constant gtk_widget_destroyed_ = link_c_proc( GTK, 
  "gtk_widget_destroyed", {C_POINTER,C_POINTER} )

global procedure gtk_widget_destroyed(atom widget_, atom widget_pointer_)
    c_proc( gtk_widget_destroyed_, {widget_,widget_pointer_} )
end procedure

----------------------------------------
-- gtk_widget_get
----------------------------------------
constant gtk_widget_get_ = link_c_proc( GTK, 
  "gtk_widget_get", {C_POINTER,C_POINTER} )

global procedure gtk_widget_get(atom widget_, atom arg_)
    c_proc( gtk_widget_get_, {widget_,arg_} )
end procedure

----------------------------------------
-- gtk_widget_getv
----------------------------------------
constant gtk_widget_getv_ = link_c_proc( GTK, 
  "gtk_widget_getv", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_widget_getv(atom widget_, integer nargs_, atom args_)
    c_proc( gtk_widget_getv_, {widget_,nargs_,args_} )
end procedure

----------------------------------------
-- gtk_widget_set
----------------------------------------
constant gtk_widget_set_ = link_c_proc( GTK, 
  "gtk_widget_set", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set(atom widget_, sequence first_arg_name_)
    atom string1
    string1 = allocate_string( first_arg_name_ )
    c_proc( gtk_widget_set_, {widget_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_widget_setv
----------------------------------------
constant gtk_widget_setv_ = link_c_proc( GTK, 
  "gtk_widget_setv", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_widget_setv(atom widget_, integer nargs_, atom args_)
    c_proc( gtk_widget_setv_, {widget_,nargs_,args_} )
end procedure

----------------------------------------
-- gtk_widget_unparent
----------------------------------------
constant gtk_widget_unparent_ = link_c_proc( GTK, 
  "gtk_widget_unparent", {C_POINTER} )

global procedure gtk_widget_unparent(atom widget_)
    c_proc( gtk_widget_unparent_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_show
----------------------------------------
constant gtk_widget_show_ = link_c_proc( GTK, 
  "gtk_widget_show", {C_POINTER} )

global procedure gtk_widget_show(atom widget_)
    c_proc( gtk_widget_show_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_show_now
----------------------------------------
constant gtk_widget_show_now_ = link_c_proc( GTK, 
  "gtk_widget_show_now", {C_POINTER} )

global procedure gtk_widget_show_now(atom widget_)
    c_proc( gtk_widget_show_now_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_hide
----------------------------------------
constant gtk_widget_hide_ = link_c_proc( GTK, 
  "gtk_widget_hide", {C_POINTER} )

global procedure gtk_widget_hide(atom widget_)
    c_proc( gtk_widget_hide_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_show_all
----------------------------------------
constant gtk_widget_show_all_ = link_c_proc( GTK, 
  "gtk_widget_show_all", {C_POINTER} )

global procedure gtk_widget_show_all(atom widget_)
    c_proc( gtk_widget_show_all_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_hide_all
----------------------------------------
constant gtk_widget_hide_all_ = link_c_proc( GTK, 
  "gtk_widget_hide_all", {C_POINTER} )

global procedure gtk_widget_hide_all(atom widget_)
    c_proc( gtk_widget_hide_all_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_map
----------------------------------------
constant gtk_widget_map_ = link_c_proc( GTK, 
  "gtk_widget_map", {C_POINTER} )

global procedure gtk_widget_map(atom widget_)
    c_proc( gtk_widget_map_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_unmap
----------------------------------------
constant gtk_widget_unmap_ = link_c_proc( GTK, 
  "gtk_widget_unmap", {C_POINTER} )

global procedure gtk_widget_unmap(atom widget_)
    c_proc( gtk_widget_unmap_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_realize
----------------------------------------
constant gtk_widget_realize_ = link_c_proc( GTK, 
  "gtk_widget_realize", {C_POINTER} )

global procedure gtk_widget_realize(atom widget_)
    c_proc( gtk_widget_realize_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_unrealize
----------------------------------------
constant gtk_widget_unrealize_ = link_c_proc( GTK, 
  "gtk_widget_unrealize", {C_POINTER} )

global procedure gtk_widget_unrealize(atom widget_)
    c_proc( gtk_widget_unrealize_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_queue_draw
----------------------------------------
constant gtk_widget_queue_draw_ = link_c_proc( GTK, 
  "gtk_widget_queue_draw", {C_POINTER} )

global procedure gtk_widget_queue_draw(atom widget_)
    c_proc( gtk_widget_queue_draw_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_queue_draw_area
----------------------------------------
constant gtk_widget_queue_draw_area_ = link_c_proc( GTK, 
  "gtk_widget_queue_draw_area", {C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_widget_queue_draw_area(atom widget_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gtk_widget_queue_draw_area_, {widget_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_widget_queue_clear
----------------------------------------
constant gtk_widget_queue_clear_ = link_c_proc( GTK, 
  "gtk_widget_queue_clear", {C_POINTER} )

global procedure gtk_widget_queue_clear(atom widget_)
    c_proc( gtk_widget_queue_clear_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_queue_clear_area
----------------------------------------
constant gtk_widget_queue_clear_area_ = link_c_proc( GTK, 
  "gtk_widget_queue_clear_area", {C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_widget_queue_clear_area(atom widget_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gtk_widget_queue_clear_area_, {widget_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_widget_queue_resize
----------------------------------------
constant gtk_widget_queue_resize_ = link_c_proc( GTK, 
  "gtk_widget_queue_resize", {C_POINTER} )

global procedure gtk_widget_queue_resize(atom widget_)
    c_proc( gtk_widget_queue_resize_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_draw
----------------------------------------
constant gtk_widget_draw_ = link_c_proc( GTK, 
  "gtk_widget_draw", {C_POINTER,C_POINTER} )

global procedure gtk_widget_draw(atom widget_, atom area_)
    c_proc( gtk_widget_draw_, {widget_,area_} )
end procedure

----------------------------------------
-- gtk_widget_draw_focus
----------------------------------------
constant gtk_widget_draw_focus_ = link_c_proc( GTK, 
  "gtk_widget_draw_focus", {C_POINTER} )

global procedure gtk_widget_draw_focus(atom widget_)
    c_proc( gtk_widget_draw_focus_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_draw_default
----------------------------------------
constant gtk_widget_draw_default_ = link_c_proc( GTK, 
  "gtk_widget_draw_default", {C_POINTER} )

global procedure gtk_widget_draw_default(atom widget_)
    c_proc( gtk_widget_draw_default_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_size_request
----------------------------------------
constant gtk_widget_size_request_ = link_c_proc( GTK, 
  "gtk_widget_size_request", {C_POINTER,C_POINTER} )

global procedure gtk_widget_size_request(atom widget_, atom requisition_)
    c_proc( gtk_widget_size_request_, {widget_,requisition_} )
end procedure

----------------------------------------
-- gtk_widget_size_allocate
----------------------------------------
constant gtk_widget_size_allocate_ = link_c_proc( GTK, 
  "gtk_widget_size_allocate", {C_POINTER,C_POINTER} )

global procedure gtk_widget_size_allocate(atom widget_, atom allocation_)
    c_proc( gtk_widget_size_allocate_, {widget_,allocation_} )
end procedure

----------------------------------------
-- gtk_widget_get_child_requisition
----------------------------------------
constant gtk_widget_get_child_requisition_ = link_c_proc( GTK, 
  "gtk_widget_get_child_requisition", {C_POINTER,C_POINTER} )

global procedure gtk_widget_get_child_requisition(atom widget_, atom requisition_)
    c_proc( gtk_widget_get_child_requisition_, {widget_,requisition_} )
end procedure

----------------------------------------
-- gtk_widget_add_accelerator
----------------------------------------
constant gtk_widget_add_accelerator_ = link_c_proc( GTK, 
  "gtk_widget_add_accelerator", {C_POINTER,C_POINTER,C_POINTER,C_UINT,C_UINT,C_POINTER} )

global procedure gtk_widget_add_accelerator(atom widget_, sequence accel_signal_, atom accel_group_, integer accel_key_, 
 integer accel_mods_, atom accel_flags_)
    atom string1
    string1 = allocate_string( accel_signal_ )
    c_proc( gtk_widget_add_accelerator_, {widget_,string1,accel_group_,accel_key_,accel_mods_,accel_flags_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_widget_remove_accelerator
----------------------------------------
constant gtk_widget_remove_accelerator_ = link_c_proc( GTK, 
  "gtk_widget_remove_accelerator", {C_POINTER,C_POINTER,C_UINT,C_UINT} )

global procedure gtk_widget_remove_accelerator(atom widget_, atom accel_group_, integer accel_key_, integer accel_mods_)
    c_proc( gtk_widget_remove_accelerator_, {widget_,accel_group_,accel_key_,accel_mods_} )
end procedure

----------------------------------------
-- gtk_widget_remove_accelerators
----------------------------------------
constant gtk_widget_remove_accelerators_ = link_c_proc( GTK, 
  "gtk_widget_remove_accelerators", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_widget_remove_accelerators(atom widget_, sequence accel_signal_, integer visible_only_)
    atom string1
    string1 = allocate_string( accel_signal_ )
    c_proc( gtk_widget_remove_accelerators_, {widget_,string1,visible_only_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_widget_accelerator_signal
----------------------------------------
constant gtk_widget_accelerator_signal_ = link_c_func( GTK, 
  "gtk_widget_accelerator_signal", {C_POINTER,C_POINTER,C_UINT,C_UINT}, C_UINT )

global function gtk_widget_accelerator_signal(atom widget_, atom accel_group_, integer accel_key_, integer accel_mods_)
    return c_func( gtk_widget_accelerator_signal_, {widget_,accel_group_,accel_key_,accel_mods_} )
end function

----------------------------------------
-- gtk_widget_lock_accelerators
----------------------------------------
constant gtk_widget_lock_accelerators_ = link_c_proc( GTK, 
  "gtk_widget_lock_accelerators", {C_POINTER} )

global procedure gtk_widget_lock_accelerators(atom widget_)
    c_proc( gtk_widget_lock_accelerators_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_unlock_accelerators
----------------------------------------
constant gtk_widget_unlock_accelerators_ = link_c_proc( GTK, 
  "gtk_widget_unlock_accelerators", {C_POINTER} )

global procedure gtk_widget_unlock_accelerators(atom widget_)
    c_proc( gtk_widget_unlock_accelerators_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_accelerators_locked
----------------------------------------
constant gtk_widget_accelerators_locked_ = link_c_func( GTK, 
  "gtk_widget_accelerators_locked", {C_POINTER}, C_INT )

global function gtk_widget_accelerators_locked(atom widget_)
    return c_func( gtk_widget_accelerators_locked_, {widget_} )
end function

----------------------------------------
-- gtk_widget_event
----------------------------------------
constant gtk_widget_event_ = link_c_func( GTK, 
  "gtk_widget_event", {C_POINTER,C_POINTER}, C_INT )

global function gtk_widget_event(atom widget_, atom event_)
    return c_func( gtk_widget_event_, {widget_,event_} )
end function

----------------------------------------
-- gtk_widget_activate
----------------------------------------
constant gtk_widget_activate_ = link_c_func( GTK, 
  "gtk_widget_activate", {C_POINTER}, C_INT )

global function gtk_widget_activate(atom widget_)
    return c_func( gtk_widget_activate_, {widget_} )
end function

----------------------------------------
-- gtk_widget_set_scroll_adjustments
----------------------------------------
constant gtk_widget_set_scroll_adjustments_ = link_c_func( GTK, 
  "gtk_widget_set_scroll_adjustments", {C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function gtk_widget_set_scroll_adjustments(atom widget_, atom hadjustment_, atom vadjustment_)
    return c_func( gtk_widget_set_scroll_adjustments_, {widget_,hadjustment_,vadjustment_} )
end function

----------------------------------------
-- gtk_widget_reparent
----------------------------------------
constant gtk_widget_reparent_ = link_c_proc( GTK, 
  "gtk_widget_reparent", {C_POINTER,C_POINTER} )

global procedure gtk_widget_reparent(atom widget_, atom new_parent_)
    c_proc( gtk_widget_reparent_, {widget_,new_parent_} )
end procedure

----------------------------------------
-- gtk_widget_popup
----------------------------------------
constant gtk_widget_popup_ = link_c_proc( GTK, 
  "gtk_widget_popup", {C_POINTER,C_INT,C_INT} )

global procedure gtk_widget_popup(atom widget_, integer x_, integer y_)
    c_proc( gtk_widget_popup_, {widget_,x_,y_} )
end procedure

----------------------------------------
-- gtk_widget_intersect
----------------------------------------
constant gtk_widget_intersect_ = link_c_func( GTK, 
  "gtk_widget_intersect", {C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function gtk_widget_intersect(atom widget_, atom area_, atom intersection_)
    return c_func( gtk_widget_intersect_, {widget_,area_,intersection_} )
end function

----------------------------------------
-- gtk_widget_grab_focus
----------------------------------------
constant gtk_widget_grab_focus_ = link_c_proc( GTK, 
  "gtk_widget_grab_focus", {C_POINTER} )

global procedure gtk_widget_grab_focus(atom widget_)
    c_proc( gtk_widget_grab_focus_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_grab_default
----------------------------------------
constant gtk_widget_grab_default_ = link_c_proc( GTK, 
  "gtk_widget_grab_default", {C_POINTER} )

global procedure gtk_widget_grab_default(atom widget_)
    c_proc( gtk_widget_grab_default_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_set_name
----------------------------------------
constant gtk_widget_set_name_ = link_c_proc( GTK, 
  "gtk_widget_set_name", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_name(atom widget_, sequence name_)
    atom string1
    string1 = allocate_string( name_ )
    c_proc( gtk_widget_set_name_, {widget_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_widget_get_name
----------------------------------------
constant gtk_widget_get_name_ = link_c_func( GTK, 
  "gtk_widget_get_name", {C_POINTER}, C_POINTER )

global function gtk_widget_get_name(atom widget_)
    return peek_string( c_func( gtk_widget_get_name_, {widget_} ) )
end function

----------------------------------------
-- gtk_widget_set_state
----------------------------------------
constant gtk_widget_set_state_ = link_c_proc( GTK, 
  "gtk_widget_set_state", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_state(atom widget_, atom state_)
    c_proc( gtk_widget_set_state_, {widget_,state_} )
end procedure

----------------------------------------
-- gtk_widget_set_sensitive
----------------------------------------
constant gtk_widget_set_sensitive_ = link_c_proc( GTK, 
  "gtk_widget_set_sensitive", {C_POINTER,C_INT} )

global procedure gtk_widget_set_sensitive(atom widget_, integer sensitive_)
    c_proc( gtk_widget_set_sensitive_, {widget_,sensitive_} )
end procedure

----------------------------------------
-- gtk_widget_set_app_paintable
----------------------------------------
constant gtk_widget_set_app_paintable_ = link_c_proc( GTK, 
  "gtk_widget_set_app_paintable", {C_POINTER,C_INT} )

global procedure gtk_widget_set_app_paintable(atom widget_, integer app_paintable_)
    c_proc( gtk_widget_set_app_paintable_, {widget_,app_paintable_} )
end procedure

----------------------------------------
-- gtk_widget_set_parent
----------------------------------------
constant gtk_widget_set_parent_ = link_c_proc( GTK, 
  "gtk_widget_set_parent", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_parent(atom widget_, atom parent_)
    c_proc( gtk_widget_set_parent_, {widget_,parent_} )
end procedure

----------------------------------------
-- gtk_widget_set_parent_window
----------------------------------------
constant gtk_widget_set_parent_window_ = link_c_proc( GTK, 
  "gtk_widget_set_parent_window", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_parent_window(atom widget_, atom parent_window_)
    c_proc( gtk_widget_set_parent_window_, {widget_,parent_window_} )
end procedure

----------------------------------------
-- gtk_widget_get_parent_window
----------------------------------------
constant gtk_widget_get_parent_window_ = link_c_func( GTK, 
  "gtk_widget_get_parent_window", {C_POINTER}, C_POINTER )

global function gtk_widget_get_parent_window(atom widget_)
    return c_func( gtk_widget_get_parent_window_, {widget_} )
end function

----------------------------------------
-- gtk_widget_set_uposition
----------------------------------------
constant gtk_widget_set_uposition_ = link_c_proc( GTK, 
  "gtk_widget_set_uposition", {C_POINTER,C_INT,C_INT} )

global procedure gtk_widget_set_uposition(atom widget_, integer x_, integer y_)
    c_proc( gtk_widget_set_uposition_, {widget_,x_,y_} )
end procedure

----------------------------------------
-- gtk_widget_set_usize
----------------------------------------
constant gtk_widget_set_usize_ = link_c_proc( GTK, 
  "gtk_widget_set_usize", {C_POINTER,C_INT,C_INT} )

global procedure gtk_widget_set_usize(atom widget_, integer width_, integer height_)
    c_proc( gtk_widget_set_usize_, {widget_,width_,height_} )
end procedure

----------------------------------------
-- gtk_widget_set_events
----------------------------------------
constant gtk_widget_set_events_ = link_c_proc( GTK, 
  "gtk_widget_set_events", {C_POINTER,C_INT} )

global procedure gtk_widget_set_events(atom widget_, integer events_)
    c_proc( gtk_widget_set_events_, {widget_,events_} )
end procedure

----------------------------------------
-- gtk_widget_add_events
----------------------------------------
constant gtk_widget_add_events_ = link_c_proc( GTK, 
  "gtk_widget_add_events", {C_POINTER,C_INT} )

global procedure gtk_widget_add_events(atom widget_, integer events_)
    c_proc( gtk_widget_add_events_, {widget_,events_} )
end procedure

----------------------------------------
-- gtk_widget_set_extension_events
----------------------------------------
constant gtk_widget_set_extension_events_ = link_c_proc( GTK, 
  "gtk_widget_set_extension_events", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_extension_events(atom widget_, atom mode_)
    c_proc( gtk_widget_set_extension_events_, {widget_,mode_} )
end procedure

----------------------------------------
-- gtk_widget_get_extension_events
----------------------------------------
constant gtk_widget_get_extension_events_ = link_c_func( GTK, 
  "gtk_widget_get_extension_events", {C_POINTER}, C_POINTER )

global function gtk_widget_get_extension_events(atom widget_)
    return c_func( gtk_widget_get_extension_events_, {widget_} )
end function

----------------------------------------
-- gtk_widget_get_toplevel
----------------------------------------
constant gtk_widget_get_toplevel_ = link_c_func( GTK, 
  "gtk_widget_get_toplevel", {C_POINTER}, C_POINTER )

global function gtk_widget_get_toplevel(atom widget_)
    return c_func( gtk_widget_get_toplevel_, {widget_} )
end function

----------------------------------------
-- gtk_widget_get_ancestor
----------------------------------------
constant gtk_widget_get_ancestor_ = link_c_func( GTK, 
  "gtk_widget_get_ancestor", {C_POINTER,C_UINT}, C_POINTER )

global function gtk_widget_get_ancestor(atom widget_, integer widget_type_)
    return c_func( gtk_widget_get_ancestor_, {widget_,widget_type_} )
end function

----------------------------------------
-- gtk_widget_get_colormap
----------------------------------------
constant gtk_widget_get_colormap_ = link_c_func( GTK, 
  "gtk_widget_get_colormap", {C_POINTER}, C_POINTER )

global function gtk_widget_get_colormap(atom widget_)
    return c_func( gtk_widget_get_colormap_, {widget_} )
end function

----------------------------------------
-- gtk_widget_get_visual
----------------------------------------
constant gtk_widget_get_visual_ = link_c_func( GTK, 
  "gtk_widget_get_visual", {C_POINTER}, C_POINTER )

global function gtk_widget_get_visual(atom widget_)
    return c_func( gtk_widget_get_visual_, {widget_} )
end function

----------------------------------------
-- gtk_widget_set_colormap
----------------------------------------
constant gtk_widget_set_colormap_ = link_c_proc( GTK, 
  "gtk_widget_set_colormap", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_colormap(atom widget_, atom colormap_)
    c_proc( gtk_widget_set_colormap_, {widget_,colormap_} )
end procedure

----------------------------------------
-- gtk_widget_set_visual
----------------------------------------
constant gtk_widget_set_visual_ = link_c_proc( GTK, 
  "gtk_widget_set_visual", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_visual(atom widget_, atom visual_)
    c_proc( gtk_widget_set_visual_, {widget_,visual_} )
end procedure

----------------------------------------
-- gtk_widget_get_events
----------------------------------------
constant gtk_widget_get_events_ = link_c_func( GTK, 
  "gtk_widget_get_events", {C_POINTER}, C_INT )

global function gtk_widget_get_events(atom widget_)
    return c_func( gtk_widget_get_events_, {widget_} )
end function

----------------------------------------
-- gtk_widget_get_pointer
----------------------------------------
constant gtk_widget_get_pointer_ = link_c_proc( GTK, 
  "gtk_widget_get_pointer", {C_POINTER,C_INT,C_INT} )

global procedure gtk_widget_get_pointer(atom widget_, integer x_, integer y_)
    c_proc( gtk_widget_get_pointer_, {widget_,x_,y_} )
end procedure

----------------------------------------
-- gtk_widget_is_ancestor
----------------------------------------
constant gtk_widget_is_ancestor_ = link_c_func( GTK, 
  "gtk_widget_is_ancestor", {C_POINTER,C_POINTER}, C_INT )

global function gtk_widget_is_ancestor(atom widget_, atom ancestor_)
    return c_func( gtk_widget_is_ancestor_, {widget_,ancestor_} )
end function

----------------------------------------
-- gtk_widget_hide_on_delete
----------------------------------------
constant gtk_widget_hide_on_delete_ = link_c_func( GTK, 
  "gtk_widget_hide_on_delete", {C_POINTER}, C_INT )

global function gtk_widget_hide_on_delete(atom widget_)
    return c_func( gtk_widget_hide_on_delete_, {widget_} )
end function

----------------------------------------
-- gtk_widget_set_style
----------------------------------------
constant gtk_widget_set_style_ = link_c_proc( GTK, 
  "gtk_widget_set_style", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_style(atom widget_, atom style_)
    c_proc( gtk_widget_set_style_, {widget_,style_} )
end procedure

----------------------------------------
-- gtk_widget_set_rc_style
----------------------------------------
constant gtk_widget_set_rc_style_ = link_c_proc( GTK, 
  "gtk_widget_set_rc_style", {C_POINTER} )

global procedure gtk_widget_set_rc_style(atom widget_)
    c_proc( gtk_widget_set_rc_style_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_ensure_style
----------------------------------------
constant gtk_widget_ensure_style_ = link_c_proc( GTK, 
  "gtk_widget_ensure_style", {C_POINTER} )

global procedure gtk_widget_ensure_style(atom widget_)
    c_proc( gtk_widget_ensure_style_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_get_style
----------------------------------------
constant gtk_widget_get_style_ = link_c_func( GTK, 
  "gtk_widget_get_style", {C_POINTER}, C_POINTER )

global function gtk_widget_get_style(atom widget_)
    return c_func( gtk_widget_get_style_, {widget_} )
end function

----------------------------------------
-- gtk_widget_restore_default_style
----------------------------------------
constant gtk_widget_restore_default_style_ = link_c_proc( GTK, 
  "gtk_widget_restore_default_style", {C_POINTER} )

global procedure gtk_widget_restore_default_style(atom widget_)
    c_proc( gtk_widget_restore_default_style_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_modify_style
----------------------------------------
constant gtk_widget_modify_style_ = link_c_proc( GTK, 
  "gtk_widget_modify_style", {C_POINTER,C_POINTER} )

global procedure gtk_widget_modify_style(atom widget_, atom style_)
    c_proc( gtk_widget_modify_style_, {widget_,style_} )
end procedure

----------------------------------------
-- gtk_widget_set_composite_name
----------------------------------------
constant gtk_widget_set_composite_name_ = link_c_proc( GTK, 
  "gtk_widget_set_composite_name", {C_POINTER,C_POINTER} )

global procedure gtk_widget_set_composite_name(atom widget_, sequence name_)
    atom string1
    string1 = allocate_string( name_ )
    c_proc( gtk_widget_set_composite_name_, {widget_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_widget_get_composite_name
----------------------------------------
constant gtk_widget_get_composite_name_ = link_c_func( GTK, 
  "gtk_widget_get_composite_name", {C_POINTER}, C_POINTER )

global function gtk_widget_get_composite_name(atom widget_)
    return peek_string( c_func( gtk_widget_get_composite_name_, {widget_} ) )
end function

----------------------------------------
-- gtk_widget_reset_rc_styles
----------------------------------------
constant gtk_widget_reset_rc_styles_ = link_c_proc( GTK, 
  "gtk_widget_reset_rc_styles", {C_POINTER} )

global procedure gtk_widget_reset_rc_styles(atom widget_)
    c_proc( gtk_widget_reset_rc_styles_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_push_style
----------------------------------------
constant gtk_widget_push_style_ = link_c_proc( GTK, 
  "gtk_widget_push_style", {C_POINTER} )

global procedure gtk_widget_push_style(atom style_)
    c_proc( gtk_widget_push_style_, {style_} )
end procedure

----------------------------------------
-- gtk_widget_push_colormap
----------------------------------------
constant gtk_widget_push_colormap_ = link_c_proc( GTK, 
  "gtk_widget_push_colormap", {C_POINTER} )

global procedure gtk_widget_push_colormap(atom cmap_)
    c_proc( gtk_widget_push_colormap_, {cmap_} )
end procedure

----------------------------------------
-- gtk_widget_push_visual
----------------------------------------
constant gtk_widget_push_visual_ = link_c_proc( GTK, 
  "gtk_widget_push_visual", {C_POINTER} )

global procedure gtk_widget_push_visual(atom visual_)
    c_proc( gtk_widget_push_visual_, {visual_} )
end procedure

----------------------------------------
-- gtk_widget_push_composite_child
----------------------------------------
constant gtk_widget_push_composite_child_ = link_c_proc( GTK, 
  "gtk_widget_push_composite_child", {} )

global procedure gtk_widget_push_composite_child()
    c_proc( gtk_widget_push_composite_child_, {} )
end procedure

----------------------------------------
-- gtk_widget_pop_composite_child
----------------------------------------
constant gtk_widget_pop_composite_child_ = link_c_proc( GTK, 
  "gtk_widget_pop_composite_child", {} )

global procedure gtk_widget_pop_composite_child()
    c_proc( gtk_widget_pop_composite_child_, {} )
end procedure

----------------------------------------
-- gtk_widget_pop_style
----------------------------------------
constant gtk_widget_pop_style_ = link_c_proc( GTK, 
  "gtk_widget_pop_style", {} )

global procedure gtk_widget_pop_style()
    c_proc( gtk_widget_pop_style_, {} )
end procedure

----------------------------------------
-- gtk_widget_pop_colormap
----------------------------------------
constant gtk_widget_pop_colormap_ = link_c_proc( GTK, 
  "gtk_widget_pop_colormap", {} )

global procedure gtk_widget_pop_colormap()
    c_proc( gtk_widget_pop_colormap_, {} )
end procedure

----------------------------------------
-- gtk_widget_pop_visual
----------------------------------------
constant gtk_widget_pop_visual_ = link_c_proc( GTK, 
  "gtk_widget_pop_visual", {} )

global procedure gtk_widget_pop_visual()
    c_proc( gtk_widget_pop_visual_, {} )
end procedure

----------------------------------------
-- gtk_widget_set_default_style
----------------------------------------
constant gtk_widget_set_default_style_ = link_c_proc( GTK, 
  "gtk_widget_set_default_style", {C_POINTER} )

global procedure gtk_widget_set_default_style(atom style_)
    c_proc( gtk_widget_set_default_style_, {style_} )
end procedure

----------------------------------------
-- gtk_widget_set_default_colormap
----------------------------------------
constant gtk_widget_set_default_colormap_ = link_c_proc( GTK, 
  "gtk_widget_set_default_colormap", {C_POINTER} )

global procedure gtk_widget_set_default_colormap(atom colormap_)
    c_proc( gtk_widget_set_default_colormap_, {colormap_} )
end procedure

----------------------------------------
-- gtk_widget_set_default_visual
----------------------------------------
constant gtk_widget_set_default_visual_ = link_c_proc( GTK, 
  "gtk_widget_set_default_visual", {C_POINTER} )

global procedure gtk_widget_set_default_visual(atom visual_)
    c_proc( gtk_widget_set_default_visual_, {visual_} )
end procedure

----------------------------------------
-- gtk_widget_get_default_style
----------------------------------------
constant gtk_widget_get_default_style_ = link_c_func( GTK, 
  "gtk_widget_get_default_style", {}, C_POINTER )

global function gtk_widget_get_default_style()
    return c_func( gtk_widget_get_default_style_, {} )
end function

----------------------------------------
-- gtk_widget_get_default_colormap
----------------------------------------
constant gtk_widget_get_default_colormap_ = link_c_func( GTK, 
  "gtk_widget_get_default_colormap", {}, C_POINTER )

global function gtk_widget_get_default_colormap()
    return c_func( gtk_widget_get_default_colormap_, {} )
end function

----------------------------------------
-- gtk_widget_get_default_visual
----------------------------------------
constant gtk_widget_get_default_visual_ = link_c_func( GTK, 
  "gtk_widget_get_default_visual", {}, C_POINTER )

global function gtk_widget_get_default_visual()
    return c_func( gtk_widget_get_default_visual_, {} )
end function

----------------------------------------
-- gtk_widget_shape_combine_mask
----------------------------------------
constant gtk_widget_shape_combine_mask_ = link_c_proc( GTK, 
  "gtk_widget_shape_combine_mask", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_widget_shape_combine_mask(atom widget_, atom shape_mask_, integer offset_x_, integer offset_y_)
    c_proc( gtk_widget_shape_combine_mask_, {widget_,shape_mask_,offset_x_,offset_y_} )
end procedure

----------------------------------------
-- gtk_widget_reset_shapes
----------------------------------------
constant gtk_widget_reset_shapes_ = link_c_proc( GTK, 
  "gtk_widget_reset_shapes", {C_POINTER} )

global procedure gtk_widget_reset_shapes(atom widget_)
    c_proc( gtk_widget_reset_shapes_, {widget_} )
end procedure

----------------------------------------
-- gtk_widget_path
----------------------------------------
constant gtk_widget_path_ = link_c_proc( GTK, 
  "gtk_widget_path", {C_POINTER,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_widget_path(atom widget_, integer path_length_, sequence path_, sequence path_reversed_)
    atom string1, string2
    string1 = allocate_string( path_ )
    string2 = allocate_string( path_reversed_ )
    c_proc( gtk_widget_path_, {widget_,path_length_,string1,string2} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- gtk_widget_class_path
----------------------------------------
constant gtk_widget_class_path_ = link_c_proc( GTK, 
  "gtk_widget_class_path", {C_POINTER,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_widget_class_path(atom widget_, integer path_length_, sequence path_, sequence path_reversed_)
    atom string1, string2
    string1 = allocate_string( path_ )
    string2 = allocate_string( path_reversed_ )
    c_proc( gtk_widget_class_path_, {widget_,path_length_,string1,string2} )
    free( string1 )
    free( string2 )
end procedure



----------------------------------------
----------------------------------------
-- GTKMISC.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkMisc
----------------------------------------
global constant
    GtkMisc_widget                      = allot(SIZEOF_GtkWidget),
    GtkMisc_xalign                      = allot(TYPE_GFLOAT),
    GtkMisc_yalign                      = allot(TYPE_GFLOAT),
    GtkMisc_xpad                        = allot(TYPE_GUINT16),
    GtkMisc_ypad                        = allot(TYPE_GUINT16),
    SIZEOF_GtkMisc                      = allotted_size()

----------------------------------------
-- GtkMiscClass
----------------------------------------
global constant
    GtkMiscClass_parent_class           = allot(SIZEOF_GtkWidgetClass),
    SIZEOF_GtkMiscClass                 = allotted_size()
----------------------------------------
-- gtk_misc_get_type
----------------------------------------
constant gtk_misc_get_type_ = link_c_func( GTK, 
  "gtk_misc_get_type", {}, C_UINT )

global function gtk_misc_get_type()
    return c_func( gtk_misc_get_type_, {} )
end function

----------------------------------------
-- gtk_misc_set_alignment
----------------------------------------
constant gtk_misc_set_alignment_ = link_c_proc( GTK, 
  "gtk_misc_set_alignment", {C_POINTER,C_LONG,C_LONG} )

global procedure gtk_misc_set_alignment(atom misc_, integer xalign_, integer yalign_)
    c_proc( gtk_misc_set_alignment_, {misc_,xalign_,yalign_} )
end procedure

----------------------------------------
-- gtk_misc_set_padding
----------------------------------------
constant gtk_misc_set_padding_ = link_c_proc( GTK, 
  "gtk_misc_set_padding", {C_POINTER,C_INT,C_INT} )

global procedure gtk_misc_set_padding(atom misc_, integer xpad_, integer ypad_)
    c_proc( gtk_misc_set_padding_, {misc_,xpad_,ypad_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKLABEL.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkLabel
----------------------------------------
global constant
    GtkLabel_misc                       = allot(SIZEOF_GtkMisc),
    GtkLabel_label                      = allot(TYPE_POINTER),
    GtkLabel_label_wc                   = allot(TYPE_POINTER),
    GtkLabel_pattern                    = allot(TYPE_POINTER),
    GtkLabel_words                      = allot(TYPE_POINTER),
    GtkLabel_max_width                  = allot(TYPE_GUINT),
    GtkLabel_jtype                      = allot(TYPE_GUINT),
    GtkLabel_wrap                       = allot(TYPE_GBOOLEAN),
    SIZEOF_GtkLabel                     = allotted_size()

----------------------------------------
-- GtkLabelClass
----------------------------------------
global constant
    GtkLabelClass_parent_class          = allot(SIZEOF_GtkMiscClass),
    SIZEOF_GtkLabelClass                = allotted_size()
----------------------------------------
-- gtk_label_get_type
----------------------------------------
constant gtk_label_get_type_ = link_c_func( GTK, 
  "gtk_label_get_type", {}, C_UINT )

global function gtk_label_get_type()
    return c_func( gtk_label_get_type_, {} )
end function

----------------------------------------
-- gtk_label_new
----------------------------------------
constant gtk_label_new_ = link_c_func( GTK, 
  "gtk_label_new", {C_POINTER}, C_POINTER )

global function gtk_label_new(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_label_new_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_label_set_text
----------------------------------------
constant gtk_label_set_text_ = link_c_proc( GTK, 
  "gtk_label_set_text", {C_POINTER,C_POINTER} )

global procedure gtk_label_set_text(atom label_, sequence str_)
    atom string1
    string1 = allocate_string( str_ )
    c_proc( gtk_label_set_text_, {label_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_label_set_justify
----------------------------------------
constant gtk_label_set_justify_ = link_c_proc( GTK, 
  "gtk_label_set_justify", {C_POINTER,C_POINTER} )

global procedure gtk_label_set_justify(atom label_, atom jtype_)
    c_proc( gtk_label_set_justify_, {label_,jtype_} )
end procedure

----------------------------------------
-- gtk_label_set_pattern
----------------------------------------
constant gtk_label_set_pattern_ = link_c_proc( GTK, 
  "gtk_label_set_pattern", {C_POINTER,C_POINTER} )

global procedure gtk_label_set_pattern(atom label_, sequence pattern_)
    atom string1
    string1 = allocate_string( pattern_ )
    c_proc( gtk_label_set_pattern_, {label_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_label_set_line_wrap
----------------------------------------
constant gtk_label_set_line_wrap_ = link_c_proc( GTK, 
  "gtk_label_set_line_wrap", {C_POINTER,C_INT} )

global procedure gtk_label_set_line_wrap(atom label_, integer wrap_)
    c_proc( gtk_label_set_line_wrap_, {label_,wrap_} )
end procedure

----------------------------------------
-- gtk_label_get
----------------------------------------
constant gtk_label_get_ = link_c_proc( GTK, 
  "gtk_label_get", {C_POINTER,C_POINTER} )

global procedure gtk_label_get(atom label_, sequence str_)
    atom string1
    string1 = allocate_string( str_ )
    c_proc( gtk_label_get_, {label_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_label_parse_uline
----------------------------------------
constant gtk_label_parse_uline_ = link_c_func( GTK, 
  "gtk_label_parse_uline", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_label_parse_uline(atom label_, sequence string_)
    integer result
    atom string1
    string1 = allocate_string( string_ )
    result = c_func( gtk_label_parse_uline_, {label_,string1} )
    free( string1 )
    return result
end function



----------------------------------------
----------------------------------------
-- GTKACCELLABEL.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkAccelLabel
----------------------------------------
global constant
    GtkAccelLabel_label                 = allot(SIZEOF_GtkLabel),
    GtkAccelLabel_queue_id              = allot(TYPE_GUINT),
    GtkAccelLabel_accel_padding         = allot(TYPE_GUINT),
    GtkAccelLabel_accel_widget          = allot(TYPE_POINTER),
    GtkAccelLabel_accel_string          = allot(TYPE_POINTER),
    GtkAccelLabel_accel_string_width    = allot(TYPE_GUINT16),
    SIZEOF_GtkAccelLabel                = allotted_size()

----------------------------------------
-- GtkAccelLabelClass
----------------------------------------
global constant
    GtkAccelLabelClass_parent_class     = allot(SIZEOF_GtkLabelClass),
    GtkAccelLabelClass_signal_quote1    = allot(TYPE_POINTER),
    GtkAccelLabelClass_signal_quote2    = allot(TYPE_POINTER),
    GtkAccelLabelClass_mod_name_shift   = allot(TYPE_POINTER),
    GtkAccelLabelClass_mod_name_control = allot(TYPE_POINTER),
    GtkAccelLabelClass_mod_name_alt     = allot(TYPE_POINTER),
    GtkAccelLabelClass_mod_separator    = allot(TYPE_POINTER),
    GtkAccelLabelClass_accel_seperator  = allot(TYPE_POINTER),
    GtkAccelLabelClass_latin1_to_char   = allot(TYPE_GUINT),
    SIZEOF_GtkAccelLabelClass           = allotted_size()
----------------------------------------
-- gtk_accel_label_get_type
----------------------------------------
constant gtk_accel_label_get_type_ = link_c_func( GTK, 
  "gtk_accel_label_get_type", {}, C_UINT )

global function gtk_accel_label_get_type()
    return c_func( gtk_accel_label_get_type_, {} )
end function

----------------------------------------
-- gtk_accel_label_new
----------------------------------------
constant gtk_accel_label_new_ = link_c_func( GTK, 
  "gtk_accel_label_new", {C_POINTER}, C_POINTER )

global function gtk_accel_label_new(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_accel_label_new_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_accel_label_get_accel_width
----------------------------------------
constant gtk_accel_label_get_accel_width_ = link_c_func( GTK, 
  "gtk_accel_label_get_accel_width", {C_POINTER}, C_UINT )

global function gtk_accel_label_get_accel_width(atom accel_label_)
    return c_func( gtk_accel_label_get_accel_width_, {accel_label_} )
end function

----------------------------------------
-- gtk_accel_label_set_accel_widget
----------------------------------------
constant gtk_accel_label_set_accel_widget_ = link_c_proc( GTK, 
  "gtk_accel_label_set_accel_widget", {C_POINTER,C_POINTER} )

global procedure gtk_accel_label_set_accel_widget(atom accel_label_, atom accel_widget_)
    c_proc( gtk_accel_label_set_accel_widget_, {accel_label_,accel_widget_} )
end procedure

----------------------------------------
-- gtk_accel_label_refetch
----------------------------------------
constant gtk_accel_label_refetch_ = link_c_func( GTK, 
  "gtk_accel_label_refetch", {C_POINTER}, C_INT )

global function gtk_accel_label_refetch(atom accel_label_)
    return c_func( gtk_accel_label_refetch_, {accel_label_} )
end function


----------------------------------------
----------------------------------------
-- GTKDATA.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkData
----------------------------------------
global constant
    GtkData_object                      = allot(SIZEOF_GtkObject),
    SIZEOF_GtkData                      = allotted_size()

----------------------------------------
-- GtkDataClass
----------------------------------------
global constant
    GtkDataClass_parent_class           = allot(SIZEOF_GtkObjectClass),
    GtkDataClass_disconnect             = allot(TYPE_GPOINTER),
    SIZEOF_GtkDataClass                 = allotted_size()
----------------------------------------
-- gtk_data_get_type
----------------------------------------
constant gtk_data_get_type_ = link_c_func( GTK, 
  "gtk_data_get_type", {}, C_UINT )

global function gtk_data_get_type()
    return c_func( gtk_data_get_type_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKADJUSTMENT.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkAdjustment
----------------------------------------
global constant
    GtkAdjustment_data                  = allot(SIZEOF_GtkData),
    GtkAdjustment_lower                 = allot(TYPE_GFLOAT),
    GtkAdjustment_upper                 = allot(TYPE_GFLOAT),
    GtkAdjustment_value                 = allot(TYPE_GFLOAT),
    GtkAdjustment_step_increment        = allot(TYPE_GFLOAT),
    GtkAdjustment_page_increment        = allot(TYPE_GFLOAT),
    GtkAdjustment_page_size             = allot(TYPE_GFLOAT),
    SIZEOF_GtkAdjustment                = allotted_size()

----------------------------------------
-- GtkAdjustmentClass
----------------------------------------
global constant
    GtkAdjustmentClass_parent_class     = allot(SIZEOF_GtkDataClass),
    GtkAdjustmentClass_changed          = allot(TYPE_GPOINTER),
    GtkAdjustmentClass_value_changed    = allot(TYPE_GPOINTER),
    SIZEOF_GtkAdjustmentClass           = allotted_size()
----------------------------------------
-- gtk_adjustment_get_type
----------------------------------------
constant gtk_adjustment_get_type_ = link_c_func( GTK, 
  "gtk_adjustment_get_type", {}, C_UINT )

global function gtk_adjustment_get_type()
    return c_func( gtk_adjustment_get_type_, {} )
end function

----------------------------------------
-- gtk_adjustment_new
----------------------------------------
constant gtk_adjustment_new_ = link_c_func( GTK, 
  "gtk_adjustment_new", {C_LONG,C_LONG,C_LONG,C_LONG,C_LONG,C_LONG}, C_POINTER )

global function gtk_adjustment_new(integer value_, integer lower_, integer upper_, integer step_increment_, integer 
 page_increment_, integer page_size_)
    return c_func( gtk_adjustment_new_, {value_,lower_,upper_,step_increment_,page_increment_,page_size_} )
end function

----------------------------------------
-- gtk_adjustment_changed
----------------------------------------
constant gtk_adjustment_changed_ = link_c_proc( GTK, 
  "gtk_adjustment_changed", {C_POINTER} )

global procedure gtk_adjustment_changed(atom adjustment_)
    c_proc( gtk_adjustment_changed_, {adjustment_} )
end procedure

----------------------------------------
-- gtk_adjustment_value_changed
----------------------------------------
constant gtk_adjustment_value_changed_ = link_c_proc( GTK, 
  "gtk_adjustment_value_changed", {C_POINTER} )

global procedure gtk_adjustment_value_changed(atom adjustment_)
    c_proc( gtk_adjustment_value_changed_, {adjustment_} )
end procedure

----------------------------------------
-- gtk_adjustment_clamp_page
----------------------------------------
constant gtk_adjustment_clamp_page_ = link_c_proc( GTK, 
  "gtk_adjustment_clamp_page", {C_POINTER,C_LONG,C_LONG} )

global procedure gtk_adjustment_clamp_page(atom adjustment_, integer lower_, integer upper_)
    c_proc( gtk_adjustment_clamp_page_, {adjustment_,lower_,upper_} )
end procedure

----------------------------------------
-- gtk_adjustment_set_value
----------------------------------------
constant gtk_adjustment_set_value_ = link_c_proc( GTK, 
  "gtk_adjustment_set_value", {C_POINTER,C_LONG} )

global procedure gtk_adjustment_set_value(atom adjustment_, integer value_)
    c_proc( gtk_adjustment_set_value_, {adjustment_,value_} )
end procedure






----------------------------------------
----------------------------------------
-- GTKSTYLE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkStyleClass
----------------------------------------
global constant
    GtkStyleClass_xthickness            = allot(TYPE_GINT),
    GtkStyleClass_ythickness            = allot(TYPE_GINT),
    GtkStyleClass_draw_hline            = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_vline            = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_shadow           = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_polygon          = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_arrow            = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_diamond          = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_oval             = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_string           = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_box              = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_flat_box         = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_check            = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_option           = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_cross            = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_ramp             = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_tab              = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_shadow_gap       = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_box_gap          = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_extension        = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_focus            = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_slider           = allot(TYPE_GPOINTER),
    GtkStyleClass_draw_handle           = allot(TYPE_GPOINTER),
    SIZEOF_GtkStyleClass                = allotted_size()
----------------------------------------
-- gtk_style_new
----------------------------------------
constant gtk_style_new_ = link_c_func( GTK, 
  "gtk_style_new", {}, C_POINTER )

global function gtk_style_new()
    return c_func( gtk_style_new_, {} )
end function

----------------------------------------
-- gtk_style_copy
----------------------------------------
constant gtk_style_copy_ = link_c_func( GTK, 
  "gtk_style_copy", {C_POINTER}, C_POINTER )

global function gtk_style_copy(atom style_)
    return c_func( gtk_style_copy_, {style_} )
end function

----------------------------------------
-- gtk_style_attach
----------------------------------------
constant gtk_style_attach_ = link_c_func( GTK, 
  "gtk_style_attach", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_style_attach(atom style_, atom window_)
    return c_func( gtk_style_attach_, {style_,window_} )
end function

----------------------------------------
-- gtk_style_detach
----------------------------------------
constant gtk_style_detach_ = link_c_proc( GTK, 
  "gtk_style_detach", {C_POINTER} )

global procedure gtk_style_detach(atom style_)
    c_proc( gtk_style_detach_, {style_} )
end procedure

----------------------------------------
-- gtk_style_ref
----------------------------------------
constant gtk_style_ref_ = link_c_func( GTK, 
  "gtk_style_ref", {C_POINTER}, C_POINTER )

global function gtk_style_ref(atom style_)
    return c_func( gtk_style_ref_, {style_} )
end function

----------------------------------------
-- gtk_style_unref
----------------------------------------
constant gtk_style_unref_ = link_c_proc( GTK, 
  "gtk_style_unref", {C_POINTER} )

global procedure gtk_style_unref(atom style_)
    c_proc( gtk_style_unref_, {style_} )
end procedure

----------------------------------------
-- gtk_style_set_background
----------------------------------------
constant gtk_style_set_background_ = link_c_proc( GTK, 
  "gtk_style_set_background", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_style_set_background(atom style_, atom window_, atom state_type_)
    c_proc( gtk_style_set_background_, {style_,window_,state_type_} )
end procedure

----------------------------------------
-- gtk_style_apply_default_background
----------------------------------------
constant gtk_style_apply_default_background_ = link_c_proc( GTK, 
  "gtk_style_apply_default_background", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_style_apply_default_background(atom style_, atom window_, integer set_bg_, atom state_type_, 
 atom area_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gtk_style_apply_default_background_, {style_,window_,set_bg_,state_type_,area_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_hline
----------------------------------------
constant gtk_draw_hline_ = link_c_proc( GTK, 
  "gtk_draw_hline", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT} )

global procedure gtk_draw_hline(atom style_, atom window_, atom state_type_, integer x1_, integer x2_, integer y_)
    c_proc( gtk_draw_hline_, {style_,window_,state_type_,x1_,x2_,y_} )
end procedure

----------------------------------------
-- gtk_draw_vline
----------------------------------------
constant gtk_draw_vline_ = link_c_proc( GTK, 
  "gtk_draw_vline", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT} )

global procedure gtk_draw_vline(atom style_, atom window_, atom state_type_, integer y1_, integer y2_, integer x_)
    c_proc( gtk_draw_vline_, {style_,window_,state_type_,y1_,y2_,x_} )
end procedure

----------------------------------------
-- gtk_draw_shadow
----------------------------------------
constant gtk_draw_shadow_ = link_c_proc( GTK, 
  "gtk_draw_shadow", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_shadow(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_)
    c_proc( gtk_draw_shadow_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_polygon
----------------------------------------
constant gtk_draw_polygon_ = link_c_proc( GTK, 
  "gtk_draw_polygon", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_draw_polygon(atom style_, atom window_, atom state_type_, atom shadow_type_, atom points_, integer npoints_, integer fill_)
    c_proc( gtk_draw_polygon_, {style_,window_,state_type_,shadow_type_,points_,npoints_,fill_} )
end procedure

----------------------------------------
-- gtk_draw_arrow
----------------------------------------
constant gtk_draw_arrow_ = link_c_proc( GTK, 
  "gtk_draw_arrow", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_draw_arrow(atom style_, atom window_, atom state_type_, atom shadow_type_, atom arrow_type_, 
 integer fill_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gtk_draw_arrow_, {style_,window_,state_type_,shadow_type_,arrow_type_,fill_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_diamond
----------------------------------------
constant gtk_draw_diamond_ = link_c_proc( GTK, 
  "gtk_draw_diamond", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_diamond(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, 
 integer y_, integer width_, integer height_)
    c_proc( gtk_draw_diamond_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_oval
----------------------------------------
constant gtk_draw_oval_ = link_c_proc( GTK, 
  "gtk_draw_oval", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_oval(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_)
    c_proc( gtk_draw_oval_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_string
----------------------------------------
constant gtk_draw_string_ = link_c_proc( GTK, 
  "gtk_draw_string", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_POINTER} )

global procedure gtk_draw_string(atom style_, atom window_, atom state_type_, integer x_, integer y_, sequence string_)
    atom string1
    string1 = allocate_string( string_ )
    c_proc( gtk_draw_string_, {style_,window_,state_type_,x_,y_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_draw_box
----------------------------------------
constant gtk_draw_box_ = link_c_proc( GTK, 
  "gtk_draw_box", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_box(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_)
    c_proc( gtk_draw_box_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_flat_box
----------------------------------------
constant gtk_draw_flat_box_ = link_c_proc( GTK, 
  "gtk_draw_flat_box", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_flat_box(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, 
 integer y_, integer width_, integer height_)
    c_proc( gtk_draw_flat_box_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_check
----------------------------------------
constant gtk_draw_check_ = link_c_proc( GTK, 
  "gtk_draw_check", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_check(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_)
    c_proc( gtk_draw_check_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_option
----------------------------------------
constant gtk_draw_option_ = link_c_proc( GTK, 
  "gtk_draw_option", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_option(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_)
    c_proc( gtk_draw_option_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_cross
----------------------------------------
constant gtk_draw_cross_ = link_c_proc( GTK, 
  "gtk_draw_cross", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_cross(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_)
    c_proc( gtk_draw_cross_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_ramp
----------------------------------------
constant gtk_draw_ramp_ = link_c_proc( GTK, 
  "gtk_draw_ramp", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_ramp(atom style_, atom window_, atom state_type_, atom shadow_type_, atom arrow_type_, 
 integer x_, integer y_, integer width_, integer height_)
    c_proc( gtk_draw_ramp_, {style_,window_,state_type_,shadow_type_,arrow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_tab
----------------------------------------
constant gtk_draw_tab_ = link_c_proc( GTK, 
  "gtk_draw_tab", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_tab(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_)
    c_proc( gtk_draw_tab_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_shadow_gap
----------------------------------------
constant gtk_draw_shadow_gap_ = link_c_proc( GTK, 
  "gtk_draw_shadow_gap", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_INT,C_INT} 
 )

global procedure gtk_draw_shadow_gap(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, 
 integer y_, integer width_, integer height_, atom gap_side_, integer gap_x_, integer gap_width_)
    c_proc( gtk_draw_shadow_gap_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_,gap_side_,gap_x_,gap_width_} )
end procedure

----------------------------------------
-- gtk_draw_box_gap
----------------------------------------
constant gtk_draw_box_gap_ = link_c_proc( GTK, 
  "gtk_draw_box_gap", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_INT,C_INT} 
 )

global procedure gtk_draw_box_gap(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, 
 integer y_, integer width_, integer height_, atom gap_side_, integer gap_x_, integer gap_width_)
    c_proc( gtk_draw_box_gap_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_,gap_side_,gap_x_,gap_width_} )
end procedure

----------------------------------------
-- gtk_draw_extension
----------------------------------------
constant gtk_draw_extension_ = link_c_proc( GTK, 
  "gtk_draw_extension", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER} 
 )

global procedure gtk_draw_extension(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, 
 integer y_, integer width_, integer height_, atom gap_side_)
    c_proc( gtk_draw_extension_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_,gap_side_} )
end procedure

----------------------------------------
-- gtk_draw_focus
----------------------------------------
constant gtk_draw_focus_ = link_c_proc( GTK, 
  "gtk_draw_focus", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_draw_focus(atom style_, atom window_, integer x_, integer y_, integer width_, integer height_)
    c_proc( gtk_draw_focus_, {style_,window_,x_,y_,width_,height_} )
end procedure

----------------------------------------
-- gtk_draw_slider
----------------------------------------
constant gtk_draw_slider_ = link_c_proc( GTK, 
  "gtk_draw_slider", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER} )

global procedure gtk_draw_slider(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_, atom orientation_)
    c_proc( gtk_draw_slider_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_,orientation_} )
end procedure

----------------------------------------
-- gtk_draw_handle
----------------------------------------
constant gtk_draw_handle_ = link_c_proc( GTK, 
  "gtk_draw_handle", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER} )

global procedure gtk_draw_handle(atom style_, atom window_, atom state_type_, atom shadow_type_, integer x_, integer 
 y_, integer width_, integer height_, atom orientation_)
    c_proc( gtk_draw_handle_, {style_,window_,state_type_,shadow_type_,x_,y_,width_,height_,orientation_} )
end procedure

----------------------------------------
-- gtk_paint_hline
----------------------------------------
constant gtk_paint_hline_ = link_c_proc( GTK, 
  "gtk_paint_hline", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_hline(atom style_, atom window_, atom state_type_, atom area_, atom widget_, sequence 
 detail_, integer x1_, integer x2_, integer y_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_hline_, {style_,window_,state_type_,area_,widget_,string1,x1_,x2_,y_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_vline
----------------------------------------
constant gtk_paint_vline_ = link_c_proc( GTK, 
  "gtk_paint_vline", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_vline(atom style_, atom window_, atom state_type_, atom area_, atom widget_, sequence 
 detail_, integer y1_, integer y2_, integer x_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_vline_, {style_,window_,state_type_,area_,widget_,string1,y1_,y2_,x_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_shadow
----------------------------------------
constant gtk_paint_shadow_ = link_c_proc( GTK, 
  "gtk_paint_shadow", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_shadow(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_shadow_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_polygon
----------------------------------------
constant gtk_paint_polygon_ = link_c_proc( GTK, 
  "gtk_paint_polygon", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT} 
 )

global procedure gtk_paint_polygon(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, atom points_, integer npoints_, integer fill_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_polygon_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,points_,npoints_,fill_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_arrow
----------------------------------------
constant gtk_paint_arrow_ = link_c_proc( GTK, 
  "gtk_paint_arrow", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_arrow(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, atom 
 widget_, sequence detail_, atom arrow_type_, integer fill_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_arrow_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,arrow_type_,fill_,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_diamond
----------------------------------------
constant gtk_paint_diamond_ = link_c_proc( GTK, 
  "gtk_paint_diamond", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_diamond(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_diamond_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_oval
----------------------------------------
constant gtk_paint_oval_ = link_c_proc( GTK, 
  "gtk_paint_oval", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_oval(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, atom 
 widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_oval_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_string
----------------------------------------
constant gtk_paint_string_ = link_c_proc( GTK, 
  "gtk_paint_string", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_POINTER} 
 )

global procedure gtk_paint_string(atom style_, atom window_, atom state_type_, atom area_, atom widget_, sequence 
 detail_, integer x_, integer y_, sequence string_)
    atom string1, string2
    string1 = allocate_string( detail_ )
    string2 = allocate_string( string_ )
    c_proc( gtk_paint_string_, {style_,window_,state_type_,area_,widget_,string1,x_,y_,string2} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- gtk_paint_box
----------------------------------------
constant gtk_paint_box_ = link_c_proc( GTK, 
  "gtk_paint_box", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_box(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, atom 
 widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_box_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_flat_box
----------------------------------------
constant gtk_paint_flat_box_ = link_c_proc( GTK, 
  "gtk_paint_flat_box", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_flat_box(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_flat_box_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_check
----------------------------------------
constant gtk_paint_check_ = link_c_proc( GTK, 
  "gtk_paint_check", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_check(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, atom 
 widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_check_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_option
----------------------------------------
constant gtk_paint_option_ = link_c_proc( GTK, 
  "gtk_paint_option", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_option(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_option_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_cross
----------------------------------------
constant gtk_paint_cross_ = link_c_proc( GTK, 
  "gtk_paint_cross", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_cross(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, atom 
 widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_cross_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_ramp
----------------------------------------
constant gtk_paint_ramp_ = link_c_proc( GTK, 
  "gtk_paint_ramp", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_ramp(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, atom 
 widget_, sequence detail_, atom arrow_type_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_ramp_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,arrow_type_,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_tab
----------------------------------------
constant gtk_paint_tab_ = link_c_proc( GTK, 
  "gtk_paint_tab", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} 
 )

global procedure gtk_paint_tab(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, atom 
 widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_tab_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_shadow_gap
----------------------------------------
constant gtk_paint_shadow_gap_ = link_c_proc( GTK, 
  "gtk_paint_shadow_gap", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_INT,C_INT} 
 )

global procedure gtk_paint_shadow_gap(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_, atom gap_side_, integer gap_x_, integer gap_width_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_shadow_gap_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_,gap_side_,gap_x_,gap_width_} 
 )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_box_gap
----------------------------------------
constant gtk_paint_box_gap_ = link_c_proc( GTK, 
  "gtk_paint_box_gap", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER,C_INT,C_INT} 
 )

global procedure gtk_paint_box_gap(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_, atom gap_side_, integer gap_x_, integer gap_width_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_box_gap_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_,gap_side_,gap_x_,gap_width_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_extension
----------------------------------------
constant gtk_paint_extension_ = link_c_proc( GTK, 
  "gtk_paint_extension", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER} 
 )

global procedure gtk_paint_extension(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_, atom gap_side_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_extension_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_,gap_side_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_focus
----------------------------------------
constant gtk_paint_focus_ = link_c_proc( GTK, 
  "gtk_paint_focus", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_paint_focus(atom style_, atom window_, atom area_, atom widget_, sequence detail_, integer 
 x_, integer y_, integer width_, integer height_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_focus_, {style_,window_,area_,widget_,string1,x_,y_,width_,height_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_slider
----------------------------------------
constant gtk_paint_slider_ = link_c_proc( GTK, 
  "gtk_paint_slider", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER} 
 )

global procedure gtk_paint_slider(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_, atom orientation_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_slider_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_,orientation_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_paint_handle
----------------------------------------
constant gtk_paint_handle_ = link_c_proc( GTK, 
  "gtk_paint_handle", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_POINTER} 
 )

global procedure gtk_paint_handle(atom style_, atom window_, atom state_type_, atom shadow_type_, atom area_, 
 atom widget_, sequence detail_, integer x_, integer y_, integer width_, integer height_, atom orientation_)
    atom string1
    string1 = allocate_string( detail_ )
    c_proc( gtk_paint_handle_, {style_,window_,state_type_,shadow_type_,area_,widget_,string1,x_,y_,width_,height_,orientation_} )
    free( string1 )
end procedure


----------------------------------------
----------------------------------------
-- GTKCONTAINER.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkContainer
----------------------------------------
global constant
    GtkContainer_widget                 = allot(SIZEOF_GtkWidget),
    GtkContainer_focus_child            = allot(TYPE_POINTER),
    GtkContainer_border_width           = allot(TYPE_GUINT),
    GtkContainer_need_resize            = allot(TYPE_GUINT),
    GtkContainer_resize_mode            = allot(TYPE_GUINT),
    GtkContainer_resize_widgets         = allot(TYPE_POINTER),
    SIZEOF_GtkContainer                 = allotted_size()

----------------------------------------
-- GtkContainerClass
----------------------------------------
-- manually corrected
-- pad1 and pad2 are pointers
global constant
    GtkContainerClass_parent_class      = allot(SIZEOF_GtkWidgetClass),
    GtkContainerClass_n_child_args      = allot(TYPE_GUINT),
    GtkContainerClass_add               = allot(TYPE_GPOINTER),
    GtkContainerClass_remove            = allot(TYPE_GPOINTER),
    GtkContainerClass_check_resize      = allot(TYPE_GPOINTER),
    GtkContainerClass_forall            = allot(TYPE_GPOINTER),
    GtkContainerClass_focus             = allot(TYPE_GPOINTER),
    GtkContainerClass_set_focus_child   = allot(TYPE_GPOINTER),
    GtkContainerClass_child_type        = allot(TYPE_GPOINTER),
    GtkContainerClass_set_child_arg     = allot(TYPE_GPOINTER),
    GtkContainerClass_get_child_arg     = allot(TYPE_GPOINTER),
    GtkContainerClass_composite_name    = allot(TYPE_GPOINTER),
    GtkContainerClass_pad1              = allot(TYPE_GPOINTER),
    GtkContainerClass_pad2              = allot(TYPE_GPOINTER),
    SIZEOF_GtkContainerClass            = allotted_size()
    
----------------------------------------
-- gtk_container_get_type
----------------------------------------
constant gtk_container_get_type_ = link_c_func( GTK, 
  "gtk_container_get_type", {}, C_UINT )

global function gtk_container_get_type()
    return c_func( gtk_container_get_type_, {} )
end function

----------------------------------------
-- gtk_container_set_border_width
----------------------------------------
constant gtk_container_set_border_width_ = link_c_proc( GTK, 
  "gtk_container_set_border_width", {C_POINTER,C_UINT} )

global procedure gtk_container_set_border_width(atom container_, integer border_width_)
    c_proc( gtk_container_set_border_width_, {container_,border_width_} )
end procedure

----------------------------------------
-- gtk_container_add
----------------------------------------
constant gtk_container_add_ = link_c_proc( GTK, 
  "gtk_container_add", {C_POINTER,C_POINTER} )

global procedure gtk_container_add(atom container_, atom widget_)
    c_proc( gtk_container_add_, {container_,widget_} )
end procedure

----------------------------------------
-- gtk_container_remove
----------------------------------------
constant gtk_container_remove_ = link_c_proc( GTK, 
  "gtk_container_remove", {C_POINTER,C_POINTER} )

global procedure gtk_container_remove(atom container_, atom widget_)
    c_proc( gtk_container_remove_, {container_,widget_} )
end procedure

----------------------------------------
-- gtk_container_set_resize_mode
----------------------------------------
constant gtk_container_set_resize_mode_ = link_c_proc( GTK, 
  "gtk_container_set_resize_mode", {C_POINTER,C_POINTER} )

global procedure gtk_container_set_resize_mode(atom container_, atom resize_mode_)
    c_proc( gtk_container_set_resize_mode_, {container_,resize_mode_} )
end procedure

----------------------------------------
-- gtk_container_check_resize
----------------------------------------
constant gtk_container_check_resize_ = link_c_proc( GTK, 
  "gtk_container_check_resize", {C_POINTER} )

global procedure gtk_container_check_resize(atom container_)
    c_proc( gtk_container_check_resize_, {container_} )
end procedure

----------------------------------------
-- gtk_container_foreach
----------------------------------------
constant gtk_container_foreach_ = link_c_proc( GTK, 
  "gtk_container_foreach", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_container_foreach(atom container_, atom callback_, atom callback_data_)
    c_proc( gtk_container_foreach_, {container_,callback_,callback_data_} )
end procedure

----------------------------------------
-- gtk_container_foreach_full
----------------------------------------
constant gtk_container_foreach_full_ = link_c_proc( GTK, 
  "gtk_container_foreach_full", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_container_foreach_full(atom container_, atom callback_, atom marshal_, atom callback_data_, atom notify_)
    c_proc( gtk_container_foreach_full_, {container_,callback_,marshal_,callback_data_,notify_} )
end procedure

----------------------------------------
-- gtk_container_children
----------------------------------------
constant gtk_container_children_ = link_c_func( GTK, 
  "gtk_container_children", {C_POINTER}, C_POINTER )

global function gtk_container_children(atom container_)
    return c_func( gtk_container_children_, {container_} )
end function

----------------------------------------
-- gtk_container_focus
----------------------------------------
constant gtk_container_focus_ = link_c_func( GTK, 
  "gtk_container_focus", {C_POINTER,C_POINTER}, C_INT )

global function gtk_container_focus(atom container_, atom direction_)
    return c_func( gtk_container_focus_, {container_,direction_} )
end function

----------------------------------------
-- gtk_container_set_focus_child
----------------------------------------
constant gtk_container_set_focus_child_ = link_c_proc( GTK, 
  "gtk_container_set_focus_child", {C_POINTER,C_POINTER} )

global procedure gtk_container_set_focus_child(atom container_, atom child_)
    c_proc( gtk_container_set_focus_child_, {container_,child_} )
end procedure

----------------------------------------
-- gtk_container_set_focus_vadjustment
----------------------------------------
constant gtk_container_set_focus_vadjustment_ = link_c_proc( GTK, 
  "gtk_container_set_focus_vadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_container_set_focus_vadjustment(atom container_, atom adjustment_)
    c_proc( gtk_container_set_focus_vadjustment_, {container_,adjustment_} )
end procedure

----------------------------------------
-- gtk_container_set_focus_hadjustment
----------------------------------------
constant gtk_container_set_focus_hadjustment_ = link_c_proc( GTK, 
  "gtk_container_set_focus_hadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_container_set_focus_hadjustment(atom container_, atom adjustment_)
    c_proc( gtk_container_set_focus_hadjustment_, {container_,adjustment_} )
end procedure

----------------------------------------
-- gtk_container_register_toplevel
----------------------------------------
constant gtk_container_register_toplevel_ = link_c_proc( GTK, 
  "gtk_container_register_toplevel", {C_POINTER} )

global procedure gtk_container_register_toplevel(atom container_)
    c_proc( gtk_container_register_toplevel_, {container_} )
end procedure

----------------------------------------
-- gtk_container_unregister_toplevel
----------------------------------------
constant gtk_container_unregister_toplevel_ = link_c_proc( GTK, 
  "gtk_container_unregister_toplevel", {C_POINTER} )

global procedure gtk_container_unregister_toplevel(atom container_)
    c_proc( gtk_container_unregister_toplevel_, {container_} )
end procedure

----------------------------------------
-- gtk_container_add_child_arg_type
----------------------------------------
constant gtk_container_add_child_arg_type_ = link_c_proc( GTK, 
  "gtk_container_add_child_arg_type", {C_POINTER,C_UINT,C_UINT,C_UINT} )

global procedure gtk_container_add_child_arg_type(sequence const_, integer arg_type_, integer arg_flags_, integer arg_id_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_container_add_child_arg_type_, {string1,arg_type_,arg_flags_,arg_id_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_container_query_child_args
----------------------------------------
constant gtk_container_query_child_args_ = link_c_func( GTK, 
  "gtk_container_query_child_args", {C_UINT,C_UINT,C_UINT}, C_POINTER )

global function gtk_container_query_child_args(integer class_type_, atom arg_flags_, integer nargs_)
    return c_func( gtk_container_query_child_args_, {class_type_,arg_flags_,nargs_} )
end function

----------------------------------------
-- gtk_container_child_getv
----------------------------------------
constant gtk_container_child_getv_ = link_c_proc( GTK, 
  "gtk_container_child_getv", {C_POINTER,C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_container_child_getv(atom container_, atom child_, integer n_args_, atom args_)
    c_proc( gtk_container_child_getv_, {container_,child_,n_args_,args_} )
end procedure

----------------------------------------
-- gtk_container_child_setv
----------------------------------------
constant gtk_container_child_setv_ = link_c_proc( GTK, 
  "gtk_container_child_setv", {C_POINTER,C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_container_child_setv(atom container_, atom child_, integer n_args_, atom args_)
    c_proc( gtk_container_child_setv_, {container_,child_,n_args_,args_} )
end procedure

----------------------------------------
-- gtk_container_add_with_args
----------------------------------------
constant gtk_container_add_with_args_ = link_c_proc( GTK, 
  "gtk_container_add_with_args", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_container_add_with_args(atom container_, atom widget_, sequence first_arg_name_)
    atom string1
    string1 = allocate_string( first_arg_name_ )
    c_proc( gtk_container_add_with_args_, {container_,widget_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_container_addv
----------------------------------------
constant gtk_container_addv_ = link_c_proc( GTK, 
  "gtk_container_addv", {C_POINTER,C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_container_addv(atom container_, atom widget_, integer n_args_, atom args_)
    c_proc( gtk_container_addv_, {container_,widget_,n_args_,args_} )
end procedure

----------------------------------------
-- gtk_container_child_set
----------------------------------------
constant gtk_container_child_set_ = link_c_proc( GTK, 
  "gtk_container_child_set", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_container_child_set(atom container_, atom child_, sequence first_arg_name_)
    atom string1
    string1 = allocate_string( first_arg_name_ )
    c_proc( gtk_container_child_set_, {container_,child_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_container_queue_resize
----------------------------------------
constant gtk_container_queue_resize_ = link_c_proc( GTK, 
  "gtk_container_queue_resize", {C_POINTER} )

global procedure gtk_container_queue_resize(atom container_)
    c_proc( gtk_container_queue_resize_, {container_} )
end procedure

----------------------------------------
-- gtk_container_clear_resize_widgets
----------------------------------------
constant gtk_container_clear_resize_widgets_ = link_c_proc( GTK, 
  "gtk_container_clear_resize_widgets", {C_POINTER} )

global procedure gtk_container_clear_resize_widgets(atom container_)
    c_proc( gtk_container_clear_resize_widgets_, {container_} )
end procedure

----------------------------------------
-- gtk_container_arg_set
----------------------------------------
constant gtk_container_arg_set_ = link_c_proc( GTK, 
  "gtk_container_arg_set", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_container_arg_set(atom container_, atom child_, atom arg_, atom info_)
    c_proc( gtk_container_arg_set_, {container_,child_,arg_,info_} )
end procedure

----------------------------------------
-- gtk_container_arg_get
----------------------------------------
constant gtk_container_arg_get_ = link_c_proc( GTK, 
  "gtk_container_arg_get", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_container_arg_get(atom container_, atom child_, atom arg_, atom info_)
    c_proc( gtk_container_arg_get_, {container_,child_,arg_,info_} )
end procedure

----------------------------------------
-- gtk_container_child_args_collect
----------------------------------------
constant gtk_container_child_args_collect_ = link_c_func( GTK, 
  "gtk_container_child_args_collect", {C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, 
 C_POINTER )

global function gtk_container_child_args_collect(integer object_type_, atom arg_list_p_, atom info_list_p_, sequence first_arg_name_, atom args_)
    atom result
    atom string1
    string1 = allocate_string( first_arg_name_ )
    result = c_func( gtk_container_child_args_collect_, {object_type_,arg_list_p_,info_list_p_,string1,args_} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_container_child_arg_get_info
----------------------------------------
constant gtk_container_child_arg_get_info_ = link_c_func( GTK, 
  "gtk_container_child_arg_get_info", {C_UINT,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_container_child_arg_get_info(integer object_type_, sequence arg_name_, atom info_p_)
    atom result
    atom string1
    string1 = allocate_string( arg_name_ )
    result = c_func( gtk_container_child_arg_get_info_, {object_type_,string1,info_p_} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_container_forall
----------------------------------------
constant gtk_container_forall_ = link_c_proc( GTK, 
  "gtk_container_forall", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_container_forall(atom container_, atom callback_, atom callback_data_)
    c_proc( gtk_container_forall_, {container_,callback_,callback_data_} )
end procedure

----------------------------------------
-- gtk_container_child_composite_name
----------------------------------------
constant gtk_container_child_composite_name_ = link_c_func( GTK, 
  "gtk_container_child_composite_name", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_container_child_composite_name(atom container_, atom child_)
    return peek_string( c_func( gtk_container_child_composite_name_, {container_,child_} ) )
end function





----------------------------------------
----------------------------------------
-- GTKBIN.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkBin
----------------------------------------
global constant
    GtkBin_container                    = allot(SIZEOF_GtkContainer),
    GtkBin_child                        = allot(TYPE_POINTER),
    SIZEOF_GtkBin                       = allotted_size()

----------------------------------------
-- GtkBinClass
----------------------------------------
global constant
    GtkBinClass_parent_class            = allot(SIZEOF_GtkContainerClass),
    SIZEOF_GtkBinClass                  = allotted_size()
----------------------------------------
-- gtk_bin_get_type
----------------------------------------
constant gtk_bin_get_type_ = link_c_func( GTK, 
  "gtk_bin_get_type", {}, C_UINT )

global function gtk_bin_get_type()
    return c_func( gtk_bin_get_type_, {} )
end function


----------------------------------------
----------------------------------------
-- GTKALIGNMENT.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkAlignment
----------------------------------------
global constant
    GtkAlignment_bin                    = allot(SIZEOF_GtkBin),
    GtkAlignment_xalign                 = allot(TYPE_GFLOAT),
    GtkAlignment_yalign                 = allot(TYPE_GFLOAT),
    GtkAlignment_xscale                 = allot(TYPE_GFLOAT),
    GtkAlignment_yscale                 = allot(TYPE_GFLOAT),
    SIZEOF_GtkAlignment                 = allotted_size()

----------------------------------------
-- GtkAlignmentClass
----------------------------------------
global constant
    GtkAlignmentClass_parent_class      = allot(SIZEOF_GtkBinClass),
    SIZEOF_GtkAlignmentClass            = allotted_size()
----------------------------------------
-- gtk_alignment_get_type
----------------------------------------
constant gtk_alignment_get_type_ = link_c_func( GTK, 
  "gtk_alignment_get_type", {}, C_UINT )

global function gtk_alignment_get_type()
    return c_func( gtk_alignment_get_type_, {} )
end function

----------------------------------------
-- gtk_alignment_new
----------------------------------------
constant gtk_alignment_new_ = link_c_func( GTK, 
  "gtk_alignment_new", {C_LONG,C_LONG,C_LONG,C_LONG}, C_POINTER )

global function gtk_alignment_new(integer xalign_, integer yalign_, integer xscale_, integer yscale_)
    return c_func( gtk_alignment_new_, {xalign_,yalign_,xscale_,yscale_} )
end function

----------------------------------------
-- gtk_alignment_set
----------------------------------------
constant gtk_alignment_set_ = link_c_proc( GTK, 
  "gtk_alignment_set", {C_POINTER,C_LONG,C_LONG,C_LONG,C_LONG} )

global procedure gtk_alignment_set(atom alignment_, integer xalign_, integer yalign_, integer xscale_, integer yscale_)
    c_proc( gtk_alignment_set_, {alignment_,xalign_,yalign_,xscale_,yscale_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKFRAME.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkFrame
----------------------------------------
global constant
    GtkFrame_bin                        = allot(SIZEOF_GtkBin),
    GtkFrame_label                      = allot(TYPE_POINTER),
    GtkFrame_shadow_type                = allot(TYPE_GINT16),
    GtkFrame_label_width                = allot(TYPE_GINT16),
    GtkFrame_label_height               = allot(TYPE_GINT16),
    GtkFrame_label_xalign               = allot(TYPE_GFLOAT),
    GtkFrame_label_yalign               = allot(TYPE_GFLOAT),
    SIZEOF_GtkFrame                     = allotted_size()

----------------------------------------
-- GtkFrameClass
----------------------------------------
global constant
    GtkFrameClass_parent_class          = allot(SIZEOF_GtkBinClass),
    SIZEOF_GtkFrameClass                = allotted_size()
----------------------------------------
-- gtk_frame_get_type
----------------------------------------
constant gtk_frame_get_type_ = link_c_func( GTK, 
  "gtk_frame_get_type", {}, C_UINT )

global function gtk_frame_get_type()
    return c_func( gtk_frame_get_type_, {} )
end function

----------------------------------------
-- gtk_frame_new
----------------------------------------
constant gtk_frame_new_ = link_c_func( GTK, 
  "gtk_frame_new", {C_POINTER}, C_POINTER )

global function gtk_frame_new(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_frame_new_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_frame_set_label
----------------------------------------
constant gtk_frame_set_label_ = link_c_proc( GTK, 
  "gtk_frame_set_label", {C_POINTER,C_POINTER} )

global procedure gtk_frame_set_label(atom frame_, sequence label_)
    atom string1
    string1 = allocate_string( label_ )
    c_proc( gtk_frame_set_label_, {frame_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_frame_set_label_align
----------------------------------------
constant gtk_frame_set_label_align_ = link_c_proc( GTK, 
  "gtk_frame_set_label_align", {C_POINTER,C_LONG,C_LONG} )

global procedure gtk_frame_set_label_align(atom frame_, integer xalign_, integer yalign_)
    c_proc( gtk_frame_set_label_align_, {frame_,xalign_,yalign_} )
end procedure

----------------------------------------
-- gtk_frame_set_shadow_type
----------------------------------------
constant gtk_frame_set_shadow_type_ = link_c_proc( GTK, 
  "gtk_frame_set_shadow_type", {C_POINTER,C_POINTER} )

global procedure gtk_frame_set_shadow_type(atom frame_, atom type_)
    c_proc( gtk_frame_set_shadow_type_, {frame_,type_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKASPECTFRAME.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkAspectFrame
----------------------------------------
global constant
    GtkAspectFrame_frame                = allot(SIZEOF_GtkFrame),
    GtkAspectFrame_xalign               = allot(TYPE_GFLOAT),
    GtkAspectFrame_yalign               = allot(TYPE_GFLOAT),
    GtkAspectFrame_ratio                = allot(TYPE_GFLOAT),
    GtkAspectFrame_obey_child           = allot(TYPE_GINT),
    GtkAspectFrame_center_allocation    = allot(SIZEOF_GtkAllocation),
    SIZEOF_GtkAspectFrame               = allotted_size()

----------------------------------------
-- GtkAspectFrameClass
----------------------------------------
global constant
    GtkAspectFrameClass_parent_class    = allot(SIZEOF_GtkBinClass),
    SIZEOF_GtkAspectFrameClass          = allotted_size()
----------------------------------------
-- gtk_aspect_frame_get_type
----------------------------------------
constant gtk_aspect_frame_get_type_ = link_c_func( GTK, 
  "gtk_aspect_frame_get_type", {}, C_UINT )

global function gtk_aspect_frame_get_type()
    return c_func( gtk_aspect_frame_get_type_, {} )
end function

----------------------------------------
-- gtk_aspect_frame_new
----------------------------------------
constant gtk_aspect_frame_new_ = link_c_func( GTK, 
  "gtk_aspect_frame_new", {C_POINTER,C_LONG,C_LONG,C_LONG,C_INT}, C_POINTER )

global function gtk_aspect_frame_new(sequence const_, integer xalign_, integer yalign_, integer ratio_, integer obey_child_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_aspect_frame_new_, {string1,xalign_,yalign_,ratio_,obey_child_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_aspect_frame_set
----------------------------------------
constant gtk_aspect_frame_set_ = link_c_proc( GTK, 
  "gtk_aspect_frame_set", {C_POINTER,C_LONG,C_LONG,C_LONG,C_INT} )

global procedure gtk_aspect_frame_set(atom aspect_frame_, integer xalign_, integer yalign_, integer ratio_, integer obey_child_)
    c_proc( gtk_aspect_frame_set_, {aspect_frame_,xalign_,yalign_,ratio_,obey_child_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKARROW.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkArrow
----------------------------------------
global constant
    GtkArrow_misc                       = allot(SIZEOF_GtkMisc),
    GtkArrow_arrow_type                 = allot(TYPE_GINT16),
    GtkArrow_shadow_type                = allot(TYPE_GINT16),
    SIZEOF_GtkArrow                     = allotted_size()

----------------------------------------
-- GtkArrowClass
----------------------------------------
global constant
    GtkArrowClass_parent_class          = allot(SIZEOF_GtkMiscClass),
    SIZEOF_GtkArrowClass                = allotted_size()
----------------------------------------
-- gtk_arrow_get_type
----------------------------------------
constant gtk_arrow_get_type_ = link_c_func( GTK, 
  "gtk_arrow_get_type", {}, C_UINT )

global function gtk_arrow_get_type()
    return c_func( gtk_arrow_get_type_, {} )
end function

----------------------------------------
-- gtk_arrow_new
----------------------------------------
constant gtk_arrow_new_ = link_c_func( GTK, 
  "gtk_arrow_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_arrow_new(atom arrow_type_, atom shadow_type_)
    return c_func( gtk_arrow_new_, {arrow_type_,shadow_type_} )
end function

----------------------------------------
-- gtk_arrow_set
----------------------------------------
constant gtk_arrow_set_ = link_c_proc( GTK, 
  "gtk_arrow_set", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_arrow_set(atom arrow_, atom arrow_type_, atom shadow_type_)
    c_proc( gtk_arrow_set_, {arrow_,arrow_type_,shadow_type_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKBINDINGS.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkPatternSpec
----------------------------------------
global constant
    GtkPatternSpec_match_type           = allot(SIZEOF_GtkMatchType),
    GtkPatternSpec_pattern_length       = allot(TYPE_GUINT),
    GtkPatternSpec_pattern              = allot(TYPE_POINTER),
    GtkPatternSpec_pattern_reversed     = allot(TYPE_POINTER),
    GtkPatternSpec_user_data            = allot(TYPE_GPOINTER),
    GtkPatternSpec_seq_id               = allot(TYPE_GUINT),
    SIZEOF_GtkPatternSpec               = allotted_size()
----------------------------------------
-- gtk_pattern_spec_init
----------------------------------------
constant gtk_pattern_spec_init_ = link_c_proc( GTK, 
  "gtk_pattern_spec_init", {C_POINTER,C_POINTER} )

global procedure gtk_pattern_spec_init(atom pspec_, sequence pattern_)
    atom string1
    string1 = allocate_string( pattern_ )
    c_proc( gtk_pattern_spec_init_, {pspec_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_pattern_spec_free_segs
----------------------------------------
constant gtk_pattern_spec_free_segs_ = link_c_proc( GTK, 
  "gtk_pattern_spec_free_segs", {C_POINTER} )

global procedure gtk_pattern_spec_free_segs(atom pspec_)
    c_proc( gtk_pattern_spec_free_segs_, {pspec_} )
end procedure

----------------------------------------
-- gtk_pattern_match
----------------------------------------
constant gtk_pattern_match_ = link_c_func( GTK, 
  "gtk_pattern_match", {C_POINTER,C_UINT,C_POINTER,C_POINTER}, C_INT )

global function gtk_pattern_match(atom pspec_, integer string_length_, sequence string_, sequence string_reversed_)
    integer result
    atom string1, string2
    string1 = allocate_string( string_ )
    string2 = allocate_string( string_reversed_ )
    result = c_func( gtk_pattern_match_, {pspec_,string_length_,string1,string2} )
    free( string1 )
    free( string2 )
    return result
end function

----------------------------------------
-- gtk_pattern_match_string
----------------------------------------
constant gtk_pattern_match_string_ = link_c_func( GTK, 
  "gtk_pattern_match_string", {C_POINTER,C_POINTER}, C_INT )

global function gtk_pattern_match_string(atom pspec_, sequence string_)
    integer result
    atom string1
    string1 = allocate_string( string_ )
    result = c_func( gtk_pattern_match_string_, {pspec_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_pattern_match_simple
----------------------------------------
constant gtk_pattern_match_simple_ = link_c_func( GTK, 
  "gtk_pattern_match_simple", {C_POINTER,C_POINTER}, C_INT )

global function gtk_pattern_match_simple(sequence const_, sequence string_)
    integer result
    atom string1, string2
    string1 = allocate_string( const_ )
    string2 = allocate_string( string_ )
    result = c_func( gtk_pattern_match_simple_, {string1,string2} )
    free( string1 )
    free( string2 )
    return result
end function


----------------------------------------
-- GtkBindingSet
----------------------------------------
global constant
    GtkBindingSet_set_name              = allot(TYPE_POINTER),
    GtkBindingSet_priority              = allot(TYPE_GINT),
    GtkBindingSet_widget_path_pspecs    = allot(TYPE_POINTER),
    GtkBindingSet_widget_class_pspecs   = allot(TYPE_POINTER),
    GtkBindingSet_class_branch_pspecs   = allot(TYPE_POINTER),
    GtkBindingSet_entries               = allot(TYPE_POINTER),
    GtkBindingSet_current               = allot(TYPE_POINTER),
    SIZEOF_GtkBindingSet                = allotted_size()

----------------------------------------
-- GtkBindingEntry
----------------------------------------
global constant
    GtkBindingEntry_keyval              = allot(TYPE_GUINT),
    GtkBindingEntry_modifiers           = allot(TYPE_GUINT),
    GtkBindingEntry_binding_set         = allot(TYPE_POINTER),
    GtkBindingEntry_destroyed           = allot(TYPE_GUINT),
    GtkBindingEntry_in_emission         = allot(TYPE_GUINT),
    GtkBindingEntry_set_next            = allot(TYPE_POINTER),
    GtkBindingEntry_hash_next           = allot(TYPE_POINTER),
    GtkBindingEntry_signals             = allot(TYPE_POINTER),
    SIZEOF_GtkBindingEntry              = allotted_size()

----------------------------------------
-- GtkBindingSignal
----------------------------------------
global constant
    GtkBindingSignal_next               = allot(TYPE_POINTER),
    GtkBindingSignal_signal_name        = allot(TYPE_POINTER),
    GtkBindingSignal_n_args             = allot(TYPE_GUINT),
    GtkBindingSignal_args               = allot(TYPE_POINTER),
    SIZEOF_GtkBindingSignal             = allotted_size()

----------------------------------------
-- GtkBindingArg
----------------------------------------
global constant
    GtkBindingArg_arg_type              = allot(TYPE_GUINT),
    GtkBindingArg_d                     = allot(TYPE_LONG), -- union,
    SIZEOF_GtkBindingArg                = allotted_size()
----------------------------------------
-- gtk_binding_set_new
----------------------------------------
constant gtk_binding_set_new_ = link_c_func( GTK, 
  "gtk_binding_set_new", {C_POINTER}, C_POINTER )

global function gtk_binding_set_new(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_binding_set_new_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_binding_set_by_class
----------------------------------------
constant gtk_binding_set_by_class_ = link_c_func( GTK, 
  "gtk_binding_set_by_class", {C_POINTER}, C_POINTER )

global function gtk_binding_set_by_class(atom object_class_)
    return c_func( gtk_binding_set_by_class_, {object_class_} )
end function

----------------------------------------
-- gtk_binding_set_find
----------------------------------------
constant gtk_binding_set_find_ = link_c_func( GTK, 
  "gtk_binding_set_find", {C_POINTER}, C_POINTER )

global function gtk_binding_set_find(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_binding_set_find_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_bindings_activate
----------------------------------------
constant gtk_bindings_activate_ = link_c_func( GTK, 
  "gtk_bindings_activate", {C_POINTER,C_UINT,C_UINT}, C_INT )

global function gtk_bindings_activate(atom object_, integer keyval_, integer modifiers_)
    return c_func( gtk_bindings_activate_, {object_,keyval_,modifiers_} )
end function

----------------------------------------
-- gtk_binding_set_activate
----------------------------------------
constant gtk_binding_set_activate_ = link_c_func( GTK, 
  "gtk_binding_set_activate", {C_POINTER,C_UINT,C_UINT,C_POINTER}, C_INT )

global function gtk_binding_set_activate(atom binding_set_, integer keyval_, integer modifiers_, atom object_)
    return c_func( gtk_binding_set_activate_, {binding_set_,keyval_,modifiers_,object_} )
end function

----------------------------------------
-- gtk_binding_entry_clear
----------------------------------------
constant gtk_binding_entry_clear_ = link_c_proc( GTK, 
  "gtk_binding_entry_clear", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_binding_entry_clear(atom binding_set_, integer keyval_, integer modifiers_)
    c_proc( gtk_binding_entry_clear_, {binding_set_,keyval_,modifiers_} )
end procedure

----------------------------------------
-- gtk_binding_entry_add_signal
----------------------------------------
constant gtk_binding_entry_add_signal_ = link_c_proc( GTK, 
  "gtk_binding_entry_add_signal", {C_POINTER,C_UINT,C_UINT,C_POINTER,C_UINT} )

global procedure gtk_binding_entry_add_signal(atom binding_set_, integer keyval_, integer modifiers_, sequence signal_name_, integer n_args_)
    atom string1
    string1 = allocate_string( signal_name_ )
    c_proc( gtk_binding_entry_add_signal_, {binding_set_,keyval_,modifiers_,string1,n_args_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_binding_set_add_path
----------------------------------------
constant gtk_binding_set_add_path_ = link_c_proc( GTK, 
  "gtk_binding_set_add_path", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_binding_set_add_path(atom binding_set_, atom path_type_, sequence path_pattern_, atom priority_)
    atom string1
    string1 = allocate_string( path_pattern_ )
    c_proc( gtk_binding_set_add_path_, {binding_set_,path_type_,string1,priority_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_binding_entry_remove
----------------------------------------
constant gtk_binding_entry_remove_ = link_c_proc( GTK, 
  "gtk_binding_entry_remove", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_binding_entry_remove(atom binding_set_, integer keyval_, integer modifiers_)
    c_proc( gtk_binding_entry_remove_, {binding_set_,keyval_,modifiers_} )
end procedure

----------------------------------------
-- gtk_binding_entry_add_signall
----------------------------------------
constant gtk_binding_entry_add_signall_ = link_c_proc( GTK, 
  "gtk_binding_entry_add_signall", {C_POINTER,C_UINT,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_binding_entry_add_signall(atom binding_set_, integer keyval_, integer modifiers_, sequence signal_name_, atom binding_args_)
    atom string1
    string1 = allocate_string( signal_name_ )
    c_proc( gtk_binding_entry_add_signall_, {binding_set_,keyval_,modifiers_,string1,binding_args_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_binding_parse_binding
----------------------------------------
constant gtk_binding_parse_binding_ = link_c_func( GTK, 
  "gtk_binding_parse_binding", {C_POINTER}, C_UINT )

global function gtk_binding_parse_binding(atom scanner_)
    return c_func( gtk_binding_parse_binding_, {scanner_} )
end function



----------------------------------------
----------------------------------------
-- GTKBOX.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkBox
----------------------------------------
global constant
    GtkBox_container                    = allot(SIZEOF_GtkContainer),
    GtkBox_children                     = allot(TYPE_POINTER),
    GtkBox_spacing                      = allot(TYPE_GINT16),
    GtkBox_homogeneous                  = allot(TYPE_GUINT),
    SIZEOF_GtkBox                       = allotted_size()

----------------------------------------
-- GtkBoxClass
----------------------------------------
global constant
    GtkBoxClass_parent_class            = allot(SIZEOF_GtkContainerClass),
    SIZEOF_GtkBoxClass                  = allotted_size()

----------------------------------------
-- GtkBoxChild
----------------------------------------
global constant
    GtkBoxChild_widget                  = allot(TYPE_POINTER),
    GtkBoxChild_padding                 = allot(TYPE_GUINT16),
    GtkBoxChild_expand                  = allot(TYPE_GUINT),
    GtkBoxChild_fill                    = allot(TYPE_GUINT),
    GtkBoxChild_pack                    = allot(TYPE_GUINT),
    SIZEOF_GtkBoxChild                  = allotted_size()
----------------------------------------
-- gtk_box_get_type
----------------------------------------
constant gtk_box_get_type_ = link_c_func( GTK, 
  "gtk_box_get_type", {}, C_UINT )

global function gtk_box_get_type()
    return c_func( gtk_box_get_type_, {} )
end function

----------------------------------------
-- gtk_box_pack_start
----------------------------------------
constant gtk_box_pack_start_ = link_c_proc( GTK, 
  "gtk_box_pack_start", {C_POINTER,C_POINTER,C_INT,C_INT,C_UINT} )

global procedure gtk_box_pack_start(atom box_, atom child_, integer expand_, integer fill_, integer padding_)
    c_proc( gtk_box_pack_start_, {box_,child_,expand_,fill_,padding_} )
end procedure

----------------------------------------
-- gtk_box_pack_end
----------------------------------------
constant gtk_box_pack_end_ = link_c_proc( GTK, 
  "gtk_box_pack_end", {C_POINTER,C_POINTER,C_INT,C_INT,C_UINT} )

global procedure gtk_box_pack_end(atom box_, atom child_, integer expand_, integer fill_, integer padding_)
    c_proc( gtk_box_pack_end_, {box_,child_,expand_,fill_,padding_} )
end procedure

----------------------------------------
-- gtk_box_pack_start_defaults
----------------------------------------
constant gtk_box_pack_start_defaults_ = link_c_proc( GTK, 
  "gtk_box_pack_start_defaults", {C_POINTER,C_POINTER} )

global procedure gtk_box_pack_start_defaults(atom box_, atom widget_)
    c_proc( gtk_box_pack_start_defaults_, {box_,widget_} )
end procedure

----------------------------------------
-- gtk_box_pack_end_defaults
----------------------------------------
constant gtk_box_pack_end_defaults_ = link_c_proc( GTK, 
  "gtk_box_pack_end_defaults", {C_POINTER,C_POINTER} )

global procedure gtk_box_pack_end_defaults(atom box_, atom widget_)
    c_proc( gtk_box_pack_end_defaults_, {box_,widget_} )
end procedure

----------------------------------------
-- gtk_box_set_homogeneous
----------------------------------------
constant gtk_box_set_homogeneous_ = link_c_proc( GTK, 
  "gtk_box_set_homogeneous", {C_POINTER,C_INT} )

global procedure gtk_box_set_homogeneous(atom box_, integer homogeneous_)
    c_proc( gtk_box_set_homogeneous_, {box_,homogeneous_} )
end procedure

----------------------------------------
-- gtk_box_set_spacing
----------------------------------------
constant gtk_box_set_spacing_ = link_c_proc( GTK, 
  "gtk_box_set_spacing", {C_POINTER,C_INT} )

global procedure gtk_box_set_spacing(atom box_, integer spacing_)
    c_proc( gtk_box_set_spacing_, {box_,spacing_} )
end procedure

----------------------------------------
-- gtk_box_reorder_child
----------------------------------------
constant gtk_box_reorder_child_ = link_c_proc( GTK, 
  "gtk_box_reorder_child", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_box_reorder_child(atom box_, atom child_, integer position_)
    c_proc( gtk_box_reorder_child_, {box_,child_,position_} )
end procedure

----------------------------------------
-- gtk_box_query_child_packing
----------------------------------------
constant gtk_box_query_child_packing_ = link_c_proc( GTK, 
  "gtk_box_query_child_packing", {C_POINTER,C_POINTER,C_INT,C_INT,C_UINT,C_POINTER} )

global procedure gtk_box_query_child_packing(atom box_, atom child_, integer expand_, integer fill_, integer padding_, atom pack_type_)
    c_proc( gtk_box_query_child_packing_, {box_,child_,expand_,fill_,padding_,pack_type_} )
end procedure

----------------------------------------
-- gtk_box_set_child_packing
----------------------------------------
constant gtk_box_set_child_packing_ = link_c_proc( GTK, 
  "gtk_box_set_child_packing", {C_POINTER,C_POINTER,C_INT,C_INT,C_UINT,C_POINTER} )

global procedure gtk_box_set_child_packing(atom box_, atom child_, integer expand_, integer fill_, integer padding_, atom pack_type_)
    c_proc( gtk_box_set_child_packing_, {box_,child_,expand_,fill_,padding_,pack_type_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKBBOX.H
----------------------------------------
----------------------------------------


global constant GTK_BUTTONBOX_DEFAULT = -1

----------------------------------------
-- GtkButtonBox
----------------------------------------
global constant
    GtkButtonBox_box                    = allot(SIZEOF_GtkBox),
    GtkButtonBox_spacing                = allot(TYPE_GINT),
    GtkButtonBox_child_min_width        = allot(TYPE_GINT),
    GtkButtonBox_child_min_height       = allot(TYPE_GINT),
    GtkButtonBox_child_ipad_x           = allot(TYPE_GINT),
    GtkButtonBox_child_ipad_y           = allot(TYPE_GINT),
    GtkButtonBox_layout_style           = allot(SIZEOF_GtkButtonBoxStyle),
    SIZEOF_GtkButtonBox                 = allotted_size()

----------------------------------------
-- GtkButtonBoxClass
----------------------------------------
global constant
    GtkButtonBoxClass_parent_class      = allot(SIZEOF_GtkBoxClass),
    SIZEOF_GtkButtonBoxClass            = allotted_size()
----------------------------------------
-- gtk_button_box_get_type
----------------------------------------
constant gtk_button_box_get_type_ = link_c_func( GTK, 
  "gtk_button_box_get_type", {}, C_UINT )

global function gtk_button_box_get_type()
    return c_func( gtk_button_box_get_type_, {} )
end function

----------------------------------------
-- gtk_button_box_get_child_size_default
----------------------------------------
constant gtk_button_box_get_child_size_default_ = link_c_proc( GTK, 
  "gtk_button_box_get_child_size_default", {C_INT} )

global procedure gtk_button_box_get_child_size_default(integer min_width_)
    c_proc( gtk_button_box_get_child_size_default_, {min_width_} )
end procedure

----------------------------------------
-- gtk_button_box_get_child_ipadding_default
----------------------------------------
constant gtk_button_box_get_child_ipadding_default_ = link_c_proc( GTK, 
  "gtk_button_box_get_child_ipadding_default", {C_INT} )

global procedure gtk_button_box_get_child_ipadding_default(integer ipad_x_)
    c_proc( gtk_button_box_get_child_ipadding_default_, {ipad_x_} )
end procedure

----------------------------------------
-- gtk_button_box_set_child_size_default
----------------------------------------
constant gtk_button_box_set_child_size_default_ = link_c_proc( GTK, 
  "gtk_button_box_set_child_size_default", {C_INT} )

global procedure gtk_button_box_set_child_size_default(integer min_width_)
    c_proc( gtk_button_box_set_child_size_default_, {min_width_} )
end procedure

----------------------------------------
-- gtk_button_box_set_child_ipadding_default
----------------------------------------
constant gtk_button_box_set_child_ipadding_default_ = link_c_proc( GTK, 
  "gtk_button_box_set_child_ipadding_default", {C_INT} )

global procedure gtk_button_box_set_child_ipadding_default(integer ipad_x_)
    c_proc( gtk_button_box_set_child_ipadding_default_, {ipad_x_} )
end procedure

----------------------------------------
-- gtk_button_box_get_spacing
----------------------------------------
constant gtk_button_box_get_spacing_ = link_c_func( GTK, 
  "gtk_button_box_get_spacing", {C_POINTER}, C_INT )

global function gtk_button_box_get_spacing(atom widget_)
    return c_func( gtk_button_box_get_spacing_, {widget_} )
end function

----------------------------------------
-- gtk_button_box_get_layout
----------------------------------------
constant gtk_button_box_get_layout_ = link_c_func( GTK, 
  "gtk_button_box_get_layout", {C_POINTER}, C_POINTER )

global function gtk_button_box_get_layout(atom widget_)
    return c_func( gtk_button_box_get_layout_, {widget_} )
end function

----------------------------------------
-- gtk_button_box_get_child_size
----------------------------------------
constant gtk_button_box_get_child_size_ = link_c_proc( GTK, 
  "gtk_button_box_get_child_size", {C_POINTER,C_INT} )

global procedure gtk_button_box_get_child_size(atom widget_, integer min_width_)
    c_proc( gtk_button_box_get_child_size_, {widget_,min_width_} )
end procedure

----------------------------------------
-- gtk_button_box_get_child_ipadding
----------------------------------------
constant gtk_button_box_get_child_ipadding_ = link_c_proc( GTK, 
  "gtk_button_box_get_child_ipadding", {C_POINTER} )

global procedure gtk_button_box_get_child_ipadding(atom widget_)
    c_proc( gtk_button_box_get_child_ipadding_, {widget_} )
end procedure

----------------------------------------
-- gtk_button_box_set_spacing
----------------------------------------
constant gtk_button_box_set_spacing_ = link_c_proc( GTK, 
  "gtk_button_box_set_spacing", {C_POINTER} )

global procedure gtk_button_box_set_spacing(atom widget_)
    c_proc( gtk_button_box_set_spacing_, {widget_} )
end procedure

----------------------------------------
-- gtk_button_box_set_layout
----------------------------------------
constant gtk_button_box_set_layout_ = link_c_proc( GTK, 
  "gtk_button_box_set_layout", {C_POINTER,C_POINTER} )

global procedure gtk_button_box_set_layout(atom widget_, atom layout_style_)
    c_proc( gtk_button_box_set_layout_, {widget_,layout_style_} )
end procedure

----------------------------------------
-- gtk_button_box_set_child_size
----------------------------------------
constant gtk_button_box_set_child_size_ = link_c_proc( GTK, 
  "gtk_button_box_set_child_size", {C_POINTER,C_INT} )

global procedure gtk_button_box_set_child_size(atom widget_, integer min_width_)
    c_proc( gtk_button_box_set_child_size_, {widget_,min_width_} )
end procedure

----------------------------------------
-- gtk_button_box_set_child_ipadding
----------------------------------------
constant gtk_button_box_set_child_ipadding_ = link_c_proc( GTK, 
  "gtk_button_box_set_child_ipadding", {C_POINTER} )

global procedure gtk_button_box_set_child_ipadding(atom widget_)
    c_proc( gtk_button_box_set_child_ipadding_, {widget_} )
end procedure

----------------------------------------
-- gtk_button_box_child_requisition
----------------------------------------
constant gtk_button_box_child_requisition_ = link_c_proc( GTK, 
  "gtk_button_box_child_requisition", {C_POINTER,C_INT,C_INT,C_INT} )

global procedure gtk_button_box_child_requisition(atom widget_, integer nvis_children_, integer width_, integer height_)
    c_proc( gtk_button_box_child_requisition_, {widget_,nvis_children_,width_,height_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKBUTTON.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkButton
----------------------------------------
global constant
    GtkButton_bin                       = allot(SIZEOF_GtkBin),
    GtkButton_child                     = allot(TYPE_POINTER),
    GtkButton_in_button                 = allot(TYPE_GUINT),
    GtkButton_button_down               = allot(TYPE_GUINT),
    GtkButton_relief                    = allot(TYPE_GUINT),
    SIZEOF_GtkButton                    = allotted_size()

----------------------------------------
-- GtkButtonClass
----------------------------------------
global constant
    GtkButtonClass_parent_class         = allot(SIZEOF_GtkBinClass),
    GtkButtonClass_pressed              = allot(TYPE_GPOINTER),
    GtkButtonClass_released             = allot(TYPE_GPOINTER),
    GtkButtonClass_clicked              = allot(TYPE_GPOINTER),
    GtkButtonClass_enter                = allot(TYPE_GPOINTER),
    GtkButtonClass_leave                = allot(TYPE_GPOINTER),
    SIZEOF_GtkButtonClass               = allotted_size()
----------------------------------------
-- gtk_button_get_type
----------------------------------------
constant gtk_button_get_type_ = link_c_func( GTK, 
  "gtk_button_get_type", {}, C_UINT )

global function gtk_button_get_type()
    return c_func( gtk_button_get_type_, {} )
end function

----------------------------------------
-- gtk_button_new
----------------------------------------
constant gtk_button_new_ = link_c_func( GTK, 
  "gtk_button_new", {}, C_POINTER )

global function gtk_button_new()
    return c_func( gtk_button_new_, {} )
end function

----------------------------------------
-- gtk_button_new_with_label
----------------------------------------
constant gtk_button_new_with_label_ = link_c_func( GTK, 
  "gtk_button_new_with_label", {C_POINTER}, C_POINTER )

global function gtk_button_new_with_label(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_button_new_with_label_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_button_pressed
----------------------------------------
constant gtk_button_pressed_ = link_c_proc( GTK, 
  "gtk_button_pressed", {C_POINTER} )

global procedure gtk_button_pressed(atom button_)
    c_proc( gtk_button_pressed_, {button_} )
end procedure

----------------------------------------
-- gtk_button_released
----------------------------------------
constant gtk_button_released_ = link_c_proc( GTK, 
  "gtk_button_released", {C_POINTER} )

global procedure gtk_button_released(atom button_)
    c_proc( gtk_button_released_, {button_} )
end procedure

----------------------------------------
-- gtk_button_clicked
----------------------------------------
constant gtk_button_clicked_ = link_c_proc( GTK, 
  "gtk_button_clicked", {C_POINTER} )

global procedure gtk_button_clicked(atom button_)
    c_proc( gtk_button_clicked_, {button_} )
end procedure

----------------------------------------
-- gtk_button_enter
----------------------------------------
constant gtk_button_enter_ = link_c_proc( GTK, 
  "gtk_button_enter", {C_POINTER} )

global procedure gtk_button_enter(atom button_)
    c_proc( gtk_button_enter_, {button_} )
end procedure

----------------------------------------
-- gtk_button_leave
----------------------------------------
constant gtk_button_leave_ = link_c_proc( GTK, 
  "gtk_button_leave", {C_POINTER} )

global procedure gtk_button_leave(atom button_)
    c_proc( gtk_button_leave_, {button_} )
end procedure

----------------------------------------
-- gtk_button_set_relief
----------------------------------------
constant gtk_button_set_relief_ = link_c_proc( GTK, 
  "gtk_button_set_relief", {C_POINTER,C_POINTER} )

global procedure gtk_button_set_relief(atom button_, atom newstyle_)
    c_proc( gtk_button_set_relief_, {button_,newstyle_} )
end procedure

----------------------------------------
-- gtk_button_get_relief
----------------------------------------
constant gtk_button_get_relief_ = link_c_func( GTK, 
  "gtk_button_get_relief", {C_POINTER}, C_POINTER )

global function gtk_button_get_relief(atom button_)
    return c_func( gtk_button_get_relief_, {button_} )
end function



----------------------------------------
----------------------------------------
-- GTKCALENDAR.H
----------------------------------------
----------------------------------------


global constant
    GTK_CALENDAR_SHOW_HEADING           = power(2,0),
    GTK_CALENDAR_SHOW_DAY_NAMES         = power(2,1),
    GTK_CALENDAR_NO_MONTH_CHANGE        = power(2,2),
    GTK_CALENDAR_SHOW_WEEK_NUMBERS      = power(2,3),
    GTK_CALENDAR_WEEK_START_MONDAY      = power(2,4)
global constant SIZEOF_GtkCalendarDisplayOptions = SIZEOF_ENUM


----------------------------------------
-- GtkCalendar
----------------------------------------
global constant
    GtkCalendar_widget                  = allot(SIZEOF_GtkWidget),
    GtkCalendar_header_style            = allot(TYPE_POINTER),
    GtkCalendar_label_style             = allot(TYPE_POINTER),
    GtkCalendar_month                   = allot(TYPE_GINT),
    GtkCalendar_year                    = allot(TYPE_GINT),
    GtkCalendar_selected_day            = allot(TYPE_GINT),
    GtkCalendar_day_month               = allot(6*7*INT_BYTES),
    GtkCalendar_day                     = allot(6*7*INT_BYTES),
    GtkCalendar_num_marked_dates        = allot(TYPE_GINT),
    GtkCalendar_marked_date             = allot(31*INT_BYTES),
    GtkCalendar_display_flags           = allot(SIZEOF_GtkCalendarDisplayOptions),
    GtkCalendar_marked_date_color       = allot(31*SIZEOF_GdkColor),
    GtkCalendar_gc                      = allot(TYPE_POINTER),
    GtkCalendar_xor_gc                  = allot(TYPE_POINTER),
    GtkCalendar_focus_row               = allot(TYPE_GINT),
    GtkCalendar_focus_col               = allot(TYPE_GINT),
    GtkCalendar_highlight_row           = allot(TYPE_GINT),
    GtkCalendar_highlight_col           = allot(TYPE_GINT),
    GtkCalendar_private_data            = allot(TYPE_GPOINTER),
    GtkCalendar_grow_space              = allot(TYPE_GCHAR),
    SIZEOF_GtkCalendar                  = allotted_size()

----------------------------------------
-- GtkCalendarClass
----------------------------------------
global constant
    GtkCalendarClass_parent_class       = allot(SIZEOF_GtkWidgetClass),
    GtkCalendarClass_month_changed      = allot(TYPE_GPOINTER),
    GtkCalendarClass_day_selected       = allot(TYPE_GPOINTER),
    GtkCalendarClass_day_selected_double_click= allot(TYPE_GPOINTER),
    GtkCalendarClass_prev_month         = allot(TYPE_GPOINTER),
    GtkCalendarClass_next_month         = allot(TYPE_GPOINTER),
    GtkCalendarClass_prev_year          = allot(TYPE_GPOINTER),
    GtkCalendarClass_next_year          = allot(TYPE_GPOINTER),
    SIZEOF_GtkCalendarClass             = allotted_size()
----------------------------------------
-- gtk_calendar_get_type
----------------------------------------
constant gtk_calendar_get_type_ = link_c_func( GTK, 
  "gtk_calendar_get_type", {}, C_UINT )

global function gtk_calendar_get_type()
    return c_func( gtk_calendar_get_type_, {} )
end function

----------------------------------------
-- gtk_calendar_new
----------------------------------------
constant gtk_calendar_new_ = link_c_func( GTK, 
  "gtk_calendar_new", {}, C_POINTER )

global function gtk_calendar_new()
    return c_func( gtk_calendar_new_, {} )
end function

----------------------------------------
-- gtk_calendar_select_month
----------------------------------------
constant gtk_calendar_select_month_ = link_c_func( GTK, 
  "gtk_calendar_select_month", {C_POINTER,C_UINT,C_UINT}, C_INT )

global function gtk_calendar_select_month(atom calendar_, integer month_, integer year_)
    return c_func( gtk_calendar_select_month_, {calendar_,month_,year_} )
end function

----------------------------------------
-- gtk_calendar_select_day
----------------------------------------
constant gtk_calendar_select_day_ = link_c_proc( GTK, 
  "gtk_calendar_select_day", {C_POINTER,C_UINT} )

global procedure gtk_calendar_select_day(atom calendar_, integer day_)
    c_proc( gtk_calendar_select_day_, {calendar_,day_} )
end procedure

----------------------------------------
-- gtk_calendar_mark_day
----------------------------------------
constant gtk_calendar_mark_day_ = link_c_func( GTK, 
  "gtk_calendar_mark_day", {C_POINTER,C_UINT}, C_INT )

global function gtk_calendar_mark_day(atom calendar_, integer day_)
    return c_func( gtk_calendar_mark_day_, {calendar_,day_} )
end function

----------------------------------------
-- gtk_calendar_unmark_day
----------------------------------------
constant gtk_calendar_unmark_day_ = link_c_func( GTK, 
  "gtk_calendar_unmark_day", {C_POINTER,C_UINT}, C_INT )

global function gtk_calendar_unmark_day(atom calendar_, integer day_)
    return c_func( gtk_calendar_unmark_day_, {calendar_,day_} )
end function

----------------------------------------
-- gtk_calendar_clear_marks
----------------------------------------
constant gtk_calendar_clear_marks_ = link_c_proc( GTK, 
  "gtk_calendar_clear_marks", {C_POINTER} )

global procedure gtk_calendar_clear_marks(atom calendar_)
    c_proc( gtk_calendar_clear_marks_, {calendar_} )
end procedure

----------------------------------------
-- gtk_calendar_display_options
----------------------------------------
constant gtk_calendar_display_options_ = link_c_proc( GTK, 
  "gtk_calendar_display_options", {C_POINTER,C_POINTER} )

global procedure gtk_calendar_display_options(atom calendar_, atom flags_)
    c_proc( gtk_calendar_display_options_, {calendar_,flags_} )
end procedure

----------------------------------------
-- gtk_calendar_get_date
----------------------------------------
constant gtk_calendar_get_date_ = link_c_proc( GTK, 
  "gtk_calendar_get_date", {C_POINTER,C_UINT,C_UINT,C_UINT} )

global procedure gtk_calendar_get_date(atom calendar_, integer year_, integer month_, integer day_)
    c_proc( gtk_calendar_get_date_, {calendar_,year_,month_,day_} )
end procedure

----------------------------------------
-- gtk_calendar_freeze
----------------------------------------
constant gtk_calendar_freeze_ = link_c_proc( GTK, 
  "gtk_calendar_freeze", {C_POINTER} )

global procedure gtk_calendar_freeze(atom calendar_)
    c_proc( gtk_calendar_freeze_, {calendar_} )
end procedure

----------------------------------------
-- gtk_calendar_thaw
----------------------------------------
constant gtk_calendar_thaw_ = link_c_proc( GTK, 
  "gtk_calendar_thaw", {C_POINTER} )

global procedure gtk_calendar_thaw(atom calendar_)
    c_proc( gtk_calendar_thaw_, {calendar_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKSIGNAL.H
----------------------------------------
----------------------------------------


----------------------------------------
-- GtkSignalMarshal
----------------------------------------
constant GtkSignalMarshal_ = link_c_proc( GTK, 
  "GtkSignalMarshal", {C_POINTER,C_POINTER,C_UINT,C_POINTER,C_UINT,C_UINT} )

global procedure GtkSignalMarshal(atom object_, atom data_, integer nparams_, atom args_, integer arg_types_, integer return_type_)
    c_proc( GtkSignalMarshal_, {object_,data_,nparams_,args_,arg_types_,return_type_} )
end procedure

----------------------------------------
-- GtkSignalDestroy
----------------------------------------
constant GtkSignalDestroy_ = link_c_proc( GTK, 
  "GtkSignalDestroy", {C_POINTER} )

global procedure GtkSignalDestroy(atom data_)
    c_proc( GtkSignalDestroy_, {data_} )
end procedure

----------------------------------------
-- GtkEmissionHook
----------------------------------------
constant GtkEmissionHook_ = link_c_func( GTK, 
  "GtkEmissionHook", {C_POINTER,C_UINT,C_UINT,C_POINTER,C_POINTER}, C_INT )

global function GtkEmissionHook(atom object_, integer signal_id_, integer n_params_, atom params_, atom data_)
    return c_func( GtkEmissionHook_, {object_,signal_id_,n_params_,params_,data_} )
end function


----------------------------------------
-- GtkSignalQuery
----------------------------------------
global constant
    GtkSignalQuery_object_type          = allot(TYPE_GUINT),
    GtkSignalQuery_signal_id            = allot(TYPE_GUINT),
    GtkSignalQuery_signal_name          = allot(TYPE_POINTER),
    GtkSignalQuery_is_user_signal       = allot(TYPE_GUINT),
    GtkSignalQuery_signal_flags         = allot(SIZEOF_GtkSignalRunType),
    GtkSignalQuery_return_val           = allot(TYPE_GUINT),
    GtkSignalQuery_nparams              = allot(TYPE_GUINT),
    GtkSignalQuery_params               = allot(TYPE_POINTER),
    SIZEOF_GtkSignalQuery               = allotted_size()
----------------------------------------
-- gtk_signal_lookup
----------------------------------------
constant gtk_signal_lookup_ = link_c_func( GTK, 
  "gtk_signal_lookup", {C_POINTER,C_UINT}, C_UINT )

global function gtk_signal_lookup(sequence const_, integer object_type_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_signal_lookup_, {string1,object_type_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_name
----------------------------------------
constant gtk_signal_name_ = link_c_func( GTK, 
  "gtk_signal_name", {C_UINT}, C_POINTER )

global function gtk_signal_name(integer signal_id_)
    return peek_string( c_func( gtk_signal_name_, {signal_id_} ) )
end function

----------------------------------------
-- gtk_signal_n_emissions
----------------------------------------
constant gtk_signal_n_emissions_ = link_c_func( GTK, 
  "gtk_signal_n_emissions", {C_POINTER,C_UINT}, C_UINT )

global function gtk_signal_n_emissions(atom object_, integer signal_id_)
    return c_func( gtk_signal_n_emissions_, {object_,signal_id_} )
end function

----------------------------------------
-- gtk_signal_n_emissions_by_name
----------------------------------------
constant gtk_signal_n_emissions_by_name_ = link_c_func( GTK, 
  "gtk_signal_n_emissions_by_name", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_signal_n_emissions_by_name(atom object_, sequence name_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_signal_n_emissions_by_name_, {object_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_emit_stop
----------------------------------------
constant gtk_signal_emit_stop_ = link_c_proc( GTK, 
  "gtk_signal_emit_stop", {C_POINTER,C_UINT} )

global procedure gtk_signal_emit_stop(atom object_, integer signal_id_)
    c_proc( gtk_signal_emit_stop_, {object_,signal_id_} )
end procedure

----------------------------------------
-- gtk_signal_emit_stop_by_name
----------------------------------------
constant gtk_signal_emit_stop_by_name_ = link_c_proc( GTK, 
  "gtk_signal_emit_stop_by_name", {C_POINTER,C_POINTER} )

global procedure gtk_signal_emit_stop_by_name(atom object_, sequence name_)
    atom string1
    string1 = allocate_string( name_ )
    c_proc( gtk_signal_emit_stop_by_name_, {object_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_signal_connect
----------------------------------------
constant gtk_signal_connect_ = link_c_func( GTK, 
  "gtk_signal_connect", {C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_UINT )

global function gtk_signal_connect(atom object_, sequence name_, atom func_, atom func_data_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_signal_connect_, {object_,string1,func_,func_data_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_connect_after
----------------------------------------
constant gtk_signal_connect_after_ = link_c_func( GTK, 
  "gtk_signal_connect_after", {C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_UINT )

global function gtk_signal_connect_after(atom object_, sequence name_, atom func_, atom func_data_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_signal_connect_after_, {object_,string1,func_,func_data_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_connect_object
----------------------------------------
constant gtk_signal_connect_object_ = link_c_func( GTK, 
  "gtk_signal_connect_object", {C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_UINT )

global function gtk_signal_connect_object(atom object_, sequence name_, atom func_, atom slot_object_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_signal_connect_object_, {object_,string1,func_,slot_object_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_connect_object_after
----------------------------------------
constant gtk_signal_connect_object_after_ = link_c_func( GTK, 
  "gtk_signal_connect_object_after", {C_POINTER,C_POINTER,C_POINTER,C_POINTER}, 
 C_UINT )

global function gtk_signal_connect_object_after(atom object_, sequence name_, atom func_, atom slot_object_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_signal_connect_object_after_, {object_,string1,func_,slot_object_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_connect_full
----------------------------------------
constant gtk_signal_connect_full_ = link_c_func( GTK, 
  "gtk_signal_connect_full", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT}, 
 C_UINT )

global function gtk_signal_connect_full(atom object_, sequence name_, atom func_, atom marshal_, atom data_, atom 
 destroy_func_, integer object_signal_, integer after_)
    integer result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_signal_connect_full_, {object_,string1,func_,marshal_,data_,destroy_func_,object_signal_,after_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_connect_object_while_alive
----------------------------------------
constant gtk_signal_connect_object_while_alive_ = link_c_proc( GTK, 
  "gtk_signal_connect_object_while_alive", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_signal_connect_object_while_alive(atom object_, sequence signal_, atom func_, atom alive_object_)
    atom string1
    string1 = allocate_string( signal_ )
    c_proc( gtk_signal_connect_object_while_alive_, {object_,string1,func_,alive_object_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_signal_connect_while_alive
----------------------------------------
constant gtk_signal_connect_while_alive_ = link_c_proc( GTK, 
  "gtk_signal_connect_while_alive", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER} 
 )

global procedure gtk_signal_connect_while_alive(atom object_, sequence signal_, atom func_, atom func_data_, atom alive_object_)
    atom string1
    string1 = allocate_string( signal_ )
    c_proc( gtk_signal_connect_while_alive_, {object_,string1,func_,func_data_,alive_object_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_signal_disconnect
----------------------------------------
constant gtk_signal_disconnect_ = link_c_proc( GTK, 
  "gtk_signal_disconnect", {C_POINTER,C_UINT} )

global procedure gtk_signal_disconnect(atom object_, integer handler_id_)
    c_proc( gtk_signal_disconnect_, {object_,handler_id_} )
end procedure

----------------------------------------
-- gtk_signal_disconnect_by_func
----------------------------------------
constant gtk_signal_disconnect_by_func_ = link_c_proc( GTK, 
  "gtk_signal_disconnect_by_func", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_signal_disconnect_by_func(atom object_, atom func_, atom data_)
    c_proc( gtk_signal_disconnect_by_func_, {object_,func_,data_} )
end procedure

----------------------------------------
-- gtk_signal_disconnect_by_data
----------------------------------------
constant gtk_signal_disconnect_by_data_ = link_c_proc( GTK, 
  "gtk_signal_disconnect_by_data", {C_POINTER,C_POINTER} )

global procedure gtk_signal_disconnect_by_data(atom object_, atom data_)
    c_proc( gtk_signal_disconnect_by_data_, {object_,data_} )
end procedure

----------------------------------------
-- gtk_signal_handler_block
----------------------------------------
constant gtk_signal_handler_block_ = link_c_proc( GTK, 
  "gtk_signal_handler_block", {C_POINTER,C_UINT} )

global procedure gtk_signal_handler_block(atom object_, integer handler_id_)
    c_proc( gtk_signal_handler_block_, {object_,handler_id_} )
end procedure

----------------------------------------
-- gtk_signal_handler_block_by_func
----------------------------------------
constant gtk_signal_handler_block_by_func_ = link_c_proc( GTK, 
  "gtk_signal_handler_block_by_func", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_signal_handler_block_by_func(atom object_, atom func_, atom data_)
    c_proc( gtk_signal_handler_block_by_func_, {object_,func_,data_} )
end procedure

----------------------------------------
-- gtk_signal_handler_block_by_data
----------------------------------------
constant gtk_signal_handler_block_by_data_ = link_c_proc( GTK, 
  "gtk_signal_handler_block_by_data", {C_POINTER,C_POINTER} )

global procedure gtk_signal_handler_block_by_data(atom object_, atom data_)
    c_proc( gtk_signal_handler_block_by_data_, {object_,data_} )
end procedure

----------------------------------------
-- gtk_signal_handler_unblock
----------------------------------------
constant gtk_signal_handler_unblock_ = link_c_proc( GTK, 
  "gtk_signal_handler_unblock", {C_POINTER,C_UINT} )

global procedure gtk_signal_handler_unblock(atom object_, integer handler_id_)
    c_proc( gtk_signal_handler_unblock_, {object_,handler_id_} )
end procedure

----------------------------------------
-- gtk_signal_handler_unblock_by_func
----------------------------------------
constant gtk_signal_handler_unblock_by_func_ = link_c_proc( GTK, 
  "gtk_signal_handler_unblock_by_func", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_signal_handler_unblock_by_func(atom object_, atom func_, atom data_)
    c_proc( gtk_signal_handler_unblock_by_func_, {object_,func_,data_} )
end procedure

----------------------------------------
-- gtk_signal_handler_unblock_by_data
----------------------------------------
constant gtk_signal_handler_unblock_by_data_ = link_c_proc( GTK, 
  "gtk_signal_handler_unblock_by_data", {C_POINTER,C_POINTER} )

global procedure gtk_signal_handler_unblock_by_data(atom object_, atom data_)
    c_proc( gtk_signal_handler_unblock_by_data_, {object_,data_} )
end procedure

----------------------------------------
-- gtk_signal_handler_pending
----------------------------------------
constant gtk_signal_handler_pending_ = link_c_func( GTK, 
  "gtk_signal_handler_pending", {C_POINTER,C_UINT,C_INT}, C_UINT )

global function gtk_signal_handler_pending(atom object_, integer signal_id_, integer may_be_blocked_)
    return c_func( gtk_signal_handler_pending_, {object_,signal_id_,may_be_blocked_} )
end function

----------------------------------------
-- gtk_signal_handler_pending_by_func
----------------------------------------
constant gtk_signal_handler_pending_by_func_ = link_c_func( GTK, 
  "gtk_signal_handler_pending_by_func", {C_POINTER,C_UINT,C_INT,C_POINTER,C_POINTER}, 
 C_UINT )

global function gtk_signal_handler_pending_by_func(atom object_, integer signal_id_, integer may_be_blocked_, atom func_, atom data_)
    return c_func( gtk_signal_handler_pending_by_func_, {object_,signal_id_,may_be_blocked_,func_,data_} )
end function

----------------------------------------
-- gtk_signal_handler_pending_by_id
----------------------------------------
constant gtk_signal_handler_pending_by_id_ = link_c_func( GTK, 
  "gtk_signal_handler_pending_by_id", {C_POINTER,C_UINT,C_INT}, C_INT )

global function gtk_signal_handler_pending_by_id(atom object_, integer handler_id_, integer may_be_blocked_)
    return c_func( gtk_signal_handler_pending_by_id_, {object_,handler_id_,may_be_blocked_} )
end function

----------------------------------------
-- gtk_signal_add_emission_hook
----------------------------------------
constant gtk_signal_add_emission_hook_ = link_c_func( GTK, 
  "gtk_signal_add_emission_hook", {C_UINT,C_POINTER,C_POINTER}, C_UINT )

global function gtk_signal_add_emission_hook(integer signal_id_, atom hook_func_, atom data_)
    return c_func( gtk_signal_add_emission_hook_, {signal_id_,hook_func_,data_} )
end function

----------------------------------------
-- gtk_signal_add_emission_hook_full
----------------------------------------
constant gtk_signal_add_emission_hook_full_ = link_c_func( GTK, 
  "gtk_signal_add_emission_hook_full", {C_UINT,C_POINTER,C_POINTER,C_POINTER}, 
 C_UINT )

global function gtk_signal_add_emission_hook_full(integer signal_id_, atom hook_func_, atom data_, atom destroy_)
    return c_func( gtk_signal_add_emission_hook_full_, {signal_id_,hook_func_,data_,destroy_} )
end function

----------------------------------------
-- gtk_signal_remove_emission_hook
----------------------------------------
constant gtk_signal_remove_emission_hook_ = link_c_proc( GTK, 
  "gtk_signal_remove_emission_hook", {C_UINT,C_UINT} )

global procedure gtk_signal_remove_emission_hook(integer signal_id_, integer hook_id_)
    c_proc( gtk_signal_remove_emission_hook_, {signal_id_,hook_id_} )
end procedure

----------------------------------------
-- gtk_signal_query
----------------------------------------
constant gtk_signal_query_ = link_c_func( GTK, 
  "gtk_signal_query", {C_UINT}, C_POINTER )

global function gtk_signal_query(integer signal_id_)
    return c_func( gtk_signal_query_, {signal_id_} )
end function

----------------------------------------
-- gtk_signal_init
----------------------------------------
constant gtk_signal_init_ = link_c_proc( GTK, 
  "gtk_signal_init", {} )

global procedure gtk_signal_init()
    c_proc( gtk_signal_init_, {} )
end procedure

----------------------------------------
-- gtk_signal_new
----------------------------------------
constant gtk_signal_new_ = link_c_func( GTK, 
  "gtk_signal_new", {C_POINTER,C_POINTER,C_UINT,C_UINT,C_POINTER,C_UINT,C_UINT}, C_UINT )

global function gtk_signal_new(sequence const_, atom signal_flags_, integer object_type_, integer function_offset_, 
 atom marshaller_, integer return_val_, integer nparams_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_signal_new_, {string1,signal_flags_,object_type_,function_offset_,marshaller_,return_val_,nparams_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_newv
----------------------------------------
constant gtk_signal_newv_ = link_c_func( GTK, 
  "gtk_signal_newv", {C_POINTER,C_POINTER,C_UINT,C_UINT,C_POINTER,C_UINT,C_UINT,C_UINT}, C_UINT )

global function gtk_signal_newv(sequence const_, atom signal_flags_, integer object_type_, integer function_offset_, 
 atom marshaller_, integer return_val_, integer nparams_, integer params_)
    integer result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_signal_newv_, {string1,signal_flags_,object_type_,function_offset_,marshaller_,return_val_,nparams_,params_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_signal_emit
----------------------------------------
constant gtk_signal_emit_ = link_c_proc( GTK, 
  "gtk_signal_emit", {C_POINTER,C_UINT} )

global procedure gtk_signal_emit(atom object_, integer signal_id_)
    c_proc( gtk_signal_emit_, {object_,signal_id_} )
end procedure

----------------------------------------
-- gtk_signal_emit_by_name
----------------------------------------
constant gtk_signal_emit_by_name_ = link_c_proc( GTK, 
  "gtk_signal_emit_by_name", {C_POINTER,C_POINTER} )

global procedure gtk_signal_emit_by_name(atom object_, sequence name_)
    atom string1
    string1 = allocate_string( name_ )
    c_proc( gtk_signal_emit_by_name_, {object_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_signal_emitv
----------------------------------------
constant gtk_signal_emitv_ = link_c_proc( GTK, 
  "gtk_signal_emitv", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_signal_emitv(atom object_, integer signal_id_, atom params_)
    c_proc( gtk_signal_emitv_, {object_,signal_id_,params_} )
end procedure

----------------------------------------
-- gtk_signal_emitv_by_name
----------------------------------------
constant gtk_signal_emitv_by_name_ = link_c_proc( GTK, 
  "gtk_signal_emitv_by_name", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_signal_emitv_by_name(atom object_, sequence name_, atom params_)
    atom string1
    string1 = allocate_string( name_ )
    c_proc( gtk_signal_emitv_by_name_, {object_,string1,params_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_signal_handlers_destroy
----------------------------------------
constant gtk_signal_handlers_destroy_ = link_c_proc( GTK, 
  "gtk_signal_handlers_destroy", {C_POINTER} )

global procedure gtk_signal_handlers_destroy(atom object_)
    c_proc( gtk_signal_handlers_destroy_, {object_} )
end procedure

----------------------------------------
-- gtk_signal_set_funcs
----------------------------------------
constant gtk_signal_set_funcs_ = link_c_proc( GTK, 
  "gtk_signal_set_funcs", {C_POINTER,C_POINTER} )

global procedure gtk_signal_set_funcs(atom marshal_func_, atom destroy_func_)
    c_proc( gtk_signal_set_funcs_, {marshal_func_,destroy_func_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKMARSHAL.H
----------------------------------------
----------------------------------------


----------------------------------------
-- gtk_marshal_BOOL__NONE
----------------------------------------
constant gtk_marshal_BOOL__NONE_ = link_c_proc( GTK, 
  "gtk_marshal_BOOL__NONE", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_BOOL__NONE(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_BOOL__NONE_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_BOOL__POINTER
----------------------------------------
constant gtk_marshal_BOOL__POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_BOOL__POINTER", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_BOOL__POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_BOOL__POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_BOOL__POINTER_POINTER_INT_INT
----------------------------------------
constant gtk_marshal_BOOL__POINTER_POINTER_INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_BOOL__POINTER_POINTER_INT_INT", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_BOOL__POINTER_POINTER_INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_BOOL__POINTER_POINTER_INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_BOOL__POINTER_INT_INT
----------------------------------------
constant gtk_marshal_BOOL__POINTER_INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_BOOL__POINTER_INT_INT", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_BOOL__POINTER_INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_BOOL__POINTER_INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_BOOL__POINTER_INT_INT_INT
----------------------------------------
constant gtk_marshal_BOOL__POINTER_INT_INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_BOOL__POINTER_INT_INT_INT", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_BOOL__POINTER_INT_INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_BOOL__POINTER_INT_INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_BOOL__POINTER_POINTER_POINTER_POINTER
----------------------------------------
constant gtk_marshal_BOOL__POINTER_POINTER_POINTER_POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_BOOL__POINTER_POINTER_POINTER_POINTER", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_BOOL__POINTER_POINTER_POINTER_POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_BOOL__POINTER_POINTER_POINTER_POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_INT__INT
----------------------------------------
constant gtk_marshal_INT__INT_ = link_c_proc( GTK, 
  "gtk_marshal_INT__INT", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_INT__INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_INT__INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_INT__POINTER
----------------------------------------
constant gtk_marshal_INT__POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_INT__POINTER", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_INT__POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_INT__POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_INT__POINTER_CHAR_CHAR
----------------------------------------
constant gtk_marshal_INT__POINTER_CHAR_CHAR_ = link_c_proc( GTK, 
  "gtk_marshal_INT__POINTER_CHAR_CHAR", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} 
 )

global procedure gtk_marshal_INT__POINTER_CHAR_CHAR(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_INT__POINTER_CHAR_CHAR_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__BOOL
----------------------------------------
constant gtk_marshal_NONE__BOOL_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__BOOL", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__BOOL(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__BOOL_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER
----------------------------------------
constant gtk_marshal_NONE__POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__C_CALLBACK
----------------------------------------
constant gtk_marshal_NONE__C_CALLBACK_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__C_CALLBACK", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__C_CALLBACK(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__C_CALLBACK_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__C_CALLBACK_C_CALLBACK
----------------------------------------
constant gtk_marshal_NONE__C_CALLBACK_C_CALLBACK_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__C_CALLBACK_C_CALLBACK", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__C_CALLBACK_C_CALLBACK(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__C_CALLBACK_C_CALLBACK_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT
----------------------------------------
constant gtk_marshal_NONE__INT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT_FLOAT
----------------------------------------
constant gtk_marshal_NONE__INT_FLOAT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT_FLOAT", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT_FLOAT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_FLOAT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT_FLOAT_BOOL
----------------------------------------
constant gtk_marshal_NONE__INT_FLOAT_BOOL_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT_FLOAT_BOOL", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT_FLOAT_BOOL(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_FLOAT_BOOL_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT_INT
----------------------------------------
constant gtk_marshal_NONE__INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT_INT", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT_INT_POINTER
----------------------------------------
constant gtk_marshal_NONE__INT_INT_POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT_INT_POINTER", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT_INT_POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_INT_POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__NONE
----------------------------------------
constant gtk_marshal_NONE__NONE_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__NONE", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__NONE(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__NONE_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER_INT
----------------------------------------
constant gtk_marshal_NONE__POINTER_INT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER_INT", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER_POINTER
----------------------------------------
constant gtk_marshal_NONE__POINTER_POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER_POINTER", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER_POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER_POINTER_POINTER
----------------------------------------
constant gtk_marshal_NONE__POINTER_POINTER_POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER_POINTER_POINTER", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER_POINTER_POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_POINTER_POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER_INT_INT
----------------------------------------
constant gtk_marshal_NONE__POINTER_INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER_INT_INT", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER_INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER_POINTER_INT_INT
----------------------------------------
constant gtk_marshal_NONE__POINTER_POINTER_INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER_POINTER_INT_INT", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER_POINTER_INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_POINTER_INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER_INT_INT_POINTER_INT_INT
----------------------------------------
constant gtk_marshal_NONE__POINTER_INT_INT_POINTER_INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER_INT_INT_POINTER_INT_INT", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER_INT_INT_POINTER_INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_INT_INT_POINTER_INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__POINTER_INT_POINTER
----------------------------------------
constant gtk_marshal_NONE__POINTER_INT_POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__POINTER_INT_POINTER", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__POINTER_INT_POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__POINTER_INT_POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT_POINTER_INT_INT_INT_POINTER
----------------------------------------
constant gtk_marshal_NONE__INT_POINTER_INT_INT_INT_POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT_POINTER_INT_INT_INT_POINTER", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT_POINTER_INT_INT_INT_POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_POINTER_INT_INT_INT_POINTER_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT_POINTER_INT_INT_INT
----------------------------------------
constant gtk_marshal_NONE__INT_POINTER_INT_INT_INT_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT_POINTER_INT_INT_INT", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT_POINTER_INT_INT_INT(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_POINTER_INT_INT_INT_, {object_,func_,func_data_,args_} )
end procedure

----------------------------------------
-- gtk_marshal_NONE__INT_POINTER
----------------------------------------
constant gtk_marshal_NONE__INT_POINTER_ = link_c_proc( GTK, 
  "gtk_marshal_NONE__INT_POINTER", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_marshal_NONE__INT_POINTER(atom object_, atom func_, atom func_data_, atom args_)
    c_proc( gtk_marshal_NONE__INT_POINTER_, {object_,func_,func_data_,args_} )
end procedure


----------------------------------------
----------------------------------------
-- GTKTOGGLEBUTTON.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkToggleButton
----------------------------------------
global constant
    GtkToggleButton_button              = allot(SIZEOF_GtkButton),
    GtkToggleButton_active              = allot(TYPE_GUINT),
    GtkToggleButton_draw_indicator      = allot(TYPE_GUINT),
    GtkToggleButton_event_window        = allot(TYPE_POINTER),
    SIZEOF_GtkToggleButton              = allotted_size()

----------------------------------------
-- GtkToggleButtonClass
----------------------------------------
global constant
    GtkToggleButtonClass_parent_class   = allot(SIZEOF_GtkButtonClass),
    GtkToggleButtonClass_toggled        = allot(TYPE_GPOINTER),
    SIZEOF_GtkToggleButtonClass         = allotted_size()
----------------------------------------
-- gtk_toggle_button_get_type
----------------------------------------
constant gtk_toggle_button_get_type_ = link_c_func( GTK, 
  "gtk_toggle_button_get_type", {}, C_UINT )

global function gtk_toggle_button_get_type()
    return c_func( gtk_toggle_button_get_type_, {} )
end function

----------------------------------------
-- gtk_toggle_button_new
----------------------------------------
constant gtk_toggle_button_new_ = link_c_func( GTK, 
  "gtk_toggle_button_new", {}, C_POINTER )

global function gtk_toggle_button_new()
    return c_func( gtk_toggle_button_new_, {} )
end function

----------------------------------------
-- gtk_toggle_button_new_with_label
----------------------------------------
constant gtk_toggle_button_new_with_label_ = link_c_func( GTK, 
  "gtk_toggle_button_new_with_label", {C_POINTER}, C_POINTER )

global function gtk_toggle_button_new_with_label(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_toggle_button_new_with_label_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_toggle_button_set_mode
----------------------------------------
constant gtk_toggle_button_set_mode_ = link_c_proc( GTK, 
  "gtk_toggle_button_set_mode", {C_POINTER,C_INT} )

global procedure gtk_toggle_button_set_mode(atom toggle_button_, integer draw_indicator_)
    c_proc( gtk_toggle_button_set_mode_, {toggle_button_,draw_indicator_} )
end procedure

----------------------------------------
-- gtk_toggle_button_set_active
----------------------------------------
constant gtk_toggle_button_set_active_ = link_c_proc( GTK, 
  "gtk_toggle_button_set_active", {C_POINTER,C_INT} )

global procedure gtk_toggle_button_set_active(atom toggle_button_, integer is_active_)
    c_proc( gtk_toggle_button_set_active_, {toggle_button_,is_active_} )
end procedure

----------------------------------------
-- gtk_toggle_button_get_active
----------------------------------------
constant gtk_toggle_button_get_active_ = link_c_func( GTK, 
  "gtk_toggle_button_get_active", {C_POINTER}, C_INT )

global function gtk_toggle_button_get_active(atom toggle_button_)
    return c_func( gtk_toggle_button_get_active_, {toggle_button_} )
end function

----------------------------------------
-- gtk_toggle_button_toggled
----------------------------------------
constant gtk_toggle_button_toggled_ = link_c_proc( GTK, 
  "gtk_toggle_button_toggled", {C_POINTER} )

global procedure gtk_toggle_button_toggled(atom toggle_button_)
    c_proc( gtk_toggle_button_toggled_, {toggle_button_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKCHECKBUTTON.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkCheckButton
----------------------------------------
global constant
    GtkCheckButton_toggle_button        = allot(SIZEOF_GtkToggleButton),
    SIZEOF_GtkCheckButton               = allotted_size()

----------------------------------------
-- GtkCheckButtonClass
----------------------------------------
global constant
    GtkCheckButtonClass_parent_class    = allot(SIZEOF_GtkToggleButtonClass),
    GtkCheckButtonClass_indicator_size  = allot(TYPE_GUINT16),
    GtkCheckButtonClass_indicator_spacing= allot(TYPE_GUINT16),
    GtkCheckButtonClass_draw_indicator  = allot(TYPE_GPOINTER),
    SIZEOF_GtkCheckButtonClass          = allotted_size()
----------------------------------------
-- gtk_check_button_get_type
----------------------------------------
constant gtk_check_button_get_type_ = link_c_func( GTK, 
  "gtk_check_button_get_type", {}, C_UINT )

global function gtk_check_button_get_type()
    return c_func( gtk_check_button_get_type_, {} )
end function

----------------------------------------
-- gtk_check_button_new
----------------------------------------
constant gtk_check_button_new_ = link_c_func( GTK, 
  "gtk_check_button_new", {}, C_POINTER )

global function gtk_check_button_new()
    return c_func( gtk_check_button_new_, {} )
end function

----------------------------------------
-- gtk_check_button_new_with_label
----------------------------------------
constant gtk_check_button_new_with_label_ = link_c_func( GTK, 
  "gtk_check_button_new_with_label", {C_POINTER}, C_POINTER )

global function gtk_check_button_new_with_label(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_check_button_new_with_label_, {string1} )
    free( string1 )
    return result
end function


----------------------------------------
----------------------------------------
-- GTKITEM.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkItem
----------------------------------------
global constant
    GtkItem_bin                         = allot(SIZEOF_GtkBin),
    SIZEOF_GtkItem                      = allotted_size()

----------------------------------------
-- GtkItemClass
----------------------------------------
global constant
    GtkItemClass_parent_class           = allot(SIZEOF_GtkBinClass),
    GtkItemClass_select                 = allot(TYPE_GPOINTER),
    GtkItemClass_deselect               = allot(TYPE_GPOINTER),
    GtkItemClass_toggle                 = allot(TYPE_GPOINTER),
    SIZEOF_GtkItemClass                 = allotted_size()
----------------------------------------
-- gtk_item_get_type
----------------------------------------
constant gtk_item_get_type_ = link_c_func( GTK, 
  "gtk_item_get_type", {}, C_UINT )

global function gtk_item_get_type()
    return c_func( gtk_item_get_type_, {} )
end function

----------------------------------------
-- gtk_item_select
----------------------------------------
constant gtk_item_select_ = link_c_proc( GTK, 
  "gtk_item_select", {C_POINTER} )

global procedure gtk_item_select(atom item_)
    c_proc( gtk_item_select_, {item_} )
end procedure

----------------------------------------
-- gtk_item_deselect
----------------------------------------
constant gtk_item_deselect_ = link_c_proc( GTK, 
  "gtk_item_deselect", {C_POINTER} )

global procedure gtk_item_deselect(atom item_)
    c_proc( gtk_item_deselect_, {item_} )
end procedure

----------------------------------------
-- gtk_item_toggle
----------------------------------------
constant gtk_item_toggle_ = link_c_proc( GTK, 
  "gtk_item_toggle", {C_POINTER} )

global procedure gtk_item_toggle(atom item_)
    c_proc( gtk_item_toggle_, {item_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKMENUITEM.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkMenuItem
----------------------------------------
global constant
    GtkMenuItem_item                    = allot(SIZEOF_GtkItem),
    GtkMenuItem_submenu                 = allot(TYPE_POINTER),
    GtkMenuItem_accelerator_signal      = allot(TYPE_GUINT),
    GtkMenuItem_toggle_size             = allot(TYPE_GUINT16),
    GtkMenuItem_accelerator_width       = allot(TYPE_GUINT16),
    GtkMenuItem_show_toggle_indicator   = allot(TYPE_GUINT),
    GtkMenuItem_show_submenu_indicator  = allot(TYPE_GUINT),
    GtkMenuItem_submenu_placement       = allot(TYPE_GUINT),
    GtkMenuItem_submenu_direction       = allot(TYPE_GUINT),
    GtkMenuItem_right_justify           = allot(TYPE_GUINT),
    GtkMenuItem_timer                   = allot(TYPE_GUINT),
    SIZEOF_GtkMenuItem                  = allotted_size()

----------------------------------------
-- GtkMenuItemClass
----------------------------------------
global constant
    GtkMenuItemClass_parent_class       = allot(SIZEOF_GtkItemClass),
    GtkMenuItemClass_toggle_size        = allot(TYPE_GUINT),
    GtkMenuItemClass_hide_on_activate   = allot(TYPE_GUINT),
    GtkMenuItemClass_activate           = allot(TYPE_GPOINTER),
    GtkMenuItemClass_activate_item      = allot(TYPE_GPOINTER),
    SIZEOF_GtkMenuItemClass             = allotted_size()
----------------------------------------
-- gtk_menu_item_get_type
----------------------------------------
constant gtk_menu_item_get_type_ = link_c_func( GTK, 
  "gtk_menu_item_get_type", {}, C_UINT )

global function gtk_menu_item_get_type()
    return c_func( gtk_menu_item_get_type_, {} )
end function

----------------------------------------
-- gtk_menu_item_new
----------------------------------------
constant gtk_menu_item_new_ = link_c_func( GTK, 
  "gtk_menu_item_new", {}, C_POINTER )

global function gtk_menu_item_new()
    return c_func( gtk_menu_item_new_, {} )
end function

----------------------------------------
-- gtk_menu_item_new_with_label
----------------------------------------
constant gtk_menu_item_new_with_label_ = link_c_func( GTK, 
  "gtk_menu_item_new_with_label", {C_POINTER}, C_POINTER )

global function gtk_menu_item_new_with_label(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_menu_item_new_with_label_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_menu_item_set_submenu
----------------------------------------
constant gtk_menu_item_set_submenu_ = link_c_proc( GTK, 
  "gtk_menu_item_set_submenu", {C_POINTER,C_POINTER} )

global procedure gtk_menu_item_set_submenu(atom menu_item_, atom submenu_)
    c_proc( gtk_menu_item_set_submenu_, {menu_item_,submenu_} )
end procedure

----------------------------------------
-- gtk_menu_item_remove_submenu
----------------------------------------
constant gtk_menu_item_remove_submenu_ = link_c_proc( GTK, 
  "gtk_menu_item_remove_submenu", {C_POINTER} )

global procedure gtk_menu_item_remove_submenu(atom menu_item_)
    c_proc( gtk_menu_item_remove_submenu_, {menu_item_} )
end procedure

----------------------------------------
-- gtk_menu_item_set_placement
----------------------------------------
constant gtk_menu_item_set_placement_ = link_c_proc( GTK, 
  "gtk_menu_item_set_placement", {C_POINTER,C_POINTER} )

global procedure gtk_menu_item_set_placement(atom menu_item_, atom placement_)
    c_proc( gtk_menu_item_set_placement_, {menu_item_,placement_} )
end procedure

----------------------------------------
-- gtk_menu_item_configure
----------------------------------------
constant gtk_menu_item_configure_ = link_c_proc( GTK, 
  "gtk_menu_item_configure", {C_POINTER,C_INT,C_INT} )

global procedure gtk_menu_item_configure(atom menu_item_, integer show_toggle_indicator_, integer show_submenu_indicator_)
    c_proc( gtk_menu_item_configure_, {menu_item_,show_toggle_indicator_,show_submenu_indicator_} )
end procedure

----------------------------------------
-- gtk_menu_item_select
----------------------------------------
constant gtk_menu_item_select_ = link_c_proc( GTK, 
  "gtk_menu_item_select", {C_POINTER} )

global procedure gtk_menu_item_select(atom menu_item_)
    c_proc( gtk_menu_item_select_, {menu_item_} )
end procedure

----------------------------------------
-- gtk_menu_item_deselect
----------------------------------------
constant gtk_menu_item_deselect_ = link_c_proc( GTK, 
  "gtk_menu_item_deselect", {C_POINTER} )

global procedure gtk_menu_item_deselect(atom menu_item_)
    c_proc( gtk_menu_item_deselect_, {menu_item_} )
end procedure

----------------------------------------
-- gtk_menu_item_activate
----------------------------------------
constant gtk_menu_item_activate_ = link_c_proc( GTK, 
  "gtk_menu_item_activate", {C_POINTER} )

global procedure gtk_menu_item_activate(atom menu_item_)
    c_proc( gtk_menu_item_activate_, {menu_item_} )
end procedure

----------------------------------------
-- gtk_menu_item_right_justify
----------------------------------------
constant gtk_menu_item_right_justify_ = link_c_proc( GTK, 
  "gtk_menu_item_right_justify", {C_POINTER} )

global procedure gtk_menu_item_right_justify(atom menu_item_)
    c_proc( gtk_menu_item_right_justify_, {menu_item_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKCHECKMENUITEM.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkCheckMenuItem
----------------------------------------
global constant
    GtkCheckMenuItem_menu_item          = allot(SIZEOF_GtkMenuItem),
    GtkCheckMenuItem_active             = allot(TYPE_GUINT),
    GtkCheckMenuItem_always_show_toggle = allot(TYPE_GUINT),
    SIZEOF_GtkCheckMenuItem             = allotted_size()

----------------------------------------
-- GtkCheckMenuItemClass
----------------------------------------
global constant
    GtkCheckMenuItemClass_parent_class  = allot(SIZEOF_GtkMenuItemClass),
    GtkCheckMenuItemClass_toggled       = allot(TYPE_GPOINTER),
    GtkCheckMenuItemClass_draw_indicator= allot(TYPE_GPOINTER),
    SIZEOF_GtkCheckMenuItemClass        = allotted_size()
----------------------------------------
-- gtk_check_menu_item_get_type
----------------------------------------
constant gtk_check_menu_item_get_type_ = link_c_func( GTK, 
  "gtk_check_menu_item_get_type", {}, C_UINT )

global function gtk_check_menu_item_get_type()
    return c_func( gtk_check_menu_item_get_type_, {} )
end function

----------------------------------------
-- gtk_check_menu_item_new
----------------------------------------
constant gtk_check_menu_item_new_ = link_c_func( GTK, 
  "gtk_check_menu_item_new", {}, C_POINTER )

global function gtk_check_menu_item_new()
    return c_func( gtk_check_menu_item_new_, {} )
end function

----------------------------------------
-- gtk_check_menu_item_new_with_label
----------------------------------------
constant gtk_check_menu_item_new_with_label_ = link_c_func( GTK, 
  "gtk_check_menu_item_new_with_label", {C_POINTER}, C_POINTER )

global function gtk_check_menu_item_new_with_label(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_check_menu_item_new_with_label_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_check_menu_item_set_active
----------------------------------------
constant gtk_check_menu_item_set_active_ = link_c_proc( GTK, 
  "gtk_check_menu_item_set_active", {C_POINTER,C_INT} )

global procedure gtk_check_menu_item_set_active(atom check_menu_item_, integer is_active_)
    c_proc( gtk_check_menu_item_set_active_, {check_menu_item_,is_active_} )
end procedure

----------------------------------------
-- gtk_check_menu_item_set_show_toggle
----------------------------------------
constant gtk_check_menu_item_set_show_toggle_ = link_c_proc( GTK, 
  "gtk_check_menu_item_set_show_toggle", {C_POINTER,C_INT} )

global procedure gtk_check_menu_item_set_show_toggle(atom menu_item_, integer always_)
    c_proc( gtk_check_menu_item_set_show_toggle_, {menu_item_,always_} )
end procedure

----------------------------------------
-- gtk_check_menu_item_toggled
----------------------------------------
constant gtk_check_menu_item_toggled_ = link_c_proc( GTK, 
  "gtk_check_menu_item_toggled", {C_POINTER} )

global procedure gtk_check_menu_item_toggled(atom check_menu_item_)
    c_proc( gtk_check_menu_item_toggled_, {check_menu_item_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKCLIST.H
----------------------------------------
----------------------------------------


global constant
    GTK_CLIST_IN_DRAG                   = power(2,0),
    GTK_CLIST_ROW_HEIGHT_SET            = power(2,1),
    GTK_CLIST_SHOW_TITLES               = power(2,2),
    GTK_CLIST_CHILD_HAS_FOCUS           = power(2,3),
    GTK_CLIST_ADD_MODE                  = power(2,4),
    GTK_CLIST_AUTO_SORT                 = power(2,5),
    GTK_CLIST_AUTO_RESIZE_BLOCKED       = power(2,6),
    GTK_CLIST_REORDERABLE               = power(2,7),
    GTK_CLIST_USE_DRAG_ICONS            = power(2,8),
    GTK_CLIST_DRAW_DRAG_LINE            = power(2,9),
    GTK_CLIST_DRAW_DRAG_RECT            = power(2,10)
global constant
    GTK_CELL_EMPTY                      = 1,
    GTK_CELL_TEXT                       = 2,
    GTK_CELL_PIXMAP                     = 3,
    GTK_CELL_PIXTEXT                    = 4,
    GTK_CELL_WIDGET                     = 5
global constant SIZEOF_GtkCellType = SIZEOF_ENUM

global constant
    GTK_CLIST_DRAG_NONE                 = 1,
    GTK_CLIST_DRAG_BEFORE               = 2,
    GTK_CLIST_DRAG_INTO                 = 3,
    GTK_CLIST_DRAG_AFTER                = 4
global constant SIZEOF_GtkCListDragPos = SIZEOF_ENUM

global constant
    GTK_BUTTON_IGNORED                  = 0,
    GTK_BUTTON_SELECTS                  = power(2,0),
    GTK_BUTTON_DRAGS                    = power(2,1),
    GTK_BUTTON_EXPANDS                  = power(2,2)
global constant SIZEOF_GtkButtonAction = SIZEOF_ENUM

----------------------------------------
-- GtkCListCompareFunc
----------------------------------------
constant GtkCListCompareFunc_ = link_c_func( GTK, 
  "GtkCListCompareFunc", {C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function GtkCListCompareFunc(atom clist_, atom ptr1_, atom ptr2_)
    return c_func( GtkCListCompareFunc_, {clist_,ptr1_,ptr2_} )
end function


----------------------------------------
-- GtkCListCellInfo
----------------------------------------
global constant
    GtkCListCellInfo_row                = allot(TYPE_GINT),
    GtkCListCellInfo_column             = allot(TYPE_GINT),
    SIZEOF_GtkCListCellInfo             = allotted_size()

----------------------------------------
-- GtkCListDestInfo
----------------------------------------
global constant
    GtkCListDestInfo_cell               = allot(SIZEOF_GtkCListCellInfo),
    GtkCListDestInfo_insert_pos         = allot(SIZEOF_GtkCListDragPos),
    SIZEOF_GtkCListDestInfo             = allotted_size()

----------------------------------------
-- GtkCList
----------------------------------------
global constant
-- manually corrected button_actions;
-- compare is a pointer
    GtkCList_container                  = allot(SIZEOF_GtkContainer),
    GtkCList_flags                      = allot(TYPE_GUINT16),
    GtkCList_row_mem_chunk              = allot(TYPE_POINTER),
    GtkCList_cell_mem_chunk             = allot(TYPE_POINTER),
    GtkCList_freeze_count               = allot(TYPE_GUINT),
    GtkCList_internal_allocation        = allot(SIZEOF_GdkRectangle),
    GtkCList_rows                       = allot(TYPE_GINT),
    GtkCList_row_center_offset          = allot(TYPE_GINT),
    GtkCList_row_height                 = allot(TYPE_GINT),
    GtkCList_row_list                   = allot(TYPE_POINTER),
    GtkCList_row_list_end               = allot(TYPE_POINTER),
    GtkCList_columns                    = allot(TYPE_GINT),
    GtkCList_column_title_area          = allot(SIZEOF_GdkRectangle),
    GtkCList_title_window               = allot(TYPE_POINTER),
    GtkCList_column                     = allot(TYPE_POINTER),
    GtkCList_clist_window               = allot(TYPE_POINTER),
    GtkCList_clist_window_width         = allot(TYPE_GINT),
    GtkCList_clist_window_height        = allot(TYPE_GINT),
    GtkCList_hoffset                    = allot(TYPE_GINT),
    GtkCList_voffset                    = allot(TYPE_GINT),
    GtkCList_shadow_type                = allot(SIZEOF_GtkShadowType),
    GtkCList_selection_mode             = allot(SIZEOF_GtkSelectionMode),
    GtkCList_selection                  = allot(TYPE_POINTER),
    GtkCList_selection_end              = allot(TYPE_POINTER),
    GtkCList_undo_selection             = allot(TYPE_POINTER),
    GtkCList_undo_unselection           = allot(TYPE_POINTER),
    GtkCList_undo_anchor                = allot(TYPE_GINT),
    GtkCList_button_actions             = allot(5*BYTE_BYTES), -- guint8
    GtkCList_drag_button                = allot(TYPE_GUINT8),
    GtkCList_click_cell                 = allot(SIZEOF_GtkCListCellInfo),
    GtkCList_hadjustment                = allot(TYPE_POINTER),
    GtkCList_vadjustment                = allot(TYPE_POINTER),
    GtkCList_xor_gc                     = allot(TYPE_POINTER),
    GtkCList_fg_gc                      = allot(TYPE_POINTER),
    GtkCList_bg_gc                      = allot(TYPE_POINTER),
    GtkCList_cursor_drag                = allot(TYPE_POINTER),
    GtkCList_x_drag                     = allot(TYPE_GINT),
    GtkCList_focus_row                  = allot(TYPE_GINT),
    GtkCList_anchor                     = allot(TYPE_GINT),
    GtkCList_anchor_state               = allot(SIZEOF_GtkStateType),
    GtkCList_drag_pos                   = allot(TYPE_GINT),
    GtkCList_htimer                     = allot(TYPE_GINT),
    GtkCList_vtimer                     = allot(TYPE_GINT),
    GtkCList_sort_type                  = allot(SIZEOF_GtkSortType),
    GtkCList_compare                    = allot(TYPE_GPOINTER),
    GtkCList_sort_column                = allot(TYPE_GINT),
    SIZEOF_GtkCList                     = allotted_size()

----------------------------------------
-- GtkCListClass
----------------------------------------
global constant
    GtkCListClass_parent_class          = allot(SIZEOF_GtkContainerClass),
    GtkCListClass_set_scroll_adjustments= allot(TYPE_GPOINTER),
    GtkCListClass_refresh               = allot(TYPE_GPOINTER),
    GtkCListClass_select_row            = allot(TYPE_GPOINTER),
    GtkCListClass_unselect_row          = allot(TYPE_GPOINTER),
    GtkCListClass_row_move              = allot(TYPE_GPOINTER),
    GtkCListClass_click_column          = allot(TYPE_GPOINTER),
    GtkCListClass_resize_column         = allot(TYPE_GPOINTER),
    GtkCListClass_toggle_focus_row      = allot(TYPE_GPOINTER),
    GtkCListClass_select_all            = allot(TYPE_GPOINTER),
    GtkCListClass_unselect_all          = allot(TYPE_GPOINTER),
    GtkCListClass_undo_selection        = allot(TYPE_GPOINTER),
    GtkCListClass_start_selection       = allot(TYPE_GPOINTER),
    GtkCListClass_end_selection         = allot(TYPE_GPOINTER),
    GtkCListClass_extend_selection      = allot(TYPE_GPOINTER),
    GtkCListClass_scroll_horizontal     = allot(TYPE_GPOINTER),
    GtkCListClass_scroll_vertical       = allot(TYPE_GPOINTER),
    GtkCListClass_toggle_add_mode       = allot(TYPE_GPOINTER),
    GtkCListClass_abort_column_resize   = allot(TYPE_GPOINTER),
    GtkCListClass_resync_selection      = allot(TYPE_GPOINTER),
    GtkCListClass_selection_find        = allot(TYPE_GPOINTER),
    GtkCListClass_draw_row              = allot(TYPE_GPOINTER),
    GtkCListClass_draw_drag_highlight   = allot(TYPE_GPOINTER),
    GtkCListClass_clear                 = allot(TYPE_GPOINTER),
    GtkCListClass_fake_unselect_all     = allot(TYPE_GPOINTER),
    GtkCListClass_sort_list             = allot(TYPE_GPOINTER),
    GtkCListClass_insert_row            = allot(TYPE_GPOINTER),
    GtkCListClass_remove_row            = allot(TYPE_GPOINTER),
    GtkCListClass_set_cell_contents     = allot(TYPE_GPOINTER),
    GtkCListClass_cell_size_request     = allot(TYPE_GPOINTER),
    SIZEOF_GtkCListClass                = allotted_size()

----------------------------------------
-- GtkCListColumn
----------------------------------------
global constant
    GtkCListColumn_title                = allot(TYPE_POINTER),
    GtkCListColumn_area                 = allot(SIZEOF_GdkRectangle),
    GtkCListColumn_button               = allot(TYPE_POINTER),
    GtkCListColumn_window               = allot(TYPE_POINTER),
    GtkCListColumn_width                = allot(TYPE_GINT),
    GtkCListColumn_min_width            = allot(TYPE_GINT),
    GtkCListColumn_max_width            = allot(TYPE_GINT),
    GtkCListColumn_justification        = allot(SIZEOF_GtkJustification),
    GtkCListColumn_visible              = allot(TYPE_GUINT),
    GtkCListColumn_width_set            = allot(TYPE_GUINT),
    GtkCListColumn_resizeable           = allot(TYPE_GUINT),
    GtkCListColumn_auto_resize          = allot(TYPE_GUINT),
    GtkCListColumn_button_passive       = allot(TYPE_GUINT),
    SIZEOF_GtkCListColumn               = allotted_size()

----------------------------------------
-- GtkCListRow
----------------------------------------
-- manually corrected
-- changed GtkDestroyNotify to TYPE_GPOINTER;
-- i'm not sure about this correction
global constant
    GtkCListRow_cell                    = allot(TYPE_POINTER),
    GtkCListRow_state                   = allot(SIZEOF_GtkStateType),
    GtkCListRow_foreground              = allot(SIZEOF_GdkColor),
    GtkCListRow_background              = allot(SIZEOF_GdkColor),
    GtkCListRow_style                   = allot(TYPE_POINTER),
    GtkCListRow_data                    = allot(TYPE_GPOINTER),
    GtkCListRow_destroy                 = allot(TYPE_GPOINTER),
    GtkCListRow_fg_set                  = allot(TYPE_GUINT),
    GtkCListRow_bg_set                  = allot(TYPE_GUINT),
    GtkCListRow_selectable              = allot(TYPE_GUINT),
    SIZEOF_GtkCListRow                  = allotted_size()

----------------------------------------
-- GtkCellText
----------------------------------------
global constant
    GtkCellText_type                    = allot(SIZEOF_GtkCellType),
    GtkCellText_vertical                = allot(TYPE_GINT16),
    GtkCellText_horizontal              = allot(TYPE_GINT16),
    GtkCellText_style                   = allot(TYPE_POINTER),
    GtkCellText_text                    = allot(TYPE_POINTER),
    SIZEOF_GtkCellText                  = allotted_size()

----------------------------------------
-- GtkCellPixmap
----------------------------------------
global constant
    GtkCellPixmap_type                  = allot(SIZEOF_GtkCellType),
    GtkCellPixmap_vertical              = allot(TYPE_GINT16),
    GtkCellPixmap_horizontal            = allot(TYPE_GINT16),
    GtkCellPixmap_style                 = allot(TYPE_POINTER),
    GtkCellPixmap_pixmap                = allot(TYPE_POINTER),
    GtkCellPixmap_mask                  = allot(TYPE_POINTER),
    SIZEOF_GtkCellPixmap                = allotted_size()

----------------------------------------
-- GtkCellPixText
----------------------------------------
global constant
    GtkCellPixText_type                 = allot(SIZEOF_GtkCellType),
    GtkCellPixText_vertical             = allot(TYPE_GINT16),
    GtkCellPixText_horizontal           = allot(TYPE_GINT16),
    GtkCellPixText_style                = allot(TYPE_POINTER),
    GtkCellPixText_text                 = allot(TYPE_POINTER),
    GtkCellPixText_spacing              = allot(TYPE_GUINT8),
    GtkCellPixText_pixmap               = allot(TYPE_POINTER),
    GtkCellPixText_mask                 = allot(TYPE_POINTER),
    SIZEOF_GtkCellPixText               = allotted_size()

----------------------------------------
-- GtkCellWidget
----------------------------------------
global constant
    GtkCellWidget_type                  = allot(SIZEOF_GtkCellType),
    GtkCellWidget_vertical              = allot(TYPE_GINT16),
    GtkCellWidget_horizontal            = allot(TYPE_GINT16),
    GtkCellWidget_style                 = allot(TYPE_POINTER),
    GtkCellWidget_widget                = allot(TYPE_POINTER),
    SIZEOF_GtkCellWidget                = allotted_size()

----------------------------------------
-- GtkCell
----------------------------------------
global constant
    GtkCell_type                        = allot(SIZEOF_GtkCellType),
    GtkCell_vertical                    = allot(TYPE_GINT16),
    GtkCell_horizontal                  = allot(TYPE_GINT16),
    GtkCell_style                       = allot(TYPE_POINTER),
    GtkCell_u                           = allot(TYPE_LONG), -- union,
    SIZEOF_GtkCell                      = allotted_size()
----------------------------------------
-- gtk_clist_get_type
----------------------------------------
constant gtk_clist_get_type_ = link_c_func( GTK, 
  "gtk_clist_get_type", {}, C_UINT )

global function gtk_clist_get_type()
    return c_func( gtk_clist_get_type_, {} )
end function

----------------------------------------
-- gtk_clist_construct
----------------------------------------
constant gtk_clist_construct_ = link_c_proc( GTK, 
  "gtk_clist_construct", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_construct(atom clist_, integer columns_, sequence titles_)
    atom strArray1
    strArray1 = allot_string_array( titles_ )
    c_proc( gtk_clist_construct_, {clist_,columns_,strArray1} )
    free_string_array( strArray1 )
end procedure

----------------------------------------
-- gtk_clist_new
----------------------------------------
constant gtk_clist_new_ = link_c_func( GTK, 
  "gtk_clist_new", {C_INT}, C_POINTER )

global function gtk_clist_new(integer columns_)
    return c_func( gtk_clist_new_, {columns_} )
end function

----------------------------------------
-- gtk_clist_new_with_titles
----------------------------------------
constant gtk_clist_new_with_titles_ = link_c_func( GTK, 
  "gtk_clist_new_with_titles", {C_INT,C_POINTER}, C_POINTER )

global function gtk_clist_new_with_titles(integer columns_, sequence titles_)
    atom result
    atom strArray1
    strArray1 = allot_string_array( titles_ )
    result = c_func( gtk_clist_new_with_titles_, {columns_,strArray1} )
    free_string_array( strArray1 )
    return result
end function

----------------------------------------
-- gtk_clist_set_hadjustment
----------------------------------------
constant gtk_clist_set_hadjustment_ = link_c_proc( GTK, 
  "gtk_clist_set_hadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_clist_set_hadjustment(atom clist_, atom adjustment_)
    c_proc( gtk_clist_set_hadjustment_, {clist_,adjustment_} )
end procedure

----------------------------------------
-- gtk_clist_set_vadjustment
----------------------------------------
constant gtk_clist_set_vadjustment_ = link_c_proc( GTK, 
  "gtk_clist_set_vadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_clist_set_vadjustment(atom clist_, atom adjustment_)
    c_proc( gtk_clist_set_vadjustment_, {clist_,adjustment_} )
end procedure

----------------------------------------
-- gtk_clist_get_hadjustment
----------------------------------------
constant gtk_clist_get_hadjustment_ = link_c_func( GTK, 
  "gtk_clist_get_hadjustment", {C_POINTER}, C_POINTER )

global function gtk_clist_get_hadjustment(atom clist_)
    return c_func( gtk_clist_get_hadjustment_, {clist_} )
end function

----------------------------------------
-- gtk_clist_get_vadjustment
----------------------------------------
constant gtk_clist_get_vadjustment_ = link_c_func( GTK, 
  "gtk_clist_get_vadjustment", {C_POINTER}, C_POINTER )

global function gtk_clist_get_vadjustment(atom clist_)
    return c_func( gtk_clist_get_vadjustment_, {clist_} )
end function

----------------------------------------
-- gtk_clist_set_shadow_type
----------------------------------------
constant gtk_clist_set_shadow_type_ = link_c_proc( GTK, 
  "gtk_clist_set_shadow_type", {C_POINTER,C_POINTER} )

global procedure gtk_clist_set_shadow_type(atom clist_, atom type_)
    c_proc( gtk_clist_set_shadow_type_, {clist_,type_} )
end procedure

----------------------------------------
-- gtk_clist_set_selection_mode
----------------------------------------
constant gtk_clist_set_selection_mode_ = link_c_proc( GTK, 
  "gtk_clist_set_selection_mode", {C_POINTER,C_POINTER} )

global procedure gtk_clist_set_selection_mode(atom clist_, atom mode_)
    c_proc( gtk_clist_set_selection_mode_, {clist_,mode_} )
end procedure

----------------------------------------
-- gtk_clist_set_reorderable
----------------------------------------
constant gtk_clist_set_reorderable_ = link_c_proc( GTK, 
  "gtk_clist_set_reorderable", {C_POINTER,C_INT} )

global procedure gtk_clist_set_reorderable(atom clist_, integer reorderable_)
    c_proc( gtk_clist_set_reorderable_, {clist_,reorderable_} )
end procedure

----------------------------------------
-- gtk_clist_set_use_drag_icons
----------------------------------------
constant gtk_clist_set_use_drag_icons_ = link_c_proc( GTK, 
  "gtk_clist_set_use_drag_icons", {C_POINTER,C_INT} )

global procedure gtk_clist_set_use_drag_icons(atom clist_, integer use_icons_)
    c_proc( gtk_clist_set_use_drag_icons_, {clist_,use_icons_} )
end procedure

----------------------------------------
-- gtk_clist_set_button_actions
----------------------------------------
constant gtk_clist_set_button_actions_ = link_c_proc( GTK, 
  "gtk_clist_set_button_actions", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_clist_set_button_actions(atom clist_, integer button_, integer button_actions_)
    c_proc( gtk_clist_set_button_actions_, {clist_,button_,button_actions_} )
end procedure

----------------------------------------
-- gtk_clist_freeze
----------------------------------------
constant gtk_clist_freeze_ = link_c_proc( GTK, 
  "gtk_clist_freeze", {C_POINTER} )

global procedure gtk_clist_freeze(atom clist_)
    c_proc( gtk_clist_freeze_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_thaw
----------------------------------------
constant gtk_clist_thaw_ = link_c_proc( GTK, 
  "gtk_clist_thaw", {C_POINTER} )

global procedure gtk_clist_thaw(atom clist_)
    c_proc( gtk_clist_thaw_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_column_titles_show
----------------------------------------
constant gtk_clist_column_titles_show_ = link_c_proc( GTK, 
  "gtk_clist_column_titles_show", {C_POINTER} )

global procedure gtk_clist_column_titles_show(atom clist_)
    c_proc( gtk_clist_column_titles_show_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_column_titles_hide
----------------------------------------
constant gtk_clist_column_titles_hide_ = link_c_proc( GTK, 
  "gtk_clist_column_titles_hide", {C_POINTER} )

global procedure gtk_clist_column_titles_hide(atom clist_)
    c_proc( gtk_clist_column_titles_hide_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_column_title_active
----------------------------------------
constant gtk_clist_column_title_active_ = link_c_proc( GTK, 
  "gtk_clist_column_title_active", {C_POINTER,C_INT} )

global procedure gtk_clist_column_title_active(atom clist_, integer column_)
    c_proc( gtk_clist_column_title_active_, {clist_,column_} )
end procedure

----------------------------------------
-- gtk_clist_column_title_passive
----------------------------------------
constant gtk_clist_column_title_passive_ = link_c_proc( GTK, 
  "gtk_clist_column_title_passive", {C_POINTER,C_INT} )

global procedure gtk_clist_column_title_passive(atom clist_, integer column_)
    c_proc( gtk_clist_column_title_passive_, {clist_,column_} )
end procedure

----------------------------------------
-- gtk_clist_column_titles_active
----------------------------------------
constant gtk_clist_column_titles_active_ = link_c_proc( GTK, 
  "gtk_clist_column_titles_active", {C_POINTER} )

global procedure gtk_clist_column_titles_active(atom clist_)
    c_proc( gtk_clist_column_titles_active_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_column_titles_passive
----------------------------------------
constant gtk_clist_column_titles_passive_ = link_c_proc( GTK, 
  "gtk_clist_column_titles_passive", {C_POINTER} )

global procedure gtk_clist_column_titles_passive(atom clist_)
    c_proc( gtk_clist_column_titles_passive_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_set_column_title
----------------------------------------
constant gtk_clist_set_column_title_ = link_c_proc( GTK, 
  "gtk_clist_set_column_title", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_set_column_title(atom clist_, integer column_, sequence title_)
    atom string1
    string1 = allocate_string( title_ )
    c_proc( gtk_clist_set_column_title_, {clist_,column_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_clist_set_column_widget
----------------------------------------
constant gtk_clist_set_column_widget_ = link_c_proc( GTK, 
  "gtk_clist_set_column_widget", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_set_column_widget(atom clist_, integer column_, atom widget_)
    c_proc( gtk_clist_set_column_widget_, {clist_,column_,widget_} )
end procedure

----------------------------------------
-- gtk_clist_set_column_justification
----------------------------------------
constant gtk_clist_set_column_justification_ = link_c_proc( GTK, 
  "gtk_clist_set_column_justification", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_set_column_justification(atom clist_, integer column_, atom justification_)
    c_proc( gtk_clist_set_column_justification_, {clist_,column_,justification_} )
end procedure

----------------------------------------
-- gtk_clist_set_column_visibility
----------------------------------------
constant gtk_clist_set_column_visibility_ = link_c_proc( GTK, 
  "gtk_clist_set_column_visibility", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_set_column_visibility(atom clist_, integer column_, integer visible_)
    c_proc( gtk_clist_set_column_visibility_, {clist_,column_,visible_} )
end procedure

----------------------------------------
-- gtk_clist_set_column_resizeable
----------------------------------------
constant gtk_clist_set_column_resizeable_ = link_c_proc( GTK, 
  "gtk_clist_set_column_resizeable", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_set_column_resizeable(atom clist_, integer column_, integer resizeable_)
    c_proc( gtk_clist_set_column_resizeable_, {clist_,column_,resizeable_} )
end procedure

----------------------------------------
-- gtk_clist_set_column_auto_resize
----------------------------------------
constant gtk_clist_set_column_auto_resize_ = link_c_proc( GTK, 
  "gtk_clist_set_column_auto_resize", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_set_column_auto_resize(atom clist_, integer column_, integer auto_resize_)
    c_proc( gtk_clist_set_column_auto_resize_, {clist_,column_,auto_resize_} )
end procedure

----------------------------------------
-- gtk_clist_columns_autosize
----------------------------------------
constant gtk_clist_columns_autosize_ = link_c_func( GTK, 
  "gtk_clist_columns_autosize", {C_POINTER}, C_INT )

global function gtk_clist_columns_autosize(atom clist_)
    return c_func( gtk_clist_columns_autosize_, {clist_} )
end function

----------------------------------------
-- gtk_clist_optimal_column_width
----------------------------------------
constant gtk_clist_optimal_column_width_ = link_c_func( GTK, 
  "gtk_clist_optimal_column_width", {C_POINTER,C_INT}, C_INT )

global function gtk_clist_optimal_column_width(atom clist_, integer column_)
    return c_func( gtk_clist_optimal_column_width_, {clist_,column_} )
end function

----------------------------------------
-- gtk_clist_set_column_width
----------------------------------------
constant gtk_clist_set_column_width_ = link_c_proc( GTK, 
  "gtk_clist_set_column_width", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_set_column_width(atom clist_, integer column_, integer width_)
    c_proc( gtk_clist_set_column_width_, {clist_,column_,width_} )
end procedure

----------------------------------------
-- gtk_clist_set_column_min_width
----------------------------------------
constant gtk_clist_set_column_min_width_ = link_c_proc( GTK, 
  "gtk_clist_set_column_min_width", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_set_column_min_width(atom clist_, integer column_, integer min_width_)
    c_proc( gtk_clist_set_column_min_width_, {clist_,column_,min_width_} )
end procedure

----------------------------------------
-- gtk_clist_set_column_max_width
----------------------------------------
constant gtk_clist_set_column_max_width_ = link_c_proc( GTK, 
  "gtk_clist_set_column_max_width", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_set_column_max_width(atom clist_, integer column_, integer max_width_)
    c_proc( gtk_clist_set_column_max_width_, {clist_,column_,max_width_} )
end procedure

----------------------------------------
-- gtk_clist_set_row_height
----------------------------------------
constant gtk_clist_set_row_height_ = link_c_proc( GTK, 
  "gtk_clist_set_row_height", {C_POINTER,C_UINT} )

global procedure gtk_clist_set_row_height(atom clist_, integer height_)
    c_proc( gtk_clist_set_row_height_, {clist_,height_} )
end procedure

----------------------------------------
-- gtk_clist_moveto
----------------------------------------
constant gtk_clist_moveto_ = link_c_proc( GTK, 
  "gtk_clist_moveto", {C_POINTER,C_INT,C_INT,C_LONG,C_LONG} )

global procedure gtk_clist_moveto(atom clist_, integer row_, integer column_, integer row_align_, integer col_align_)
    c_proc( gtk_clist_moveto_, {clist_,row_,column_,row_align_,col_align_} )
end procedure

----------------------------------------
-- gtk_clist_row_is_visible
----------------------------------------
constant gtk_clist_row_is_visible_ = link_c_func( GTK, 
  "gtk_clist_row_is_visible", {C_POINTER,C_INT}, C_POINTER )

global function gtk_clist_row_is_visible(atom clist_, integer row_)
    return c_func( gtk_clist_row_is_visible_, {clist_,row_} )
end function

----------------------------------------
-- gtk_clist_get_cell_type
----------------------------------------
constant gtk_clist_get_cell_type_ = link_c_func( GTK, 
  "gtk_clist_get_cell_type", {C_POINTER,C_INT,C_INT}, C_POINTER )

global function gtk_clist_get_cell_type(atom clist_, integer row_, integer column_)
    return c_func( gtk_clist_get_cell_type_, {clist_,row_,column_} )
end function

----------------------------------------
-- gtk_clist_set_text
----------------------------------------
constant gtk_clist_set_text_ = link_c_proc( GTK, 
  "gtk_clist_set_text", {C_POINTER,C_INT,C_INT,C_POINTER} )

global procedure gtk_clist_set_text(atom clist_, integer row_, integer column_, sequence text_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_clist_set_text_, {clist_,row_,column_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_clist_get_text
----------------------------------------
constant gtk_clist_get_text_ = link_c_func( GTK, 
  "gtk_clist_get_text", {C_POINTER,C_INT,C_INT,C_POINTER}, C_INT )

global function gtk_clist_get_text(atom clist_, integer row_, integer column_, sequence text_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gtk_clist_get_text_, {clist_,row_,column_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_clist_set_pixmap
----------------------------------------
constant gtk_clist_set_pixmap_ = link_c_proc( GTK, 
  "gtk_clist_set_pixmap", {C_POINTER,C_INT,C_INT,C_POINTER,C_POINTER} )

global procedure gtk_clist_set_pixmap(atom clist_, integer row_, integer column_, atom pixmap_, atom mask_)
    c_proc( gtk_clist_set_pixmap_, {clist_,row_,column_,pixmap_,mask_} )
end procedure

----------------------------------------
-- gtk_clist_get_pixmap
----------------------------------------
constant gtk_clist_get_pixmap_ = link_c_func( GTK, 
  "gtk_clist_get_pixmap", {C_POINTER,C_INT,C_INT,C_POINTER,C_POINTER}, C_INT )

global function gtk_clist_get_pixmap(atom clist_, integer row_, integer column_, atom pixmap_, atom mask_)
    return c_func( gtk_clist_get_pixmap_, {clist_,row_,column_,pixmap_,mask_} )
end function

----------------------------------------
-- gtk_clist_set_pixtext
----------------------------------------
constant gtk_clist_set_pixtext_ = link_c_proc( GTK, 
  "gtk_clist_set_pixtext", {C_POINTER,C_INT,C_INT,C_POINTER,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_clist_set_pixtext(atom clist_, integer row_, integer column_, sequence text_, integer spacing_, atom pixmap_, atom mask_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_clist_set_pixtext_, {clist_,row_,column_,string1,spacing_,pixmap_,mask_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_clist_get_pixtext
----------------------------------------
constant gtk_clist_get_pixtext_ = link_c_func( GTK, 
  "gtk_clist_get_pixtext", {C_POINTER,C_INT,C_INT,C_POINTER,C_UINT,C_POINTER,C_POINTER}, 
 C_INT )

global function gtk_clist_get_pixtext(atom clist_, integer row_, integer column_, sequence text_, integer spacing_, atom pixmap_, atom mask_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gtk_clist_get_pixtext_, {clist_,row_,column_,string1,spacing_,pixmap_,mask_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_clist_set_foreground
----------------------------------------
constant gtk_clist_set_foreground_ = link_c_proc( GTK, 
  "gtk_clist_set_foreground", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_set_foreground(atom clist_, integer row_, atom color_)
    c_proc( gtk_clist_set_foreground_, {clist_,row_,color_} )
end procedure

----------------------------------------
-- gtk_clist_set_background
----------------------------------------
constant gtk_clist_set_background_ = link_c_proc( GTK, 
  "gtk_clist_set_background", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_set_background(atom clist_, integer row_, atom color_)
    c_proc( gtk_clist_set_background_, {clist_,row_,color_} )
end procedure

----------------------------------------
-- gtk_clist_set_cell_style
----------------------------------------
constant gtk_clist_set_cell_style_ = link_c_proc( GTK, 
  "gtk_clist_set_cell_style", {C_POINTER,C_INT,C_INT,C_POINTER} )

global procedure gtk_clist_set_cell_style(atom clist_, integer row_, integer column_, atom style_)
    c_proc( gtk_clist_set_cell_style_, {clist_,row_,column_,style_} )
end procedure

----------------------------------------
-- gtk_clist_get_cell_style
----------------------------------------
constant gtk_clist_get_cell_style_ = link_c_func( GTK, 
  "gtk_clist_get_cell_style", {C_POINTER,C_INT,C_INT}, C_POINTER )

global function gtk_clist_get_cell_style(atom clist_, integer row_, integer column_)
    return c_func( gtk_clist_get_cell_style_, {clist_,row_,column_} )
end function

----------------------------------------
-- gtk_clist_set_row_style
----------------------------------------
constant gtk_clist_set_row_style_ = link_c_proc( GTK, 
  "gtk_clist_set_row_style", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_set_row_style(atom clist_, integer row_, atom style_)
    c_proc( gtk_clist_set_row_style_, {clist_,row_,style_} )
end procedure

----------------------------------------
-- gtk_clist_get_row_style
----------------------------------------
constant gtk_clist_get_row_style_ = link_c_func( GTK, 
  "gtk_clist_get_row_style", {C_POINTER,C_INT}, C_POINTER )

global function gtk_clist_get_row_style(atom clist_, integer row_)
    return c_func( gtk_clist_get_row_style_, {clist_,row_} )
end function

----------------------------------------
-- gtk_clist_set_shift
----------------------------------------
constant gtk_clist_set_shift_ = link_c_proc( GTK, 
  "gtk_clist_set_shift", {C_POINTER,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_clist_set_shift(atom clist_, integer row_, integer column_, integer vertical_, integer horizontal_)
    c_proc( gtk_clist_set_shift_, {clist_,row_,column_,vertical_,horizontal_} )
end procedure

----------------------------------------
-- gtk_clist_set_selectable
----------------------------------------
constant gtk_clist_set_selectable_ = link_c_proc( GTK, 
  "gtk_clist_set_selectable", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_set_selectable(atom clist_, integer row_, integer selectable_)
    c_proc( gtk_clist_set_selectable_, {clist_,row_,selectable_} )
end procedure

----------------------------------------
-- gtk_clist_get_selectable
----------------------------------------
constant gtk_clist_get_selectable_ = link_c_func( GTK, 
  "gtk_clist_get_selectable", {C_POINTER,C_INT}, C_INT )

global function gtk_clist_get_selectable(atom clist_, integer row_)
    return c_func( gtk_clist_get_selectable_, {clist_,row_} )
end function

----------------------------------------
-- gtk_clist_prepend
----------------------------------------
constant gtk_clist_prepend_ = link_c_func( GTK, 
  "gtk_clist_prepend", {C_POINTER,C_POINTER}, C_INT )

global function gtk_clist_prepend(atom clist_, sequence text_)
    integer result
    atom strArray1
    strArray1 = allot_string_array( text_ )
    result = c_func( gtk_clist_prepend_, {clist_,strArray1} )
    free_string_array( strArray1 )
    return result
end function

----------------------------------------
-- gtk_clist_append
----------------------------------------
constant gtk_clist_append_ = link_c_func( GTK, 
  "gtk_clist_append", {C_POINTER,C_POINTER}, C_INT )

global function gtk_clist_append(atom clist_, sequence text_)
    integer result
    atom strArray1
    strArray1 = allot_string_array( text_ )
    result = c_func( gtk_clist_append_, {clist_,strArray1} )
    free_string_array( strArray1 )
    return result
end function

----------------------------------------
-- gtk_clist_insert
----------------------------------------
constant gtk_clist_insert_ = link_c_func( GTK, 
  "gtk_clist_insert", {C_POINTER,C_INT,C_POINTER}, C_INT )

global function gtk_clist_insert(atom clist_, integer row_, sequence text_)
    integer result
    atom strArray1
    strArray1 = allot_string_array( text_ )
    result = c_func( gtk_clist_insert_, {clist_,row_,strArray1} )
    free_string_array( strArray1 )
    return result
end function

----------------------------------------
-- gtk_clist_remove
----------------------------------------
constant gtk_clist_remove_ = link_c_proc( GTK, 
  "gtk_clist_remove", {C_POINTER,C_INT} )

global procedure gtk_clist_remove(atom clist_, integer row_)
    c_proc( gtk_clist_remove_, {clist_,row_} )
end procedure

----------------------------------------
-- gtk_clist_set_row_data
----------------------------------------
constant gtk_clist_set_row_data_ = link_c_proc( GTK, 
  "gtk_clist_set_row_data", {C_POINTER,C_INT,C_POINTER} )

global procedure gtk_clist_set_row_data(atom clist_, integer row_, atom data_)
    c_proc( gtk_clist_set_row_data_, {clist_,row_,data_} )
end procedure

----------------------------------------
-- gtk_clist_set_row_data_full
----------------------------------------
constant gtk_clist_set_row_data_full_ = link_c_proc( GTK, 
  "gtk_clist_set_row_data_full", {C_POINTER,C_INT,C_POINTER,C_POINTER} )

global procedure gtk_clist_set_row_data_full(atom clist_, integer row_, atom data_, atom destroy_)
    c_proc( gtk_clist_set_row_data_full_, {clist_,row_,data_,destroy_} )
end procedure

----------------------------------------
-- gtk_clist_get_row_data
----------------------------------------
constant gtk_clist_get_row_data_ = link_c_func( GTK, 
  "gtk_clist_get_row_data", {C_POINTER,C_INT}, C_POINTER )

global function gtk_clist_get_row_data(atom clist_, integer row_)
    return c_func( gtk_clist_get_row_data_, {clist_,row_} )
end function

----------------------------------------
-- gtk_clist_find_row_from_data
----------------------------------------
constant gtk_clist_find_row_from_data_ = link_c_func( GTK, 
  "gtk_clist_find_row_from_data", {C_POINTER,C_POINTER}, C_INT )

global function gtk_clist_find_row_from_data(atom clist_, atom data_)
    return c_func( gtk_clist_find_row_from_data_, {clist_,data_} )
end function

----------------------------------------
-- gtk_clist_select_row
----------------------------------------
constant gtk_clist_select_row_ = link_c_proc( GTK, 
  "gtk_clist_select_row", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_select_row(atom clist_, integer row_, integer column_)
    c_proc( gtk_clist_select_row_, {clist_,row_,column_} )
end procedure

----------------------------------------
-- gtk_clist_unselect_row
----------------------------------------
constant gtk_clist_unselect_row_ = link_c_proc( GTK, 
  "gtk_clist_unselect_row", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_unselect_row(atom clist_, integer row_, integer column_)
    c_proc( gtk_clist_unselect_row_, {clist_,row_,column_} )
end procedure

----------------------------------------
-- gtk_clist_undo_selection
----------------------------------------
constant gtk_clist_undo_selection_ = link_c_proc( GTK, 
  "gtk_clist_undo_selection", {C_POINTER} )

global procedure gtk_clist_undo_selection(atom clist_)
    c_proc( gtk_clist_undo_selection_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_clear
----------------------------------------
constant gtk_clist_clear_ = link_c_proc( GTK, 
  "gtk_clist_clear", {C_POINTER} )

global procedure gtk_clist_clear(atom clist_)
    c_proc( gtk_clist_clear_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_get_selection_info
----------------------------------------
constant gtk_clist_get_selection_info_ = link_c_func( GTK, 
  "gtk_clist_get_selection_info", {C_POINTER,C_INT,C_INT,C_INT,C_INT}, C_INT )

global function gtk_clist_get_selection_info(atom clist_, integer x_, integer y_, integer row_, integer column_)
    return c_func( gtk_clist_get_selection_info_, {clist_,x_,y_,row_,column_} )
end function

----------------------------------------
-- gtk_clist_select_all
----------------------------------------
constant gtk_clist_select_all_ = link_c_proc( GTK, 
  "gtk_clist_select_all", {C_POINTER} )

global procedure gtk_clist_select_all(atom clist_)
    c_proc( gtk_clist_select_all_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_unselect_all
----------------------------------------
constant gtk_clist_unselect_all_ = link_c_proc( GTK, 
  "gtk_clist_unselect_all", {C_POINTER} )

global procedure gtk_clist_unselect_all(atom clist_)
    c_proc( gtk_clist_unselect_all_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_swap_rows
----------------------------------------
constant gtk_clist_swap_rows_ = link_c_proc( GTK, 
  "gtk_clist_swap_rows", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_swap_rows(atom clist_, integer row1_, integer row2_)
    c_proc( gtk_clist_swap_rows_, {clist_,row1_,row2_} )
end procedure

----------------------------------------
-- gtk_clist_row_move
----------------------------------------
constant gtk_clist_row_move_ = link_c_proc( GTK, 
  "gtk_clist_row_move", {C_POINTER,C_INT,C_INT} )

global procedure gtk_clist_row_move(atom clist_, integer source_row_, integer dest_row_)
    c_proc( gtk_clist_row_move_, {clist_,source_row_,dest_row_} )
end procedure

----------------------------------------
-- gtk_clist_set_compare_func
----------------------------------------
constant gtk_clist_set_compare_func_ = link_c_proc( GTK, 
  "gtk_clist_set_compare_func", {C_POINTER,C_POINTER} )

global procedure gtk_clist_set_compare_func(atom clist_, atom cmp_func_)
    c_proc( gtk_clist_set_compare_func_, {clist_,cmp_func_} )
end procedure

----------------------------------------
-- gtk_clist_set_sort_column
----------------------------------------
constant gtk_clist_set_sort_column_ = link_c_proc( GTK, 
  "gtk_clist_set_sort_column", {C_POINTER,C_INT} )

global procedure gtk_clist_set_sort_column(atom clist_, integer column_)
    c_proc( gtk_clist_set_sort_column_, {clist_,column_} )
end procedure

----------------------------------------
-- gtk_clist_set_sort_type
----------------------------------------
constant gtk_clist_set_sort_type_ = link_c_proc( GTK, 
  "gtk_clist_set_sort_type", {C_POINTER,C_POINTER} )

global procedure gtk_clist_set_sort_type(atom clist_, atom sort_type_)
    c_proc( gtk_clist_set_sort_type_, {clist_,sort_type_} )
end procedure

----------------------------------------
-- gtk_clist_sort
----------------------------------------
constant gtk_clist_sort_ = link_c_proc( GTK, 
  "gtk_clist_sort", {C_POINTER} )

global procedure gtk_clist_sort(atom clist_)
    c_proc( gtk_clist_sort_, {clist_} )
end procedure

----------------------------------------
-- gtk_clist_set_auto_sort
----------------------------------------
constant gtk_clist_set_auto_sort_ = link_c_proc( GTK, 
  "gtk_clist_set_auto_sort", {C_POINTER,C_INT} )

global procedure gtk_clist_set_auto_sort(atom clist_, integer auto_sort_)
    c_proc( gtk_clist_set_auto_sort_, {clist_,auto_sort_} )
end procedure


----------------------------------------
----------------------------------------
-- GTKRANGE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkRange
----------------------------------------
global constant
    GtkRange_widget                     = allot(SIZEOF_GtkWidget),
    GtkRange_trough                     = allot(TYPE_POINTER),
    GtkRange_slider                     = allot(TYPE_POINTER),
    GtkRange_step_forw                  = allot(TYPE_POINTER),
    GtkRange_step_back                  = allot(TYPE_POINTER),
    GtkRange_x_click_point              = allot(TYPE_GINT16),
    GtkRange_y_click_point              = allot(TYPE_GINT16),
    GtkRange_button                     = allot(TYPE_GUINT8),
    GtkRange_digits                     = allot(TYPE_GINT8),
    GtkRange_policy                     = allot(TYPE_GUINT),
    GtkRange_scroll_type                = allot(TYPE_GUINT),
    GtkRange_in_child                   = allot(TYPE_GUINT),
    GtkRange_click_child                = allot(TYPE_GUINT),
    GtkRange_need_timer                 = allot(TYPE_GUINT),
    GtkRange_timer                      = allot(TYPE_GUINT32),
    GtkRange_old_value                  = allot(TYPE_GFLOAT),
    GtkRange_old_lower                  = allot(TYPE_GFLOAT),
    GtkRange_old_upper                  = allot(TYPE_GFLOAT),
    GtkRange_old_page_size              = allot(TYPE_GFLOAT),
    GtkRange_adjustment                 = allot(TYPE_POINTER),
    SIZEOF_GtkRange                     = allotted_size()

----------------------------------------
-- GtkRangeClass
----------------------------------------
global constant
    GtkRangeClass_parent_class          = allot(SIZEOF_GtkWidgetClass),
    GtkRangeClass_slider_width          = allot(TYPE_GINT),
    GtkRangeClass_stepper_size          = allot(TYPE_GINT),
    GtkRangeClass_stepper_slider_spacing= allot(TYPE_GINT),
    GtkRangeClass_min_slider_size       = allot(TYPE_GINT),
    GtkRangeClass_trough                = allot(TYPE_GUINT8),
    GtkRangeClass_slider                = allot(TYPE_GUINT8),
    GtkRangeClass_step_forw             = allot(TYPE_GUINT8),
    GtkRangeClass_step_back             = allot(TYPE_GUINT8),
    GtkRangeClass_draw_background       = allot(TYPE_GPOINTER),
    GtkRangeClass_clear_background      = allot(TYPE_GPOINTER),
    GtkRangeClass_draw_trough           = allot(TYPE_GPOINTER),
    GtkRangeClass_draw_slider           = allot(TYPE_GPOINTER),
    GtkRangeClass_draw_step_forw        = allot(TYPE_GPOINTER),
    GtkRangeClass_draw_step_back        = allot(TYPE_GPOINTER),
    GtkRangeClass_slider_update         = allot(TYPE_GPOINTER),
    GtkRangeClass_trough_click          = allot(TYPE_GPOINTER),
    GtkRangeClass_trough_keys           = allot(TYPE_GPOINTER),
    GtkRangeClass_motion                = allot(TYPE_GPOINTER),
    GtkRangeClass_timer                 = allot(TYPE_GPOINTER),
    SIZEOF_GtkRangeClass                = allotted_size()
----------------------------------------
-- gtk_range_get_type
----------------------------------------
constant gtk_range_get_type_ = link_c_func( GTK, 
  "gtk_range_get_type", {}, C_UINT )

global function gtk_range_get_type()
    return c_func( gtk_range_get_type_, {} )
end function

----------------------------------------
-- gtk_range_get_adjustment
----------------------------------------
constant gtk_range_get_adjustment_ = link_c_func( GTK, 
  "gtk_range_get_adjustment", {C_POINTER}, C_POINTER )

global function gtk_range_get_adjustment(atom range_)
    return c_func( gtk_range_get_adjustment_, {range_} )
end function

----------------------------------------
-- gtk_range_set_update_policy
----------------------------------------
constant gtk_range_set_update_policy_ = link_c_proc( GTK, 
  "gtk_range_set_update_policy", {C_POINTER,C_POINTER} )

global procedure gtk_range_set_update_policy(atom range_, atom policy_)
    c_proc( gtk_range_set_update_policy_, {range_,policy_} )
end procedure

----------------------------------------
-- gtk_range_set_adjustment
----------------------------------------
constant gtk_range_set_adjustment_ = link_c_proc( GTK, 
  "gtk_range_set_adjustment", {C_POINTER,C_POINTER} )

global procedure gtk_range_set_adjustment(atom range_, atom adjustment_)
    c_proc( gtk_range_set_adjustment_, {range_,adjustment_} )
end procedure

----------------------------------------
-- gtk_range_draw_background
----------------------------------------
constant gtk_range_draw_background_ = link_c_proc( GTK, 
  "gtk_range_draw_background", {C_POINTER} )

global procedure gtk_range_draw_background(atom range_)
    c_proc( gtk_range_draw_background_, {range_} )
end procedure

----------------------------------------
-- gtk_range_clear_background
----------------------------------------
constant gtk_range_clear_background_ = link_c_proc( GTK, 
  "gtk_range_clear_background", {C_POINTER} )

global procedure gtk_range_clear_background(atom range_)
    c_proc( gtk_range_clear_background_, {range_} )
end procedure

----------------------------------------
-- gtk_range_draw_trough
----------------------------------------
constant gtk_range_draw_trough_ = link_c_proc( GTK, 
  "gtk_range_draw_trough", {C_POINTER} )

global procedure gtk_range_draw_trough(atom range_)
    c_proc( gtk_range_draw_trough_, {range_} )
end procedure

----------------------------------------
-- gtk_range_draw_slider
----------------------------------------
constant gtk_range_draw_slider_ = link_c_proc( GTK, 
  "gtk_range_draw_slider", {C_POINTER} )

global procedure gtk_range_draw_slider(atom range_)
    c_proc( gtk_range_draw_slider_, {range_} )
end procedure

----------------------------------------
-- gtk_range_draw_step_forw
----------------------------------------
constant gtk_range_draw_step_forw_ = link_c_proc( GTK, 
  "gtk_range_draw_step_forw", {C_POINTER} )

global procedure gtk_range_draw_step_forw(atom range_)
    c_proc( gtk_range_draw_step_forw_, {range_} )
end procedure

----------------------------------------
-- gtk_range_draw_step_back
----------------------------------------
constant gtk_range_draw_step_back_ = link_c_proc( GTK, 
  "gtk_range_draw_step_back", {C_POINTER} )

global procedure gtk_range_draw_step_back(atom range_)
    c_proc( gtk_range_draw_step_back_, {range_} )
end procedure

----------------------------------------
-- gtk_range_slider_update
----------------------------------------
constant gtk_range_slider_update_ = link_c_proc( GTK, 
  "gtk_range_slider_update", {C_POINTER} )

global procedure gtk_range_slider_update(atom range_)
    c_proc( gtk_range_slider_update_, {range_} )
end procedure

----------------------------------------
-- gtk_range_trough_click
----------------------------------------
constant gtk_range_trough_click_ = link_c_func( GTK, 
  "gtk_range_trough_click", {C_POINTER,C_INT,C_INT,C_LONG}, C_INT )

global function gtk_range_trough_click(atom range_, integer x_, integer y_, integer jump_perc_)
    return c_func( gtk_range_trough_click_, {range_,x_,y_,jump_perc_} )
end function

----------------------------------------
-- gtk_range_default_hslider_update
----------------------------------------
constant gtk_range_default_hslider_update_ = link_c_proc( GTK, 
  "gtk_range_default_hslider_update", {C_POINTER} )

global procedure gtk_range_default_hslider_update(atom range_)
    c_proc( gtk_range_default_hslider_update_, {range_} )
end procedure

----------------------------------------
-- gtk_range_default_vslider_update
----------------------------------------
constant gtk_range_default_vslider_update_ = link_c_proc( GTK, 
  "gtk_range_default_vslider_update", {C_POINTER} )

global procedure gtk_range_default_vslider_update(atom range_)
    c_proc( gtk_range_default_vslider_update_, {range_} )
end procedure

----------------------------------------
-- gtk_range_default_htrough_click
----------------------------------------
constant gtk_range_default_htrough_click_ = link_c_func( GTK, 
  "gtk_range_default_htrough_click", {C_POINTER,C_INT,C_INT,C_LONG}, C_INT )

global function gtk_range_default_htrough_click(atom range_, integer x_, integer y_, integer jump_perc_)
    return c_func( gtk_range_default_htrough_click_, {range_,x_,y_,jump_perc_} )
end function

----------------------------------------
-- gtk_range_default_vtrough_click
----------------------------------------
constant gtk_range_default_vtrough_click_ = link_c_func( GTK, 
  "gtk_range_default_vtrough_click", {C_POINTER,C_INT,C_INT,C_LONG}, C_INT )

global function gtk_range_default_vtrough_click(atom range_, integer x_, integer y_, integer jump_perc_)
    return c_func( gtk_range_default_vtrough_click_, {range_,x_,y_,jump_perc_} )
end function

----------------------------------------
-- gtk_range_default_hmotion
----------------------------------------
constant gtk_range_default_hmotion_ = link_c_proc( GTK, 
  "gtk_range_default_hmotion", {C_POINTER,C_INT,C_INT} )

global procedure gtk_range_default_hmotion(atom range_, integer xdelta_, integer ydelta_)
    c_proc( gtk_range_default_hmotion_, {range_,xdelta_,ydelta_} )
end procedure

----------------------------------------
-- gtk_range_default_vmotion
----------------------------------------
constant gtk_range_default_vmotion_ = link_c_proc( GTK, 
  "gtk_range_default_vmotion", {C_POINTER,C_INT,C_INT} )

global procedure gtk_range_default_vmotion(atom range_, integer xdelta_, integer ydelta_)
    c_proc( gtk_range_default_vmotion_, {range_,xdelta_,ydelta_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKSCROLLBAR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkScrollbar
----------------------------------------
global constant
    GtkScrollbar_range                  = allot(SIZEOF_GtkRange),
    SIZEOF_GtkScrollbar                 = allotted_size()

----------------------------------------
-- GtkScrollbarClass
----------------------------------------
global constant
    GtkScrollbarClass_parent_class      = allot(SIZEOF_GtkRangeClass),
    SIZEOF_GtkScrollbarClass            = allotted_size()
----------------------------------------
-- gtk_scrollbar_get_type
----------------------------------------
constant gtk_scrollbar_get_type_ = link_c_func( GTK, 
  "gtk_scrollbar_get_type", {}, C_UINT )

global function gtk_scrollbar_get_type()
    return c_func( gtk_scrollbar_get_type_, {} )
end function






----------------------------------------
----------------------------------------
-- GTKHSCROLLBAR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHScrollbar
----------------------------------------
global constant
    GtkHScrollbar_scrollbar             = allot(SIZEOF_GtkScrollbar),
    SIZEOF_GtkHScrollbar                = allotted_size()

----------------------------------------
-- GtkHScrollbarClass
----------------------------------------
global constant
    GtkHScrollbarClass_parent_class     = allot(SIZEOF_GtkScrollbarClass),
    SIZEOF_GtkHScrollbarClass           = allotted_size()
----------------------------------------
-- gtk_hscrollbar_get_type
----------------------------------------
constant gtk_hscrollbar_get_type_ = link_c_func( GTK, 
  "gtk_hscrollbar_get_type", {}, C_UINT )

global function gtk_hscrollbar_get_type()
    return c_func( gtk_hscrollbar_get_type_, {} )
end function

----------------------------------------
-- gtk_hscrollbar_new
----------------------------------------
constant gtk_hscrollbar_new_ = link_c_func( GTK, 
  "gtk_hscrollbar_new", {C_POINTER}, C_POINTER )

global function gtk_hscrollbar_new(atom adjustment_)
    return c_func( gtk_hscrollbar_new_, {adjustment_} )
end function



----------------------------------------
----------------------------------------
-- GTKVSCROLLBAR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkVScrollbar
----------------------------------------
global constant
    GtkVScrollbar_scrollbar             = allot(SIZEOF_GtkScrollbar),
    SIZEOF_GtkVScrollbar                = allotted_size()

----------------------------------------
-- GtkVScrollbarClass
----------------------------------------
global constant
    GtkVScrollbarClass_parent_class     = allot(SIZEOF_GtkScrollbarClass),
    SIZEOF_GtkVScrollbarClass           = allotted_size()
----------------------------------------
-- gtk_vscrollbar_get_type
----------------------------------------
constant gtk_vscrollbar_get_type_ = link_c_func( GTK, 
  "gtk_vscrollbar_get_type", {}, C_UINT )

global function gtk_vscrollbar_get_type()
    return c_func( gtk_vscrollbar_get_type_, {} )
end function

----------------------------------------
-- gtk_vscrollbar_new
----------------------------------------
constant gtk_vscrollbar_new_ = link_c_func( GTK, 
  "gtk_vscrollbar_new", {C_POINTER}, C_POINTER )

global function gtk_vscrollbar_new(atom adjustment_)
    return c_func( gtk_vscrollbar_new_, {adjustment_} )
end function

----------------------------------------
----------------------------------------
-- GTKVBOX.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkVBox
----------------------------------------
global constant
    GtkVBox_box                         = allot(SIZEOF_GtkBox),
    SIZEOF_GtkVBox                      = allotted_size()

----------------------------------------
-- GtkVBoxClass
----------------------------------------
global constant
    GtkVBoxClass_parent_class           = allot(SIZEOF_GtkBoxClass),
    SIZEOF_GtkVBoxClass                 = allotted_size()
----------------------------------------
-- gtk_vbox_get_type
----------------------------------------
constant gtk_vbox_get_type_ = link_c_func( GTK, 
  "gtk_vbox_get_type", {}, C_UINT )

global function gtk_vbox_get_type()
    return c_func( gtk_vbox_get_type_, {} )
end function

----------------------------------------
-- gtk_vbox_new
----------------------------------------
constant gtk_vbox_new_ = link_c_func( GTK, 
  "gtk_vbox_new", {C_INT,C_INT}, C_POINTER )

global function gtk_vbox_new(integer homogeneous_, integer spacing_)
    return c_func( gtk_vbox_new_, {homogeneous_,spacing_} )
end function


----------------------------------------
----------------------------------------
-- GTKWINDOW.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkWindow
----------------------------------------
global constant
    GtkWindow_bin                       = allot(SIZEOF_GtkBin),
    GtkWindow_title                     = allot(TYPE_POINTER),
    GtkWindow_wmclass_name              = allot(TYPE_POINTER),
    GtkWindow_wmclass_class             = allot(TYPE_POINTER),
    GtkWindow_type                      = allot(SIZEOF_GtkWindowType),
    GtkWindow_focus_widget              = allot(TYPE_POINTER),
    GtkWindow_default_widget            = allot(TYPE_POINTER),
    GtkWindow_transient_parent          = allot(TYPE_POINTER),
    GtkWindow_resize_count              = allot(TYPE_GUSHORT),
    GtkWindow_allow_shrink              = allot(TYPE_GUINT),
    GtkWindow_allow_grow                = allot(TYPE_GUINT),
    GtkWindow_auto_shrink               = allot(TYPE_GUINT),
    GtkWindow_handling_resize           = allot(TYPE_GUINT),
    GtkWindow_position                  = allot(TYPE_GUINT),
    GtkWindow_use_uposition             = allot(TYPE_GUINT),
    GtkWindow_modal                     = allot(TYPE_GUINT),
    SIZEOF_GtkWindow                    = allotted_size()

----------------------------------------
-- GtkWindowClass
----------------------------------------
global constant
    GtkWindowClass_parent_class         = allot(SIZEOF_GtkBinClass),
    GtkWindowClass_set_focus            = allot(TYPE_GPOINTER),
    SIZEOF_GtkWindowClass               = allotted_size()
----------------------------------------
-- gtk_window_get_type
----------------------------------------
constant gtk_window_get_type_ = link_c_func( GTK, 
  "gtk_window_get_type", {}, C_UINT )

global function gtk_window_get_type()
    return c_func( gtk_window_get_type_, {} )
end function

----------------------------------------
-- gtk_window_new
----------------------------------------
constant gtk_window_new_ = link_c_func( GTK, 
  "gtk_window_new", {C_POINTER}, C_POINTER )

global function gtk_window_new(atom type_)
    return c_func( gtk_window_new_, {type_} )
end function

----------------------------------------
-- gtk_window_set_title
----------------------------------------
constant gtk_window_set_title_ = link_c_proc( GTK, 
  "gtk_window_set_title", {C_POINTER,C_POINTER} )

global procedure gtk_window_set_title(atom window_, sequence title_)
    atom string1
    string1 = allocate_string( title_ )
    c_proc( gtk_window_set_title_, {window_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_window_set_wmclass
----------------------------------------
constant gtk_window_set_wmclass_ = link_c_proc( GTK, 
  "gtk_window_set_wmclass", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_window_set_wmclass(atom window_, sequence wmclass_name_, sequence wmclass_class_)
    atom string1, string2
    string1 = allocate_string( wmclass_name_ )
    string2 = allocate_string( wmclass_class_ )
    c_proc( gtk_window_set_wmclass_, {window_,string1,string2} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- gtk_window_set_policy
----------------------------------------
constant gtk_window_set_policy_ = link_c_proc( GTK, 
  "gtk_window_set_policy", {C_POINTER,C_INT,C_INT,C_INT} )

global procedure gtk_window_set_policy(atom window_, integer allow_shrink_, integer allow_grow_, integer auto_shrink_)
    c_proc( gtk_window_set_policy_, {window_,allow_shrink_,allow_grow_,auto_shrink_} )
end procedure

----------------------------------------
-- gtk_window_add_accel_group
----------------------------------------
constant gtk_window_add_accel_group_ = link_c_proc( GTK, 
  "gtk_window_add_accel_group", {C_POINTER,C_POINTER} )

global procedure gtk_window_add_accel_group(atom window_, atom accel_group_)
    c_proc( gtk_window_add_accel_group_, {window_,accel_group_} )
end procedure

----------------------------------------
-- gtk_window_remove_accel_group
----------------------------------------
constant gtk_window_remove_accel_group_ = link_c_proc( GTK, 
  "gtk_window_remove_accel_group", {C_POINTER,C_POINTER} )

global procedure gtk_window_remove_accel_group(atom window_, atom accel_group_)
    c_proc( gtk_window_remove_accel_group_, {window_,accel_group_} )
end procedure

----------------------------------------
-- gtk_window_set_position
----------------------------------------
constant gtk_window_set_position_ = link_c_proc( GTK, 
  "gtk_window_set_position", {C_POINTER,C_POINTER} )

global procedure gtk_window_set_position(atom window_, atom position_)
    c_proc( gtk_window_set_position_, {window_,position_} )
end procedure

----------------------------------------
-- gtk_window_activate_focus
----------------------------------------
constant gtk_window_activate_focus_ = link_c_func( GTK, 
  "gtk_window_activate_focus", {C_POINTER}, C_INT )

global function gtk_window_activate_focus(atom window_)
    return c_func( gtk_window_activate_focus_, {window_} )
end function

----------------------------------------
-- gtk_window_activate_default
----------------------------------------
constant gtk_window_activate_default_ = link_c_func( GTK, 
  "gtk_window_activate_default", {C_POINTER}, C_INT )

global function gtk_window_activate_default(atom window_)
    return c_func( gtk_window_activate_default_, {window_} )
end function

----------------------------------------
-- gtk_window_set_transient_for
----------------------------------------
constant gtk_window_set_transient_for_ = link_c_proc( GTK, 
  "gtk_window_set_transient_for", {C_POINTER,C_POINTER} )

global procedure gtk_window_set_transient_for(atom window_, atom parent_)
    c_proc( gtk_window_set_transient_for_, {window_,parent_} )
end procedure

----------------------------------------
-- gtk_window_set_geometry_hints
----------------------------------------
constant gtk_window_set_geometry_hints_ = link_c_proc( GTK, 
  "gtk_window_set_geometry_hints", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_window_set_geometry_hints(atom window_, atom geometry_widget_, atom geometry_, atom geom_mask_)
    c_proc( gtk_window_set_geometry_hints_, {window_,geometry_widget_,geometry_,geom_mask_} )
end procedure

----------------------------------------
-- gtk_window_set_default_size
----------------------------------------
constant gtk_window_set_default_size_ = link_c_proc( GTK, 
  "gtk_window_set_default_size", {C_POINTER,C_INT,C_INT} )

global procedure gtk_window_set_default_size(atom window_, integer width_, integer height_)
    c_proc( gtk_window_set_default_size_, {window_,width_,height_} )
end procedure

----------------------------------------
-- gtk_window_set_modal
----------------------------------------
constant gtk_window_set_modal_ = link_c_proc( GTK, 
  "gtk_window_set_modal", {C_POINTER,C_INT} )

global procedure gtk_window_set_modal(atom window_, integer modal_)
    c_proc( gtk_window_set_modal_, {window_,modal_} )
end procedure

----------------------------------------
-- gtk_window_set_focus
----------------------------------------
constant gtk_window_set_focus_ = link_c_proc( GTK, 
  "gtk_window_set_focus", {C_POINTER,C_POINTER} )

global procedure gtk_window_set_focus(atom window_, atom focus_)
    c_proc( gtk_window_set_focus_, {window_,focus_} )
end procedure

----------------------------------------
-- gtk_window_set_default
----------------------------------------
constant gtk_window_set_default_ = link_c_proc( GTK, 
  "gtk_window_set_default", {C_POINTER,C_POINTER} )

global procedure gtk_window_set_default(atom window_, atom defaultw_)
    c_proc( gtk_window_set_default_, {window_,defaultw_} )
end procedure

----------------------------------------
-- gtk_window_remove_embedded_xid
----------------------------------------
constant gtk_window_remove_embedded_xid_ = link_c_proc( GTK, 
  "gtk_window_remove_embedded_xid", {C_POINTER,C_UINT} )

global procedure gtk_window_remove_embedded_xid(atom window_, integer xid_)
    c_proc( gtk_window_remove_embedded_xid_, {window_,xid_} )
end procedure

----------------------------------------
-- gtk_window_add_embedded_xid
----------------------------------------
constant gtk_window_add_embedded_xid_ = link_c_proc( GTK, 
  "gtk_window_add_embedded_xid", {C_POINTER,C_UINT} )

global procedure gtk_window_add_embedded_xid(atom window_, integer xid_)
    c_proc( gtk_window_add_embedded_xid_, {window_,xid_} )
end procedure







----------------------------------------
----------------------------------------
-- GTKCOLORSEL.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkColorSelection
----------------------------------------
-- manually corrected
-- fixed scales[8] and values[8]
-- fixed values[8] and old_values[8]
global constant
    GtkColorSelection_vbox              = allot(SIZEOF_GtkVBox),
    GtkColorSelection_wheel_area        = allot(TYPE_POINTER),
    GtkColorSelection_value_area        = allot(TYPE_POINTER),
    GtkColorSelection_sample_area       = allot(TYPE_POINTER),
    GtkColorSelection_sample_area_eb    = allot(TYPE_POINTER),
    GtkColorSelection_scales            = allot(8*LONG_BYTES),
    GtkColorSelection_entries           = allot(8*LONG_BYTES),
    GtkColorSelection_opacity_label     = allot(TYPE_POINTER),
    GtkColorSelection_wheel_gc          = allot(TYPE_POINTER),
    GtkColorSelection_value_gc          = allot(TYPE_POINTER),
    GtkColorSelection_sample_gc         = allot(TYPE_POINTER),
    GtkColorSelection_policy            = allot(SIZEOF_GtkUpdateType),
    GtkColorSelection_use_opacity       = allot(TYPE_GINT),
    GtkColorSelection_timer_active      = allot(TYPE_GINT),
    GtkColorSelection_timer_tag         = allot(TYPE_GINT),
    GtkColorSelection_values            = allot(8*LONG_BYTES), -- gdouble
    GtkColorSelection_old_values        = allot(8*LONG_BYTES), -- gdouble
    GtkColorSelection_wheel_buf         = allot(TYPE_POINTER),
    GtkColorSelection_value_buf         = allot(TYPE_POINTER),
    GtkColorSelection_sample_buf        = allot(TYPE_POINTER),
    SIZEOF_GtkColorSelection            = allotted_size()

----------------------------------------
-- GtkColorSelectionClass
----------------------------------------
global constant
    GtkColorSelectionClass_parent_class = allot(SIZEOF_GtkVBoxClass),
    GtkColorSelectionClass_color_changed= allot(TYPE_GPOINTER),
    SIZEOF_GtkColorSelectionClass       = allotted_size()

----------------------------------------
-- GtkColorSelectionDialog
----------------------------------------
global constant
    GtkColorSelectionDialog_window      = allot(SIZEOF_GtkWindow),
    GtkColorSelectionDialog_colorsel    = allot(TYPE_POINTER),
    GtkColorSelectionDialog_main_vbox   = allot(TYPE_POINTER),
    GtkColorSelectionDialog_ok_button   = allot(TYPE_POINTER),
    GtkColorSelectionDialog_reset_button= allot(TYPE_POINTER),
    GtkColorSelectionDialog_cancel_button= allot(TYPE_POINTER),
    GtkColorSelectionDialog_help_button = allot(TYPE_POINTER),
    SIZEOF_GtkColorSelectionDialog      = allotted_size()

----------------------------------------
-- GtkColorSelectionDialogClass
----------------------------------------
global constant
    GtkColorSelectionDialogClass_parent_class= allot(SIZEOF_GtkWindowClass),
    SIZEOF_GtkColorSelectionDialogClass = allotted_size()
----------------------------------------
-- gtk_color_selection_get_type
----------------------------------------
constant gtk_color_selection_get_type_ = link_c_func( GTK, 
  "gtk_color_selection_get_type", {}, C_UINT )

global function gtk_color_selection_get_type()
    return c_func( gtk_color_selection_get_type_, {} )
end function

----------------------------------------
-- gtk_color_selection_new
----------------------------------------
constant gtk_color_selection_new_ = link_c_func( GTK, 
  "gtk_color_selection_new", {}, C_POINTER )

global function gtk_color_selection_new()
    return c_func( gtk_color_selection_new_, {} )
end function

----------------------------------------
-- gtk_color_selection_set_update_policy
----------------------------------------
constant gtk_color_selection_set_update_policy_ = link_c_proc( GTK, 
  "gtk_color_selection_set_update_policy", {C_POINTER,C_POINTER} )

global procedure gtk_color_selection_set_update_policy(atom colorsel_, atom policy_)
    c_proc( gtk_color_selection_set_update_policy_, {colorsel_,policy_} )
end procedure

----------------------------------------
-- gtk_color_selection_set_opacity
----------------------------------------
constant gtk_color_selection_set_opacity_ = link_c_proc( GTK, 
  "gtk_color_selection_set_opacity", {C_POINTER,C_INT} )

global procedure gtk_color_selection_set_opacity(atom colorsel_, integer use_opacity_)
    c_proc( gtk_color_selection_set_opacity_, {colorsel_,use_opacity_} )
end procedure

----------------------------------------
-- gtk_color_selection_set_color
----------------------------------------
constant gtk_color_selection_set_color_ = link_c_proc( GTK, 
  "gtk_color_selection_set_color", {C_POINTER,C_LONG} )

global procedure gtk_color_selection_set_color(atom colorsel_, atom color_)
    c_proc( gtk_color_selection_set_color_, {colorsel_,color_} )
end procedure

----------------------------------------
-- gtk_color_selection_get_color
----------------------------------------
constant gtk_color_selection_get_color_ = link_c_proc( GTK, 
  "gtk_color_selection_get_color", {C_POINTER,C_LONG} )

global procedure gtk_color_selection_get_color(atom colorsel_, atom color_)
    c_proc( gtk_color_selection_get_color_, {colorsel_,color_} )
end procedure

----------------------------------------
-- gtk_color_selection_dialog_get_type
----------------------------------------
constant gtk_color_selection_dialog_get_type_ = link_c_func( GTK, 
  "gtk_color_selection_dialog_get_type", {}, C_UINT )

global function gtk_color_selection_dialog_get_type()
    return c_func( gtk_color_selection_dialog_get_type_, {} )
end function

----------------------------------------
-- gtk_color_selection_dialog_new
----------------------------------------
constant gtk_color_selection_dialog_new_ = link_c_func( GTK, 
  "gtk_color_selection_dialog_new", {C_POINTER}, C_POINTER )

global function gtk_color_selection_dialog_new(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_color_selection_dialog_new_, {string1} )
    free( string1 )
    return result
end function



----------------------------------------
----------------------------------------
-- GTKPREVIEW.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkPreview
----------------------------------------
global constant
    GtkPreview_widget                   = allot(SIZEOF_GtkWidget),
    GtkPreview_buffer                   = allot(TYPE_POINTER),
    GtkPreview_buffer_width             = allot(TYPE_GUINT16),
    GtkPreview_buffer_height            = allot(TYPE_GUINT16),
    GtkPreview_bpp                      = allot(TYPE_GUINT16),
    GtkPreview_rowstride                = allot(TYPE_GUINT16),
    GtkPreview_dither                   = allot(SIZEOF_GdkRgbDither),
    GtkPreview_type                     = allot(TYPE_GUINT),
    GtkPreview_expand                   = allot(TYPE_GUINT),
    SIZEOF_GtkPreview                   = allotted_size()

----------------------------------------
-- GtkPreviewInfo
----------------------------------------
global constant
    GtkPreviewInfo_visual               = allot(TYPE_POINTER),
    GtkPreviewInfo_cmap                 = allot(TYPE_POINTER),
    GtkPreviewInfo_lookup               = allot(TYPE_POINTER),
    GtkPreviewInfo_gamma                = allot(TYPE_GDOUBLE),
    SIZEOF_GtkPreviewInfo               = allotted_size()

----------------------------------------
-- GtkPreviewClass
----------------------------------------
global constant
    GtkPreviewClass_parent_class        = allot(SIZEOF_GtkWidgetClass),
    GtkPreviewClass_info                = allot(SIZEOF_GtkPreviewInfo),
    SIZEOF_GtkPreviewClass              = allotted_size()
----------------------------------------
-- gtk_preview_get_type
----------------------------------------
constant gtk_preview_get_type_ = link_c_func( GTK, 
  "gtk_preview_get_type", {}, C_UINT )

global function gtk_preview_get_type()
    return c_func( gtk_preview_get_type_, {} )
end function

----------------------------------------
-- gtk_preview_uninit
----------------------------------------
constant gtk_preview_uninit_ = link_c_proc( GTK, 
  "gtk_preview_uninit", {} )

global procedure gtk_preview_uninit()
    c_proc( gtk_preview_uninit_, {} )
end procedure

----------------------------------------
-- gtk_preview_new
----------------------------------------
constant gtk_preview_new_ = link_c_func( GTK, 
  "gtk_preview_new", {C_POINTER}, C_POINTER )

global function gtk_preview_new(atom type_)
    return c_func( gtk_preview_new_, {type_} )
end function

----------------------------------------
-- gtk_preview_size
----------------------------------------
constant gtk_preview_size_ = link_c_proc( GTK, 
  "gtk_preview_size", {C_POINTER,C_INT,C_INT} )

global procedure gtk_preview_size(atom preview_, integer width_, integer height_)
    c_proc( gtk_preview_size_, {preview_,width_,height_} )
end procedure

----------------------------------------
-- gtk_preview_put
----------------------------------------
constant gtk_preview_put_ = link_c_proc( GTK, 
  "gtk_preview_put", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT,C_INT,C_INT,C_INT,C_INT} )

global procedure gtk_preview_put(atom preview_, atom window_, atom gc_, integer srcx_, integer srcy_, integer 
 destx_, integer desty_, integer width_, integer height_)
    c_proc( gtk_preview_put_, {preview_,window_,gc_,srcx_,srcy_,destx_,desty_,width_,height_} )
end procedure

----------------------------------------
-- gtk_preview_draw_row
----------------------------------------
constant gtk_preview_draw_row_ = link_c_proc( GTK, 
  "gtk_preview_draw_row", {C_POINTER,C_UINT,C_INT,C_INT,C_INT} )

global procedure gtk_preview_draw_row(atom preview_, integer data_, integer x_, integer y_, integer w_)
    c_proc( gtk_preview_draw_row_, {preview_,data_,x_,y_,w_} )
end procedure

----------------------------------------
-- gtk_preview_set_expand
----------------------------------------
constant gtk_preview_set_expand_ = link_c_proc( GTK, 
  "gtk_preview_set_expand", {C_POINTER,C_INT} )

global procedure gtk_preview_set_expand(atom preview_, integer expand_)
    c_proc( gtk_preview_set_expand_, {preview_,expand_} )
end procedure

----------------------------------------
-- gtk_preview_set_gamma
----------------------------------------
constant gtk_preview_set_gamma_ = link_c_proc( GTK, 
  "gtk_preview_set_gamma", {C_LONG} )

global procedure gtk_preview_set_gamma(atom gamma_)
    c_proc( gtk_preview_set_gamma_, {gamma_} )
end procedure

----------------------------------------
-- gtk_preview_set_color_cube
----------------------------------------
constant gtk_preview_set_color_cube_ = link_c_proc( GTK, 
  "gtk_preview_set_color_cube", {C_UINT,C_UINT,C_UINT,C_UINT} )

global procedure gtk_preview_set_color_cube(integer nred_shades_, integer ngreen_shades_, integer nblue_shades_, integer ngray_shades_)
    c_proc( gtk_preview_set_color_cube_, {nred_shades_,ngreen_shades_,nblue_shades_,ngray_shades_} )
end procedure

----------------------------------------
-- gtk_preview_set_install_cmap
----------------------------------------
constant gtk_preview_set_install_cmap_ = link_c_proc( GTK, 
  "gtk_preview_set_install_cmap", {C_INT} )

global procedure gtk_preview_set_install_cmap(integer install_cmap_)
    c_proc( gtk_preview_set_install_cmap_, {install_cmap_} )
end procedure

----------------------------------------
-- gtk_preview_set_reserved
----------------------------------------
constant gtk_preview_set_reserved_ = link_c_proc( GTK, 
  "gtk_preview_set_reserved", {C_INT} )

global procedure gtk_preview_set_reserved(integer nreserved_)
    c_proc( gtk_preview_set_reserved_, {nreserved_} )
end procedure

----------------------------------------
-- gtk_preview_set_dither
----------------------------------------
constant gtk_preview_set_dither_ = link_c_proc( GTK, 
  "gtk_preview_set_dither", {C_POINTER,C_POINTER} )

global procedure gtk_preview_set_dither(atom preview_, atom dither_)
    c_proc( gtk_preview_set_dither_, {preview_,dither_} )
end procedure

----------------------------------------
-- gtk_preview_get_visual
----------------------------------------
constant gtk_preview_get_visual_ = link_c_func( GTK, 
  "gtk_preview_get_visual", {}, C_POINTER )

global function gtk_preview_get_visual()
    return c_func( gtk_preview_get_visual_, {} )
end function

----------------------------------------
-- gtk_preview_get_cmap
----------------------------------------
constant gtk_preview_get_cmap_ = link_c_func( GTK, 
  "gtk_preview_get_cmap", {}, C_POINTER )

global function gtk_preview_get_cmap()
    return c_func( gtk_preview_get_cmap_, {} )
end function

----------------------------------------
-- gtk_preview_get_info
----------------------------------------
constant gtk_preview_get_info_ = link_c_func( GTK, 
  "gtk_preview_get_info", {}, C_POINTER )

global function gtk_preview_get_info()
    return c_func( gtk_preview_get_info_, {} )
end function

----------------------------------------
-- gtk_preview_reset
----------------------------------------
constant gtk_preview_reset_ = link_c_proc( GTK, 
  "gtk_preview_reset", {} )

global procedure gtk_preview_reset()
    c_proc( gtk_preview_reset_, {} )
end procedure


----------------------------------------
----------------------------------------
-- GTKEDITABLE.H
----------------------------------------
----------------------------------------


----------------------------------------
-- GtkTextFunction
----------------------------------------
constant GtkTextFunction_ = link_c_proc( GTK, 
  "GtkTextFunction", {C_POINTER} )

global procedure GtkTextFunction(atom editable_)
    c_proc( GtkTextFunction_, {editable_} )
end procedure


----------------------------------------
-- GtkEditable
----------------------------------------
global constant
    GtkEditable_widget                  = allot(SIZEOF_GtkWidget),
    GtkEditable_current_pos             = allot(TYPE_GUINT),
    GtkEditable_selection_start_pos     = allot(TYPE_GUINT),
    GtkEditable_selection_end_pos       = allot(TYPE_GUINT),
    GtkEditable_has_selection           = allot(TYPE_GUINT),
    GtkEditable_editable                = allot(TYPE_GUINT),
    GtkEditable_visible                 = allot(TYPE_GUINT),
    GtkEditable_ic                      = allot(TYPE_POINTER),
    GtkEditable_ic_attr                 = allot(TYPE_POINTER),
    GtkEditable_clipboard_text          = allot(TYPE_POINTER),
    SIZEOF_GtkEditable                  = allotted_size()

----------------------------------------
-- GtkEditableClass
----------------------------------------
global constant
    GtkEditableClass_parent_class       = allot(SIZEOF_GtkWidgetClass),
    GtkEditableClass_changed            = allot(TYPE_GPOINTER),
    GtkEditableClass_insert_text        = allot(TYPE_GPOINTER),
    GtkEditableClass_delete_text        = allot(TYPE_GPOINTER),
    GtkEditableClass_activate           = allot(TYPE_GPOINTER),
    GtkEditableClass_set_editable       = allot(TYPE_GPOINTER),
    GtkEditableClass_move_cursor        = allot(TYPE_GPOINTER),
    GtkEditableClass_move_word          = allot(TYPE_GPOINTER),
    GtkEditableClass_move_page          = allot(TYPE_GPOINTER),
    GtkEditableClass_move_to_row        = allot(TYPE_GPOINTER),
    GtkEditableClass_move_to_column     = allot(TYPE_GPOINTER),
    GtkEditableClass_kill_char          = allot(TYPE_GPOINTER),
    GtkEditableClass_kill_word          = allot(TYPE_GPOINTER),
    GtkEditableClass_kill_line          = allot(TYPE_GPOINTER),
    GtkEditableClass_cut_clipboard      = allot(TYPE_GPOINTER),
    GtkEditableClass_copy_clipboard     = allot(TYPE_GPOINTER),
    GtkEditableClass_paste_clipboard    = allot(TYPE_GPOINTER),
    GtkEditableClass_update_text        = allot(TYPE_GPOINTER),
    GtkEditableClass_get_chars          = allot(TYPE_GPOINTER),
    GtkEditableClass_set_selection      = allot(TYPE_GPOINTER),
    GtkEditableClass_set_position       = allot(TYPE_GPOINTER),
    SIZEOF_GtkEditableClass             = allotted_size()
----------------------------------------
-- gtk_editable_get_type
----------------------------------------
constant gtk_editable_get_type_ = link_c_func( GTK, 
  "gtk_editable_get_type", {}, C_UINT )

global function gtk_editable_get_type()
    return c_func( gtk_editable_get_type_, {} )
end function

----------------------------------------
-- gtk_editable_select_region
----------------------------------------
constant gtk_editable_select_region_ = link_c_proc( GTK, 
  "gtk_editable_select_region", {C_POINTER,C_INT,C_INT} )

global procedure gtk_editable_select_region(atom editable_, integer start_, integer end_)
    c_proc( gtk_editable_select_region_, {editable_,start_,end_} )
end procedure

----------------------------------------
-- gtk_editable_insert_text
----------------------------------------
constant gtk_editable_insert_text_ = link_c_proc( GTK, 
  "gtk_editable_insert_text", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_editable_insert_text(atom editable_, sequence new_text_, integer new_text_length_, integer position_)
    atom string1
    string1 = allocate_string( new_text_ )
    c_proc( gtk_editable_insert_text_, {editable_,string1,new_text_length_,position_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_editable_delete_text
----------------------------------------
constant gtk_editable_delete_text_ = link_c_proc( GTK, 
  "gtk_editable_delete_text", {C_POINTER,C_INT,C_INT} )

global procedure gtk_editable_delete_text(atom editable_, integer start_pos_, integer end_pos_)
    c_proc( gtk_editable_delete_text_, {editable_,start_pos_,end_pos_} )
end procedure

----------------------------------------
-- gtk_editable_get_chars
----------------------------------------
constant gtk_editable_get_chars_ = link_c_func( GTK, 
  "gtk_editable_get_chars", {C_POINTER,C_INT,C_INT}, C_POINTER )

global function gtk_editable_get_chars(atom editable_, integer start_pos_, integer end_pos_)
    return peek_string( c_func( gtk_editable_get_chars_, {editable_,start_pos_,end_pos_} ) )
end function

----------------------------------------
-- gtk_editable_cut_clipboard
----------------------------------------
constant gtk_editable_cut_clipboard_ = link_c_proc( GTK, 
  "gtk_editable_cut_clipboard", {C_POINTER} )

global procedure gtk_editable_cut_clipboard(atom editable_)
    c_proc( gtk_editable_cut_clipboard_, {editable_} )
end procedure

----------------------------------------
-- gtk_editable_copy_clipboard
----------------------------------------
constant gtk_editable_copy_clipboard_ = link_c_proc( GTK, 
  "gtk_editable_copy_clipboard", {C_POINTER} )

global procedure gtk_editable_copy_clipboard(atom editable_)
    c_proc( gtk_editable_copy_clipboard_, {editable_} )
end procedure

----------------------------------------
-- gtk_editable_paste_clipboard
----------------------------------------
constant gtk_editable_paste_clipboard_ = link_c_proc( GTK, 
  "gtk_editable_paste_clipboard", {C_POINTER} )

global procedure gtk_editable_paste_clipboard(atom editable_)
    c_proc( gtk_editable_paste_clipboard_, {editable_} )
end procedure

----------------------------------------
-- gtk_editable_claim_selection
----------------------------------------
constant gtk_editable_claim_selection_ = link_c_proc( GTK, 
  "gtk_editable_claim_selection", {C_POINTER,C_INT,C_UINT} )

global procedure gtk_editable_claim_selection(atom editable_, integer claim_, atom time_)
    c_proc( gtk_editable_claim_selection_, {editable_,claim_,time_} )
end procedure

----------------------------------------
-- gtk_editable_delete_selection
----------------------------------------
constant gtk_editable_delete_selection_ = link_c_proc( GTK, 
  "gtk_editable_delete_selection", {C_POINTER} )

global procedure gtk_editable_delete_selection(atom editable_)
    c_proc( gtk_editable_delete_selection_, {editable_} )
end procedure

----------------------------------------
-- gtk_editable_changed
----------------------------------------
constant gtk_editable_changed_ = link_c_proc( GTK, 
  "gtk_editable_changed", {C_POINTER} )

global procedure gtk_editable_changed(atom editable_)
    c_proc( gtk_editable_changed_, {editable_} )
end procedure

----------------------------------------
-- gtk_editable_set_position
----------------------------------------
constant gtk_editable_set_position_ = link_c_proc( GTK, 
  "gtk_editable_set_position", {C_POINTER,C_INT} )

global procedure gtk_editable_set_position(atom editable_, integer position_)
    c_proc( gtk_editable_set_position_, {editable_,position_} )
end procedure

----------------------------------------
-- gtk_editable_get_position
----------------------------------------
constant gtk_editable_get_position_ = link_c_func( GTK, 
  "gtk_editable_get_position", {C_POINTER}, C_INT )

global function gtk_editable_get_position(atom editable_)
    return c_func( gtk_editable_get_position_, {editable_} )
end function

----------------------------------------
-- gtk_editable_set_editable
----------------------------------------
constant gtk_editable_set_editable_ = link_c_proc( GTK, 
  "gtk_editable_set_editable", {C_POINTER,C_INT} )

global procedure gtk_editable_set_editable(atom editable_, integer is_editable_)
    c_proc( gtk_editable_set_editable_, {editable_,is_editable_} )
end procedure






----------------------------------------
----------------------------------------
-- GTKENTRY.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkEntry
----------------------------------------
global constant
    GtkEntry_editable                   = allot(SIZEOF_GtkEditable),
    GtkEntry_text_area                  = allot(TYPE_POINTER),
    GtkEntry_backing_pixmap             = allot(TYPE_POINTER),
    GtkEntry_cursor                     = allot(TYPE_POINTER),
    GtkEntry_text                       = allot(TYPE_POINTER),
    GtkEntry_text_size                  = allot(TYPE_GUINT16),
    GtkEntry_text_length                = allot(TYPE_GUINT16),
    GtkEntry_text_max_length            = allot(TYPE_GUINT16),
    GtkEntry_scroll_offset              = allot(TYPE_GINT),
    GtkEntry_visible                    = allot(TYPE_GUINT),
    GtkEntry_timer                      = allot(TYPE_GUINT32),
    GtkEntry_button                     = allot(TYPE_GUINT),
    GtkEntry_char_offset                = allot(TYPE_POINTER),
    GtkEntry_text_mb                    = allot(TYPE_POINTER),
    GtkEntry_text_mb_dirty              = allot(TYPE_GUINT),
    GtkEntry_use_wchar                  = allot(TYPE_GUINT),
    SIZEOF_GtkEntry                     = allotted_size()

----------------------------------------
-- GtkEntryClass
----------------------------------------
global constant
    GtkEntryClass_parent_class          = allot(SIZEOF_GtkEditableClass),
    SIZEOF_GtkEntryClass                = allotted_size()
----------------------------------------
-- gtk_entry_get_type
----------------------------------------
constant gtk_entry_get_type_ = link_c_func( GTK, 
  "gtk_entry_get_type", {}, C_UINT )

global function gtk_entry_get_type()
    return c_func( gtk_entry_get_type_, {} )
end function

----------------------------------------
-- gtk_entry_new
----------------------------------------
constant gtk_entry_new_ = link_c_func( GTK, 
  "gtk_entry_new", {}, C_POINTER )

global function gtk_entry_new()
    return c_func( gtk_entry_new_, {} )
end function

----------------------------------------
-- gtk_entry_new_with_max_length
----------------------------------------
constant gtk_entry_new_with_max_length_ = link_c_func( GTK, 
  "gtk_entry_new_with_max_length", {C_UINT}, C_POINTER )

global function gtk_entry_new_with_max_length(integer max_)
    return c_func( gtk_entry_new_with_max_length_, {max_} )
end function

----------------------------------------
-- gtk_entry_set_text
----------------------------------------
constant gtk_entry_set_text_ = link_c_proc( GTK, 
  "gtk_entry_set_text", {C_POINTER,C_POINTER} )

global procedure gtk_entry_set_text(atom entry_, sequence text_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_entry_set_text_, {entry_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_entry_append_text
----------------------------------------
constant gtk_entry_append_text_ = link_c_proc( GTK, 
  "gtk_entry_append_text", {C_POINTER,C_POINTER} )

global procedure gtk_entry_append_text(atom entry_, sequence text_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_entry_append_text_, {entry_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_entry_prepend_text
----------------------------------------
constant gtk_entry_prepend_text_ = link_c_proc( GTK, 
  "gtk_entry_prepend_text", {C_POINTER,C_POINTER} )

global procedure gtk_entry_prepend_text(atom entry_, sequence text_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_entry_prepend_text_, {entry_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_entry_set_position
----------------------------------------
constant gtk_entry_set_position_ = link_c_proc( GTK, 
  "gtk_entry_set_position", {C_POINTER,C_INT} )

global procedure gtk_entry_set_position(atom entry_, integer position_)
    c_proc( gtk_entry_set_position_, {entry_,position_} )
end procedure

----------------------------------------
-- gtk_entry_get_text
----------------------------------------
constant gtk_entry_get_text_ = link_c_func( GTK, 
  "gtk_entry_get_text", {C_POINTER}, C_POINTER )

global function gtk_entry_get_text(atom entry_)
    return peek_string( c_func( gtk_entry_get_text_, {entry_} ) )
end function

----------------------------------------
-- gtk_entry_select_region
----------------------------------------
constant gtk_entry_select_region_ = link_c_proc( GTK, 
  "gtk_entry_select_region", {C_POINTER,C_INT,C_INT} )

global procedure gtk_entry_select_region(atom entry_, integer start_, integer end_)
    c_proc( gtk_entry_select_region_, {entry_,start_,end_} )
end procedure

----------------------------------------
-- gtk_entry_set_visibility
----------------------------------------
constant gtk_entry_set_visibility_ = link_c_proc( GTK, 
  "gtk_entry_set_visibility", {C_POINTER,C_INT} )

global procedure gtk_entry_set_visibility(atom entry_, integer visible_)
    c_proc( gtk_entry_set_visibility_, {entry_,visible_} )
end procedure

----------------------------------------
-- gtk_entry_set_editable
----------------------------------------
constant gtk_entry_set_editable_ = link_c_proc( GTK, 
  "gtk_entry_set_editable", {C_POINTER,C_INT} )

global procedure gtk_entry_set_editable(atom entry_, integer editable_)
    c_proc( gtk_entry_set_editable_, {entry_,editable_} )
end procedure

----------------------------------------
-- gtk_entry_set_max_length
----------------------------------------
constant gtk_entry_set_max_length_ = link_c_proc( GTK, 
  "gtk_entry_set_max_length", {C_POINTER,C_UINT} )

global procedure gtk_entry_set_max_length(atom entry_, integer max_)
    c_proc( gtk_entry_set_max_length_, {entry_,max_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKHBOX.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHBox
----------------------------------------
global constant
    GtkHBox_box                         = allot(SIZEOF_GtkBox),
    SIZEOF_GtkHBox                      = allotted_size()

----------------------------------------
-- GtkHBoxClass
----------------------------------------
global constant
    GtkHBoxClass_parent_class           = allot(SIZEOF_GtkBoxClass),
    SIZEOF_GtkHBoxClass                 = allotted_size()
----------------------------------------
-- gtk_hbox_get_type
----------------------------------------
constant gtk_hbox_get_type_ = link_c_func( GTK, 
  "gtk_hbox_get_type", {}, C_UINT )

global function gtk_hbox_get_type()
    return c_func( gtk_hbox_get_type_, {} )
end function

----------------------------------------
-- gtk_hbox_new
----------------------------------------
constant gtk_hbox_new_ = link_c_func( GTK, 
  "gtk_hbox_new", {C_INT,C_INT}, C_POINTER )

global function gtk_hbox_new(integer homogeneous_, integer spacing_)
    return c_func( gtk_hbox_new_, {homogeneous_,spacing_} )
end function



----------------------------------------
----------------------------------------
-- GTKMAIN.H
----------------------------------------
----------------------------------------


-- *** ERROR: WHY ARE THESE NOT DEFINED?
-- global constant GTK_PRIORITY_HIGH = G_PRIORITY_HIGH
-- global constant GTK_PRIORITY_INTERNAL = GTK_PRIORITY_REDRAW
-- global constant GTK_PRIORITY_DEFAULT = G_PRIORITY_DEFAULT_IDLE
-- global constant GTK_PRIORITY_LOW = G_PRIORITY_LOW
----------------------------------------
-- GtkModuleInitFunc
----------------------------------------
constant GtkModuleInitFunc_ = link_c_proc( GTK, 
  "GtkModuleInitFunc", {C_INT,C_POINTER} )

global procedure GtkModuleInitFunc(integer argc_, sequence argv_)
    atom string1
    string1 = allocate_string( argv_ )
    c_proc( GtkModuleInitFunc_, {argc_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- GtkKeySnoopFunc
----------------------------------------
constant GtkKeySnoopFunc_ = link_c_func( GTK, 
  "GtkKeySnoopFunc", {C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function GtkKeySnoopFunc(atom grab_widget_, atom event_, atom func_data_)
    return c_func( GtkKeySnoopFunc_, {grab_widget_,event_,func_data_} )
end function

----------------------------------------
-- gtk_check_version
----------------------------------------
constant gtk_check_version_ = link_c_func( GTK, 
  "gtk_check_version", {C_UINT,C_UINT,C_UINT}, C_POINTER )

global function gtk_check_version(integer required_major_, integer required_minor_, integer required_micro_)
    return peek_string( c_func( gtk_check_version_, {required_major_,required_minor_,required_micro_} ) )
end function

----------------------------------------
-- gtk_init
----------------------------------------
constant gtk_init_ = link_c_proc( GTK, 
  "gtk_init", {C_INT,C_POINTER} )

global procedure gtk_init(integer argc_, sequence argv_)
    atom string1
    string1 = allocate_string( argv_ )
    c_proc( gtk_init_, {argc_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_init_check
----------------------------------------
constant gtk_init_check_ = link_c_func( GTK, 
  "gtk_init_check", {C_INT,C_POINTER}, C_INT )

global function gtk_init_check(integer argc_, sequence argv_)
    integer result
    atom string1
    string1 = allocate_string( argv_ )
    result = c_func( gtk_init_check_, {argc_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_exit
----------------------------------------
constant gtk_exit_ = link_c_proc( GTK, 
  "gtk_exit", {C_INT} )

global procedure gtk_exit(integer error_code_)
    c_proc( gtk_exit_, {error_code_} )
end procedure

----------------------------------------
-- gtk_set_locale
----------------------------------------
constant gtk_set_locale_ = link_c_func( GTK, 
  "gtk_set_locale", {}, C_POINTER )

global function gtk_set_locale()
    return peek_string( c_func( gtk_set_locale_, {} ) )
end function

----------------------------------------
-- gtk_events_pending
----------------------------------------
constant gtk_events_pending_ = link_c_func( GTK, 
  "gtk_events_pending", {}, C_INT )

global function gtk_events_pending()
    return c_func( gtk_events_pending_, {} )
end function

----------------------------------------
-- gtk_main_do_event
----------------------------------------
constant gtk_main_do_event_ = link_c_proc( GTK, 
  "gtk_main_do_event", {C_POINTER} )

global procedure gtk_main_do_event(atom event_)
    c_proc( gtk_main_do_event_, {event_} )
end procedure

----------------------------------------
-- gtk_main
----------------------------------------
constant gtk_main_ = link_c_proc( GTK, 
  "gtk_main", {} )

global procedure gtk_main()
    c_proc( gtk_main_, {} )
end procedure

----------------------------------------
-- gtk_main_level
----------------------------------------
constant gtk_main_level_ = link_c_func( GTK, 
  "gtk_main_level", {}, C_UINT )

global function gtk_main_level()
    return c_func( gtk_main_level_, {} )
end function

----------------------------------------
-- gtk_main_quit
----------------------------------------
constant gtk_main_quit_ = link_c_proc( GTK, 
  "gtk_main_quit", {} )

global procedure gtk_main_quit()
    c_proc( gtk_main_quit_, {} )
end procedure

----------------------------------------
-- gtk_main_iteration
----------------------------------------
constant gtk_main_iteration_ = link_c_func( GTK, 
  "gtk_main_iteration", {}, C_INT )

global function gtk_main_iteration()
    return c_func( gtk_main_iteration_, {} )
end function

----------------------------------------
-- gtk_main_iteration_do
----------------------------------------
constant gtk_main_iteration_do_ = link_c_func( GTK, 
  "gtk_main_iteration_do", {C_INT}, C_INT )

global function gtk_main_iteration_do(integer blocking_)
    return c_func( gtk_main_iteration_do_, {blocking_} )
end function

----------------------------------------
-- gtk_true
----------------------------------------
constant gtk_true_ = link_c_func( GTK, 
  "gtk_true", {}, C_INT )

global function gtk_true()
    return c_func( gtk_true_, {} )
end function

----------------------------------------
-- gtk_false
----------------------------------------
constant gtk_false_ = link_c_func( GTK, 
  "gtk_false", {}, C_INT )

global function gtk_false()
    return c_func( gtk_false_, {} )
end function

----------------------------------------
-- gtk_grab_add
----------------------------------------
constant gtk_grab_add_ = link_c_proc( GTK, 
  "gtk_grab_add", {C_POINTER} )

global procedure gtk_grab_add(atom widget_)
    c_proc( gtk_grab_add_, {widget_} )
end procedure

----------------------------------------
-- gtk_grab_get_current
----------------------------------------
constant gtk_grab_get_current_ = link_c_func( GTK, 
  "gtk_grab_get_current", {}, C_POINTER )

global function gtk_grab_get_current()
    return c_func( gtk_grab_get_current_, {} )
end function

----------------------------------------
-- gtk_grab_remove
----------------------------------------
constant gtk_grab_remove_ = link_c_proc( GTK, 
  "gtk_grab_remove", {C_POINTER} )

global procedure gtk_grab_remove(atom widget_)
    c_proc( gtk_grab_remove_, {widget_} )
end procedure

----------------------------------------
-- gtk_init_add
----------------------------------------
constant gtk_init_add_ = link_c_proc( GTK, 
  "gtk_init_add", {C_POINTER,C_POINTER} )

global procedure gtk_init_add(atom function_, atom data_)
    c_proc( gtk_init_add_, {function_,data_} )
end procedure

----------------------------------------
-- gtk_quit_add_destroy
----------------------------------------
constant gtk_quit_add_destroy_ = link_c_proc( GTK, 
  "gtk_quit_add_destroy", {C_UINT,C_POINTER} )

global procedure gtk_quit_add_destroy(integer main_level_, atom object_)
    c_proc( gtk_quit_add_destroy_, {main_level_,object_} )
end procedure

----------------------------------------
-- gtk_quit_add
----------------------------------------
constant gtk_quit_add_ = link_c_func( GTK, 
  "gtk_quit_add", {C_UINT,C_POINTER,C_POINTER}, C_UINT )

global function gtk_quit_add(integer main_level_, atom function_, atom data_)
    return c_func( gtk_quit_add_, {main_level_,function_,data_} )
end function

----------------------------------------
-- gtk_quit_add_full
----------------------------------------
constant gtk_quit_add_full_ = link_c_func( GTK, 
  "gtk_quit_add_full", {C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_UINT )

global function gtk_quit_add_full(integer main_level_, atom function_, atom marshal_, atom data_, atom destroy_)
    return c_func( gtk_quit_add_full_, {main_level_,function_,marshal_,data_,destroy_} )
end function

----------------------------------------
-- gtk_quit_remove
----------------------------------------
constant gtk_quit_remove_ = link_c_proc( GTK, 
  "gtk_quit_remove", {C_UINT} )

global procedure gtk_quit_remove(integer quit_handler_id_)
    c_proc( gtk_quit_remove_, {quit_handler_id_} )
end procedure

----------------------------------------
-- gtk_quit_remove_by_data
----------------------------------------
constant gtk_quit_remove_by_data_ = link_c_proc( GTK, 
  "gtk_quit_remove_by_data", {C_POINTER} )

global procedure gtk_quit_remove_by_data(atom data_)
    c_proc( gtk_quit_remove_by_data_, {data_} )
end procedure

----------------------------------------
-- gtk_timeout_add
----------------------------------------
constant gtk_timeout_add_ = link_c_func( GTK, 
  "gtk_timeout_add", {C_UINT,C_POINTER,C_POINTER}, C_UINT )

global function gtk_timeout_add(atom interval_, atom function_, atom data_)
    return c_func( gtk_timeout_add_, {interval_,function_,data_} )
end function

----------------------------------------
-- gtk_timeout_add_full
----------------------------------------
constant gtk_timeout_add_full_ = link_c_func( GTK, 
  "gtk_timeout_add_full", {C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_UINT )

global function gtk_timeout_add_full(atom interval_, atom function_, atom marshal_, atom data_, atom destroy_)
    return c_func( gtk_timeout_add_full_, {interval_,function_,marshal_,data_,destroy_} )
end function

----------------------------------------
-- gtk_timeout_remove
----------------------------------------
constant gtk_timeout_remove_ = link_c_proc( GTK, 
  "gtk_timeout_remove", {C_UINT} )

global procedure gtk_timeout_remove(integer timeout_handler_id_)
    c_proc( gtk_timeout_remove_, {timeout_handler_id_} )
end procedure

----------------------------------------
-- gtk_idle_add
----------------------------------------
constant gtk_idle_add_ = link_c_func( GTK, 
  "gtk_idle_add", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_idle_add(atom function_, atom data_)
    return c_func( gtk_idle_add_, {function_,data_} )
end function

----------------------------------------
-- gtk_idle_add_priority
----------------------------------------
constant gtk_idle_add_priority_ = link_c_func( GTK, 
  "gtk_idle_add_priority", {C_INT,C_POINTER,C_POINTER}, C_UINT )

global function gtk_idle_add_priority(integer priority_, atom function_, atom data_)
    return c_func( gtk_idle_add_priority_, {priority_,function_,data_} )
end function

----------------------------------------
-- gtk_idle_add_full
----------------------------------------
constant gtk_idle_add_full_ = link_c_func( GTK, 
  "gtk_idle_add_full", {C_INT,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_UINT )

global function gtk_idle_add_full(integer priority_, atom function_, atom marshal_, atom data_, atom destroy_)
    return c_func( gtk_idle_add_full_, {priority_,function_,marshal_,data_,destroy_} )
end function

----------------------------------------
-- gtk_idle_remove
----------------------------------------
constant gtk_idle_remove_ = link_c_proc( GTK, 
  "gtk_idle_remove", {C_UINT} )

global procedure gtk_idle_remove(integer idle_handler_id_)
    c_proc( gtk_idle_remove_, {idle_handler_id_} )
end procedure

----------------------------------------
-- gtk_idle_remove_by_data
----------------------------------------
constant gtk_idle_remove_by_data_ = link_c_proc( GTK, 
  "gtk_idle_remove_by_data", {C_POINTER} )

global procedure gtk_idle_remove_by_data(atom data_)
    c_proc( gtk_idle_remove_by_data_, {data_} )
end procedure

----------------------------------------
-- gtk_input_add_full
----------------------------------------
constant gtk_input_add_full_ = link_c_func( GTK, 
  "gtk_input_add_full", {C_INT,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_UINT )

global function gtk_input_add_full(integer source_, atom condition_, atom function_, atom marshal_, atom data_, atom destroy_)
    return c_func( gtk_input_add_full_, {source_,condition_,function_,marshal_,data_,destroy_} )
end function

----------------------------------------
-- gtk_input_remove
----------------------------------------
constant gtk_input_remove_ = link_c_proc( GTK, 
  "gtk_input_remove", {C_UINT} )

global procedure gtk_input_remove(integer input_handler_id_)
    c_proc( gtk_input_remove_, {input_handler_id_} )
end procedure

----------------------------------------
-- gtk_key_snooper_install
----------------------------------------
constant gtk_key_snooper_install_ = link_c_func( GTK, 
  "gtk_key_snooper_install", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_key_snooper_install(atom snooper_, atom func_data_)
    return c_func( gtk_key_snooper_install_, {snooper_,func_data_} )
end function

----------------------------------------
-- gtk_key_snooper_remove
----------------------------------------
constant gtk_key_snooper_remove_ = link_c_proc( GTK, 
  "gtk_key_snooper_remove", {C_UINT} )

global procedure gtk_key_snooper_remove(integer snooper_handler_id_)
    c_proc( gtk_key_snooper_remove_, {snooper_handler_id_} )
end procedure

----------------------------------------
-- gtk_get_current_event
----------------------------------------
constant gtk_get_current_event_ = link_c_func( GTK, 
  "gtk_get_current_event", {}, C_POINTER )

global function gtk_get_current_event()
    return c_func( gtk_get_current_event_, {} )
end function

----------------------------------------
-- gtk_get_event_widget
----------------------------------------
constant gtk_get_event_widget_ = link_c_func( GTK, 
  "gtk_get_event_widget", {C_POINTER}, C_POINTER )

global function gtk_get_event_widget(atom event_)
    return c_func( gtk_get_event_widget_, {event_} )
end function

----------------------------------------
-- gtk_propagate_event
----------------------------------------
constant gtk_propagate_event_ = link_c_proc( GTK, 
  "gtk_propagate_event", {C_POINTER,C_POINTER} )

global procedure gtk_propagate_event(atom widget_, atom event_)
    c_proc( gtk_propagate_event_, {widget_,event_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKSCALE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkScale
----------------------------------------
global constant
    GtkScale_range                      = allot(SIZEOF_GtkRange),
    GtkScale_draw_value                 = allot(TYPE_GUINT),
    GtkScale_value_pos                  = allot(TYPE_GUINT),
    SIZEOF_GtkScale                     = allotted_size()

----------------------------------------
-- GtkScaleClass
----------------------------------------
global constant
    GtkScaleClass_parent_class          = allot(SIZEOF_GtkRangeClass),
    GtkScaleClass_slider_length         = allot(TYPE_GINT),
    GtkScaleClass_value_spacing         = allot(TYPE_GINT),
    GtkScaleClass_draw_value            = allot(TYPE_GPOINTER),
    SIZEOF_GtkScaleClass                = allotted_size()
----------------------------------------
-- gtk_scale_get_type
----------------------------------------
constant gtk_scale_get_type_ = link_c_func( GTK, 
  "gtk_scale_get_type", {}, C_UINT )

global function gtk_scale_get_type()
    return c_func( gtk_scale_get_type_, {} )
end function

----------------------------------------
-- gtk_scale_set_digits
----------------------------------------
constant gtk_scale_set_digits_ = link_c_proc( GTK, 
  "gtk_scale_set_digits", {C_POINTER,C_INT} )

global procedure gtk_scale_set_digits(atom scale_, integer digits_)
    c_proc( gtk_scale_set_digits_, {scale_,digits_} )
end procedure

----------------------------------------
-- gtk_scale_set_draw_value
----------------------------------------
constant gtk_scale_set_draw_value_ = link_c_proc( GTK, 
  "gtk_scale_set_draw_value", {C_POINTER,C_INT} )

global procedure gtk_scale_set_draw_value(atom scale_, integer draw_value_)
    c_proc( gtk_scale_set_draw_value_, {scale_,draw_value_} )
end procedure

----------------------------------------
-- gtk_scale_set_value_pos
----------------------------------------
constant gtk_scale_set_value_pos_ = link_c_proc( GTK, 
  "gtk_scale_set_value_pos", {C_POINTER,C_POINTER} )

global procedure gtk_scale_set_value_pos(atom scale_, atom pos_)
    c_proc( gtk_scale_set_value_pos_, {scale_,pos_} )
end procedure

----------------------------------------
-- gtk_scale_get_value_width
----------------------------------------
constant gtk_scale_get_value_width_ = link_c_func( GTK, 
  "gtk_scale_get_value_width", {C_POINTER}, C_INT )

global function gtk_scale_get_value_width(atom scale_)
    return c_func( gtk_scale_get_value_width_, {scale_} )
end function

----------------------------------------
-- gtk_scale_draw_value
----------------------------------------
constant gtk_scale_draw_value_ = link_c_proc( GTK, 
  "gtk_scale_draw_value", {C_POINTER} )

global procedure gtk_scale_draw_value(atom scale_)
    c_proc( gtk_scale_draw_value_, {scale_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKHSCALE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHScale
----------------------------------------
global constant
    GtkHScale_scale                     = allot(SIZEOF_GtkScale),
    SIZEOF_GtkHScale                    = allotted_size()

----------------------------------------
-- GtkHScaleClass
----------------------------------------
global constant
    GtkHScaleClass_parent_class         = allot(SIZEOF_GtkScaleClass),
    SIZEOF_GtkHScaleClass               = allotted_size()
----------------------------------------
-- gtk_hscale_get_type
----------------------------------------
constant gtk_hscale_get_type_ = link_c_func( GTK, 
  "gtk_hscale_get_type", {}, C_UINT )

global function gtk_hscale_get_type()
    return c_func( gtk_hscale_get_type_, {} )
end function

----------------------------------------
-- gtk_hscale_new
----------------------------------------
constant gtk_hscale_new_ = link_c_func( GTK, 
  "gtk_hscale_new", {C_POINTER}, C_POINTER )

global function gtk_hscale_new(atom adjustment_)
    return c_func( gtk_hscale_new_, {adjustment_} )
end function



----------------------------------------
----------------------------------------
-- GTKTABLE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkTable
----------------------------------------
global constant
    GtkTable_container                  = allot(SIZEOF_GtkContainer),
    GtkTable_children                   = allot(TYPE_POINTER),
    GtkTable_rows                       = allot(TYPE_POINTER),
    GtkTable_cols                       = allot(TYPE_POINTER),
    GtkTable_nrows                      = allot(TYPE_GUINT16),
    GtkTable_ncols                      = allot(TYPE_GUINT16),
    GtkTable_column_spacing             = allot(TYPE_GUINT16),
    GtkTable_row_spacing                = allot(TYPE_GUINT16),
    GtkTable_homogeneous                = allot(TYPE_GUINT),
    SIZEOF_GtkTable                     = allotted_size()

----------------------------------------
-- GtkTableClass
----------------------------------------
global constant
    GtkTableClass_parent_class          = allot(SIZEOF_GtkContainerClass),
    SIZEOF_GtkTableClass                = allotted_size()

----------------------------------------
-- GtkTableChild
----------------------------------------
global constant
    GtkTableChild_widget                = allot(TYPE_POINTER),
    GtkTableChild_left_attach           = allot(TYPE_GUINT16),
    GtkTableChild_right_attach          = allot(TYPE_GUINT16),
    GtkTableChild_top_attach            = allot(TYPE_GUINT16),
    GtkTableChild_bottom_attach         = allot(TYPE_GUINT16),
    GtkTableChild_xpadding              = allot(TYPE_GUINT16),
    GtkTableChild_ypadding              = allot(TYPE_GUINT16),
    GtkTableChild_xexpand               = allot(TYPE_GUINT),
    GtkTableChild_yexpand               = allot(TYPE_GUINT),
    GtkTableChild_xshrink               = allot(TYPE_GUINT),
    GtkTableChild_yshrink               = allot(TYPE_GUINT),
    GtkTableChild_xfill                 = allot(TYPE_GUINT),
    GtkTableChild_yfill                 = allot(TYPE_GUINT),
    SIZEOF_GtkTableChild                = allotted_size()

----------------------------------------
-- GtkTableRowCol
----------------------------------------
global constant
    GtkTableRowCol_requisition          = allot(TYPE_GUINT16),
    GtkTableRowCol_allocation           = allot(TYPE_GUINT16),
    GtkTableRowCol_spacing              = allot(TYPE_GUINT16),
    GtkTableRowCol_need_expand          = allot(TYPE_GUINT),
    GtkTableRowCol_need_shrink          = allot(TYPE_GUINT),
    GtkTableRowCol_expand               = allot(TYPE_GUINT),
    GtkTableRowCol_shrink               = allot(TYPE_GUINT),
    GtkTableRowCol_empty                = allot(TYPE_GUINT),
    SIZEOF_GtkTableRowCol               = allotted_size()
----------------------------------------
-- gtk_table_get_type
----------------------------------------
constant gtk_table_get_type_ = link_c_func( GTK, 
  "gtk_table_get_type", {}, C_UINT )

global function gtk_table_get_type()
    return c_func( gtk_table_get_type_, {} )
end function

----------------------------------------
-- gtk_table_new
----------------------------------------
constant gtk_table_new_ = link_c_func( GTK, 
  "gtk_table_new", {C_UINT,C_UINT,C_INT}, C_POINTER )

global function gtk_table_new(integer rows_, integer columns_, integer homogeneous_)
    return c_func( gtk_table_new_, {rows_,columns_,homogeneous_} )
end function

----------------------------------------
-- gtk_table_resize
----------------------------------------
constant gtk_table_resize_ = link_c_proc( GTK, 
  "gtk_table_resize", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_table_resize(atom table_, integer rows_, integer columns_)
    c_proc( gtk_table_resize_, {table_,rows_,columns_} )
end procedure

----------------------------------------
-- gtk_table_attach
----------------------------------------
constant gtk_table_attach_ = link_c_proc( GTK, 
  "gtk_table_attach", {C_POINTER,C_POINTER,C_UINT,C_UINT,C_UINT,C_UINT,C_POINTER,C_POINTER,C_UINT,C_UINT} 
 )

global procedure gtk_table_attach(atom table_, atom child_, integer left_attach_, integer right_attach_, integer 
 top_attach_, integer bottom_attach_, atom xoptions_, atom yoptions_, integer xpadding_, integer ypadding_)
    c_proc( gtk_table_attach_, {table_,child_,left_attach_,right_attach_,top_attach_,bottom_attach_,xoptions_,yoptions_,xpadding_,ypadding_} )
end procedure

----------------------------------------
-- gtk_table_attach_defaults
----------------------------------------
constant gtk_table_attach_defaults_ = link_c_proc( GTK, 
  "gtk_table_attach_defaults", {C_POINTER,C_POINTER,C_UINT,C_UINT,C_UINT,C_UINT} )

global procedure gtk_table_attach_defaults(atom table_, atom widget_, integer left_attach_, integer right_attach_, 
 integer top_attach_, integer bottom_attach_)
    c_proc( gtk_table_attach_defaults_, {table_,widget_,left_attach_,right_attach_,top_attach_,bottom_attach_} )
end procedure

----------------------------------------
-- gtk_table_set_row_spacing
----------------------------------------
constant gtk_table_set_row_spacing_ = link_c_proc( GTK, 
  "gtk_table_set_row_spacing", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_table_set_row_spacing(atom table_, integer row_, integer spacing_)
    c_proc( gtk_table_set_row_spacing_, {table_,row_,spacing_} )
end procedure

----------------------------------------
-- gtk_table_set_col_spacing
----------------------------------------
constant gtk_table_set_col_spacing_ = link_c_proc( GTK, 
  "gtk_table_set_col_spacing", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_table_set_col_spacing(atom table_, integer column_, integer spacing_)
    c_proc( gtk_table_set_col_spacing_, {table_,column_,spacing_} )
end procedure

----------------------------------------
-- gtk_table_set_row_spacings
----------------------------------------
constant gtk_table_set_row_spacings_ = link_c_proc( GTK, 
  "gtk_table_set_row_spacings", {C_POINTER,C_UINT} )

global procedure gtk_table_set_row_spacings(atom table_, integer spacing_)
    c_proc( gtk_table_set_row_spacings_, {table_,spacing_} )
end procedure

----------------------------------------
-- gtk_table_set_col_spacings
----------------------------------------
constant gtk_table_set_col_spacings_ = link_c_proc( GTK, 
  "gtk_table_set_col_spacings", {C_POINTER,C_UINT} )

global procedure gtk_table_set_col_spacings(atom table_, integer spacing_)
    c_proc( gtk_table_set_col_spacings_, {table_,spacing_} )
end procedure

----------------------------------------
-- gtk_table_set_homogeneous
----------------------------------------
constant gtk_table_set_homogeneous_ = link_c_proc( GTK, 
  "gtk_table_set_homogeneous", {C_POINTER,C_INT} )

global procedure gtk_table_set_homogeneous(atom table_, integer homogeneous_)
    c_proc( gtk_table_set_homogeneous_, {table_,homogeneous_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKEVENTBOX.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkEventBox
----------------------------------------
global constant
    GtkEventBox_bin                     = allot(SIZEOF_GtkBin),
    SIZEOF_GtkEventBox                  = allotted_size()

----------------------------------------
-- GtkEventBoxClass
----------------------------------------
global constant
    GtkEventBoxClass_parent_class       = allot(SIZEOF_GtkBinClass),
    SIZEOF_GtkEventBoxClass             = allotted_size()
----------------------------------------
-- gtk_event_box_get_type
----------------------------------------
constant gtk_event_box_get_type_ = link_c_func( GTK, 
  "gtk_event_box_get_type", {}, C_UINT )

global function gtk_event_box_get_type()
    return c_func( gtk_event_box_get_type_, {} )
end function

----------------------------------------
-- gtk_event_box_new
----------------------------------------
constant gtk_event_box_new_ = link_c_func( GTK, 
  "gtk_event_box_new", {}, C_POINTER )

global function gtk_event_box_new()
    return c_func( gtk_event_box_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKCOMBO.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkCombo
----------------------------------------
global constant
    GtkCombo_hbox                       = allot(SIZEOF_GtkHBox),
    GtkCombo_entry                      = allot(TYPE_POINTER),
    GtkCombo_button                     = allot(TYPE_POINTER),
    GtkCombo_popup                      = allot(TYPE_POINTER),
    GtkCombo_popwin                     = allot(TYPE_POINTER),
    GtkCombo_list                       = allot(TYPE_POINTER),
    GtkCombo_entry_change_id            = allot(TYPE_GUINT),
    GtkCombo_list_change_id             = allot(TYPE_GUINT),
    GtkCombo_value_in_list              = allot(TYPE_GUINT),
    GtkCombo_ok_if_empty                = allot(TYPE_GUINT),
    GtkCombo_case_sensitive             = allot(TYPE_GUINT),
    GtkCombo_use_arrows                 = allot(TYPE_GUINT),
    GtkCombo_use_arrows_always          = allot(TYPE_GUINT),
    GtkCombo_current_button             = allot(TYPE_GUINT16),
    GtkCombo_activate_id                = allot(TYPE_GUINT),
    SIZEOF_GtkCombo                     = allotted_size()

----------------------------------------
-- GtkComboClass
----------------------------------------
global constant
    GtkComboClass_parent_class          = allot(SIZEOF_GtkHBoxClass),
    SIZEOF_GtkComboClass                = allotted_size()
----------------------------------------
-- gtk_combo_get_type
----------------------------------------
constant gtk_combo_get_type_ = link_c_func( GTK, 
  "gtk_combo_get_type", {}, C_UINT )

global function gtk_combo_get_type()
    return c_func( gtk_combo_get_type_, {} )
end function

----------------------------------------
-- gtk_combo_new
----------------------------------------
constant gtk_combo_new_ = link_c_func( GTK, 
  "gtk_combo_new", {}, C_POINTER )

global function gtk_combo_new()
    return c_func( gtk_combo_new_, {} )
end function

----------------------------------------
-- gtk_combo_set_value_in_list
----------------------------------------
constant gtk_combo_set_value_in_list_ = link_c_proc( GTK, 
  "gtk_combo_set_value_in_list", {C_POINTER,C_INT,C_INT} )

global procedure gtk_combo_set_value_in_list(atom combo_, integer val_, integer ok_if_empty_)
    c_proc( gtk_combo_set_value_in_list_, {combo_,val_,ok_if_empty_} )
end procedure

----------------------------------------
-- gtk_combo_set_use_arrows
----------------------------------------
constant gtk_combo_set_use_arrows_ = link_c_proc( GTK, 
  "gtk_combo_set_use_arrows", {C_POINTER,C_INT} )

global procedure gtk_combo_set_use_arrows(atom combo_, integer val_)
    c_proc( gtk_combo_set_use_arrows_, {combo_,val_} )
end procedure

----------------------------------------
-- gtk_combo_set_use_arrows_always
----------------------------------------
constant gtk_combo_set_use_arrows_always_ = link_c_proc( GTK, 
  "gtk_combo_set_use_arrows_always", {C_POINTER,C_INT} )

global procedure gtk_combo_set_use_arrows_always(atom combo_, integer val_)
    c_proc( gtk_combo_set_use_arrows_always_, {combo_,val_} )
end procedure

----------------------------------------
-- gtk_combo_set_case_sensitive
----------------------------------------
constant gtk_combo_set_case_sensitive_ = link_c_proc( GTK, 
  "gtk_combo_set_case_sensitive", {C_POINTER,C_INT} )

global procedure gtk_combo_set_case_sensitive(atom combo_, integer val_)
    c_proc( gtk_combo_set_case_sensitive_, {combo_,val_} )
end procedure

----------------------------------------
-- gtk_combo_set_item_string
----------------------------------------
constant gtk_combo_set_item_string_ = link_c_proc( GTK, 
  "gtk_combo_set_item_string", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_combo_set_item_string(atom combo_, atom item_, sequence item_value_)
    atom string1
    string1 = allocate_string( item_value_ )
    c_proc( gtk_combo_set_item_string_, {combo_,item_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_combo_set_popdown_strings
----------------------------------------
constant gtk_combo_set_popdown_strings_ = link_c_proc( GTK, 
  "gtk_combo_set_popdown_strings", {C_POINTER,C_POINTER} )

global procedure gtk_combo_set_popdown_strings(atom combo_, atom strings_)
    c_proc( gtk_combo_set_popdown_strings_, {combo_,strings_} )
end procedure

----------------------------------------
-- gtk_combo_disable_activate
----------------------------------------
constant gtk_combo_disable_activate_ = link_c_proc( GTK, 
  "gtk_combo_disable_activate", {C_POINTER} )

global procedure gtk_combo_disable_activate(atom combo_)
    c_proc( gtk_combo_disable_activate_, {combo_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKCOMPAT.H
----------------------------------------
----------------------------------------


----------------------------------------
----------------------------------------
-- GTKCTREE.H
----------------------------------------
----------------------------------------


global constant
    GTK_CTREE_POS_BEFORE                = 1,
    GTK_CTREE_POS_AS_CHILD              = 2,
    GTK_CTREE_POS_AFTER                 = 3
global constant SIZEOF_GtkCTreePos = SIZEOF_ENUM

global constant
    GTK_CTREE_LINES_NONE                = 1,
    GTK_CTREE_LINES_SOLID               = 2,
    GTK_CTREE_LINES_DOTTED              = 3,
    GTK_CTREE_LINES_TABBED              = 4
global constant SIZEOF_GtkCTreeLineStyle = SIZEOF_ENUM

global constant
    GTK_CTREE_EXPANDER_NONE             = 1,
    GTK_CTREE_EXPANDER_SQUARE           = 2,
    GTK_CTREE_EXPANDER_TRIANGLE         = 3,
    GTK_CTREE_EXPANDER_CIRCULAR         = 4
global constant SIZEOF_GtkCTreeExpanderStyle = SIZEOF_ENUM

global constant
    GTK_CTREE_EXPANSION_EXPAND          = 1,
    GTK_CTREE_EXPANSION_EXPAND_RECURSIVE= 2,
    GTK_CTREE_EXPANSION_COLLAPSE        = 3,
    GTK_CTREE_EXPANSION_COLLAPSE_RECURSIVE= 4,
    GTK_CTREE_EXPANSION_TOGGLE          = 5,
    GTK_CTREE_EXPANSION_TOGGLE_RECURSIVE= 6
global constant SIZEOF_GtkCTreeExpansionType = SIZEOF_ENUM

----------------------------------------
-- GtkCTreeFunc
----------------------------------------
constant GtkCTreeFunc_ = link_c_proc( GTK, 
  "GtkCTreeFunc", {C_POINTER,C_POINTER,C_POINTER} )

global procedure GtkCTreeFunc(atom ctree_, atom node_, atom data_)
    c_proc( GtkCTreeFunc_, {ctree_,node_,data_} )
end procedure

----------------------------------------
-- GtkCTreeGNodeFunc
----------------------------------------
constant GtkCTreeGNodeFunc_ = link_c_func( GTK, 
  "GtkCTreeGNodeFunc", {C_POINTER,C_UINT,C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function GtkCTreeGNodeFunc(atom ctree_, integer depth_, atom gnode_, atom cnode_, atom data_)
    return c_func( GtkCTreeGNodeFunc_, {ctree_,depth_,gnode_,cnode_,data_} )
end function

----------------------------------------
-- GtkCTreeCompareDragFunc
----------------------------------------
constant GtkCTreeCompareDragFunc_ = link_c_func( GTK, 
  "GtkCTreeCompareDragFunc", {C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_INT )

global function GtkCTreeCompareDragFunc(atom ctree_, atom source_node_, atom new_parent_, atom new_sibling_)
    return c_func( GtkCTreeCompareDragFunc_, {ctree_,source_node_,new_parent_,new_sibling_} )
end function


----------------------------------------
-- GtkCTree
----------------------------------------
-- manually corrected:
-- GtkCTreeCompareDragFunc changed to TYPE_GPOINTER
global constant
    GtkCTree_clist                      = allot(SIZEOF_GtkCList),
    GtkCTree_lines_gc                   = allot(TYPE_POINTER),
    GtkCTree_tree_indent                = allot(TYPE_GINT),
    GtkCTree_tree_spacing               = allot(TYPE_GINT),
    GtkCTree_tree_column                = allot(TYPE_GINT),
    GtkCTree_line_style                 = allot(TYPE_GUINT),
    GtkCTree_expander_style             = allot(TYPE_GUINT),
    GtkCTree_show_stub                  = allot(TYPE_GUINT),
    GtkCTree_drag_compare               = allot(TYPE_GPOINTER),
    SIZEOF_GtkCTree                     = allotted_size()

----------------------------------------
-- GtkCTreeClass
----------------------------------------
global constant
    GtkCTreeClass_parent_class          = allot(SIZEOF_GtkCListClass),
    GtkCTreeClass_tree_select_row       = allot(TYPE_GPOINTER),
    GtkCTreeClass_tree_unselect_row     = allot(TYPE_GPOINTER),
    GtkCTreeClass_tree_expand           = allot(TYPE_GPOINTER),
    GtkCTreeClass_tree_collapse         = allot(TYPE_GPOINTER),
    GtkCTreeClass_tree_move             = allot(TYPE_GPOINTER),
    GtkCTreeClass_change_focus_row_expansion= allot(TYPE_GPOINTER),
    SIZEOF_GtkCTreeClass                = allotted_size()

----------------------------------------
-- GtkCTreeRow
----------------------------------------
global constant
    GtkCTreeRow_row                     = allot(SIZEOF_GtkCListRow),
    GtkCTreeRow_parent                  = allot(TYPE_POINTER),
    GtkCTreeRow_sibling                 = allot(TYPE_POINTER),
    GtkCTreeRow_children                = allot(TYPE_POINTER),
    GtkCTreeRow_pixmap_closed           = allot(TYPE_POINTER),
    GtkCTreeRow_mask_closed             = allot(TYPE_POINTER),
    GtkCTreeRow_pixmap_opened           = allot(TYPE_POINTER),
    GtkCTreeRow_mask_opened             = allot(TYPE_POINTER),
    GtkCTreeRow_level                   = allot(TYPE_GUINT16),
    GtkCTreeRow_is_leaf                 = allot(TYPE_GUINT),
    GtkCTreeRow_expanded                = allot(TYPE_GUINT),
    SIZEOF_GtkCTreeRow                  = allotted_size()

----------------------------------------
-- GtkCTreeNode
----------------------------------------
-- ERROR! This needs to be corrected.
-- I don't know the size of a GList

global constant
--    GtkCTreeNode_list                   = allot(SIZEOF_GList),
    SIZEOF_GtkCTreeNode                 = allotted_size()
    
----------------------------------------
-- gtk_ctree_get_type
----------------------------------------
constant gtk_ctree_get_type_ = link_c_func( GTK, 
  "gtk_ctree_get_type", {}, C_UINT )

global function gtk_ctree_get_type()
    return c_func( gtk_ctree_get_type_, {} )
end function

----------------------------------------
-- gtk_ctree_construct
----------------------------------------
constant gtk_ctree_construct_ = link_c_proc( GTK, 
  "gtk_ctree_construct", {C_POINTER,C_INT,C_INT,C_POINTER} )

global procedure gtk_ctree_construct(atom ctree_, integer columns_, integer tree_column_, sequence titles_)
    atom strArray1
    strArray1 = allot_string_array( titles_ )
    c_proc( gtk_ctree_construct_, {ctree_,columns_,tree_column_,strArray1} )
    free_string_array( strArray1 )
end procedure

----------------------------------------
-- gtk_ctree_post_recursive
----------------------------------------
constant gtk_ctree_post_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_post_recursive", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_ctree_post_recursive(atom ctree_, atom node_, atom func_, atom data_)
    c_proc( gtk_ctree_post_recursive_, {ctree_,node_,func_,data_} )
end procedure

----------------------------------------
-- gtk_ctree_post_recursive_to_depth
----------------------------------------
constant gtk_ctree_post_recursive_to_depth_ = link_c_proc( GTK, 
  "gtk_ctree_post_recursive_to_depth", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_POINTER} 
 )

global procedure gtk_ctree_post_recursive_to_depth(atom ctree_, atom node_, integer depth_, atom func_, atom data_)
    c_proc( gtk_ctree_post_recursive_to_depth_, {ctree_,node_,depth_,func_,data_} )
end procedure

----------------------------------------
-- gtk_ctree_pre_recursive
----------------------------------------
constant gtk_ctree_pre_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_pre_recursive", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_ctree_pre_recursive(atom ctree_, atom node_, atom func_, atom data_)
    c_proc( gtk_ctree_pre_recursive_, {ctree_,node_,func_,data_} )
end procedure

----------------------------------------
-- gtk_ctree_pre_recursive_to_depth
----------------------------------------
constant gtk_ctree_pre_recursive_to_depth_ = link_c_proc( GTK, 
  "gtk_ctree_pre_recursive_to_depth", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_POINTER} 
 )

global procedure gtk_ctree_pre_recursive_to_depth(atom ctree_, atom node_, integer depth_, atom func_, atom data_)
    c_proc( gtk_ctree_pre_recursive_to_depth_, {ctree_,node_,depth_,func_,data_} )
end procedure

----------------------------------------
-- gtk_ctree_is_viewable
----------------------------------------
constant gtk_ctree_is_viewable_ = link_c_func( GTK, 
  "gtk_ctree_is_viewable", {C_POINTER,C_POINTER}, C_INT )

global function gtk_ctree_is_viewable(atom ctree_, atom node_)
    return c_func( gtk_ctree_is_viewable_, {ctree_,node_} )
end function

----------------------------------------
-- gtk_ctree_move
----------------------------------------
constant gtk_ctree_move_ = link_c_proc( GTK, 
  "gtk_ctree_move", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_ctree_move(atom ctree_, atom node_, atom new_parent_, atom new_sibling_)
    c_proc( gtk_ctree_move_, {ctree_,node_,new_parent_,new_sibling_} )
end procedure

----------------------------------------
-- gtk_ctree_expand
----------------------------------------
constant gtk_ctree_expand_ = link_c_proc( GTK, 
  "gtk_ctree_expand", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_expand(atom ctree_, atom node_)
    c_proc( gtk_ctree_expand_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_expand_recursive
----------------------------------------
constant gtk_ctree_expand_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_expand_recursive", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_expand_recursive(atom ctree_, atom node_)
    c_proc( gtk_ctree_expand_recursive_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_expand_to_depth
----------------------------------------
constant gtk_ctree_expand_to_depth_ = link_c_proc( GTK, 
  "gtk_ctree_expand_to_depth", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_ctree_expand_to_depth(atom ctree_, atom node_, integer depth_)
    c_proc( gtk_ctree_expand_to_depth_, {ctree_,node_,depth_} )
end procedure

----------------------------------------
-- gtk_ctree_collapse
----------------------------------------
constant gtk_ctree_collapse_ = link_c_proc( GTK, 
  "gtk_ctree_collapse", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_collapse(atom ctree_, atom node_)
    c_proc( gtk_ctree_collapse_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_collapse_recursive
----------------------------------------
constant gtk_ctree_collapse_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_collapse_recursive", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_collapse_recursive(atom ctree_, atom node_)
    c_proc( gtk_ctree_collapse_recursive_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_collapse_to_depth
----------------------------------------
constant gtk_ctree_collapse_to_depth_ = link_c_proc( GTK, 
  "gtk_ctree_collapse_to_depth", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_ctree_collapse_to_depth(atom ctree_, atom node_, integer depth_)
    c_proc( gtk_ctree_collapse_to_depth_, {ctree_,node_,depth_} )
end procedure

----------------------------------------
-- gtk_ctree_toggle_expansion
----------------------------------------
constant gtk_ctree_toggle_expansion_ = link_c_proc( GTK, 
  "gtk_ctree_toggle_expansion", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_toggle_expansion(atom ctree_, atom node_)
    c_proc( gtk_ctree_toggle_expansion_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_toggle_expansion_recursive
----------------------------------------
constant gtk_ctree_toggle_expansion_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_toggle_expansion_recursive", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_toggle_expansion_recursive(atom ctree_, atom node_)
    c_proc( gtk_ctree_toggle_expansion_recursive_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_select
----------------------------------------
constant gtk_ctree_select_ = link_c_proc( GTK, 
  "gtk_ctree_select", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_select(atom ctree_, atom node_)
    c_proc( gtk_ctree_select_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_select_recursive
----------------------------------------
constant gtk_ctree_select_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_select_recursive", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_select_recursive(atom ctree_, atom node_)
    c_proc( gtk_ctree_select_recursive_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_unselect
----------------------------------------
constant gtk_ctree_unselect_ = link_c_proc( GTK, 
  "gtk_ctree_unselect", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_unselect(atom ctree_, atom node_)
    c_proc( gtk_ctree_unselect_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_unselect_recursive
----------------------------------------
constant gtk_ctree_unselect_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_unselect_recursive", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_unselect_recursive(atom ctree_, atom node_)
    c_proc( gtk_ctree_unselect_recursive_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_real_select_recursive
----------------------------------------
constant gtk_ctree_real_select_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_real_select_recursive", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_ctree_real_select_recursive(atom ctree_, atom node_, integer state_)
    c_proc( gtk_ctree_real_select_recursive_, {ctree_,node_,state_} )
end procedure

----------------------------------------
-- gtk_ctree_node_set_text
----------------------------------------
constant gtk_ctree_node_set_text_ = link_c_proc( GTK, 
  "gtk_ctree_node_set_text", {C_POINTER,C_POINTER,C_INT,C_POINTER} )

global procedure gtk_ctree_node_set_text(atom ctree_, atom node_, integer column_, sequence text_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_ctree_node_set_text_, {ctree_,node_,column_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_ctree_node_set_pixmap
----------------------------------------
constant gtk_ctree_node_set_pixmap_ = link_c_proc( GTK, 
  "gtk_ctree_node_set_pixmap", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_POINTER} )

global procedure gtk_ctree_node_set_pixmap(atom ctree_, atom node_, integer column_, atom pixmap_, atom mask_)
    c_proc( gtk_ctree_node_set_pixmap_, {ctree_,node_,column_,pixmap_,mask_} )
end procedure

----------------------------------------
-- gtk_ctree_node_set_pixtext
----------------------------------------
constant gtk_ctree_node_set_pixtext_ = link_c_proc( GTK, 
  "gtk_ctree_node_set_pixtext", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_UINT,C_POINTER,C_POINTER} 
 )

global procedure gtk_ctree_node_set_pixtext(atom ctree_, atom node_, integer column_, sequence text_, integer spacing_, atom pixmap_, atom mask_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_ctree_node_set_pixtext_, {ctree_,node_,column_,string1,spacing_,pixmap_,mask_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_ctree_set_node_info
----------------------------------------
constant gtk_ctree_set_node_info_ = link_c_proc( GTK, 
  "gtk_ctree_set_node_info", {C_POINTER,C_POINTER,C_POINTER,C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT} 
 )

global procedure gtk_ctree_set_node_info(atom ctree_, atom node_, sequence text_, integer spacing_, atom pixmap_closed_, 
 atom mask_closed_, atom pixmap_opened_, atom mask_opened_, integer is_leaf_, integer expanded_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_ctree_set_node_info_, {ctree_,node_,string1,spacing_,pixmap_closed_,mask_closed_,pixmap_opened_,mask_opened_,is_leaf_,expanded_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_ctree_node_set_shift
----------------------------------------
constant gtk_ctree_node_set_shift_ = link_c_proc( GTK, 
  "gtk_ctree_node_set_shift", {C_POINTER,C_POINTER,C_INT,C_INT,C_INT} )

global procedure gtk_ctree_node_set_shift(atom ctree_, atom node_, integer column_, integer vertical_, integer horizontal_)
    c_proc( gtk_ctree_node_set_shift_, {ctree_,node_,column_,vertical_,horizontal_} )
end procedure

----------------------------------------
-- gtk_ctree_node_set_selectable
----------------------------------------
constant gtk_ctree_node_set_selectable_ = link_c_proc( GTK, 
  "gtk_ctree_node_set_selectable", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_ctree_node_set_selectable(atom ctree_, atom node_, integer selectable_)
    c_proc( gtk_ctree_node_set_selectable_, {ctree_,node_,selectable_} )
end procedure

----------------------------------------
-- gtk_ctree_node_get_selectable
----------------------------------------
constant gtk_ctree_node_get_selectable_ = link_c_func( GTK, 
  "gtk_ctree_node_get_selectable", {C_POINTER,C_POINTER}, C_INT )

global function gtk_ctree_node_get_selectable(atom ctree_, atom node_)
    return c_func( gtk_ctree_node_get_selectable_, {ctree_,node_} )
end function

----------------------------------------
-- gtk_ctree_node_get_cell_type
----------------------------------------
constant gtk_ctree_node_get_cell_type_ = link_c_func( GTK, 
  "gtk_ctree_node_get_cell_type", {C_POINTER,C_POINTER,C_INT}, C_POINTER )

global function gtk_ctree_node_get_cell_type(atom ctree_, atom node_, integer column_)
    return c_func( gtk_ctree_node_get_cell_type_, {ctree_,node_,column_} )
end function

----------------------------------------
-- gtk_ctree_node_get_text
----------------------------------------
constant gtk_ctree_node_get_text_ = link_c_func( GTK, 
  "gtk_ctree_node_get_text", {C_POINTER,C_POINTER,C_INT,C_POINTER}, C_INT )

global function gtk_ctree_node_get_text(atom ctree_, atom node_, integer column_, sequence text_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gtk_ctree_node_get_text_, {ctree_,node_,column_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_ctree_node_get_pixmap
----------------------------------------
constant gtk_ctree_node_get_pixmap_ = link_c_func( GTK, 
  "gtk_ctree_node_get_pixmap", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_POINTER}, C_INT )

global function gtk_ctree_node_get_pixmap(atom ctree_, atom node_, integer column_, atom pixmap_, atom mask_)
    return c_func( gtk_ctree_node_get_pixmap_, {ctree_,node_,column_,pixmap_,mask_} )
end function

----------------------------------------
-- gtk_ctree_node_get_pixtext
----------------------------------------
constant gtk_ctree_node_get_pixtext_ = link_c_func( GTK, 
  "gtk_ctree_node_get_pixtext", {C_POINTER,C_POINTER,C_INT,C_POINTER,C_UINT,C_POINTER,C_POINTER}, 
 C_INT )

global function gtk_ctree_node_get_pixtext(atom ctree_, atom node_, integer column_, sequence text_, integer spacing_, atom pixmap_, atom mask_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gtk_ctree_node_get_pixtext_, {ctree_,node_,column_,string1,spacing_,pixmap_,mask_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_ctree_get_node_info
----------------------------------------
constant gtk_ctree_get_node_info_ = link_c_func( GTK, 
  "gtk_ctree_get_node_info", {C_POINTER,C_POINTER,C_POINTER,C_UINT,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT}, 
 C_INT )

global function gtk_ctree_get_node_info(atom ctree_, atom node_, sequence text_, integer spacing_, atom pixmap_closed_, 
 atom mask_closed_, atom pixmap_opened_, atom mask_opened_, integer is_leaf_, integer expanded_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gtk_ctree_get_node_info_, {ctree_,node_,string1,spacing_,pixmap_closed_,mask_closed_,pixmap_opened_,mask_opened_,is_leaf_,expanded_} 
 )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_ctree_node_set_row_style
----------------------------------------
constant gtk_ctree_node_set_row_style_ = link_c_proc( GTK, 
  "gtk_ctree_node_set_row_style", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_ctree_node_set_row_style(atom ctree_, atom node_, atom style_)
    c_proc( gtk_ctree_node_set_row_style_, {ctree_,node_,style_} )
end procedure

----------------------------------------
-- gtk_ctree_set_indent
----------------------------------------
constant gtk_ctree_set_indent_ = link_c_proc( GTK, 
  "gtk_ctree_set_indent", {C_POINTER,C_INT} )

global procedure gtk_ctree_set_indent(atom ctree_, integer indent_)
    c_proc( gtk_ctree_set_indent_, {ctree_,indent_} )
end procedure

----------------------------------------
-- gtk_ctree_set_spacing
----------------------------------------
constant gtk_ctree_set_spacing_ = link_c_proc( GTK, 
  "gtk_ctree_set_spacing", {C_POINTER,C_INT} )

global procedure gtk_ctree_set_spacing(atom ctree_, integer spacing_)
    c_proc( gtk_ctree_set_spacing_, {ctree_,spacing_} )
end procedure

----------------------------------------
-- gtk_ctree_set_show_stub
----------------------------------------
constant gtk_ctree_set_show_stub_ = link_c_proc( GTK, 
  "gtk_ctree_set_show_stub", {C_POINTER,C_INT} )

global procedure gtk_ctree_set_show_stub(atom ctree_, integer show_stub_)
    c_proc( gtk_ctree_set_show_stub_, {ctree_,show_stub_} )
end procedure

----------------------------------------
-- gtk_ctree_set_line_style
----------------------------------------
constant gtk_ctree_set_line_style_ = link_c_proc( GTK, 
  "gtk_ctree_set_line_style", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_set_line_style(atom ctree_, atom line_style_)
    c_proc( gtk_ctree_set_line_style_, {ctree_,line_style_} )
end procedure

----------------------------------------
-- gtk_ctree_set_expander_style
----------------------------------------
constant gtk_ctree_set_expander_style_ = link_c_proc( GTK, 
  "gtk_ctree_set_expander_style", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_set_expander_style(atom ctree_, atom expander_style_)
    c_proc( gtk_ctree_set_expander_style_, {ctree_,expander_style_} )
end procedure

----------------------------------------
-- gtk_ctree_set_drag_compare_func
----------------------------------------
constant gtk_ctree_set_drag_compare_func_ = link_c_proc( GTK, 
  "gtk_ctree_set_drag_compare_func", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_set_drag_compare_func(atom ctree_, atom cmp_func_)
    c_proc( gtk_ctree_set_drag_compare_func_, {ctree_,cmp_func_} )
end procedure

----------------------------------------
-- gtk_ctree_sort_node
----------------------------------------
constant gtk_ctree_sort_node_ = link_c_proc( GTK, 
  "gtk_ctree_sort_node", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_sort_node(atom ctree_, atom node_)
    c_proc( gtk_ctree_sort_node_, {ctree_,node_} )
end procedure

----------------------------------------
-- gtk_ctree_sort_recursive
----------------------------------------
constant gtk_ctree_sort_recursive_ = link_c_proc( GTK, 
  "gtk_ctree_sort_recursive", {C_POINTER,C_POINTER} )

global procedure gtk_ctree_sort_recursive(atom ctree_, atom node_)
    c_proc( gtk_ctree_sort_recursive_, {ctree_,node_} )
end procedure


----------------------------------------
----------------------------------------
-- GTKDRAWINGAREA.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkDrawingArea
----------------------------------------
global constant
    GtkDrawingArea_widget               = allot(SIZEOF_GtkWidget),
    GtkDrawingArea_draw_data            = allot(TYPE_GPOINTER),
    SIZEOF_GtkDrawingArea               = allotted_size()

----------------------------------------
-- GtkDrawingAreaClass
----------------------------------------
global constant
    GtkDrawingAreaClass_parent_class    = allot(SIZEOF_GtkWidgetClass),
    SIZEOF_GtkDrawingAreaClass          = allotted_size()
----------------------------------------
-- gtk_drawing_area_get_type
----------------------------------------
constant gtk_drawing_area_get_type_ = link_c_func( GTK, 
  "gtk_drawing_area_get_type", {}, C_UINT )

global function gtk_drawing_area_get_type()
    return c_func( gtk_drawing_area_get_type_, {} )
end function

----------------------------------------
-- gtk_drawing_area_new
----------------------------------------
constant gtk_drawing_area_new_ = link_c_func( GTK, 
  "gtk_drawing_area_new", {}, C_POINTER )

global function gtk_drawing_area_new()
    return c_func( gtk_drawing_area_new_, {} )
end function

----------------------------------------
-- gtk_drawing_area_size
----------------------------------------
constant gtk_drawing_area_size_ = link_c_proc( GTK, 
  "gtk_drawing_area_size", {C_POINTER,C_INT,C_INT} )

global procedure gtk_drawing_area_size(atom darea_, integer width_, integer height_)
    c_proc( gtk_drawing_area_size_, {darea_,width_,height_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKCURVE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkCurve
----------------------------------------
global constant
    GtkCurve_graph                      = allot(SIZEOF_GtkDrawingArea),
    GtkCurve_cursor_type                = allot(TYPE_GINT),
    GtkCurve_min_x                      = allot(TYPE_GFLOAT),
    GtkCurve_max_x                      = allot(TYPE_GFLOAT),
    GtkCurve_min_y                      = allot(TYPE_GFLOAT),
    GtkCurve_max_y                      = allot(TYPE_GFLOAT),
    GtkCurve_pixmap                     = allot(TYPE_POINTER),
    GtkCurve_curve_type                 = allot(SIZEOF_GtkCurveType),
    GtkCurve_height                     = allot(TYPE_GINT),
    GtkCurve_grab_point                 = allot(TYPE_GINT),
    GtkCurve_last                       = allot(TYPE_GINT),
    GtkCurve_num_points                 = allot(TYPE_GINT),
    GtkCurve_point                      = allot(TYPE_POINTER),
    GtkCurve_num_ctlpoints              = allot(TYPE_GINT),
    GtkCurve_ctlpoint                   = allot(TYPE_GPOINTER),
    SIZEOF_GtkCurve                     = allotted_size()

----------------------------------------
-- GtkCurveClass
----------------------------------------
global constant
    GtkCurveClass_parent_class          = allot(SIZEOF_GtkDrawingAreaClass),
    GtkCurveClass_curve_type_changed    = allot(TYPE_GPOINTER),
    SIZEOF_GtkCurveClass                = allotted_size()
----------------------------------------
-- gtk_curve_get_type
----------------------------------------
constant gtk_curve_get_type_ = link_c_func( GTK, 
  "gtk_curve_get_type", {}, C_UINT )

global function gtk_curve_get_type()
    return c_func( gtk_curve_get_type_, {} )
end function

----------------------------------------
-- gtk_curve_new
----------------------------------------
constant gtk_curve_new_ = link_c_func( GTK, 
  "gtk_curve_new", {}, C_POINTER )

global function gtk_curve_new()
    return c_func( gtk_curve_new_, {} )
end function

----------------------------------------
-- gtk_curve_reset
----------------------------------------
constant gtk_curve_reset_ = link_c_proc( GTK, 
  "gtk_curve_reset", {C_POINTER} )

global procedure gtk_curve_reset(atom curve_)
    c_proc( gtk_curve_reset_, {curve_} )
end procedure

----------------------------------------
-- gtk_curve_set_gamma
----------------------------------------
constant gtk_curve_set_gamma_ = link_c_proc( GTK, 
  "gtk_curve_set_gamma", {C_POINTER} )

global procedure gtk_curve_set_gamma(atom curve_)
    c_proc( gtk_curve_set_gamma_, {curve_} )
end procedure

----------------------------------------
-- gtk_curve_set_range
----------------------------------------
constant gtk_curve_set_range_ = link_c_proc( GTK, 
  "gtk_curve_set_range", {C_POINTER,C_LONG,C_LONG} )

global procedure gtk_curve_set_range(atom curve_, integer min_x_, integer min_y_)
    c_proc( gtk_curve_set_range_, {curve_,min_x_,min_y_} )
end procedure

----------------------------------------
-- gtk_curve_get_vector
----------------------------------------
constant gtk_curve_get_vector_ = link_c_proc( GTK, 
  "gtk_curve_get_vector", {C_POINTER,C_INT} )

global procedure gtk_curve_get_vector(atom curve_, integer veclen_)
    c_proc( gtk_curve_get_vector_, {curve_,veclen_} )
end procedure

----------------------------------------
-- gtk_curve_set_vector
----------------------------------------
constant gtk_curve_set_vector_ = link_c_proc( GTK, 
  "gtk_curve_set_vector", {C_POINTER,C_INT} )

global procedure gtk_curve_set_vector(atom curve_, integer veclen_)
    c_proc( gtk_curve_set_vector_, {curve_,veclen_} )
end procedure

----------------------------------------
-- gtk_curve_set_curve_type
----------------------------------------
constant gtk_curve_set_curve_type_ = link_c_proc( GTK, 
  "gtk_curve_set_curve_type", {C_POINTER} )

global procedure gtk_curve_set_curve_type(atom curve_)
    c_proc( gtk_curve_set_curve_type_, {curve_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKDIALOG.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkDialog
----------------------------------------
global constant
    GtkDialog_window                    = allot(SIZEOF_GtkWindow),
    GtkDialog_vbox                      = allot(TYPE_POINTER),
    GtkDialog_action_area               = allot(TYPE_POINTER),
    SIZEOF_GtkDialog                    = allotted_size()

----------------------------------------
-- GtkDialogClass
----------------------------------------
global constant
    GtkDialogClass_parent_class         = allot(SIZEOF_GtkWindowClass),
    SIZEOF_GtkDialogClass               = allotted_size()
----------------------------------------
-- gtk_dialog_get_type
----------------------------------------
constant gtk_dialog_get_type_ = link_c_func( GTK, 
  "gtk_dialog_get_type", {}, C_UINT )

global function gtk_dialog_get_type()
    return c_func( gtk_dialog_get_type_, {} )
end function

----------------------------------------
-- gtk_dialog_new
----------------------------------------
constant gtk_dialog_new_ = link_c_func( GTK, 
  "gtk_dialog_new", {}, C_POINTER )

global function gtk_dialog_new()
    return c_func( gtk_dialog_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKDND.H
----------------------------------------
----------------------------------------


global constant
    GTK_DEST_DEFAULT_MOTION             = power(2,0),
    GTK_DEST_DEFAULT_HIGHLIGHT          = power(2,1),
    GTK_DEST_DEFAULT_DROP               = power(2,2),
    GTK_DEST_DEFAULT_ALL                = #07
global constant SIZEOF_GtkDestDefaults = SIZEOF_ENUM

global constant
    GTK_TARGET_SAME_APP                 = power(2,0),
    GTK_TARGET_SAME_WIDGET              = power(2,1)
global constant SIZEOF_GtkTargetFlags = SIZEOF_ENUM

----------------------------------------
-- gtk_drag_get_data
----------------------------------------
constant gtk_drag_get_data_ = link_c_proc( GTK, 
  "gtk_drag_get_data", {C_POINTER,C_POINTER,C_ULONG,C_UINT} )

global procedure gtk_drag_get_data(atom widget_, atom context_, atom target_, atom time_)
    c_proc( gtk_drag_get_data_, {widget_,context_,target_,time_} )
end procedure

----------------------------------------
-- gtk_drag_finish
----------------------------------------
constant gtk_drag_finish_ = link_c_proc( GTK, 
  "gtk_drag_finish", {C_POINTER,C_INT,C_INT,C_UINT} )

global procedure gtk_drag_finish(atom context_, integer success_, integer del_, atom time_)
    c_proc( gtk_drag_finish_, {context_,success_,del_,time_} )
end procedure

----------------------------------------
-- gtk_drag_get_source_widget
----------------------------------------
constant gtk_drag_get_source_widget_ = link_c_func( GTK, 
  "gtk_drag_get_source_widget", {C_POINTER}, C_POINTER )

global function gtk_drag_get_source_widget(atom context_)
    return c_func( gtk_drag_get_source_widget_, {context_} )
end function

----------------------------------------
-- gtk_drag_highlight
----------------------------------------
constant gtk_drag_highlight_ = link_c_proc( GTK, 
  "gtk_drag_highlight", {C_POINTER} )

global procedure gtk_drag_highlight(atom widget_)
    c_proc( gtk_drag_highlight_, {widget_} )
end procedure

----------------------------------------
-- gtk_drag_unhighlight
----------------------------------------
constant gtk_drag_unhighlight_ = link_c_proc( GTK, 
  "gtk_drag_unhighlight", {C_POINTER} )

global procedure gtk_drag_unhighlight(atom widget_)
    c_proc( gtk_drag_unhighlight_, {widget_} )
end procedure

----------------------------------------
-- gtk_drag_dest_set
----------------------------------------
constant gtk_drag_dest_set_ = link_c_proc( GTK, 
  "gtk_drag_dest_set", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_POINTER} )

global procedure gtk_drag_dest_set(atom widget_, atom flags_, atom targets_, integer n_targets_, atom actions_)
    c_proc( gtk_drag_dest_set_, {widget_,flags_,targets_,n_targets_,actions_} )
end procedure

----------------------------------------
-- gtk_drag_dest_set_proxy
----------------------------------------
constant gtk_drag_dest_set_proxy_ = link_c_proc( GTK, 
  "gtk_drag_dest_set_proxy", {C_POINTER,C_POINTER,C_POINTER,C_INT} )

global procedure gtk_drag_dest_set_proxy(atom widget_, atom proxy_window_, atom protocol_, integer use_coordinates_)
    c_proc( gtk_drag_dest_set_proxy_, {widget_,proxy_window_,protocol_,use_coordinates_} )
end procedure

----------------------------------------
-- gtk_drag_dest_unset
----------------------------------------
constant gtk_drag_dest_unset_ = link_c_proc( GTK, 
  "gtk_drag_dest_unset", {C_POINTER} )

global procedure gtk_drag_dest_unset(atom widget_)
    c_proc( gtk_drag_dest_unset_, {widget_} )
end procedure

----------------------------------------
-- gtk_drag_source_set
----------------------------------------
constant gtk_drag_source_set_ = link_c_proc( GTK, 
  "gtk_drag_source_set", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_POINTER} )

global procedure gtk_drag_source_set(atom widget_, atom start_button_mask_, atom targets_, integer n_targets_, atom actions_)
    c_proc( gtk_drag_source_set_, {widget_,start_button_mask_,targets_,n_targets_,actions_} )
end procedure

----------------------------------------
-- gtk_drag_source_unset
----------------------------------------
constant gtk_drag_source_unset_ = link_c_proc( GTK, 
  "gtk_drag_source_unset", {C_POINTER} )

global procedure gtk_drag_source_unset(atom widget_)
    c_proc( gtk_drag_source_unset_, {widget_} )
end procedure

----------------------------------------
-- gtk_drag_source_set_icon
----------------------------------------
constant gtk_drag_source_set_icon_ = link_c_proc( GTK, 
  "gtk_drag_source_set_icon", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_drag_source_set_icon(atom widget_, atom colormap_, atom pixmap_, atom mask_)
    c_proc( gtk_drag_source_set_icon_, {widget_,colormap_,pixmap_,mask_} )
end procedure

----------------------------------------
-- gtk_drag_begin
----------------------------------------
constant gtk_drag_begin_ = link_c_func( GTK, 
  "gtk_drag_begin", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_POINTER}, C_POINTER )

global function gtk_drag_begin(atom widget_, atom targets_, atom actions_, integer button_, atom event_)
    return c_func( gtk_drag_begin_, {widget_,targets_,actions_,button_,event_} )
end function

----------------------------------------
-- gtk_drag_set_icon_widget
----------------------------------------
constant gtk_drag_set_icon_widget_ = link_c_proc( GTK, 
  "gtk_drag_set_icon_widget", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_drag_set_icon_widget(atom context_, atom widget_, integer hot_x_, integer hot_y_)
    c_proc( gtk_drag_set_icon_widget_, {context_,widget_,hot_x_,hot_y_} )
end procedure

----------------------------------------
-- gtk_drag_set_icon_pixmap
----------------------------------------
constant gtk_drag_set_icon_pixmap_ = link_c_proc( GTK, 
  "gtk_drag_set_icon_pixmap", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_drag_set_icon_pixmap(atom context_, atom colormap_, atom pixmap_, atom mask_, integer hot_x_, integer hot_y_)
    c_proc( gtk_drag_set_icon_pixmap_, {context_,colormap_,pixmap_,mask_,hot_x_,hot_y_} )
end procedure

----------------------------------------
-- gtk_drag_set_icon_default
----------------------------------------
constant gtk_drag_set_icon_default_ = link_c_proc( GTK, 
  "gtk_drag_set_icon_default", {C_POINTER} )

global procedure gtk_drag_set_icon_default(atom context_)
    c_proc( gtk_drag_set_icon_default_, {context_} )
end procedure

----------------------------------------
-- gtk_drag_set_default_icon
----------------------------------------
constant gtk_drag_set_default_icon_ = link_c_proc( GTK, 
  "gtk_drag_set_default_icon", {C_POINTER,C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_drag_set_default_icon(atom colormap_, atom pixmap_, atom mask_, integer hot_x_, integer hot_y_)
    c_proc( gtk_drag_set_default_icon_, {colormap_,pixmap_,mask_,hot_x_,hot_y_} )
end procedure

----------------------------------------
-- gtk_drag_source_handle_event
----------------------------------------
constant gtk_drag_source_handle_event_ = link_c_proc( GTK, 
  "gtk_drag_source_handle_event", {C_POINTER,C_POINTER} )

global procedure gtk_drag_source_handle_event(atom widget_, atom event_)
    c_proc( gtk_drag_source_handle_event_, {widget_,event_} )
end procedure

----------------------------------------
-- gtk_drag_dest_handle_event
----------------------------------------
constant gtk_drag_dest_handle_event_ = link_c_proc( GTK, 
  "gtk_drag_dest_handle_event", {C_POINTER,C_POINTER} )

global procedure gtk_drag_dest_handle_event(atom toplevel_, atom event_)
    c_proc( gtk_drag_dest_handle_event_, {toplevel_,event_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKSELECTION.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkTargetEntry
----------------------------------------
global constant
    GtkTargetEntry_target               = allot(TYPE_POINTER),
    GtkTargetEntry_flags                = allot(TYPE_GUINT),
    GtkTargetEntry_info                 = allot(TYPE_GUINT),
    SIZEOF_GtkTargetEntry               = allotted_size()

----------------------------------------
-- GtkTargetList
----------------------------------------
global constant
    GtkTargetList_list                  = allot(TYPE_POINTER),
    GtkTargetList_ref_count             = allot(TYPE_GUINT),
    SIZEOF_GtkTargetList                = allotted_size()

----------------------------------------
-- GtkTargetPair
----------------------------------------
global constant
    GtkTargetPair_target                = allot(TYPE_GULONG),
    GtkTargetPair_flags                 = allot(TYPE_GUINT),
    GtkTargetPair_info                  = allot(TYPE_GUINT),
    SIZEOF_GtkTargetPair                = allotted_size()
----------------------------------------
-- gtk_target_list_new
----------------------------------------
constant gtk_target_list_new_ = link_c_func( GTK, 
  "gtk_target_list_new", {C_POINTER,C_UINT}, C_POINTER )

global function gtk_target_list_new(atom const_, integer ntargets_)
    return c_func( gtk_target_list_new_, {const_,ntargets_} )
end function

----------------------------------------
-- gtk_target_list_ref
----------------------------------------
constant gtk_target_list_ref_ = link_c_proc( GTK, 
  "gtk_target_list_ref", {C_POINTER} )

global procedure gtk_target_list_ref(atom list_)
    c_proc( gtk_target_list_ref_, {list_} )
end procedure

----------------------------------------
-- gtk_target_list_unref
----------------------------------------
constant gtk_target_list_unref_ = link_c_proc( GTK, 
  "gtk_target_list_unref", {C_POINTER} )

global procedure gtk_target_list_unref(atom list_)
    c_proc( gtk_target_list_unref_, {list_} )
end procedure

----------------------------------------
-- gtk_target_list_add
----------------------------------------
constant gtk_target_list_add_ = link_c_proc( GTK, 
  "gtk_target_list_add", {C_POINTER,C_ULONG,C_UINT,C_UINT} )

global procedure gtk_target_list_add(atom list_, atom target_, integer flags_, integer info_)
    c_proc( gtk_target_list_add_, {list_,target_,flags_,info_} )
end procedure

----------------------------------------
-- gtk_target_list_add_table
----------------------------------------
constant gtk_target_list_add_table_ = link_c_proc( GTK, 
  "gtk_target_list_add_table", {C_POINTER,C_POINTER,C_UINT} )

global procedure gtk_target_list_add_table(atom list_, atom targets_, integer ntargets_)
    c_proc( gtk_target_list_add_table_, {list_,targets_,ntargets_} )
end procedure

----------------------------------------
-- gtk_target_list_remove
----------------------------------------
constant gtk_target_list_remove_ = link_c_proc( GTK, 
  "gtk_target_list_remove", {C_POINTER,C_ULONG} )

global procedure gtk_target_list_remove(atom list_, atom target_)
    c_proc( gtk_target_list_remove_, {list_,target_} )
end procedure

----------------------------------------
-- gtk_target_list_find
----------------------------------------
constant gtk_target_list_find_ = link_c_func( GTK, 
  "gtk_target_list_find", {C_POINTER,C_ULONG,C_UINT}, C_INT )

global function gtk_target_list_find(atom list_, atom target_, integer info_)
    return c_func( gtk_target_list_find_, {list_,target_,info_} )
end function

----------------------------------------
-- gtk_selection_owner_set
----------------------------------------
constant gtk_selection_owner_set_ = link_c_func( GTK, 
  "gtk_selection_owner_set", {C_POINTER,C_ULONG,C_UINT}, C_INT )

global function gtk_selection_owner_set(atom widget_, atom selection_, atom time_)
    return c_func( gtk_selection_owner_set_, {widget_,selection_,time_} )
end function

----------------------------------------
-- gtk_selection_add_target
----------------------------------------
constant gtk_selection_add_target_ = link_c_proc( GTK, 
  "gtk_selection_add_target", {C_POINTER,C_ULONG,C_ULONG,C_UINT} )

global procedure gtk_selection_add_target(atom widget_, atom selection_, atom target_, integer info_)
    c_proc( gtk_selection_add_target_, {widget_,selection_,target_,info_} )
end procedure

----------------------------------------
-- gtk_selection_add_targets
----------------------------------------
constant gtk_selection_add_targets_ = link_c_proc( GTK, 
  "gtk_selection_add_targets", {C_POINTER,C_ULONG,C_POINTER,C_UINT} )

global procedure gtk_selection_add_targets(atom widget_, atom selection_, atom targets_, integer ntargets_)
    c_proc( gtk_selection_add_targets_, {widget_,selection_,targets_,ntargets_} )
end procedure

----------------------------------------
-- gtk_selection_convert
----------------------------------------
constant gtk_selection_convert_ = link_c_func( GTK, 
  "gtk_selection_convert", {C_POINTER,C_ULONG,C_ULONG,C_UINT}, C_INT )

global function gtk_selection_convert(atom widget_, atom selection_, atom target_, atom time_)
    return c_func( gtk_selection_convert_, {widget_,selection_,target_,time_} )
end function

----------------------------------------
-- gtk_selection_data_set
----------------------------------------
constant gtk_selection_data_set_ = link_c_proc( GTK, 
  "gtk_selection_data_set", {C_POINTER,C_ULONG,C_INT,C_UINT,C_INT} )

global procedure gtk_selection_data_set(atom selection_data_, atom type_, integer format_, integer data_, integer length_)
    c_proc( gtk_selection_data_set_, {selection_data_,type_,format_,data_,length_} )
end procedure

----------------------------------------
-- gtk_selection_remove_all
----------------------------------------
constant gtk_selection_remove_all_ = link_c_proc( GTK, 
  "gtk_selection_remove_all", {C_POINTER} )

global procedure gtk_selection_remove_all(atom widget_)
    c_proc( gtk_selection_remove_all_, {widget_} )
end procedure

----------------------------------------
-- gtk_selection_clear
----------------------------------------
constant gtk_selection_clear_ = link_c_func( GTK, 
  "gtk_selection_clear", {C_POINTER,C_POINTER}, C_INT )

global function gtk_selection_clear(atom widget_, atom event_)
    return c_func( gtk_selection_clear_, {widget_,event_} )
end function

----------------------------------------
-- gtk_selection_request
----------------------------------------
constant gtk_selection_request_ = link_c_func( GTK, 
  "gtk_selection_request", {C_POINTER,C_POINTER}, C_INT )

global function gtk_selection_request(atom widget_, atom event_)
    return c_func( gtk_selection_request_, {widget_,event_} )
end function

----------------------------------------
-- gtk_selection_incr_event
----------------------------------------
constant gtk_selection_incr_event_ = link_c_func( GTK, 
  "gtk_selection_incr_event", {C_POINTER,C_POINTER}, C_INT )

global function gtk_selection_incr_event(atom window_, atom event_)
    return c_func( gtk_selection_incr_event_, {window_,event_} )
end function

----------------------------------------
-- gtk_selection_notify
----------------------------------------
constant gtk_selection_notify_ = link_c_func( GTK, 
  "gtk_selection_notify", {C_POINTER,C_POINTER}, C_INT )

global function gtk_selection_notify(atom widget_, atom event_)
    return c_func( gtk_selection_notify_, {widget_,event_} )
end function

----------------------------------------
-- gtk_selection_property_notify
----------------------------------------
constant gtk_selection_property_notify_ = link_c_func( GTK, 
  "gtk_selection_property_notify", {C_POINTER,C_POINTER}, C_INT )

global function gtk_selection_property_notify(atom widget_, atom event_)
    return c_func( gtk_selection_property_notify_, {widget_,event_} )
end function

----------------------------------------
-- gtk_selection_data_copy
----------------------------------------
constant gtk_selection_data_copy_ = link_c_func( GTK, 
  "gtk_selection_data_copy", {C_POINTER}, C_POINTER )

global function gtk_selection_data_copy(atom data_)
    return c_func( gtk_selection_data_copy_, {data_} )
end function

----------------------------------------
-- gtk_selection_data_free
----------------------------------------
constant gtk_selection_data_free_ = link_c_proc( GTK, 
  "gtk_selection_data_free", {C_POINTER} )

global procedure gtk_selection_data_free(atom data_)
    c_proc( gtk_selection_data_free_, {data_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKFILESEL.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkFileSelection
----------------------------------------
global constant
    GtkFileSelection_window             = allot(SIZEOF_GtkWindow),
    GtkFileSelection_dir_list           = allot(TYPE_POINTER),
    GtkFileSelection_file_list          = allot(TYPE_POINTER),
    GtkFileSelection_selection_entry    = allot(TYPE_POINTER),
    GtkFileSelection_selection_text     = allot(TYPE_POINTER),
    GtkFileSelection_main_vbox          = allot(TYPE_POINTER),
    GtkFileSelection_ok_button          = allot(TYPE_POINTER),
    GtkFileSelection_cancel_button      = allot(TYPE_POINTER),
    GtkFileSelection_help_button        = allot(TYPE_POINTER),
    GtkFileSelection_history_pulldown   = allot(TYPE_POINTER),
    GtkFileSelection_history_menu       = allot(TYPE_POINTER),
    GtkFileSelection_history_list       = allot(TYPE_POINTER),
    GtkFileSelection_fileop_dialog      = allot(TYPE_POINTER),
    GtkFileSelection_fileop_entry       = allot(TYPE_POINTER),
    GtkFileSelection_fileop_file        = allot(TYPE_POINTER),
    GtkFileSelection_cmpl_state         = allot(TYPE_GPOINTER),
    GtkFileSelection_fileop_c_dir       = allot(TYPE_POINTER),
    GtkFileSelection_fileop_del_file    = allot(TYPE_POINTER),
    GtkFileSelection_fileop_ren_file    = allot(TYPE_POINTER),
    GtkFileSelection_button_area        = allot(TYPE_POINTER),
    GtkFileSelection_action_area        = allot(TYPE_POINTER),
    SIZEOF_GtkFileSelection             = allotted_size()

----------------------------------------
-- GtkFileSelectionClass
----------------------------------------
global constant
    GtkFileSelectionClass_parent_class  = allot(SIZEOF_GtkWindowClass),
    SIZEOF_GtkFileSelectionClass        = allotted_size()
----------------------------------------
-- gtk_file_selection_get_type
----------------------------------------
constant gtk_file_selection_get_type_ = link_c_func( GTK, 
  "gtk_file_selection_get_type", {}, C_UINT )

global function gtk_file_selection_get_type()
    return c_func( gtk_file_selection_get_type_, {} )
end function

----------------------------------------
-- gtk_file_selection_new
----------------------------------------
constant gtk_file_selection_new_ = link_c_func( GTK, 
  "gtk_file_selection_new", {C_POINTER}, C_POINTER )

global function gtk_file_selection_new(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_file_selection_new_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_file_selection_set_filename
----------------------------------------
constant gtk_file_selection_set_filename_ = link_c_proc( GTK, 
  "gtk_file_selection_set_filename", {C_POINTER,C_POINTER} )

global procedure gtk_file_selection_set_filename(atom filesel_, sequence filename_)
    atom string1
    string1 = allocate_string( filename_ )
    c_proc( gtk_file_selection_set_filename_, {filesel_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_file_selection_get_filename
----------------------------------------
constant gtk_file_selection_get_filename_ = link_c_func( GTK, 
  "gtk_file_selection_get_filename", {C_POINTER}, C_POINTER )

global function gtk_file_selection_get_filename(atom filesel_)
    return peek_string( c_func( gtk_file_selection_get_filename_, {filesel_} ) )
end function

----------------------------------------
-- gtk_file_selection_complete
----------------------------------------
constant gtk_file_selection_complete_ = link_c_proc( GTK, 
  "gtk_file_selection_complete", {C_POINTER,C_POINTER} )

global procedure gtk_file_selection_complete(atom filesel_, sequence pattern_)
    atom string1
    string1 = allocate_string( pattern_ )
    c_proc( gtk_file_selection_complete_, {filesel_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_file_selection_show_fileop_buttons
----------------------------------------
constant gtk_file_selection_show_fileop_buttons_ = link_c_proc( GTK, 
  "gtk_file_selection_show_fileop_buttons", {C_POINTER} )

global procedure gtk_file_selection_show_fileop_buttons(atom filesel_)
    c_proc( gtk_file_selection_show_fileop_buttons_, {filesel_} )
end procedure

----------------------------------------
-- gtk_file_selection_hide_fileop_buttons
----------------------------------------
constant gtk_file_selection_hide_fileop_buttons_ = link_c_proc( GTK, 
  "gtk_file_selection_hide_fileop_buttons", {C_POINTER} )

global procedure gtk_file_selection_hide_fileop_buttons(atom filesel_)
    c_proc( gtk_file_selection_hide_fileop_buttons_, {filesel_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKFIXED.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkFixed
----------------------------------------
global constant
    GtkFixed_container                  = allot(SIZEOF_GtkContainer),
    GtkFixed_children                   = allot(TYPE_POINTER),
    SIZEOF_GtkFixed                     = allotted_size()

----------------------------------------
-- GtkFixedClass
----------------------------------------
global constant
    GtkFixedClass_parent_class          = allot(SIZEOF_GtkContainerClass),
    SIZEOF_GtkFixedClass                = allotted_size()

----------------------------------------
-- GtkFixedChild
----------------------------------------
global constant
    GtkFixedChild_widget                = allot(TYPE_POINTER),
    GtkFixedChild_x                     = allot(TYPE_GINT16),
    GtkFixedChild_y                     = allot(TYPE_GINT16),
    SIZEOF_GtkFixedChild                = allotted_size()
----------------------------------------
-- gtk_fixed_get_type
----------------------------------------
constant gtk_fixed_get_type_ = link_c_func( GTK, 
  "gtk_fixed_get_type", {}, C_UINT )

global function gtk_fixed_get_type()
    return c_func( gtk_fixed_get_type_, {} )
end function

----------------------------------------
-- gtk_fixed_new
----------------------------------------
constant gtk_fixed_new_ = link_c_func( GTK, 
  "gtk_fixed_new", {}, C_POINTER )

global function gtk_fixed_new()
    return c_func( gtk_fixed_new_, {} )
end function

----------------------------------------
-- gtk_fixed_put
----------------------------------------
constant gtk_fixed_put_ = link_c_proc( GTK, 
  "gtk_fixed_put", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_fixed_put(atom fixed_, atom widget_, integer x_, integer y_)
    c_proc( gtk_fixed_put_, {fixed_,widget_,x_,y_} )
end procedure

----------------------------------------
-- gtk_fixed_move
----------------------------------------
constant gtk_fixed_move_ = link_c_proc( GTK, 
  "gtk_fixed_move", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_fixed_move(atom fixed_, atom widget_, integer x_, integer y_)
    c_proc( gtk_fixed_move_, {fixed_,widget_,x_,y_} )
end procedure


----------------------------------------
----------------------------------------
-- GTKNOTEBOOK.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkNotebook
----------------------------------------
global constant
    GtkNotebook_container               = allot(SIZEOF_GtkContainer),
    GtkNotebook_cur_page                = allot(TYPE_POINTER),
    GtkNotebook_children                = allot(TYPE_POINTER),
    GtkNotebook_first_tab               = allot(TYPE_POINTER),
    GtkNotebook_focus_tab               = allot(TYPE_POINTER),
    GtkNotebook_menu                    = allot(TYPE_POINTER),
    GtkNotebook_panel                   = allot(TYPE_POINTER),
    GtkNotebook_timer                   = allot(TYPE_GUINT32),
    GtkNotebook_tab_hborder             = allot(TYPE_GUINT16),
    GtkNotebook_tab_vborder             = allot(TYPE_GUINT16),
    GtkNotebook_show_tabs               = allot(TYPE_GUINT),
    GtkNotebook_homogeneous             = allot(TYPE_GUINT),
    GtkNotebook_show_border             = allot(TYPE_GUINT),
    GtkNotebook_tab_pos                 = allot(TYPE_GUINT),
    GtkNotebook_scrollable              = allot(TYPE_GUINT),
    GtkNotebook_in_child                = allot(TYPE_GUINT),
    GtkNotebook_click_child             = allot(TYPE_GUINT),
    GtkNotebook_button                  = allot(TYPE_GUINT),
    GtkNotebook_need_timer              = allot(TYPE_GUINT),
    GtkNotebook_child_has_focus         = allot(TYPE_GUINT),
    GtkNotebook_have_visible_child      = allot(TYPE_GUINT),
    SIZEOF_GtkNotebook                  = allotted_size()

----------------------------------------
-- GtkNotebookClass
----------------------------------------
global constant
    GtkNotebookClass_parent_class       = allot(SIZEOF_GtkContainerClass),
    GtkNotebookClass_switch_page        = allot(TYPE_GPOINTER),
    SIZEOF_GtkNotebookClass             = allotted_size()

----------------------------------------
-- GtkNotebookPage
----------------------------------------
global constant
    GtkNotebookPage_child               = allot(TYPE_POINTER),
    GtkNotebookPage_tab_label           = allot(TYPE_POINTER),
    GtkNotebookPage_menu_label          = allot(TYPE_POINTER),
    GtkNotebookPage_default_menu        = allot(TYPE_GUINT),
    GtkNotebookPage_default_tab         = allot(TYPE_GUINT),
    GtkNotebookPage_expand              = allot(TYPE_GUINT),
    GtkNotebookPage_fill                = allot(TYPE_GUINT),
    GtkNotebookPage_pack                = allot(TYPE_GUINT),
    GtkNotebookPage_requisition         = allot(SIZEOF_GtkRequisition),
    GtkNotebookPage_allocation          = allot(SIZEOF_GtkAllocation),
    SIZEOF_GtkNotebookPage              = allotted_size()
----------------------------------------
-- gtk_notebook_get_type
----------------------------------------
constant gtk_notebook_get_type_ = link_c_func( GTK, 
  "gtk_notebook_get_type", {}, C_UINT )

global function gtk_notebook_get_type()
    return c_func( gtk_notebook_get_type_, {} )
end function

----------------------------------------
-- gtk_notebook_get_current_page
----------------------------------------
constant gtk_notebook_get_current_page_ = link_c_func( GTK, 
  "gtk_notebook_get_current_page", {C_POINTER}, C_INT )

global function gtk_notebook_get_current_page(atom notebook_)
    return c_func( gtk_notebook_get_current_page_, {notebook_} )
end function

----------------------------------------
-- gtk_notebook_get_nth_page
----------------------------------------
constant gtk_notebook_get_nth_page_ = link_c_func( GTK, 
  "gtk_notebook_get_nth_page", {C_POINTER,C_INT}, C_POINTER )

global function gtk_notebook_get_nth_page(atom notebook_, integer page_num_)
    return c_func( gtk_notebook_get_nth_page_, {notebook_,page_num_} )
end function

----------------------------------------
-- gtk_notebook_page_num
----------------------------------------
constant gtk_notebook_page_num_ = link_c_func( GTK, 
  "gtk_notebook_page_num", {C_POINTER,C_POINTER}, C_INT )

global function gtk_notebook_page_num(atom notebook_, atom child_)
    return c_func( gtk_notebook_page_num_, {notebook_,child_} )
end function

----------------------------------------
-- gtk_notebook_set_page
----------------------------------------
constant gtk_notebook_set_page_ = link_c_proc( GTK, 
  "gtk_notebook_set_page", {C_POINTER,C_INT} )

global procedure gtk_notebook_set_page(atom notebook_, integer page_num_)
    c_proc( gtk_notebook_set_page_, {notebook_,page_num_} )
end procedure

----------------------------------------
-- gtk_notebook_next_page
----------------------------------------
constant gtk_notebook_next_page_ = link_c_proc( GTK, 
  "gtk_notebook_next_page", {C_POINTER} )

global procedure gtk_notebook_next_page(atom notebook_)
    c_proc( gtk_notebook_next_page_, {notebook_} )
end procedure

----------------------------------------
-- gtk_notebook_prev_page
----------------------------------------
constant gtk_notebook_prev_page_ = link_c_proc( GTK, 
  "gtk_notebook_prev_page", {C_POINTER} )

global procedure gtk_notebook_prev_page(atom notebook_)
    c_proc( gtk_notebook_prev_page_, {notebook_} )
end procedure

----------------------------------------
-- gtk_notebook_set_show_border
----------------------------------------
constant gtk_notebook_set_show_border_ = link_c_proc( GTK, 
  "gtk_notebook_set_show_border", {C_POINTER,C_INT} )

global procedure gtk_notebook_set_show_border(atom notebook_, integer show_border_)
    c_proc( gtk_notebook_set_show_border_, {notebook_,show_border_} )
end procedure

----------------------------------------
-- gtk_notebook_set_show_tabs
----------------------------------------
constant gtk_notebook_set_show_tabs_ = link_c_proc( GTK, 
  "gtk_notebook_set_show_tabs", {C_POINTER,C_INT} )

global procedure gtk_notebook_set_show_tabs(atom notebook_, integer show_tabs_)
    c_proc( gtk_notebook_set_show_tabs_, {notebook_,show_tabs_} )
end procedure

----------------------------------------
-- gtk_notebook_set_tab_pos
----------------------------------------
constant gtk_notebook_set_tab_pos_ = link_c_proc( GTK, 
  "gtk_notebook_set_tab_pos", {C_POINTER,C_POINTER} )

global procedure gtk_notebook_set_tab_pos(atom notebook_, atom pos_)
    c_proc( gtk_notebook_set_tab_pos_, {notebook_,pos_} )
end procedure

----------------------------------------
-- gtk_notebook_set_homogeneous_tabs
----------------------------------------
constant gtk_notebook_set_homogeneous_tabs_ = link_c_proc( GTK, 
  "gtk_notebook_set_homogeneous_tabs", {C_POINTER,C_INT} )

global procedure gtk_notebook_set_homogeneous_tabs(atom notebook_, integer homogeneous_)
    c_proc( gtk_notebook_set_homogeneous_tabs_, {notebook_,homogeneous_} )
end procedure

----------------------------------------
-- gtk_notebook_set_tab_border
----------------------------------------
constant gtk_notebook_set_tab_border_ = link_c_proc( GTK, 
  "gtk_notebook_set_tab_border", {C_POINTER,C_UINT} )

global procedure gtk_notebook_set_tab_border(atom notebook_, integer border_width_)
    c_proc( gtk_notebook_set_tab_border_, {notebook_,border_width_} )
end procedure

----------------------------------------
-- gtk_notebook_set_tab_hborder
----------------------------------------
constant gtk_notebook_set_tab_hborder_ = link_c_proc( GTK, 
  "gtk_notebook_set_tab_hborder", {C_POINTER,C_UINT} )

global procedure gtk_notebook_set_tab_hborder(atom notebook_, integer tab_hborder_)
    c_proc( gtk_notebook_set_tab_hborder_, {notebook_,tab_hborder_} )
end procedure

----------------------------------------
-- gtk_notebook_set_tab_vborder
----------------------------------------
constant gtk_notebook_set_tab_vborder_ = link_c_proc( GTK, 
  "gtk_notebook_set_tab_vborder", {C_POINTER,C_UINT} )

global procedure gtk_notebook_set_tab_vborder(atom notebook_, integer tab_vborder_)
    c_proc( gtk_notebook_set_tab_vborder_, {notebook_,tab_vborder_} )
end procedure

----------------------------------------
-- gtk_notebook_set_scrollable
----------------------------------------
constant gtk_notebook_set_scrollable_ = link_c_proc( GTK, 
  "gtk_notebook_set_scrollable", {C_POINTER,C_INT} )

global procedure gtk_notebook_set_scrollable(atom notebook_, integer scrollable_)
    c_proc( gtk_notebook_set_scrollable_, {notebook_,scrollable_} )
end procedure

----------------------------------------
-- gtk_notebook_popup_enable
----------------------------------------
constant gtk_notebook_popup_enable_ = link_c_proc( GTK, 
  "gtk_notebook_popup_enable", {C_POINTER} )

global procedure gtk_notebook_popup_enable(atom notebook_)
    c_proc( gtk_notebook_popup_enable_, {notebook_} )
end procedure

----------------------------------------
-- gtk_notebook_popup_disable
----------------------------------------
constant gtk_notebook_popup_disable_ = link_c_proc( GTK, 
  "gtk_notebook_popup_disable", {C_POINTER} )

global procedure gtk_notebook_popup_disable(atom notebook_)
    c_proc( gtk_notebook_popup_disable_, {notebook_} )
end procedure






----------------------------------------
----------------------------------------
-- GTKFONTSEL.H
----------------------------------------
----------------------------------------


global constant GTK_NUM_FONT_PROPERTIES = 6
global constant GTK_NUM_STYLE_PROPERTIES = 5
global constant
    GTK_FONT_METRIC_PIXELS              = 1,
    GTK_FONT_METRIC_POINTS              = 2
global constant SIZEOF_GtkFontMetricType = SIZEOF_ENUM

global constant
    GTK_FONT_BITMAP                     = power(2,0),
    GTK_FONT_SCALABLE                   = power(2,1),
    GTK_FONT_SCALABLE_BITMAP            = power(2,2),
    GTK_FONT_ALL                        = #07
global constant SIZEOF_GtkFontType = SIZEOF_ENUM

global constant GTK_NUM_FONT_FILTERS = 2
global constant
    GTK_FONT_FILTER_BASE                = 1,
    GTK_FONT_FILTER_USER                = 2
global constant SIZEOF_GtkFontFilterType = SIZEOF_ENUM


----------------------------------------
-- GtkFontFilter
----------------------------------------
global constant
-- manually corrected:
-- property filters and property_nfilters
    GtkFontFilter_font_type             = allot(TYPE_GINT),
    GtkFontFilter_property_filters      = allot(GTK_NUM_FONT_PROPERTIES*LONG_BYTES),
    GtkFontFilter_property_nfilters     = allot(GTK_NUM_FONT_PROPERTIES*INT_BYTES),
    SIZEOF_GtkFontFilter                = allotted_size()

----------------------------------------
-- GtkFontSelection
----------------------------------------
-- manually corrected:
-- filter_clists, property_values, clists
global constant
    GtkFontSelection_notebook           = allot(SIZEOF_GtkNotebook),
    GtkFontSelection_main_vbox          = allot(TYPE_POINTER),
    GtkFontSelection_font_label         = allot(TYPE_POINTER),
    GtkFontSelection_font_entry         = allot(TYPE_POINTER),
    GtkFontSelection_font_clist         = allot(TYPE_POINTER),
    GtkFontSelection_font_style_entry   = allot(TYPE_POINTER),
    GtkFontSelection_font_style_clist   = allot(TYPE_POINTER),
    GtkFontSelection_size_entry         = allot(TYPE_POINTER),
    GtkFontSelection_size_clist         = allot(TYPE_POINTER),
    GtkFontSelection_pixels_button      = allot(TYPE_POINTER),
    GtkFontSelection_points_button      = allot(TYPE_POINTER),
    GtkFontSelection_filter_button      = allot(TYPE_POINTER),
    GtkFontSelection_preview_entry      = allot(TYPE_POINTER),
    GtkFontSelection_message_label      = allot(TYPE_POINTER),
    GtkFontSelection_info_vbox          = allot(TYPE_POINTER),
    GtkFontSelection_info_clist         = allot(TYPE_POINTER),
    GtkFontSelection_requested_font_name= allot(TYPE_POINTER),
    GtkFontSelection_actual_font_name   = allot(TYPE_POINTER),
    GtkFontSelection_filter_vbox        = allot(TYPE_POINTER),
    GtkFontSelection_type_bitmaps_button= allot(TYPE_POINTER),
    GtkFontSelection_type_scalable_button= allot(TYPE_POINTER),
    GtkFontSelection_type_scaled_bitmaps_button= allot(TYPE_POINTER),
    GtkFontSelection_filter_clists      = allot(GTK_NUM_FONT_PROPERTIES*LONG_BYTES),
    GtkFontSelection_font               = allot(TYPE_POINTER),
    GtkFontSelection_font_index         = allot(TYPE_GINT),
    GtkFontSelection_style              = allot(TYPE_GINT),
    GtkFontSelection_metric             = allot(SIZEOF_GtkFontMetricType),
    GtkFontSelection_size               = allot(TYPE_GINT),
    GtkFontSelection_selected_size      = allot(TYPE_GINT),
    GtkFontSelection_property_values    = allot(GTK_NUM_STYLE_PROPERTIES*INT_BYTES),
    GtkFontSelection_filters            = allot(GTK_NUM_FONT_FILTERS*SIZEOF_GtkFontFilter),
    SIZEOF_GtkFontSelection             = allotted_size()

----------------------------------------
-- GtkFontSelectionClass
----------------------------------------
global constant
    GtkFontSelectionClass_parent_class  = allot(SIZEOF_GtkNotebookClass),
    SIZEOF_GtkFontSelectionClass        = allotted_size()

----------------------------------------
-- GtkFontSelectionDialog
----------------------------------------
global constant
    GtkFontSelectionDialog_window       = allot(SIZEOF_GtkWindow),
    GtkFontSelectionDialog_fontsel      = allot(TYPE_POINTER),
    GtkFontSelectionDialog_main_vbox    = allot(TYPE_POINTER),
    GtkFontSelectionDialog_action_area  = allot(TYPE_POINTER),
    GtkFontSelectionDialog_ok_button    = allot(TYPE_POINTER),
    GtkFontSelectionDialog_apply_button = allot(TYPE_POINTER),
    GtkFontSelectionDialog_cancel_button= allot(TYPE_POINTER),
    GtkFontSelectionDialog_dialog_width = allot(TYPE_GINT),
    GtkFontSelectionDialog_auto_resize  = allot(TYPE_GBOOLEAN),
    SIZEOF_GtkFontSelectionDialog       = allotted_size()

----------------------------------------
-- GtkFontSelectionDialogClass
----------------------------------------
global constant
    GtkFontSelectionDialogClass_parent_class= allot(SIZEOF_GtkWindowClass),
    SIZEOF_GtkFontSelectionDialogClass  = allotted_size()
----------------------------------------
-- gtk_font_selection_get_type
----------------------------------------
constant gtk_font_selection_get_type_ = link_c_func( GTK, 
  "gtk_font_selection_get_type", {}, C_UINT )

global function gtk_font_selection_get_type()
    return c_func( gtk_font_selection_get_type_, {} )
end function

----------------------------------------
-- gtk_font_selection_new
----------------------------------------
constant gtk_font_selection_new_ = link_c_func( GTK, 
  "gtk_font_selection_new", {}, C_POINTER )

global function gtk_font_selection_new()
    return c_func( gtk_font_selection_new_, {} )
end function

----------------------------------------
-- gtk_font_selection_get_font_name
----------------------------------------
constant gtk_font_selection_get_font_name_ = link_c_func( GTK, 
  "gtk_font_selection_get_font_name", {C_POINTER}, C_POINTER )

global function gtk_font_selection_get_font_name(atom fontsel_)
    return peek_string( c_func( gtk_font_selection_get_font_name_, {fontsel_} ) )
end function

----------------------------------------
-- gtk_font_selection_get_font
----------------------------------------
constant gtk_font_selection_get_font_ = link_c_func( GTK, 
  "gtk_font_selection_get_font", {C_POINTER}, C_POINTER )

global function gtk_font_selection_get_font(atom fontsel_)
    return c_func( gtk_font_selection_get_font_, {fontsel_} )
end function

----------------------------------------
-- gtk_font_selection_set_font_name
----------------------------------------
constant gtk_font_selection_set_font_name_ = link_c_func( GTK, 
  "gtk_font_selection_set_font_name", {C_POINTER,C_POINTER}, C_INT )

global function gtk_font_selection_set_font_name(atom fontsel_, sequence fontname_)
    integer result
    atom string1
    string1 = allocate_string( fontname_ )
    result = c_func( gtk_font_selection_set_font_name_, {fontsel_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_font_selection_set_filter
----------------------------------------
constant gtk_font_selection_set_filter_ = link_c_proc( GTK, 
  "gtk_font_selection_set_filter", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER} 
 )

global procedure gtk_font_selection_set_filter(atom fontsel_, atom filter_type_, atom font_type_, sequence foundries_, 
 sequence weights_, sequence slants_, sequence setwidths_, sequence spacings_, sequence charsets_)
    atom string1, string2, string3, string4, string5, string6
    string1 = allocate_string( foundries_ )
    string2 = allocate_string( weights_ )
    string3 = allocate_string( slants_ )
    string4 = allocate_string( setwidths_ )
    string5 = allocate_string( spacings_ )
    string6 = allocate_string( charsets_ )
    c_proc( gtk_font_selection_set_filter_, {fontsel_,filter_type_,font_type_,string1,string2,string3,string4,string5,string6} )
    free( string1 )
    free( string2 )
    free( string3 )
    free( string4 )
    free( string5 )
    free( string6 )
end procedure

----------------------------------------
-- gtk_font_selection_get_preview_text
----------------------------------------
constant gtk_font_selection_get_preview_text_ = link_c_func( GTK, 
  "gtk_font_selection_get_preview_text", {C_POINTER}, C_POINTER )

global function gtk_font_selection_get_preview_text(atom fontsel_)
    return peek_string( c_func( gtk_font_selection_get_preview_text_, {fontsel_} ) )
end function

----------------------------------------
-- gtk_font_selection_set_preview_text
----------------------------------------
constant gtk_font_selection_set_preview_text_ = link_c_proc( GTK, 
  "gtk_font_selection_set_preview_text", {C_POINTER,C_POINTER} )

global procedure gtk_font_selection_set_preview_text(atom fontsel_, sequence text_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_font_selection_set_preview_text_, {fontsel_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_font_selection_dialog_get_type
----------------------------------------
constant gtk_font_selection_dialog_get_type_ = link_c_func( GTK, 
  "gtk_font_selection_dialog_get_type", {}, C_UINT )

global function gtk_font_selection_dialog_get_type()
    return c_func( gtk_font_selection_dialog_get_type_, {} )
end function

----------------------------------------
-- gtk_font_selection_dialog_new
----------------------------------------
constant gtk_font_selection_dialog_new_ = link_c_func( GTK, 
  "gtk_font_selection_dialog_new", {C_POINTER}, C_POINTER )

global function gtk_font_selection_dialog_new(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_font_selection_dialog_new_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_font_selection_dialog_get_font_name
----------------------------------------
constant gtk_font_selection_dialog_get_font_name_ = link_c_func( GTK, 
  "gtk_font_selection_dialog_get_font_name", {C_POINTER}, C_POINTER )

global function gtk_font_selection_dialog_get_font_name(atom fsd_)
    return peek_string( c_func( gtk_font_selection_dialog_get_font_name_, {fsd_} ) )
end function

----------------------------------------
-- gtk_font_selection_dialog_get_font
----------------------------------------
constant gtk_font_selection_dialog_get_font_ = link_c_func( GTK, 
  "gtk_font_selection_dialog_get_font", {C_POINTER}, C_POINTER )

global function gtk_font_selection_dialog_get_font(atom fsd_)
    return c_func( gtk_font_selection_dialog_get_font_, {fsd_} )
end function

----------------------------------------
-- gtk_font_selection_dialog_set_font_name
----------------------------------------
constant gtk_font_selection_dialog_set_font_name_ = link_c_func( GTK, 
  "gtk_font_selection_dialog_set_font_name", {C_POINTER,C_POINTER}, C_INT )

global function gtk_font_selection_dialog_set_font_name(atom fsd_, sequence fontname_)
    integer result
    atom string1
    string1 = allocate_string( fontname_ )
    result = c_func( gtk_font_selection_dialog_set_font_name_, {fsd_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_font_selection_dialog_set_filter
----------------------------------------
constant gtk_font_selection_dialog_set_filter_ = link_c_proc( GTK, 
  "gtk_font_selection_dialog_set_filter", 
 {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_font_selection_dialog_set_filter(atom fsd_, atom filter_type_, atom font_type_, sequence 
 foundries_, sequence weights_, sequence slants_, sequence setwidths_, sequence spacings_, sequence charsets_)
    atom string1, string2, string3, string4, string5, string6
    string1 = allocate_string( foundries_ )
    string2 = allocate_string( weights_ )
    string3 = allocate_string( slants_ )
    string4 = allocate_string( setwidths_ )
    string5 = allocate_string( spacings_ )
    string6 = allocate_string( charsets_ )
    c_proc( gtk_font_selection_dialog_set_filter_, {fsd_,filter_type_,font_type_,string1,string2,string3,string4,string5,string6} )
    free( string1 )
    free( string2 )
    free( string3 )
    free( string4 )
    free( string5 )
    free( string6 )
end procedure

----------------------------------------
-- gtk_font_selection_dialog_get_preview_text
----------------------------------------
constant gtk_font_selection_dialog_get_preview_text_ = link_c_func( GTK, 
  "gtk_font_selection_dialog_get_preview_text", {C_POINTER}, C_POINTER )

global function gtk_font_selection_dialog_get_preview_text(atom fsd_)
    return peek_string( c_func( gtk_font_selection_dialog_get_preview_text_, {fsd_} ) )
end function

----------------------------------------
-- gtk_font_selection_dialog_set_preview_text
----------------------------------------
constant gtk_font_selection_dialog_set_preview_text_ = link_c_proc( GTK, 
  "gtk_font_selection_dialog_set_preview_text", {C_POINTER,C_POINTER} )

global procedure gtk_font_selection_dialog_set_preview_text(atom fsd_, sequence text_)
    atom string1
    string1 = allocate_string( text_ )
    c_proc( gtk_font_selection_dialog_set_preview_text_, {fsd_,string1} )
    free( string1 )
end procedure



----------------------------------------
----------------------------------------
-- GTKGAMMA.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkGammaCurve
----------------------------------------
-- corrected manually:
-- button[5]
global constant
    GtkGammaCurve_vbox                  = allot(SIZEOF_GtkVBox),
    GtkGammaCurve_table                 = allot(TYPE_POINTER),
    GtkGammaCurve_curve                 = allot(TYPE_POINTER),
    GtkGammaCurve_button                = allot(5*LONG_BYTES), -- gpointer
    GtkGammaCurve_gamma                 = allot(TYPE_GFLOAT),
    GtkGammaCurve_gamma_dialog          = allot(TYPE_POINTER),
    GtkGammaCurve_gamma_text            = allot(TYPE_POINTER),
    SIZEOF_GtkGammaCurve                = allotted_size()

----------------------------------------
-- GtkGammaCurveClass
----------------------------------------
global constant
    GtkGammaCurveClass_parent_class     = allot(SIZEOF_GtkVBoxClass),
    SIZEOF_GtkGammaCurveClass           = allotted_size()
----------------------------------------
-- gtk_gamma_curve_get_type
----------------------------------------
constant gtk_gamma_curve_get_type_ = link_c_func( GTK, 
  "gtk_gamma_curve_get_type", {}, C_UINT )

global function gtk_gamma_curve_get_type()
    return c_func( gtk_gamma_curve_get_type_, {} )
end function

----------------------------------------
-- gtk_gamma_curve_new
----------------------------------------
constant gtk_gamma_curve_new_ = link_c_func( GTK, 
  "gtk_gamma_curve_new", {}, C_POINTER )

global function gtk_gamma_curve_new()
    return c_func( gtk_gamma_curve_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKGC.H
----------------------------------------
----------------------------------------


----------------------------------------
-- gtk_gc_get
----------------------------------------
constant gtk_gc_get_ = link_c_func( GTK, 
  "gtk_gc_get", {C_INT,C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_gc_get(integer depth_, atom colormap_, atom values_, atom values_mask_)
    return c_func( gtk_gc_get_, {depth_,colormap_,values_,values_mask_} )
end function

----------------------------------------
-- gtk_gc_release
----------------------------------------
constant gtk_gc_release_ = link_c_proc( GTK, 
  "gtk_gc_release", {C_POINTER} )

global procedure gtk_gc_release(atom gc_)
    c_proc( gtk_gc_release_, {gc_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKHANDLEBOX.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHandleBox
----------------------------------------
global constant
    GtkHandleBox_bin                    = allot(SIZEOF_GtkBin),
    GtkHandleBox_bin_window             = allot(TYPE_POINTER),
    GtkHandleBox_float_window           = allot(TYPE_POINTER),
    GtkHandleBox_shadow_type            = allot(SIZEOF_GtkShadowType),
    GtkHandleBox_handle_position        = allot(TYPE_GUINT),
    GtkHandleBox_float_window_mapped    = allot(TYPE_GUINT),
    GtkHandleBox_child_detached         = allot(TYPE_GUINT),
    GtkHandleBox_in_drag                = allot(TYPE_GUINT),
    GtkHandleBox_shrink_on_detach       = allot(TYPE_GUINT),
    GtkHandleBox_snap_edge              = allot(TYPE_GINT),
    GtkHandleBox_deskoff_x              = allot(TYPE_POINTER),
    GtkHandleBox_deskoff_y              = allot(TYPE_POINTER),
    GtkHandleBox_attach_allocation      = allot(SIZEOF_GtkAllocation),
    GtkHandleBox_float_allocation       = allot(SIZEOF_GtkAllocation),
    SIZEOF_GtkHandleBox                 = allotted_size()

----------------------------------------
-- GtkHandleBoxClass
----------------------------------------
global constant
    GtkHandleBoxClass_parent_class      = allot(SIZEOF_GtkBinClass),
    GtkHandleBoxClass_child_attached    = allot(TYPE_GPOINTER),
    GtkHandleBoxClass_child_detached    = allot(TYPE_GPOINTER),
    SIZEOF_GtkHandleBoxClass            = allotted_size()
----------------------------------------
-- gtk_handle_box_get_type
----------------------------------------
constant gtk_handle_box_get_type_ = link_c_func( GTK, 
  "gtk_handle_box_get_type", {}, C_UINT )

global function gtk_handle_box_get_type()
    return c_func( gtk_handle_box_get_type_, {} )
end function

----------------------------------------
-- gtk_handle_box_new
----------------------------------------
constant gtk_handle_box_new_ = link_c_func( GTK, 
  "gtk_handle_box_new", {}, C_POINTER )

global function gtk_handle_box_new()
    return c_func( gtk_handle_box_new_, {} )
end function

----------------------------------------
-- gtk_handle_box_set_shadow_type
----------------------------------------
constant gtk_handle_box_set_shadow_type_ = link_c_proc( GTK, 
  "gtk_handle_box_set_shadow_type", {C_POINTER,C_POINTER} )

global procedure gtk_handle_box_set_shadow_type(atom handle_box_, atom type_)
    c_proc( gtk_handle_box_set_shadow_type_, {handle_box_,type_} )
end procedure

----------------------------------------
-- gtk_handle_box_set_handle_position
----------------------------------------
constant gtk_handle_box_set_handle_position_ = link_c_proc( GTK, 
  "gtk_handle_box_set_handle_position", {C_POINTER,C_POINTER} )

global procedure gtk_handle_box_set_handle_position(atom handle_box_, atom position_)
    c_proc( gtk_handle_box_set_handle_position_, {handle_box_,position_} )
end procedure

----------------------------------------
-- gtk_handle_box_set_snap_edge
----------------------------------------
constant gtk_handle_box_set_snap_edge_ = link_c_proc( GTK, 
  "gtk_handle_box_set_snap_edge", {C_POINTER,C_POINTER} )

global procedure gtk_handle_box_set_snap_edge(atom handle_box_, atom edge_)
    c_proc( gtk_handle_box_set_snap_edge_, {handle_box_,edge_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKHBBOX.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHButtonBox
----------------------------------------
global constant
    GtkHButtonBox_button_box            = allot(SIZEOF_GtkButtonBox),
    SIZEOF_GtkHButtonBox                = allotted_size()

----------------------------------------
-- GtkHButtonBoxClass
----------------------------------------
global constant
    GtkHButtonBoxClass_parent_class     = allot(SIZEOF_GtkButtonBoxClass),
    SIZEOF_GtkHButtonBoxClass           = allotted_size()
----------------------------------------
-- gtk_hbutton_box_get_type
----------------------------------------
constant gtk_hbutton_box_get_type_ = link_c_func( GTK, 
  "gtk_hbutton_box_get_type", {}, C_UINT )

global function gtk_hbutton_box_get_type()
    return c_func( gtk_hbutton_box_get_type_, {} )
end function

----------------------------------------
-- gtk_hbutton_box_new
----------------------------------------
constant gtk_hbutton_box_new_ = link_c_func( GTK, 
  "gtk_hbutton_box_new", {}, C_POINTER )

global function gtk_hbutton_box_new()
    return c_func( gtk_hbutton_box_new_, {} )
end function

----------------------------------------
-- gtk_hbutton_box_get_spacing_default
----------------------------------------
constant gtk_hbutton_box_get_spacing_default_ = link_c_func( GTK, 
  "gtk_hbutton_box_get_spacing_default", {}, C_INT )

global function gtk_hbutton_box_get_spacing_default()
    return c_func( gtk_hbutton_box_get_spacing_default_, {} )
end function

----------------------------------------
-- gtk_hbutton_box_get_layout_default
----------------------------------------
constant gtk_hbutton_box_get_layout_default_ = link_c_func( GTK, 
  "gtk_hbutton_box_get_layout_default", {}, C_POINTER )

global function gtk_hbutton_box_get_layout_default()
    return c_func( gtk_hbutton_box_get_layout_default_, {} )
end function

----------------------------------------
-- gtk_hbutton_box_set_spacing_default
----------------------------------------
constant gtk_hbutton_box_set_spacing_default_ = link_c_proc( GTK, 
  "gtk_hbutton_box_set_spacing_default", {C_INT} )

global procedure gtk_hbutton_box_set_spacing_default(integer spacing_)
    c_proc( gtk_hbutton_box_set_spacing_default_, {spacing_} )
end procedure

----------------------------------------
-- gtk_hbutton_box_set_layout_default
----------------------------------------
constant gtk_hbutton_box_set_layout_default_ = link_c_proc( GTK, 
  "gtk_hbutton_box_set_layout_default", {C_POINTER} )

global procedure gtk_hbutton_box_set_layout_default(atom layout_)
    c_proc( gtk_hbutton_box_set_layout_default_, {layout_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKPANED.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkPaned
----------------------------------------
global constant
    GtkPaned_container                  = allot(SIZEOF_GtkContainer),
    GtkPaned_child1                     = allot(TYPE_POINTER),
    GtkPaned_child2                     = allot(TYPE_POINTER),
    GtkPaned_handle                     = allot(TYPE_POINTER),
    GtkPaned_groove_rectangle           = allot(SIZEOF_GdkRectangle),
    GtkPaned_xor_gc                     = allot(TYPE_POINTER),
    GtkPaned_handle_size                = allot(TYPE_GUINT16),
    GtkPaned_gutter_size                = allot(TYPE_GUINT16),
    GtkPaned_child1_size                = allot(TYPE_GINT),
    GtkPaned_last_allocation            = allot(TYPE_GINT),
    GtkPaned_min_position               = allot(TYPE_GINT),
    GtkPaned_max_position               = allot(TYPE_GINT),
    GtkPaned_position_set               = allot(TYPE_GUINT),
    GtkPaned_in_drag                    = allot(TYPE_GUINT),
    GtkPaned_child1_shrink              = allot(TYPE_GUINT),
    GtkPaned_child1_resize              = allot(TYPE_GUINT),
    GtkPaned_child2_shrink              = allot(TYPE_GUINT),
    GtkPaned_child2_resize              = allot(TYPE_GUINT),
    GtkPaned_handle_xpos                = allot(TYPE_GINT16),
    GtkPaned_handle_ypos                = allot(TYPE_GINT16),
    SIZEOF_GtkPaned                     = allotted_size()

----------------------------------------
-- GtkPanedClass
----------------------------------------
global constant
    GtkPanedClass_parent_class          = allot(SIZEOF_GtkContainerClass),
    SIZEOF_GtkPanedClass                = allotted_size()
----------------------------------------
-- gtk_paned_get_type
----------------------------------------
constant gtk_paned_get_type_ = link_c_func( GTK, 
  "gtk_paned_get_type", {}, C_UINT )

global function gtk_paned_get_type()
    return c_func( gtk_paned_get_type_, {} )
end function

----------------------------------------
-- gtk_paned_add1
----------------------------------------
constant gtk_paned_add1_ = link_c_proc( GTK, 
  "gtk_paned_add1", {C_POINTER,C_POINTER} )

global procedure gtk_paned_add1(atom paned_, atom child_)
    c_proc( gtk_paned_add1_, {paned_,child_} )
end procedure

----------------------------------------
-- gtk_paned_add2
----------------------------------------
constant gtk_paned_add2_ = link_c_proc( GTK, 
  "gtk_paned_add2", {C_POINTER,C_POINTER} )

global procedure gtk_paned_add2(atom paned_, atom child_)
    c_proc( gtk_paned_add2_, {paned_,child_} )
end procedure

----------------------------------------
-- gtk_paned_pack1
----------------------------------------
constant gtk_paned_pack1_ = link_c_proc( GTK, 
  "gtk_paned_pack1", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_paned_pack1(atom paned_, atom child_, integer resize_, integer shrink_)
    c_proc( gtk_paned_pack1_, {paned_,child_,resize_,shrink_} )
end procedure

----------------------------------------
-- gtk_paned_pack2
----------------------------------------
constant gtk_paned_pack2_ = link_c_proc( GTK, 
  "gtk_paned_pack2", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_paned_pack2(atom paned_, atom child_, integer resize_, integer shrink_)
    c_proc( gtk_paned_pack2_, {paned_,child_,resize_,shrink_} )
end procedure

----------------------------------------
-- gtk_paned_set_position
----------------------------------------
constant gtk_paned_set_position_ = link_c_proc( GTK, 
  "gtk_paned_set_position", {C_POINTER,C_INT} )

global procedure gtk_paned_set_position(atom paned_, integer position_)
    c_proc( gtk_paned_set_position_, {paned_,position_} )
end procedure

----------------------------------------
-- gtk_paned_set_handle_size
----------------------------------------
constant gtk_paned_set_handle_size_ = link_c_proc( GTK, 
  "gtk_paned_set_handle_size", {C_POINTER,C_UINT} )

global procedure gtk_paned_set_handle_size(atom paned_, integer size_)
    c_proc( gtk_paned_set_handle_size_, {paned_,size_} )
end procedure

----------------------------------------
-- gtk_paned_set_gutter_size
----------------------------------------
constant gtk_paned_set_gutter_size_ = link_c_proc( GTK, 
  "gtk_paned_set_gutter_size", {C_POINTER,C_UINT} )

global procedure gtk_paned_set_gutter_size(atom paned_, integer size_)
    c_proc( gtk_paned_set_gutter_size_, {paned_,size_} )
end procedure

----------------------------------------
-- gtk_paned_compute_position
----------------------------------------
constant gtk_paned_compute_position_ = link_c_proc( GTK, 
  "gtk_paned_compute_position", {C_POINTER,C_INT,C_INT,C_INT} )

global procedure gtk_paned_compute_position(atom paned_, integer allocation_, integer child1_req_, integer child2_req_)
    c_proc( gtk_paned_compute_position_, {paned_,allocation_,child1_req_,child2_req_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKHPANED.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHPaned
----------------------------------------
global constant
    GtkHPaned_paned                     = allot(SIZEOF_GtkPaned),
    SIZEOF_GtkHPaned                    = allotted_size()

----------------------------------------
-- GtkHPanedClass
----------------------------------------
global constant
    GtkHPanedClass_parent_class         = allot(SIZEOF_GtkPanedClass),
    SIZEOF_GtkHPanedClass               = allotted_size()
----------------------------------------
-- gtk_hpaned_get_type
----------------------------------------
constant gtk_hpaned_get_type_ = link_c_func( GTK, 
  "gtk_hpaned_get_type", {}, C_UINT )

global function gtk_hpaned_get_type()
    return c_func( gtk_hpaned_get_type_, {} )
end function

----------------------------------------
-- gtk_hpaned_new
----------------------------------------
constant gtk_hpaned_new_ = link_c_func( GTK, 
  "gtk_hpaned_new", {}, C_POINTER )

global function gtk_hpaned_new()
    return c_func( gtk_hpaned_new_, {} )
end function


----------------------------------------
----------------------------------------
-- GTKRULER.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkRuler
----------------------------------------
global constant
    GtkRuler_widget                     = allot(SIZEOF_GtkWidget),
    GtkRuler_backing_store              = allot(TYPE_POINTER),
    GtkRuler_non_gr_exp_gc              = allot(TYPE_POINTER),
    GtkRuler_metric                     = allot(TYPE_POINTER),
    GtkRuler_xsrc                       = allot(TYPE_GINT),
    GtkRuler_ysrc                       = allot(TYPE_GINT),
    GtkRuler_slider_size                = allot(TYPE_GINT),
    GtkRuler_lower                      = allot(TYPE_GFLOAT),
    GtkRuler_upper                      = allot(TYPE_GFLOAT),
    GtkRuler_position                   = allot(TYPE_GFLOAT),
    GtkRuler_max_size                   = allot(TYPE_GFLOAT),
    SIZEOF_GtkRuler                     = allotted_size()

----------------------------------------
-- GtkRulerClass
----------------------------------------
global constant
    GtkRulerClass_parent_class          = allot(SIZEOF_GtkWidgetClass),
    GtkRulerClass_draw_ticks            = allot(TYPE_GPOINTER),
    GtkRulerClass_draw_pos              = allot(TYPE_GPOINTER),
    SIZEOF_GtkRulerClass                = allotted_size()

----------------------------------------
-- GtkRulerMetric
----------------------------------------
-- fixed manually
-- ruler_scale[10], subdivide[5]
-- should a gfloat cast differently?
global constant
    GtkRulerMetric_metric_name          = allot(TYPE_POINTER),
    GtkRulerMetric_abbrev               = allot(TYPE_POINTER),
    GtkRulerMetric_pixels_per_unit      = allot(TYPE_GFLOAT),
    GtkRulerMetric_ruler_scale          = allot(10*LONG_BYTES), -- gfloat
    GtkRulerMetric_subdivide            = allot(5*INT_BYTES),   -- gint
    SIZEOF_GtkRulerMetric               = allotted_size()
----------------------------------------
-- gtk_ruler_get_type
----------------------------------------
constant gtk_ruler_get_type_ = link_c_func( GTK, 
  "gtk_ruler_get_type", {}, C_UINT )

global function gtk_ruler_get_type()
    return c_func( gtk_ruler_get_type_, {} )
end function

----------------------------------------
-- gtk_ruler_set_metric
----------------------------------------
constant gtk_ruler_set_metric_ = link_c_proc( GTK, 
  "gtk_ruler_set_metric", {C_POINTER,C_POINTER} )

global procedure gtk_ruler_set_metric(atom ruler_, atom metric_)
    c_proc( gtk_ruler_set_metric_, {ruler_,metric_} )
end procedure

----------------------------------------
-- gtk_ruler_set_range
----------------------------------------
constant gtk_ruler_set_range_ = link_c_proc( GTK, 
  "gtk_ruler_set_range", {C_POINTER,C_LONG,C_LONG,C_LONG,C_LONG} )

global procedure gtk_ruler_set_range(atom ruler_, integer lower_, integer upper_, integer position_, integer max_size_)
    c_proc( gtk_ruler_set_range_, {ruler_,lower_,upper_,position_,max_size_} )
end procedure

----------------------------------------
-- gtk_ruler_draw_ticks
----------------------------------------
constant gtk_ruler_draw_ticks_ = link_c_proc( GTK, 
  "gtk_ruler_draw_ticks", {C_POINTER} )

global procedure gtk_ruler_draw_ticks(atom ruler_)
    c_proc( gtk_ruler_draw_ticks_, {ruler_} )
end procedure

----------------------------------------
-- gtk_ruler_draw_pos
----------------------------------------
constant gtk_ruler_draw_pos_ = link_c_proc( GTK, 
  "gtk_ruler_draw_pos", {C_POINTER} )

global procedure gtk_ruler_draw_pos(atom ruler_)
    c_proc( gtk_ruler_draw_pos_, {ruler_} )
end procedure






----------------------------------------
----------------------------------------
-- GTKHRULER.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHRuler
----------------------------------------
global constant
    GtkHRuler_ruler                     = allot(SIZEOF_GtkRuler),
    SIZEOF_GtkHRuler                    = allotted_size()

----------------------------------------
-- GtkHRulerClass
----------------------------------------
global constant
    GtkHRulerClass_parent_class         = allot(SIZEOF_GtkRulerClass),
    SIZEOF_GtkHRulerClass               = allotted_size()
----------------------------------------
-- gtk_hruler_get_type
----------------------------------------
constant gtk_hruler_get_type_ = link_c_func( GTK, 
  "gtk_hruler_get_type", {}, C_UINT )

global function gtk_hruler_get_type()
    return c_func( gtk_hruler_get_type_, {} )
end function

----------------------------------------
-- gtk_hruler_new
----------------------------------------
constant gtk_hruler_new_ = link_c_func( GTK, 
  "gtk_hruler_new", {}, C_POINTER )

global function gtk_hruler_new()
    return c_func( gtk_hruler_new_, {} )
end function


----------------------------------------
----------------------------------------
-- GTKSEPARATOR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkSeparator
----------------------------------------
global constant
    GtkSeparator_widget                 = allot(SIZEOF_GtkWidget),
    SIZEOF_GtkSeparator                 = allotted_size()

----------------------------------------
-- GtkSeparatorClass
----------------------------------------
global constant
    GtkSeparatorClass_parent_class      = allot(SIZEOF_GtkWidgetClass),
    SIZEOF_GtkSeparatorClass            = allotted_size()
----------------------------------------
-- gtk_separator_get_type
----------------------------------------
constant gtk_separator_get_type_ = link_c_func( GTK, 
  "gtk_separator_get_type", {}, C_UINT )

global function gtk_separator_get_type()
    return c_func( gtk_separator_get_type_, {} )
end function






----------------------------------------
----------------------------------------
-- GTKHSEPARATOR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkHSeparator
----------------------------------------
global constant
    GtkHSeparator_separator             = allot(SIZEOF_GtkSeparator),
    SIZEOF_GtkHSeparator                = allotted_size()

----------------------------------------
-- GtkHSeparatorClass
----------------------------------------
global constant
    GtkHSeparatorClass_parent_class     = allot(SIZEOF_GtkSeparatorClass),
    SIZEOF_GtkHSeparatorClass           = allotted_size()
----------------------------------------
-- gtk_hseparator_get_type
----------------------------------------
constant gtk_hseparator_get_type_ = link_c_func( GTK, 
  "gtk_hseparator_get_type", {}, C_UINT )

global function gtk_hseparator_get_type()
    return c_func( gtk_hseparator_get_type_, {} )
end function

----------------------------------------
-- gtk_hseparator_new
----------------------------------------
constant gtk_hseparator_new_ = link_c_func( GTK, 
  "gtk_hseparator_new", {}, C_POINTER )

global function gtk_hseparator_new()
    return c_func( gtk_hseparator_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKIMAGE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkImage
----------------------------------------
global constant
    GtkImage_misc                       = allot(SIZEOF_GtkMisc),
    GtkImage_image                      = allot(TYPE_POINTER),
    GtkImage_mask                       = allot(TYPE_POINTER),
    SIZEOF_GtkImage                     = allotted_size()

----------------------------------------
-- GtkImageClass
----------------------------------------
global constant
    GtkImageClass_parent_class          = allot(SIZEOF_GtkMiscClass),
    SIZEOF_GtkImageClass                = allotted_size()
----------------------------------------
-- gtk_image_get_type
----------------------------------------
constant gtk_image_get_type_ = link_c_func( GTK, 
  "gtk_image_get_type", {}, C_UINT )

global function gtk_image_get_type()
    return c_func( gtk_image_get_type_, {} )
end function

----------------------------------------
-- gtk_image_new
----------------------------------------
constant gtk_image_new_ = link_c_func( GTK, 
  "gtk_image_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_image_new(atom val_, atom mask_)
    return c_func( gtk_image_new_, {val_,mask_} )
end function

----------------------------------------
-- gtk_image_set
----------------------------------------
constant gtk_image_set_ = link_c_proc( GTK, 
  "gtk_image_set", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_image_set(atom image_, atom val_, atom mask_)
    c_proc( gtk_image_set_, {image_,val_,mask_} )
end procedure

----------------------------------------
-- gtk_image_get
----------------------------------------
constant gtk_image_get_ = link_c_proc( GTK, 
  "gtk_image_get", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_image_get(atom image_, atom val_, atom mask_)
    c_proc( gtk_image_get_, {image_,val_,mask_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKINPUTDIALOG.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkInputDialog
---------------------------------------- 
-- manually fixed:
-- asis_items
global constant
    GtkInputDialog_dialog               = allot(SIZEOF_GtkDialog),
    GtkInputDialog_axis_list            = allot(TYPE_POINTER),
    GtkInputDialog_axis_listbox         = allot(TYPE_POINTER),
    GtkInputDialog_mode_optionmenu      = allot(TYPE_POINTER),
    GtkInputDialog_close_button         = allot(TYPE_POINTER),
    GtkInputDialog_save_button          = allot(TYPE_POINTER),
    GtkInputDialog_axis_items           = allot(GDK_AXIS_LAST*LONG_BYTES), -- pointer
    GtkInputDialog_current_device       = allot(TYPE_GUINT32),
    GtkInputDialog_keys_list            = allot(TYPE_POINTER),
    GtkInputDialog_keys_listbox         = allot(TYPE_POINTER),
    SIZEOF_GtkInputDialog               = allotted_size()

----------------------------------------
-- GtkInputDialogClass
----------------------------------------
global constant
    GtkInputDialogClass_parent_class    = allot(SIZEOF_GtkWindowClass),
    GtkInputDialogClass_enable_device   = allot(TYPE_GPOINTER),
    GtkInputDialogClass_disable_device  = allot(TYPE_GPOINTER),
    SIZEOF_GtkInputDialogClass          = allotted_size()
----------------------------------------
-- gtk_input_dialog_get_type
----------------------------------------
constant gtk_input_dialog_get_type_ = link_c_func( GTK, 
  "gtk_input_dialog_get_type", {}, C_UINT )

global function gtk_input_dialog_get_type()
    return c_func( gtk_input_dialog_get_type_, {} )
end function

----------------------------------------
-- gtk_input_dialog_new
----------------------------------------
constant gtk_input_dialog_new_ = link_c_func( GTK, 
  "gtk_input_dialog_new", {}, C_POINTER )

global function gtk_input_dialog_new()
    return c_func( gtk_input_dialog_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKITEMFACTORY.H
----------------------------------------
----------------------------------------


----------------------------------------
-- GtkPrintFunc
----------------------------------------
constant GtkPrintFunc_ = link_c_proc( GTK, 
  "GtkPrintFunc", {C_POINTER,C_POINTER} )

global procedure GtkPrintFunc(atom func_data_, sequence str_)
    atom string1
    string1 = allocate_string( str_ )
    c_proc( GtkPrintFunc_, {func_data_,string1} )
    free( string1 )
end procedure


----------------------------------------
-- GtkItemFactoryItem
----------------------------------------
global constant
    GtkItemFactoryItem_path             = allot(TYPE_POINTER),
    GtkItemFactoryItem_accelerator_key  = allot(TYPE_GUINT),
    GtkItemFactoryItem_accelerator_mods = allot(TYPE_GUINT),
    GtkItemFactoryItem_modified         = allot(TYPE_GUINT),
    GtkItemFactoryItem_in_propagation   = allot(TYPE_GUINT),
    GtkItemFactoryItem_dummy            = allot(TYPE_POINTER),
    GtkItemFactoryItem_widgets          = allot(TYPE_POINTER),
    SIZEOF_GtkItemFactoryItem           = allotted_size()
----------------------------------------
-- gtk_item_factory_get_type
----------------------------------------
constant gtk_item_factory_get_type_ = link_c_func( GTK, 
  "gtk_item_factory_get_type", {}, C_UINT )

global function gtk_item_factory_get_type()
    return c_func( gtk_item_factory_get_type_, {} )
end function

----------------------------------------
-- gtk_item_factory_new
----------------------------------------
constant gtk_item_factory_new_ = link_c_func( GTK, 
  "gtk_item_factory_new", {C_UINT,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_item_factory_new(integer container_type_, sequence path_, atom accel_group_)
    atom result
    atom string1
    string1 = allocate_string( path_ )
    result = c_func( gtk_item_factory_new_, {container_type_,string1,accel_group_} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_item_factory_construct
----------------------------------------
constant gtk_item_factory_construct_ = link_c_proc( GTK, 
  "gtk_item_factory_construct", {C_POINTER,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_item_factory_construct(atom ifactory_, integer container_type_, sequence path_, atom accel_group_)
    atom string1
    string1 = allocate_string( path_ )
    c_proc( gtk_item_factory_construct_, {ifactory_,container_type_,string1,accel_group_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_item_factory_parse_rc
----------------------------------------
constant gtk_item_factory_parse_rc_ = link_c_proc( GTK, 
  "gtk_item_factory_parse_rc", {C_POINTER} )

global procedure gtk_item_factory_parse_rc(sequence const_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_item_factory_parse_rc_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_item_factory_parse_rc_string
----------------------------------------
constant gtk_item_factory_parse_rc_string_ = link_c_proc( GTK, 
  "gtk_item_factory_parse_rc_string", {C_POINTER} )

global procedure gtk_item_factory_parse_rc_string(sequence const_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_item_factory_parse_rc_string_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_item_factory_parse_rc_scanner
----------------------------------------
constant gtk_item_factory_parse_rc_scanner_ = link_c_proc( GTK, 
  "gtk_item_factory_parse_rc_scanner", {C_POINTER} )

global procedure gtk_item_factory_parse_rc_scanner(atom scanner_)
    c_proc( gtk_item_factory_parse_rc_scanner_, {scanner_} )
end procedure

----------------------------------------
-- gtk_item_factory_add_foreign
----------------------------------------
constant gtk_item_factory_add_foreign_ = link_c_proc( GTK, 
  "gtk_item_factory_add_foreign", {C_POINTER,C_POINTER,C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_item_factory_add_foreign(atom accel_widget_, sequence full_path_, atom accel_group_, integer keyval_, atom modifiers_)
    atom string1
    string1 = allocate_string( full_path_ )
    c_proc( gtk_item_factory_add_foreign_, {accel_widget_,string1,accel_group_,keyval_,modifiers_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_item_factory_from_widget
----------------------------------------
constant gtk_item_factory_from_widget_ = link_c_func( GTK, 
  "gtk_item_factory_from_widget", {C_POINTER}, C_POINTER )

global function gtk_item_factory_from_widget(atom widget_)
    return c_func( gtk_item_factory_from_widget_, {widget_} )
end function

----------------------------------------
-- gtk_item_factory_path_from_widget
----------------------------------------
constant gtk_item_factory_path_from_widget_ = link_c_func( GTK, 
  "gtk_item_factory_path_from_widget", {C_POINTER}, C_POINTER )

global function gtk_item_factory_path_from_widget(atom widget_)
    return peek_string( c_func( gtk_item_factory_path_from_widget_, {widget_} ) )
end function

----------------------------------------
-- gtk_item_factory_get_item
----------------------------------------
constant gtk_item_factory_get_item_ = link_c_func( GTK, 
  "gtk_item_factory_get_item", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_item_factory_get_item(atom ifactory_, sequence path_)
    atom result
    atom string1
    string1 = allocate_string( path_ )
    result = c_func( gtk_item_factory_get_item_, {ifactory_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_item_factory_get_widget
----------------------------------------
constant gtk_item_factory_get_widget_ = link_c_func( GTK, 
  "gtk_item_factory_get_widget", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_item_factory_get_widget(atom ifactory_, sequence path_)
    atom result
    atom string1
    string1 = allocate_string( path_ )
    result = c_func( gtk_item_factory_get_widget_, {ifactory_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_item_factory_get_widget_by_action
----------------------------------------
constant gtk_item_factory_get_widget_by_action_ = link_c_func( GTK, 
  "gtk_item_factory_get_widget_by_action", {C_POINTER,C_UINT}, C_POINTER )

global function gtk_item_factory_get_widget_by_action(atom ifactory_, integer action_)
    return c_func( gtk_item_factory_get_widget_by_action_, {ifactory_,action_} )
end function

----------------------------------------
-- gtk_item_factory_get_item_by_action
----------------------------------------
constant gtk_item_factory_get_item_by_action_ = link_c_func( GTK, 
  "gtk_item_factory_get_item_by_action", {C_POINTER,C_UINT}, C_POINTER )

global function gtk_item_factory_get_item_by_action(atom ifactory_, integer action_)
    return c_func( gtk_item_factory_get_item_by_action_, {ifactory_,action_} )
end function

----------------------------------------
-- gtk_item_factory_dump_items
----------------------------------------
constant gtk_item_factory_dump_items_ = link_c_proc( GTK, 
  "gtk_item_factory_dump_items", {C_POINTER,C_INT,C_POINTER,C_POINTER} )

global procedure gtk_item_factory_dump_items(atom path_pspec_, integer modified_only_, atom print_func_, atom func_data_)
    c_proc( gtk_item_factory_dump_items_, {path_pspec_,modified_only_,print_func_,func_data_} )
end procedure

----------------------------------------
-- gtk_item_factory_dump_rc
----------------------------------------
constant gtk_item_factory_dump_rc_ = link_c_proc( GTK, 
  "gtk_item_factory_dump_rc", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_item_factory_dump_rc(sequence const_, atom path_pspec_, integer modified_only_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_item_factory_dump_rc_, {string1,path_pspec_,modified_only_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_item_factory_print_func
----------------------------------------
constant gtk_item_factory_print_func_ = link_c_proc( GTK, 
  "gtk_item_factory_print_func", {C_POINTER,C_POINTER} )

global procedure gtk_item_factory_print_func(atom FILE_pointer_, sequence string_)
    atom string1
    string1 = allocate_string( string_ )
    c_proc( gtk_item_factory_print_func_, {FILE_pointer_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_item_factory_create_item
----------------------------------------
constant gtk_item_factory_create_item_ = link_c_proc( GTK, 
  "gtk_item_factory_create_item", {C_POINTER,C_POINTER,C_POINTER,C_UINT} )

global procedure gtk_item_factory_create_item(atom ifactory_, atom entry_, atom callback_data_, integer callback_type_)
    c_proc( gtk_item_factory_create_item_, {ifactory_,entry_,callback_data_,callback_type_} )
end procedure

----------------------------------------
-- gtk_item_factory_create_items
----------------------------------------
constant gtk_item_factory_create_items_ = link_c_proc( GTK, 
  "gtk_item_factory_create_items", {C_POINTER,C_UINT,C_POINTER,C_POINTER} )

global procedure gtk_item_factory_create_items(atom ifactory_, integer n_entries_, atom entries_, atom callback_data_)
    c_proc( gtk_item_factory_create_items_, {ifactory_,n_entries_,entries_,callback_data_} )
end procedure

----------------------------------------
-- gtk_item_factory_delete_item
----------------------------------------
constant gtk_item_factory_delete_item_ = link_c_proc( GTK, 
  "gtk_item_factory_delete_item", {C_POINTER,C_POINTER} )

global procedure gtk_item_factory_delete_item(atom ifactory_, sequence path_)
    atom string1
    string1 = allocate_string( path_ )
    c_proc( gtk_item_factory_delete_item_, {ifactory_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_item_factory_delete_entry
----------------------------------------
constant gtk_item_factory_delete_entry_ = link_c_proc( GTK, 
  "gtk_item_factory_delete_entry", {C_POINTER,C_POINTER} )

global procedure gtk_item_factory_delete_entry(atom ifactory_, atom entry_)
    c_proc( gtk_item_factory_delete_entry_, {ifactory_,entry_} )
end procedure

----------------------------------------
-- gtk_item_factory_delete_entries
----------------------------------------
constant gtk_item_factory_delete_entries_ = link_c_proc( GTK, 
  "gtk_item_factory_delete_entries", {C_POINTER,C_UINT,C_POINTER} )

global procedure gtk_item_factory_delete_entries(atom ifactory_, integer n_entries_, atom entries_)
    c_proc( gtk_item_factory_delete_entries_, {ifactory_,n_entries_,entries_} )
end procedure

----------------------------------------
-- gtk_item_factory_popup
----------------------------------------
constant gtk_item_factory_popup_ = link_c_proc( GTK, 
  "gtk_item_factory_popup", {C_POINTER,C_UINT,C_UINT,C_UINT,C_UINT} )

global procedure gtk_item_factory_popup(atom ifactory_, integer x_, integer y_, integer mouse_button_, atom time_)
    c_proc( gtk_item_factory_popup_, {ifactory_,x_,y_,mouse_button_,time_} )
end procedure

----------------------------------------
-- gtk_item_factory_popup_with_data
----------------------------------------
constant gtk_item_factory_popup_with_data_ = link_c_proc( GTK, 
  "gtk_item_factory_popup_with_data", {C_POINTER,C_POINTER,C_POINTER,C_UINT,C_UINT,C_UINT,C_UINT} 
 )

global procedure gtk_item_factory_popup_with_data(atom ifactory_, atom popup_data_, atom destroy_, integer x_, 
 integer y_, integer mouse_button_, atom time_)
    c_proc( gtk_item_factory_popup_with_data_, {ifactory_,popup_data_,destroy_,x_,y_,mouse_button_,time_} )
end procedure

----------------------------------------
-- gtk_item_factory_popup_data
----------------------------------------
constant gtk_item_factory_popup_data_ = link_c_func( GTK, 
  "gtk_item_factory_popup_data", {C_POINTER}, C_POINTER )

global function gtk_item_factory_popup_data(atom ifactory_)
    return c_func( gtk_item_factory_popup_data_, {ifactory_} )
end function

----------------------------------------
-- gtk_item_factory_popup_data_from_widget
----------------------------------------
constant gtk_item_factory_popup_data_from_widget_ = link_c_func( GTK, 
  "gtk_item_factory_popup_data_from_widget", {C_POINTER}, C_POINTER )

global function gtk_item_factory_popup_data_from_widget(atom widget_)
    return c_func( gtk_item_factory_popup_data_from_widget_, {widget_} )
end function

----------------------------------------
-- gtk_item_factory_set_translate_func
----------------------------------------
constant gtk_item_factory_set_translate_func_ = link_c_proc( GTK, 
  "gtk_item_factory_set_translate_func", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} 
 )

global procedure gtk_item_factory_set_translate_func(atom ifactory_, atom func_, atom data_, atom notify_)
    c_proc( gtk_item_factory_set_translate_func_, {ifactory_,func_,data_,notify_} )
end procedure

----------------------------------------
-- gtk_item_factory_from_path
----------------------------------------
constant gtk_item_factory_from_path_ = link_c_func( GTK, 
  "gtk_item_factory_from_path", {C_POINTER}, C_POINTER )

global function gtk_item_factory_from_path(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_item_factory_from_path_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_item_factory_create_menu_entries
----------------------------------------
constant gtk_item_factory_create_menu_entries_ = link_c_proc( GTK, 
  "gtk_item_factory_create_menu_entries", {C_UINT,C_POINTER} )

global procedure gtk_item_factory_create_menu_entries(integer n_entries_, atom entries_)
    c_proc( gtk_item_factory_create_menu_entries_, {n_entries_,entries_} )
end procedure

----------------------------------------
-- gtk_item_factories_path_delete
----------------------------------------
constant gtk_item_factories_path_delete_ = link_c_proc( GTK, 
  "gtk_item_factories_path_delete", {C_POINTER,C_POINTER} )

global procedure gtk_item_factories_path_delete(sequence const_, sequence path_)
    atom string1, string2
    string1 = allocate_string( const_ )
    string2 = allocate_string( path_ )
    c_proc( gtk_item_factories_path_delete_, {string1,string2} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- GtkItemFactoryCallback2
----------------------------------------
constant GtkItemFactoryCallback2_ = link_c_proc( GTK, 
  "GtkItemFactoryCallback2", {C_POINTER,C_POINTER,C_UINT} )

global procedure GtkItemFactoryCallback2(atom widget_, atom callback_data_, integer callback_action_)
    c_proc( GtkItemFactoryCallback2_, {widget_,callback_data_,callback_action_} )
end procedure

----------------------------------------
-- gtk_item_factory_create_items_ac
----------------------------------------
constant gtk_item_factory_create_items_ac_ = link_c_proc( GTK, 
  "gtk_item_factory_create_items_ac", {C_POINTER,C_UINT,C_POINTER,C_POINTER,C_UINT} 
 )

global procedure gtk_item_factory_create_items_ac(atom ifactory_, integer n_entries_, atom entries_, atom callback_data_, integer callback_type_)
    c_proc( gtk_item_factory_create_items_ac_, {ifactory_,n_entries_,entries_,callback_data_,callback_type_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKMENUFACTORY.H
----------------------------------------
----------------------------------------


----------------------------------------
-- GtkMenuCallback
----------------------------------------
constant GtkMenuCallback_ = link_c_proc( GTK, 
  "GtkMenuCallback", {C_POINTER,C_POINTER} )

global procedure GtkMenuCallback(atom widget_, atom user_data_)
    c_proc( GtkMenuCallback_, {widget_,user_data_} )
end procedure


----------------------------------------
-- GtkMenuEntry
----------------------------------------
-- manually corrected:
-- callback changed to TYPE_POINTER
global constant
    GtkMenuEntry_path                   = allot(TYPE_POINTER),
    GtkMenuEntry_accelerator            = allot(TYPE_POINTER),
    GtkMenuEntry_callback               = allot(TYPE_POINTER),
    GtkMenuEntry_callback_data          = allot(TYPE_GPOINTER),
    GtkMenuEntry_widget                 = allot(TYPE_POINTER),
    SIZEOF_GtkMenuEntry                 = allotted_size()

----------------------------------------
-- GtkMenuPath
----------------------------------------
global constant
    GtkMenuPath_path                    = allot(TYPE_POINTER),
    GtkMenuPath_widget                  = allot(TYPE_POINTER),
    SIZEOF_GtkMenuPath                  = allotted_size()

----------------------------------------
-- GtkMenuFactory
----------------------------------------
global constant
    GtkMenuFactory_path                 = allot(TYPE_POINTER),
    GtkMenuFactory_type                 = allot(SIZEOF_GtkMenuFactoryType),
    GtkMenuFactory_accel_group          = allot(TYPE_POINTER),
    GtkMenuFactory_widget               = allot(TYPE_POINTER),
    GtkMenuFactory_subfactories         = allot(TYPE_POINTER),
    SIZEOF_GtkMenuFactory               = allotted_size()
----------------------------------------
-- gtk_menu_factory_new
----------------------------------------
constant gtk_menu_factory_new_ = link_c_func( GTK, 
  "gtk_menu_factory_new", {C_POINTER}, C_POINTER )

global function gtk_menu_factory_new(atom type_)
    return c_func( gtk_menu_factory_new_, {type_} )
end function

----------------------------------------
-- gtk_menu_factory_destroy
----------------------------------------
constant gtk_menu_factory_destroy_ = link_c_proc( GTK, 
  "gtk_menu_factory_destroy", {C_POINTER} )

global procedure gtk_menu_factory_destroy(atom factory_)
    c_proc( gtk_menu_factory_destroy_, {factory_} )
end procedure

----------------------------------------
-- gtk_menu_factory_add_entries
----------------------------------------
constant gtk_menu_factory_add_entries_ = link_c_proc( GTK, 
  "gtk_menu_factory_add_entries", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_factory_add_entries(atom factory_, atom entries_, integer nentries_)
    c_proc( gtk_menu_factory_add_entries_, {factory_,entries_,nentries_} )
end procedure

----------------------------------------
-- gtk_menu_factory_add_subfactory
----------------------------------------
constant gtk_menu_factory_add_subfactory_ = link_c_proc( GTK, 
  "gtk_menu_factory_add_subfactory", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_menu_factory_add_subfactory(atom factory_, atom subfactory_, sequence path_)
    atom string1
    string1 = allocate_string( path_ )
    c_proc( gtk_menu_factory_add_subfactory_, {factory_,subfactory_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_menu_factory_remove_paths
----------------------------------------
constant gtk_menu_factory_remove_paths_ = link_c_proc( GTK, 
  "gtk_menu_factory_remove_paths", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_factory_remove_paths(atom factory_, sequence paths_, integer npaths_)
    atom string1
    string1 = allocate_string( paths_ )
    c_proc( gtk_menu_factory_remove_paths_, {factory_,string1,npaths_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_menu_factory_remove_entries
----------------------------------------
constant gtk_menu_factory_remove_entries_ = link_c_proc( GTK, 
  "gtk_menu_factory_remove_entries", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_factory_remove_entries(atom factory_, atom entries_, integer nentries_)
    c_proc( gtk_menu_factory_remove_entries_, {factory_,entries_,nentries_} )
end procedure

----------------------------------------
-- gtk_menu_factory_remove_subfactory
----------------------------------------
constant gtk_menu_factory_remove_subfactory_ = link_c_proc( GTK, 
  "gtk_menu_factory_remove_subfactory", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_menu_factory_remove_subfactory(atom factory_, atom subfactory_, sequence path_)
    atom string1
    string1 = allocate_string( path_ )
    c_proc( gtk_menu_factory_remove_subfactory_, {factory_,subfactory_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_menu_factory_find
----------------------------------------
constant gtk_menu_factory_find_ = link_c_func( GTK, 
  "gtk_menu_factory_find", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_menu_factory_find(atom factory_, sequence path_)
    atom result
    atom string1
    string1 = allocate_string( path_ )
    result = c_func( gtk_menu_factory_find_, {factory_,string1} )
    free( string1 )
    return result
end function



----------------------------------------
----------------------------------------
-- GTKLAYOUT.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkLayout
----------------------------------------
global constant
    GtkLayout_container                 = allot(SIZEOF_GtkContainer),
    GtkLayout_children                  = allot(TYPE_POINTER),
    GtkLayout_width                     = allot(TYPE_GUINT),
    GtkLayout_height                    = allot(TYPE_GUINT),
    GtkLayout_xoffset                   = allot(TYPE_GUINT),
    GtkLayout_yoffset                   = allot(TYPE_GUINT),
    GtkLayout_hadjustment               = allot(TYPE_POINTER),
    GtkLayout_vadjustment               = allot(TYPE_POINTER),
    GtkLayout_bin_window                = allot(TYPE_POINTER),
    GtkLayout_visibility                = allot(SIZEOF_GdkVisibilityState),
    GtkLayout_configure_serial          = allot(TYPE_GULONG),
    GtkLayout_scroll_x                  = allot(TYPE_GINT),
    GtkLayout_scroll_y                  = allot(TYPE_GINT),
    GtkLayout_freeze_count              = allot(TYPE_GUINT),
    SIZEOF_GtkLayout                    = allotted_size()

----------------------------------------
-- GtkLayoutClass
----------------------------------------
global constant
    GtkLayoutClass_parent_class         = allot(SIZEOF_GtkContainerClass),
    GtkLayoutClass_set_scroll_adjustments= allot(TYPE_GPOINTER),
    SIZEOF_GtkLayoutClass               = allotted_size()
----------------------------------------
-- gtk_layout_get_type
----------------------------------------
constant gtk_layout_get_type_ = link_c_func( GTK, 
  "gtk_layout_get_type", {}, C_UINT )

global function gtk_layout_get_type()
    return c_func( gtk_layout_get_type_, {} )
end function

----------------------------------------
-- gtk_layout_new
----------------------------------------
constant gtk_layout_new_ = link_c_func( GTK, 
  "gtk_layout_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_layout_new(atom hadjustment_, atom vadjustment_)
    return c_func( gtk_layout_new_, {hadjustment_,vadjustment_} )
end function

----------------------------------------
-- gtk_layout_put
----------------------------------------
constant gtk_layout_put_ = link_c_proc( GTK, 
  "gtk_layout_put", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_layout_put(atom layout_, atom widget_, integer x_, integer y_)
    c_proc( gtk_layout_put_, {layout_,widget_,x_,y_} )
end procedure

----------------------------------------
-- gtk_layout_move
----------------------------------------
constant gtk_layout_move_ = link_c_proc( GTK, 
  "gtk_layout_move", {C_POINTER,C_POINTER,C_INT,C_INT} )

global procedure gtk_layout_move(atom layout_, atom widget_, integer x_, integer y_)
    c_proc( gtk_layout_move_, {layout_,widget_,x_,y_} )
end procedure

----------------------------------------
-- gtk_layout_set_size
----------------------------------------
constant gtk_layout_set_size_ = link_c_proc( GTK, 
  "gtk_layout_set_size", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_layout_set_size(atom layout_, integer width_, integer height_)
    c_proc( gtk_layout_set_size_, {layout_,width_,height_} )
end procedure

----------------------------------------
-- gtk_layout_get_hadjustment
----------------------------------------
constant gtk_layout_get_hadjustment_ = link_c_func( GTK, 
  "gtk_layout_get_hadjustment", {C_POINTER}, C_POINTER )

global function gtk_layout_get_hadjustment(atom layout_)
    return c_func( gtk_layout_get_hadjustment_, {layout_} )
end function

----------------------------------------
-- gtk_layout_get_vadjustment
----------------------------------------
constant gtk_layout_get_vadjustment_ = link_c_func( GTK, 
  "gtk_layout_get_vadjustment", {C_POINTER}, C_POINTER )

global function gtk_layout_get_vadjustment(atom layout_)
    return c_func( gtk_layout_get_vadjustment_, {layout_} )
end function

----------------------------------------
-- gtk_layout_set_hadjustment
----------------------------------------
constant gtk_layout_set_hadjustment_ = link_c_proc( GTK, 
  "gtk_layout_set_hadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_layout_set_hadjustment(atom layout_, atom adjustment_)
    c_proc( gtk_layout_set_hadjustment_, {layout_,adjustment_} )
end procedure

----------------------------------------
-- gtk_layout_set_vadjustment
----------------------------------------
constant gtk_layout_set_vadjustment_ = link_c_proc( GTK, 
  "gtk_layout_set_vadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_layout_set_vadjustment(atom layout_, atom adjustment_)
    c_proc( gtk_layout_set_vadjustment_, {layout_,adjustment_} )
end procedure

----------------------------------------
-- gtk_layout_freeze
----------------------------------------
constant gtk_layout_freeze_ = link_c_proc( GTK, 
  "gtk_layout_freeze", {C_POINTER} )

global procedure gtk_layout_freeze(atom layout_)
    c_proc( gtk_layout_freeze_, {layout_} )
end procedure

----------------------------------------
-- gtk_layout_thaw
----------------------------------------
constant gtk_layout_thaw_ = link_c_proc( GTK, 
  "gtk_layout_thaw", {C_POINTER} )

global procedure gtk_layout_thaw(atom layout_)
    c_proc( gtk_layout_thaw_, {layout_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKLIST.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkList
----------------------------------------
global constant
    GtkList_container                   = allot(SIZEOF_GtkContainer),
    GtkList_children                    = allot(TYPE_POINTER),
    GtkList_selection                   = allot(TYPE_POINTER),
    GtkList_undo_selection              = allot(TYPE_POINTER),
    GtkList_undo_unselection            = allot(TYPE_POINTER),
    GtkList_last_focus_child            = allot(TYPE_POINTER),
    GtkList_undo_focus_child            = allot(TYPE_POINTER),
    GtkList_htimer                      = allot(TYPE_GUINT),
    GtkList_vtimer                      = allot(TYPE_GUINT),
    GtkList_anchor                      = allot(TYPE_GINT),
    GtkList_drag_pos                    = allot(TYPE_GINT),
    GtkList_anchor_state                = allot(SIZEOF_GtkStateType),
    GtkList_selection_mode              = allot(TYPE_GUINT),
    GtkList_drag_selection              = allot(TYPE_GUINT),
    GtkList_add_mode                    = allot(TYPE_GUINT),
    SIZEOF_GtkList                      = allotted_size()

----------------------------------------
-- GtkListClass
----------------------------------------
global constant
    GtkListClass_parent_class           = allot(SIZEOF_GtkContainerClass),
    GtkListClass_selection_changed      = allot(TYPE_GPOINTER),
    GtkListClass_select_child           = allot(TYPE_GPOINTER),
    GtkListClass_unselect_child         = allot(TYPE_GPOINTER),
    SIZEOF_GtkListClass                 = allotted_size()
----------------------------------------
-- gtk_list_get_type
----------------------------------------
constant gtk_list_get_type_ = link_c_func( GTK, 
  "gtk_list_get_type", {}, C_UINT )

global function gtk_list_get_type()
    return c_func( gtk_list_get_type_, {} )
end function

----------------------------------------
-- gtk_list_new
----------------------------------------
constant gtk_list_new_ = link_c_func( GTK, 
  "gtk_list_new", {}, C_POINTER )

global function gtk_list_new()
    return c_func( gtk_list_new_, {} )
end function

----------------------------------------
-- gtk_list_insert_items
----------------------------------------
constant gtk_list_insert_items_ = link_c_proc( GTK, 
  "gtk_list_insert_items", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_list_insert_items(atom list_, atom items_, integer position_)
    c_proc( gtk_list_insert_items_, {list_,items_,position_} )
end procedure

----------------------------------------
-- gtk_list_append_items
----------------------------------------
constant gtk_list_append_items_ = link_c_proc( GTK, 
  "gtk_list_append_items", {C_POINTER,C_POINTER} )

global procedure gtk_list_append_items(atom list_, atom items_)
    c_proc( gtk_list_append_items_, {list_,items_} )
end procedure

----------------------------------------
-- gtk_list_prepend_items
----------------------------------------
constant gtk_list_prepend_items_ = link_c_proc( GTK, 
  "gtk_list_prepend_items", {C_POINTER,C_POINTER} )

global procedure gtk_list_prepend_items(atom list_, atom items_)
    c_proc( gtk_list_prepend_items_, {list_,items_} )
end procedure

----------------------------------------
-- gtk_list_remove_items
----------------------------------------
constant gtk_list_remove_items_ = link_c_proc( GTK, 
  "gtk_list_remove_items", {C_POINTER,C_POINTER} )

global procedure gtk_list_remove_items(atom list_, atom items_)
    c_proc( gtk_list_remove_items_, {list_,items_} )
end procedure

----------------------------------------
-- gtk_list_remove_items_no_unref
----------------------------------------
constant gtk_list_remove_items_no_unref_ = link_c_proc( GTK, 
  "gtk_list_remove_items_no_unref", {C_POINTER,C_POINTER} )

global procedure gtk_list_remove_items_no_unref(atom list_, atom items_)
    c_proc( gtk_list_remove_items_no_unref_, {list_,items_} )
end procedure

----------------------------------------
-- gtk_list_clear_items
----------------------------------------
constant gtk_list_clear_items_ = link_c_proc( GTK, 
  "gtk_list_clear_items", {C_POINTER,C_INT,C_INT} )

global procedure gtk_list_clear_items(atom list_, integer start_, integer end_)
    c_proc( gtk_list_clear_items_, {list_,start_,end_} )
end procedure

----------------------------------------
-- gtk_list_select_item
----------------------------------------
constant gtk_list_select_item_ = link_c_proc( GTK, 
  "gtk_list_select_item", {C_POINTER,C_INT} )

global procedure gtk_list_select_item(atom list_, integer item_)
    c_proc( gtk_list_select_item_, {list_,item_} )
end procedure

----------------------------------------
-- gtk_list_unselect_item
----------------------------------------
constant gtk_list_unselect_item_ = link_c_proc( GTK, 
  "gtk_list_unselect_item", {C_POINTER,C_INT} )

global procedure gtk_list_unselect_item(atom list_, integer item_)
    c_proc( gtk_list_unselect_item_, {list_,item_} )
end procedure

----------------------------------------
-- gtk_list_select_child
----------------------------------------
constant gtk_list_select_child_ = link_c_proc( GTK, 
  "gtk_list_select_child", {C_POINTER,C_POINTER} )

global procedure gtk_list_select_child(atom list_, atom child_)
    c_proc( gtk_list_select_child_, {list_,child_} )
end procedure

----------------------------------------
-- gtk_list_unselect_child
----------------------------------------
constant gtk_list_unselect_child_ = link_c_proc( GTK, 
  "gtk_list_unselect_child", {C_POINTER,C_POINTER} )

global procedure gtk_list_unselect_child(atom list_, atom child_)
    c_proc( gtk_list_unselect_child_, {list_,child_} )
end procedure

----------------------------------------
-- gtk_list_child_position
----------------------------------------
constant gtk_list_child_position_ = link_c_func( GTK, 
  "gtk_list_child_position", {C_POINTER,C_POINTER}, C_INT )

global function gtk_list_child_position(atom list_, atom child_)
    return c_func( gtk_list_child_position_, {list_,child_} )
end function

----------------------------------------
-- gtk_list_set_selection_mode
----------------------------------------
constant gtk_list_set_selection_mode_ = link_c_proc( GTK, 
  "gtk_list_set_selection_mode", {C_POINTER,C_POINTER} )

global procedure gtk_list_set_selection_mode(atom list_, atom mode_)
    c_proc( gtk_list_set_selection_mode_, {list_,mode_} )
end procedure

----------------------------------------
-- gtk_list_extend_selection
----------------------------------------
constant gtk_list_extend_selection_ = link_c_proc( GTK, 
  "gtk_list_extend_selection", {C_POINTER,C_POINTER,C_LONG,C_INT} )

global procedure gtk_list_extend_selection(atom list_, atom scroll_type_, integer position_, integer auto_start_selection_)
    c_proc( gtk_list_extend_selection_, {list_,scroll_type_,position_,auto_start_selection_} )
end procedure

----------------------------------------
-- gtk_list_start_selection
----------------------------------------
constant gtk_list_start_selection_ = link_c_proc( GTK, 
  "gtk_list_start_selection", {C_POINTER} )

global procedure gtk_list_start_selection(atom list_)
    c_proc( gtk_list_start_selection_, {list_} )
end procedure

----------------------------------------
-- gtk_list_end_selection
----------------------------------------
constant gtk_list_end_selection_ = link_c_proc( GTK, 
  "gtk_list_end_selection", {C_POINTER} )

global procedure gtk_list_end_selection(atom list_)
    c_proc( gtk_list_end_selection_, {list_} )
end procedure

----------------------------------------
-- gtk_list_select_all
----------------------------------------
constant gtk_list_select_all_ = link_c_proc( GTK, 
  "gtk_list_select_all", {C_POINTER} )

global procedure gtk_list_select_all(atom list_)
    c_proc( gtk_list_select_all_, {list_} )
end procedure

----------------------------------------
-- gtk_list_unselect_all
----------------------------------------
constant gtk_list_unselect_all_ = link_c_proc( GTK, 
  "gtk_list_unselect_all", {C_POINTER} )

global procedure gtk_list_unselect_all(atom list_)
    c_proc( gtk_list_unselect_all_, {list_} )
end procedure

----------------------------------------
-- gtk_list_scroll_horizontal
----------------------------------------
constant gtk_list_scroll_horizontal_ = link_c_proc( GTK, 
  "gtk_list_scroll_horizontal", {C_POINTER,C_POINTER,C_LONG} )

global procedure gtk_list_scroll_horizontal(atom list_, atom scroll_type_, integer position_)
    c_proc( gtk_list_scroll_horizontal_, {list_,scroll_type_,position_} )
end procedure

----------------------------------------
-- gtk_list_scroll_vertical
----------------------------------------
constant gtk_list_scroll_vertical_ = link_c_proc( GTK, 
  "gtk_list_scroll_vertical", {C_POINTER,C_POINTER,C_LONG} )

global procedure gtk_list_scroll_vertical(atom list_, atom scroll_type_, integer position_)
    c_proc( gtk_list_scroll_vertical_, {list_,scroll_type_,position_} )
end procedure

----------------------------------------
-- gtk_list_toggle_add_mode
----------------------------------------
constant gtk_list_toggle_add_mode_ = link_c_proc( GTK, 
  "gtk_list_toggle_add_mode", {C_POINTER} )

global procedure gtk_list_toggle_add_mode(atom list_)
    c_proc( gtk_list_toggle_add_mode_, {list_} )
end procedure

----------------------------------------
-- gtk_list_toggle_focus_row
----------------------------------------
constant gtk_list_toggle_focus_row_ = link_c_proc( GTK, 
  "gtk_list_toggle_focus_row", {C_POINTER} )

global procedure gtk_list_toggle_focus_row(atom list_)
    c_proc( gtk_list_toggle_focus_row_, {list_} )
end procedure

----------------------------------------
-- gtk_list_toggle_row
----------------------------------------
constant gtk_list_toggle_row_ = link_c_proc( GTK, 
  "gtk_list_toggle_row", {C_POINTER,C_POINTER} )

global procedure gtk_list_toggle_row(atom list_, atom item_)
    c_proc( gtk_list_toggle_row_, {list_,item_} )
end procedure

----------------------------------------
-- gtk_list_undo_selection
----------------------------------------
constant gtk_list_undo_selection_ = link_c_proc( GTK, 
  "gtk_list_undo_selection", {C_POINTER} )

global procedure gtk_list_undo_selection(atom list_)
    c_proc( gtk_list_undo_selection_, {list_} )
end procedure

----------------------------------------
-- gtk_list_end_drag_selection
----------------------------------------
constant gtk_list_end_drag_selection_ = link_c_proc( GTK, 
  "gtk_list_end_drag_selection", {C_POINTER} )

global procedure gtk_list_end_drag_selection(atom list_)
    c_proc( gtk_list_end_drag_selection_, {list_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKLISTITEM.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkListItem
----------------------------------------
global constant
    GtkListItem_item                    = allot(SIZEOF_GtkItem),
    SIZEOF_GtkListItem                  = allotted_size()

----------------------------------------
-- GtkListItemClass
----------------------------------------
global constant
    GtkListItemClass_parent_class       = allot(SIZEOF_GtkItemClass),
    GtkListItemClass_toggle_focus_row   = allot(TYPE_GPOINTER),
    GtkListItemClass_select_all         = allot(TYPE_GPOINTER),
    GtkListItemClass_unselect_all       = allot(TYPE_GPOINTER),
    GtkListItemClass_undo_selection     = allot(TYPE_GPOINTER),
    GtkListItemClass_start_selection    = allot(TYPE_GPOINTER),
    GtkListItemClass_end_selection      = allot(TYPE_GPOINTER),
    GtkListItemClass_extend_selection   = allot(TYPE_GPOINTER),
    GtkListItemClass_scroll_horizontal  = allot(TYPE_GPOINTER),
    GtkListItemClass_scroll_vertical    = allot(TYPE_GPOINTER),
    GtkListItemClass_toggle_add_mode    = allot(TYPE_GPOINTER),
    SIZEOF_GtkListItemClass             = allotted_size()
----------------------------------------
-- gtk_list_item_get_type
----------------------------------------
constant gtk_list_item_get_type_ = link_c_func( GTK, 
  "gtk_list_item_get_type", {}, C_UINT )

global function gtk_list_item_get_type()
    return c_func( gtk_list_item_get_type_, {} )
end function

----------------------------------------
-- gtk_list_item_new
----------------------------------------
constant gtk_list_item_new_ = link_c_func( GTK, 
  "gtk_list_item_new", {}, C_POINTER )

global function gtk_list_item_new()
    return c_func( gtk_list_item_new_, {} )
end function

----------------------------------------
-- gtk_list_item_new_with_label
----------------------------------------
constant gtk_list_item_new_with_label_ = link_c_func( GTK, 
  "gtk_list_item_new_with_label", {C_POINTER}, C_POINTER )

global function gtk_list_item_new_with_label(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_list_item_new_with_label_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_list_item_select
----------------------------------------
constant gtk_list_item_select_ = link_c_proc( GTK, 
  "gtk_list_item_select", {C_POINTER} )

global procedure gtk_list_item_select(atom list_item_)
    c_proc( gtk_list_item_select_, {list_item_} )
end procedure

----------------------------------------
-- gtk_list_item_deselect
----------------------------------------
constant gtk_list_item_deselect_ = link_c_proc( GTK, 
  "gtk_list_item_deselect", {C_POINTER} )

global procedure gtk_list_item_deselect(atom list_item_)
    c_proc( gtk_list_item_deselect_, {list_item_} )
end procedure


----------------------------------------
----------------------------------------
-- GTKMENUSHELL.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkMenuShell
----------------------------------------
global constant
    GtkMenuShell_container              = allot(SIZEOF_GtkContainer),
    GtkMenuShell_children               = allot(TYPE_POINTER),
    GtkMenuShell_active_menu_item       = allot(TYPE_POINTER),
    GtkMenuShell_parent_menu_shell      = allot(TYPE_POINTER),
    GtkMenuShell_active                 = allot(TYPE_GUINT),
    GtkMenuShell_have_grab              = allot(TYPE_GUINT),
    GtkMenuShell_have_xgrab             = allot(TYPE_GUINT),
    GtkMenuShell_button                 = allot(TYPE_GUINT),
    GtkMenuShell_ignore_leave           = allot(TYPE_GUINT),
    GtkMenuShell_menu_flag              = allot(TYPE_GUINT),
    GtkMenuShell_ignore_enter           = allot(TYPE_GUINT),
    GtkMenuShell_activate_time          = allot(TYPE_GUINT32),
    SIZEOF_GtkMenuShell                 = allotted_size()

----------------------------------------
-- GtkMenuShellClass
----------------------------------------
global constant
    GtkMenuShellClass_parent_class      = allot(SIZEOF_GtkContainerClass),
    GtkMenuShellClass_submenu_placement = allot(TYPE_GUINT),
    GtkMenuShellClass_deactivate        = allot(TYPE_GPOINTER),
    GtkMenuShellClass_selection_done    = allot(TYPE_GPOINTER),
    GtkMenuShellClass_move_current      = allot(TYPE_GPOINTER),
    GtkMenuShellClass_activate_current  = allot(TYPE_GPOINTER),
    GtkMenuShellClass_cancel            = allot(TYPE_GPOINTER),
    SIZEOF_GtkMenuShellClass            = allotted_size()
----------------------------------------
-- gtk_menu_shell_get_type
----------------------------------------
constant gtk_menu_shell_get_type_ = link_c_func( GTK, 
  "gtk_menu_shell_get_type", {}, C_UINT )

global function gtk_menu_shell_get_type()
    return c_func( gtk_menu_shell_get_type_, {} )
end function

----------------------------------------
-- gtk_menu_shell_append
----------------------------------------
constant gtk_menu_shell_append_ = link_c_proc( GTK, 
  "gtk_menu_shell_append", {C_POINTER,C_POINTER} )

global procedure gtk_menu_shell_append(atom menu_shell_, atom child_)
    c_proc( gtk_menu_shell_append_, {menu_shell_,child_} )
end procedure

----------------------------------------
-- gtk_menu_shell_prepend
----------------------------------------
constant gtk_menu_shell_prepend_ = link_c_proc( GTK, 
  "gtk_menu_shell_prepend", {C_POINTER,C_POINTER} )

global procedure gtk_menu_shell_prepend(atom menu_shell_, atom child_)
    c_proc( gtk_menu_shell_prepend_, {menu_shell_,child_} )
end procedure

----------------------------------------
-- gtk_menu_shell_insert
----------------------------------------
constant gtk_menu_shell_insert_ = link_c_proc( GTK, 
  "gtk_menu_shell_insert", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_shell_insert(atom menu_shell_, atom child_, integer position_)
    c_proc( gtk_menu_shell_insert_, {menu_shell_,child_,position_} )
end procedure

----------------------------------------
-- gtk_menu_shell_deactivate
----------------------------------------
constant gtk_menu_shell_deactivate_ = link_c_proc( GTK, 
  "gtk_menu_shell_deactivate", {C_POINTER} )

global procedure gtk_menu_shell_deactivate(atom menu_shell_)
    c_proc( gtk_menu_shell_deactivate_, {menu_shell_} )
end procedure

----------------------------------------
-- gtk_menu_shell_select_item
----------------------------------------
constant gtk_menu_shell_select_item_ = link_c_proc( GTK, 
  "gtk_menu_shell_select_item", {C_POINTER,C_POINTER} )

global procedure gtk_menu_shell_select_item(atom menu_shell_, atom menu_item_)
    c_proc( gtk_menu_shell_select_item_, {menu_shell_,menu_item_} )
end procedure

----------------------------------------
-- gtk_menu_shell_deselect
----------------------------------------
constant gtk_menu_shell_deselect_ = link_c_proc( GTK, 
  "gtk_menu_shell_deselect", {C_POINTER} )

global procedure gtk_menu_shell_deselect(atom menu_shell_)
    c_proc( gtk_menu_shell_deselect_, {menu_shell_} )
end procedure

----------------------------------------
-- gtk_menu_shell_activate_item
----------------------------------------
constant gtk_menu_shell_activate_item_ = link_c_proc( GTK, 
  "gtk_menu_shell_activate_item", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_shell_activate_item(atom menu_shell_, atom menu_item_, integer force_deactivate_)
    c_proc( gtk_menu_shell_activate_item_, {menu_shell_,menu_item_,force_deactivate_} )
end procedure





----------------------------------------
----------------------------------------
-- GTKMENU.H
----------------------------------------
----------------------------------------


----------------------------------------
-- GtkMenuPositionFunc
----------------------------------------
constant GtkMenuPositionFunc_ = link_c_proc( GTK, 
  "GtkMenuPositionFunc", {C_POINTER,C_INT,C_INT,C_POINTER} )

global procedure GtkMenuPositionFunc(atom menu_, integer x_, integer y_, atom user_data_)
    c_proc( GtkMenuPositionFunc_, {menu_,x_,y_,user_data_} )
end procedure

----------------------------------------
-- GtkMenuDetachFunc
----------------------------------------
constant GtkMenuDetachFunc_ = link_c_proc( GTK, 
  "GtkMenuDetachFunc", {C_POINTER,C_POINTER} )

global procedure GtkMenuDetachFunc(atom attach_widget_, atom menu_)
    c_proc( GtkMenuDetachFunc_, {attach_widget_,menu_} )
end procedure


----------------------------------------
-- GtkMenu
----------------------------------------
-- manually corrected:
-- changed GtkMenuPositionFunc to TYPE_POINTER
global constant
    GtkMenu_menu_shell                  = allot(SIZEOF_GtkMenuShell),
    GtkMenu_parent_menu_item            = allot(TYPE_POINTER),
    GtkMenu_old_active_menu_item        = allot(TYPE_POINTER),
    GtkMenu_accel_group                 = allot(TYPE_POINTER),
    GtkMenu_position_func               = allot(TYPE_POINTER),
    GtkMenu_position_func_data          = allot(TYPE_GPOINTER),
    GtkMenu_toplevel                    = allot(TYPE_POINTER),
    GtkMenu_tearoff_window              = allot(TYPE_POINTER),
    GtkMenu_torn_off                    = allot(TYPE_GUINT),
    SIZEOF_GtkMenu                      = allotted_size()

----------------------------------------
-- GtkMenuClass
----------------------------------------
global constant
    GtkMenuClass_parent_class           = allot(SIZEOF_GtkMenuShellClass),
    SIZEOF_GtkMenuClass                 = allotted_size()
----------------------------------------
-- gtk_menu_get_type
----------------------------------------
constant gtk_menu_get_type_ = link_c_func( GTK, 
  "gtk_menu_get_type", {}, C_UINT )

global function gtk_menu_get_type()
    return c_func( gtk_menu_get_type_, {} )
end function

----------------------------------------
-- gtk_menu_new
----------------------------------------
constant gtk_menu_new_ = link_c_func( GTK, 
  "gtk_menu_new", {}, C_POINTER )

global function gtk_menu_new()
    return c_func( gtk_menu_new_, {} )
end function

----------------------------------------
-- gtk_menu_append
----------------------------------------
constant gtk_menu_append_ = link_c_proc( GTK, 
  "gtk_menu_append", {C_POINTER,C_POINTER} )

global procedure gtk_menu_append(atom menu_, atom child_)
    c_proc( gtk_menu_append_, {menu_,child_} )
end procedure

----------------------------------------
-- gtk_menu_prepend
----------------------------------------
constant gtk_menu_prepend_ = link_c_proc( GTK, 
  "gtk_menu_prepend", {C_POINTER,C_POINTER} )

global procedure gtk_menu_prepend(atom menu_, atom child_)
    c_proc( gtk_menu_prepend_, {menu_,child_} )
end procedure

----------------------------------------
-- gtk_menu_insert
----------------------------------------
constant gtk_menu_insert_ = link_c_proc( GTK, 
  "gtk_menu_insert", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_insert(atom menu_, atom child_, integer position_)
    c_proc( gtk_menu_insert_, {menu_,child_,position_} )
end procedure

----------------------------------------
-- gtk_menu_popup
----------------------------------------
constant gtk_menu_popup_ = link_c_proc( GTK, 
  "gtk_menu_popup", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_UINT,C_UINT} )

global procedure gtk_menu_popup(atom menu_, atom parent_menu_shell_, atom parent_menu_item_, atom func_, atom 
 data_, integer button_, atom activate_time_)
    c_proc( gtk_menu_popup_, {menu_,parent_menu_shell_,parent_menu_item_,func_,data_,button_,activate_time_} )
end procedure

----------------------------------------
-- gtk_menu_reposition
----------------------------------------
constant gtk_menu_reposition_ = link_c_proc( GTK, 
  "gtk_menu_reposition", {C_POINTER} )

global procedure gtk_menu_reposition(atom menu_)
    c_proc( gtk_menu_reposition_, {menu_} )
end procedure

----------------------------------------
-- gtk_menu_popdown
----------------------------------------
constant gtk_menu_popdown_ = link_c_proc( GTK, 
  "gtk_menu_popdown", {C_POINTER} )

global procedure gtk_menu_popdown(atom menu_)
    c_proc( gtk_menu_popdown_, {menu_} )
end procedure

----------------------------------------
-- gtk_menu_get_active
----------------------------------------
constant gtk_menu_get_active_ = link_c_func( GTK, 
  "gtk_menu_get_active", {C_POINTER}, C_POINTER )

global function gtk_menu_get_active(atom menu_)
    return c_func( gtk_menu_get_active_, {menu_} )
end function

----------------------------------------
-- gtk_menu_set_active
----------------------------------------
constant gtk_menu_set_active_ = link_c_proc( GTK, 
  "gtk_menu_set_active", {C_POINTER,C_UINT} )

global procedure gtk_menu_set_active(atom menu_, integer index_)
    c_proc( gtk_menu_set_active_, {menu_,index_} )
end procedure

----------------------------------------
-- gtk_menu_set_accel_group
----------------------------------------
constant gtk_menu_set_accel_group_ = link_c_proc( GTK, 
  "gtk_menu_set_accel_group", {C_POINTER,C_POINTER} )

global procedure gtk_menu_set_accel_group(atom menu_, atom accel_group_)
    c_proc( gtk_menu_set_accel_group_, {menu_,accel_group_} )
end procedure

----------------------------------------
-- gtk_menu_get_accel_group
----------------------------------------
constant gtk_menu_get_accel_group_ = link_c_func( GTK, 
  "gtk_menu_get_accel_group", {C_POINTER}, C_POINTER )

global function gtk_menu_get_accel_group(atom menu_)
    return c_func( gtk_menu_get_accel_group_, {menu_} )
end function

----------------------------------------
-- gtk_menu_get_uline_accel_group
----------------------------------------
constant gtk_menu_get_uline_accel_group_ = link_c_func( GTK, 
  "gtk_menu_get_uline_accel_group", {C_POINTER}, C_POINTER )

global function gtk_menu_get_uline_accel_group(atom menu_)
    return c_func( gtk_menu_get_uline_accel_group_, {menu_} )
end function

----------------------------------------
-- gtk_menu_ensure_uline_accel_group
----------------------------------------
constant gtk_menu_ensure_uline_accel_group_ = link_c_func( GTK, 
  "gtk_menu_ensure_uline_accel_group", {C_POINTER}, C_POINTER )

global function gtk_menu_ensure_uline_accel_group(atom menu_)
    return c_func( gtk_menu_ensure_uline_accel_group_, {menu_} )
end function

----------------------------------------
-- gtk_menu_attach_to_widget
----------------------------------------
constant gtk_menu_attach_to_widget_ = link_c_proc( GTK, 
  "gtk_menu_attach_to_widget", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_menu_attach_to_widget(atom menu_, atom attach_widget_, atom detacher_)
    c_proc( gtk_menu_attach_to_widget_, {menu_,attach_widget_,detacher_} )
end procedure

----------------------------------------
-- gtk_menu_detach
----------------------------------------
constant gtk_menu_detach_ = link_c_proc( GTK, 
  "gtk_menu_detach", {C_POINTER} )

global procedure gtk_menu_detach(atom menu_)
    c_proc( gtk_menu_detach_, {menu_} )
end procedure

----------------------------------------
-- gtk_menu_get_attach_widget
----------------------------------------
constant gtk_menu_get_attach_widget_ = link_c_func( GTK, 
  "gtk_menu_get_attach_widget", {C_POINTER}, C_POINTER )

global function gtk_menu_get_attach_widget(atom menu_)
    return c_func( gtk_menu_get_attach_widget_, {menu_} )
end function

----------------------------------------
-- gtk_menu_set_tearoff_state
----------------------------------------
constant gtk_menu_set_tearoff_state_ = link_c_proc( GTK, 
  "gtk_menu_set_tearoff_state", {C_POINTER,C_INT} )

global procedure gtk_menu_set_tearoff_state(atom menu_, integer torn_off_)
    c_proc( gtk_menu_set_tearoff_state_, {menu_,torn_off_} )
end procedure

----------------------------------------
-- gtk_menu_set_title
----------------------------------------
constant gtk_menu_set_title_ = link_c_proc( GTK, 
  "gtk_menu_set_title", {C_POINTER,C_POINTER} )

global procedure gtk_menu_set_title(atom menu_, sequence title_)
    atom string1
    string1 = allocate_string( title_ )
    c_proc( gtk_menu_set_title_, {menu_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_menu_reorder_child
----------------------------------------
constant gtk_menu_reorder_child_ = link_c_proc( GTK, 
  "gtk_menu_reorder_child", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_reorder_child(atom menu_, atom child_, integer position_)
    c_proc( gtk_menu_reorder_child_, {menu_,child_,position_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKMENUBAR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkMenuBar
----------------------------------------
global constant
    GtkMenuBar_menu_shell               = allot(SIZEOF_GtkMenuShell),
    GtkMenuBar_shadow_type              = allot(SIZEOF_GtkShadowType),
    SIZEOF_GtkMenuBar                   = allotted_size()

----------------------------------------
-- GtkMenuBarClass
----------------------------------------
global constant
    GtkMenuBarClass_parent_class        = allot(SIZEOF_GtkMenuShellClass),
    SIZEOF_GtkMenuBarClass              = allotted_size()
----------------------------------------
-- gtk_menu_bar_get_type
----------------------------------------
constant gtk_menu_bar_get_type_ = link_c_func( GTK, 
  "gtk_menu_bar_get_type", {}, C_UINT )

global function gtk_menu_bar_get_type()
    return c_func( gtk_menu_bar_get_type_, {} )
end function

----------------------------------------
-- gtk_menu_bar_new
----------------------------------------
constant gtk_menu_bar_new_ = link_c_func( GTK, 
  "gtk_menu_bar_new", {}, C_POINTER )

global function gtk_menu_bar_new()
    return c_func( gtk_menu_bar_new_, {} )
end function

----------------------------------------
-- gtk_menu_bar_append
----------------------------------------
constant gtk_menu_bar_append_ = link_c_proc( GTK, 
  "gtk_menu_bar_append", {C_POINTER,C_POINTER} )

global procedure gtk_menu_bar_append(atom menu_bar_, atom child_)
    c_proc( gtk_menu_bar_append_, {menu_bar_,child_} )
end procedure

----------------------------------------
-- gtk_menu_bar_prepend
----------------------------------------
constant gtk_menu_bar_prepend_ = link_c_proc( GTK, 
  "gtk_menu_bar_prepend", {C_POINTER,C_POINTER} )

global procedure gtk_menu_bar_prepend(atom menu_bar_, atom child_)
    c_proc( gtk_menu_bar_prepend_, {menu_bar_,child_} )
end procedure

----------------------------------------
-- gtk_menu_bar_insert
----------------------------------------
constant gtk_menu_bar_insert_ = link_c_proc( GTK, 
  "gtk_menu_bar_insert", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_menu_bar_insert(atom menu_bar_, atom child_, integer position_)
    c_proc( gtk_menu_bar_insert_, {menu_bar_,child_,position_} )
end procedure

----------------------------------------
-- gtk_menu_bar_set_shadow_type
----------------------------------------
constant gtk_menu_bar_set_shadow_type_ = link_c_proc( GTK, 
  "gtk_menu_bar_set_shadow_type", {C_POINTER,C_POINTER} )

global procedure gtk_menu_bar_set_shadow_type(atom menu_bar_, atom type_)
    c_proc( gtk_menu_bar_set_shadow_type_, {menu_bar_,type_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKOPTIONMENU.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkOptionMenu
----------------------------------------
global constant
    GtkOptionMenu_button                = allot(SIZEOF_GtkButton),
    GtkOptionMenu_menu                  = allot(TYPE_POINTER),
    GtkOptionMenu_menu_item             = allot(TYPE_POINTER),
    GtkOptionMenu_width                 = allot(TYPE_GUINT16),
    GtkOptionMenu_height                = allot(TYPE_GUINT16),
    SIZEOF_GtkOptionMenu                = allotted_size()

----------------------------------------
-- GtkOptionMenuClass
----------------------------------------
global constant
    GtkOptionMenuClass_parent_class     = allot(SIZEOF_GtkButtonClass),
    SIZEOF_GtkOptionMenuClass           = allotted_size()
----------------------------------------
-- gtk_option_menu_get_type
----------------------------------------
constant gtk_option_menu_get_type_ = link_c_func( GTK, 
  "gtk_option_menu_get_type", {}, C_UINT )

global function gtk_option_menu_get_type()
    return c_func( gtk_option_menu_get_type_, {} )
end function

----------------------------------------
-- gtk_option_menu_new
----------------------------------------
constant gtk_option_menu_new_ = link_c_func( GTK, 
  "gtk_option_menu_new", {}, C_POINTER )

global function gtk_option_menu_new()
    return c_func( gtk_option_menu_new_, {} )
end function

----------------------------------------
-- gtk_option_menu_get_menu
----------------------------------------
constant gtk_option_menu_get_menu_ = link_c_func( GTK, 
  "gtk_option_menu_get_menu", {C_POINTER}, C_POINTER )

global function gtk_option_menu_get_menu(atom option_menu_)
    return c_func( gtk_option_menu_get_menu_, {option_menu_} )
end function

----------------------------------------
-- gtk_option_menu_set_menu
----------------------------------------
constant gtk_option_menu_set_menu_ = link_c_proc( GTK, 
  "gtk_option_menu_set_menu", {C_POINTER,C_POINTER} )

global procedure gtk_option_menu_set_menu(atom option_menu_, atom menu_)
    c_proc( gtk_option_menu_set_menu_, {option_menu_,menu_} )
end procedure

----------------------------------------
-- gtk_option_menu_remove_menu
----------------------------------------
constant gtk_option_menu_remove_menu_ = link_c_proc( GTK, 
  "gtk_option_menu_remove_menu", {C_POINTER} )

global procedure gtk_option_menu_remove_menu(atom option_menu_)
    c_proc( gtk_option_menu_remove_menu_, {option_menu_} )
end procedure

----------------------------------------
-- gtk_option_menu_set_history
----------------------------------------
constant gtk_option_menu_set_history_ = link_c_proc( GTK, 
  "gtk_option_menu_set_history", {C_POINTER,C_UINT} )

global procedure gtk_option_menu_set_history(atom option_menu_, integer index_)
    c_proc( gtk_option_menu_set_history_, {option_menu_,index_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKPACKER.H
----------------------------------------
----------------------------------------


global constant
    GTK_PACK_EXPAND                     = power(2,0),
    GTK_FILL_X                          = power(2,1),
    GTK_FILL_Y                          = power(2,2)
global constant SIZEOF_GtkPackerOptions = SIZEOF_ENUM

global constant
    GTK_SIDE_TOP                        = 1,
    GTK_SIDE_BOTTOM                     = 2,
    GTK_SIDE_LEFT                       = 3,
    GTK_SIDE_RIGHT                      = 4
global constant SIZEOF_GtkSideType = SIZEOF_ENUM

global constant
    GTK_ANCHOR_CENTER                   = 1,
    GTK_ANCHOR_NORTH                    = 2,
    GTK_ANCHOR_NORTH_WEST               = 3,
    GTK_ANCHOR_NORTH_EAST               = 4,
    GTK_ANCHOR_SOUTH                    = 5,
    GTK_ANCHOR_SOUTH_WEST               = 6,
    GTK_ANCHOR_SOUTH_EAST               = 7,
    GTK_ANCHOR_WEST                     = 8,
    GTK_ANCHOR_EAST                     = 9,
    GTK_ANCHOR_N                        = GTK_ANCHOR_NORTH,
    GTK_ANCHOR_NW                       = GTK_ANCHOR_NORTH_WEST,
    GTK_ANCHOR_NE                       = GTK_ANCHOR_NORTH_EAST,
    GTK_ANCHOR_S                        = GTK_ANCHOR_SOUTH,
    GTK_ANCHOR_SW                       = GTK_ANCHOR_SOUTH_WEST,
    GTK_ANCHOR_SE                       = GTK_ANCHOR_SOUTH_EAST,
    GTK_ANCHOR_W                        = GTK_ANCHOR_WEST,
    GTK_ANCHOR_E                        = GTK_ANCHOR_EAST
global constant SIZEOF_GtkAnchorType = SIZEOF_ENUM


----------------------------------------
-- GtkPackerChild
----------------------------------------
global constant
    GtkPackerChild_widget               = allot(TYPE_POINTER),
    GtkPackerChild_anchor               = allot(SIZEOF_GtkAnchorType),
    GtkPackerChild_side                 = allot(SIZEOF_GtkSideType),
    GtkPackerChild_options              = allot(SIZEOF_GtkPackerOptions),
    GtkPackerChild_use_default          = allot(TYPE_GUINT),
    GtkPackerChild_border_width         = allot(TYPE_GUINT),
    GtkPackerChild_pad_x                = allot(TYPE_GUINT),
    GtkPackerChild_pad_y                = allot(TYPE_GUINT),
    GtkPackerChild_i_pad_x              = allot(TYPE_GUINT),
    GtkPackerChild_i_pad_y              = allot(TYPE_GUINT),
    SIZEOF_GtkPackerChild               = allotted_size()

----------------------------------------
-- GtkPacker
----------------------------------------
global constant
    GtkPacker_parent                    = allot(SIZEOF_GtkContainer),
    GtkPacker_children                  = allot(TYPE_POINTER),
    GtkPacker_spacing                   = allot(TYPE_GUINT),
    GtkPacker_default_border_width      = allot(TYPE_GUINT),
    GtkPacker_default_pad_x             = allot(TYPE_GUINT),
    GtkPacker_default_pad_y             = allot(TYPE_GUINT),
    GtkPacker_default_i_pad_x           = allot(TYPE_GUINT),
    GtkPacker_default_i_pad_y           = allot(TYPE_GUINT),
    SIZEOF_GtkPacker                    = allotted_size()

----------------------------------------
-- GtkPackerClass
----------------------------------------
global constant
    GtkPackerClass_parent_class         = allot(SIZEOF_GtkContainerClass),
    SIZEOF_GtkPackerClass               = allotted_size()
----------------------------------------
-- gtk_packer_get_type
----------------------------------------
constant gtk_packer_get_type_ = link_c_func( GTK, 
  "gtk_packer_get_type", {}, C_UINT )

global function gtk_packer_get_type()
    return c_func( gtk_packer_get_type_, {} )
end function

----------------------------------------
-- gtk_packer_new
----------------------------------------
constant gtk_packer_new_ = link_c_func( GTK, 
  "gtk_packer_new", {}, C_POINTER )

global function gtk_packer_new()
    return c_func( gtk_packer_new_, {} )
end function

----------------------------------------
-- gtk_packer_add_defaults
----------------------------------------
constant gtk_packer_add_defaults_ = link_c_proc( GTK, 
  "gtk_packer_add_defaults", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_packer_add_defaults(atom packer_, atom child_, atom side_, atom anchor_, atom options_)
    c_proc( gtk_packer_add_defaults_, {packer_,child_,side_,anchor_,options_} )
end procedure

----------------------------------------
-- gtk_packer_add
----------------------------------------
constant gtk_packer_add_ = link_c_proc( GTK, 
  "gtk_packer_add", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_UINT,C_UINT,C_UINT,C_UINT,C_UINT} 
 )

global procedure gtk_packer_add(atom packer_, atom child_, atom side_, atom anchor_, atom options_, integer border_width_, 
 integer pad_x_, integer pad_y_, integer i_pad_x_, integer i_pad_y_)
    c_proc( gtk_packer_add_, {packer_,child_,side_,anchor_,options_,border_width_,pad_x_,pad_y_,i_pad_x_,i_pad_y_} )
end procedure

----------------------------------------
-- gtk_packer_set_child_packing
----------------------------------------
constant gtk_packer_set_child_packing_ = link_c_proc( GTK, 
  "gtk_packer_set_child_packing", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_UINT,C_UINT,C_UINT,C_UINT,C_UINT} 
 )

global procedure gtk_packer_set_child_packing(atom packer_, atom child_, atom side_, atom anchor_, atom options_, 
 integer border_width_, integer pad_x_, integer pad_y_, integer i_pad_x_, integer i_pad_y_)
    c_proc( gtk_packer_set_child_packing_, {packer_,child_,side_,anchor_,options_,border_width_,pad_x_,pad_y_,i_pad_x_,i_pad_y_} )
end procedure

----------------------------------------
-- gtk_packer_reorder_child
----------------------------------------
constant gtk_packer_reorder_child_ = link_c_proc( GTK, 
  "gtk_packer_reorder_child", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_packer_reorder_child(atom packer_, atom child_, integer position_)
    c_proc( gtk_packer_reorder_child_, {packer_,child_,position_} )
end procedure

----------------------------------------
-- gtk_packer_set_spacing
----------------------------------------
constant gtk_packer_set_spacing_ = link_c_proc( GTK, 
  "gtk_packer_set_spacing", {C_POINTER,C_UINT} )

global procedure gtk_packer_set_spacing(atom packer_, integer spacing_)
    c_proc( gtk_packer_set_spacing_, {packer_,spacing_} )
end procedure

----------------------------------------
-- gtk_packer_set_default_border_width
----------------------------------------
constant gtk_packer_set_default_border_width_ = link_c_proc( GTK, 
  "gtk_packer_set_default_border_width", {C_POINTER,C_UINT} )

global procedure gtk_packer_set_default_border_width(atom packer_, integer border_)
    c_proc( gtk_packer_set_default_border_width_, {packer_,border_} )
end procedure

----------------------------------------
-- gtk_packer_set_default_pad
----------------------------------------
constant gtk_packer_set_default_pad_ = link_c_proc( GTK, 
  "gtk_packer_set_default_pad", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_packer_set_default_pad(atom packer_, integer pad_x_, integer pad_y_)
    c_proc( gtk_packer_set_default_pad_, {packer_,pad_x_,pad_y_} )
end procedure

----------------------------------------
-- gtk_packer_set_default_ipad
----------------------------------------
constant gtk_packer_set_default_ipad_ = link_c_proc( GTK, 
  "gtk_packer_set_default_ipad", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_packer_set_default_ipad(atom packer_, integer i_pad_x_, integer i_pad_y_)
    c_proc( gtk_packer_set_default_ipad_, {packer_,i_pad_x_,i_pad_y_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKPIXMAP.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkPixmap
----------------------------------------
global constant
    GtkPixmap_misc                      = allot(SIZEOF_GtkMisc),
    GtkPixmap_pixmap                    = allot(TYPE_POINTER),
    GtkPixmap_mask                      = allot(TYPE_POINTER),
    GtkPixmap_pixmap_insensitive        = allot(TYPE_POINTER),
    GtkPixmap_build_insensitive         = allot(TYPE_GUINT),
    SIZEOF_GtkPixmap                    = allotted_size()

----------------------------------------
-- GtkPixmapClass
----------------------------------------
global constant
    GtkPixmapClass_parent_class         = allot(SIZEOF_GtkMiscClass),
    SIZEOF_GtkPixmapClass               = allotted_size()
----------------------------------------
-- gtk_pixmap_get_type
----------------------------------------
constant gtk_pixmap_get_type_ = link_c_func( GTK, 
  "gtk_pixmap_get_type", {}, C_UINT )

global function gtk_pixmap_get_type()
    return c_func( gtk_pixmap_get_type_, {} )
end function

----------------------------------------
-- gtk_pixmap_new
----------------------------------------
constant gtk_pixmap_new_ = link_c_func( GTK, 
  "gtk_pixmap_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_pixmap_new(atom pixmap_, atom mask_)
    return c_func( gtk_pixmap_new_, {pixmap_,mask_} )
end function

----------------------------------------
-- gtk_pixmap_set
----------------------------------------
constant gtk_pixmap_set_ = link_c_proc( GTK, 
  "gtk_pixmap_set", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_pixmap_set(atom pixmap_, atom val_, atom mask_)
    c_proc( gtk_pixmap_set_, {pixmap_,val_,mask_} )
end procedure

----------------------------------------
-- gtk_pixmap_get
----------------------------------------
constant gtk_pixmap_get_ = link_c_proc( GTK, 
  "gtk_pixmap_get", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_pixmap_get(atom pixmap_, atom val_, atom mask_)
    c_proc( gtk_pixmap_get_, {pixmap_,val_,mask_} )
end procedure

----------------------------------------
-- gtk_pixmap_set_build_insensitive
----------------------------------------
constant gtk_pixmap_set_build_insensitive_ = link_c_proc( GTK, 
  "gtk_pixmap_set_build_insensitive", {C_POINTER,C_UINT} )

global procedure gtk_pixmap_set_build_insensitive(atom pixmap_, integer build_)
    c_proc( gtk_pixmap_set_build_insensitive_, {pixmap_,build_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKPLUG.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkPlug
----------------------------------------
global constant
    GtkPlug_window                      = allot(SIZEOF_GtkWindow),
    GtkPlug_socket_window               = allot(TYPE_POINTER),
    GtkPlug_same_app                    = allot(TYPE_GINT),
    SIZEOF_GtkPlug                      = allotted_size()

----------------------------------------
-- GtkPlugClass
----------------------------------------
global constant
    GtkPlugClass_parent_class           = allot(SIZEOF_GtkWindowClass),
    SIZEOF_GtkPlugClass                 = allotted_size()
----------------------------------------
-- gtk_plug_get_type
----------------------------------------
constant gtk_plug_get_type_ = link_c_func( GTK, 
  "gtk_plug_get_type", {}, C_UINT )

global function gtk_plug_get_type()
    return c_func( gtk_plug_get_type_, {} )
end function

----------------------------------------
-- gtk_plug_construct
----------------------------------------
constant gtk_plug_construct_ = link_c_proc( GTK, 
  "gtk_plug_construct", {C_POINTER} )

global procedure gtk_plug_construct(atom plug_)
    c_proc( gtk_plug_construct_, {plug_} )
end procedure

----------------------------------------
-- gtk_plug_new
----------------------------------------
constant gtk_plug_new_ = link_c_func( GTK, 
  "gtk_plug_new", {C_UINT}, C_POINTER )

global function gtk_plug_new(atom socket_id_)
    return c_func( gtk_plug_new_, {socket_id_} )
end function



----------------------------------------
----------------------------------------
-- GTKPROGRESS.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkProgress
----------------------------------------
global constant
    GtkProgress_widget                  = allot(SIZEOF_GtkWidget),
    GtkProgress_adjustment              = allot(TYPE_POINTER),
    GtkProgress_offscreen_pixmap        = allot(TYPE_POINTER),
    GtkProgress_format                  = allot(TYPE_POINTER),
    GtkProgress_x_align                 = allot(TYPE_GFLOAT),
    GtkProgress_y_align                 = allot(TYPE_GFLOAT),
    GtkProgress_show_text               = allot(TYPE_GUINT),
    GtkProgress_activity_mode           = allot(TYPE_GUINT),
    SIZEOF_GtkProgress                  = allotted_size()

----------------------------------------
-- GtkProgressClass
----------------------------------------
global constant
    GtkProgressClass_parent_class       = allot(SIZEOF_GtkWidgetClass),
    GtkProgressClass_paint              = allot(TYPE_GPOINTER),
    GtkProgressClass_update             = allot(TYPE_GPOINTER),
    GtkProgressClass_act_mode_enter     = allot(TYPE_GPOINTER),
    SIZEOF_GtkProgressClass             = allotted_size()
----------------------------------------
-- gtk_progress_get_type
----------------------------------------
constant gtk_progress_get_type_ = link_c_func( GTK, 
  "gtk_progress_get_type", {}, C_UINT )

global function gtk_progress_get_type()
    return c_func( gtk_progress_get_type_, {} )
end function

----------------------------------------
-- gtk_progress_set_show_text
----------------------------------------
constant gtk_progress_set_show_text_ = link_c_proc( GTK, 
  "gtk_progress_set_show_text", {C_POINTER,C_INT} )

global procedure gtk_progress_set_show_text(atom progress_, integer show_text_)
    c_proc( gtk_progress_set_show_text_, {progress_,show_text_} )
end procedure

----------------------------------------
-- gtk_progress_set_text_alignment
----------------------------------------
constant gtk_progress_set_text_alignment_ = link_c_proc( GTK, 
  "gtk_progress_set_text_alignment", {C_POINTER,C_LONG,C_LONG} )

global procedure gtk_progress_set_text_alignment(atom progress_, integer x_align_, integer y_align_)
    c_proc( gtk_progress_set_text_alignment_, {progress_,x_align_,y_align_} )
end procedure

----------------------------------------
-- gtk_progress_set_format_string
----------------------------------------
constant gtk_progress_set_format_string_ = link_c_proc( GTK, 
  "gtk_progress_set_format_string", {C_POINTER,C_POINTER} )

global procedure gtk_progress_set_format_string(atom progress_, sequence format_)
    atom string1
    string1 = allocate_string( format_ )
    c_proc( gtk_progress_set_format_string_, {progress_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_progress_set_adjustment
----------------------------------------
constant gtk_progress_set_adjustment_ = link_c_proc( GTK, 
  "gtk_progress_set_adjustment", {C_POINTER,C_POINTER} )

global procedure gtk_progress_set_adjustment(atom progress_, atom adjustment_)
    c_proc( gtk_progress_set_adjustment_, {progress_,adjustment_} )
end procedure

----------------------------------------
-- gtk_progress_configure
----------------------------------------
constant gtk_progress_configure_ = link_c_proc( GTK, 
  "gtk_progress_configure", {C_POINTER,C_LONG,C_LONG,C_LONG} )

global procedure gtk_progress_configure(atom progress_, integer value_, integer min_, integer max_)
    c_proc( gtk_progress_configure_, {progress_,value_,min_,max_} )
end procedure

----------------------------------------
-- gtk_progress_set_percentage
----------------------------------------
constant gtk_progress_set_percentage_ = link_c_proc( GTK, 
  "gtk_progress_set_percentage", {C_POINTER,C_LONG} )

global procedure gtk_progress_set_percentage(atom progress_, integer percentage_)
    c_proc( gtk_progress_set_percentage_, {progress_,percentage_} )
end procedure

----------------------------------------
-- gtk_progress_set_value
----------------------------------------
constant gtk_progress_set_value_ = link_c_proc( GTK, 
  "gtk_progress_set_value", {C_POINTER,C_LONG} )

global procedure gtk_progress_set_value(atom progress_, integer value_)
    c_proc( gtk_progress_set_value_, {progress_,value_} )
end procedure

----------------------------------------
-- gtk_progress_get_value
----------------------------------------
constant gtk_progress_get_value_ = link_c_func( GTK, 
  "gtk_progress_get_value", {C_POINTER}, C_LONG )

global function gtk_progress_get_value(atom progress_)
    return c_func( gtk_progress_get_value_, {progress_} )
end function

----------------------------------------
-- gtk_progress_set_activity_mode
----------------------------------------
constant gtk_progress_set_activity_mode_ = link_c_proc( GTK, 
  "gtk_progress_set_activity_mode", {C_POINTER,C_UINT} )

global procedure gtk_progress_set_activity_mode(atom progress_, integer activity_mode_)
    c_proc( gtk_progress_set_activity_mode_, {progress_,activity_mode_} )
end procedure

----------------------------------------
-- gtk_progress_get_current_text
----------------------------------------
constant gtk_progress_get_current_text_ = link_c_func( GTK, 
  "gtk_progress_get_current_text", {C_POINTER}, C_POINTER )

global function gtk_progress_get_current_text(atom progress_)
    return peek_string( c_func( gtk_progress_get_current_text_, {progress_} ) )
end function

----------------------------------------
-- gtk_progress_get_text_from_value
----------------------------------------
constant gtk_progress_get_text_from_value_ = link_c_func( GTK, 
  "gtk_progress_get_text_from_value", {C_POINTER,C_LONG}, C_POINTER )

global function gtk_progress_get_text_from_value(atom progress_, integer value_)
    return peek_string( c_func( gtk_progress_get_text_from_value_, {progress_,value_} ) )
end function

----------------------------------------
-- gtk_progress_get_current_percentage
----------------------------------------
constant gtk_progress_get_current_percentage_ = link_c_func( GTK, 
  "gtk_progress_get_current_percentage", {C_POINTER}, C_LONG )

global function gtk_progress_get_current_percentage(atom progress_)
    return c_func( gtk_progress_get_current_percentage_, {progress_} )
end function

----------------------------------------
-- gtk_progress_get_percentage_from_value
----------------------------------------
constant gtk_progress_get_percentage_from_value_ = link_c_func( GTK, 
  "gtk_progress_get_percentage_from_value", {C_POINTER,C_LONG}, C_LONG )

global function gtk_progress_get_percentage_from_value(atom progress_, integer value_)
    return c_func( gtk_progress_get_percentage_from_value_, {progress_,value_} )
end function



----------------------------------------
----------------------------------------
-- GTKPROGRESSBAR.H
----------------------------------------
----------------------------------------


global constant
    GTK_PROGRESS_CONTINUOUS             = 1,
    GTK_PROGRESS_DISCRETE               = 2
global constant SIZEOF_GtkProgressBarStyle = SIZEOF_ENUM

global constant
    GTK_PROGRESS_LEFT_TO_RIGHT          = 1,
    GTK_PROGRESS_RIGHT_TO_LEFT          = 2,
    GTK_PROGRESS_BOTTOM_TO_TOP          = 3,
    GTK_PROGRESS_TOP_TO_BOTTOM          = 4
global constant SIZEOF_GtkProgressBarOrientation = SIZEOF_ENUM


----------------------------------------
-- GtkProgressBar
----------------------------------------
global constant
    GtkProgressBar_progress             = allot(SIZEOF_GtkProgress),
    GtkProgressBar_bar_style            = allot(SIZEOF_GtkProgressBarStyle),
    GtkProgressBar_orientation          = allot(SIZEOF_GtkProgressBarOrientation),
    GtkProgressBar_blocks               = allot(TYPE_GUINT),
    GtkProgressBar_in_block             = allot(TYPE_GINT),
    GtkProgressBar_activity_pos         = allot(TYPE_GINT),
    GtkProgressBar_activity_step        = allot(TYPE_GUINT),
    GtkProgressBar_activity_blocks      = allot(TYPE_GUINT),
    GtkProgressBar_activity_dir         = allot(TYPE_GUINT),
    SIZEOF_GtkProgressBar               = allotted_size()

----------------------------------------
-- GtkProgressBarClass
----------------------------------------
global constant
    GtkProgressBarClass_parent_class    = allot(SIZEOF_GtkProgressClass),
    SIZEOF_GtkProgressBarClass          = allotted_size()
----------------------------------------
-- gtk_progress_bar_get_type
----------------------------------------
constant gtk_progress_bar_get_type_ = link_c_func( GTK, 
  "gtk_progress_bar_get_type", {}, C_UINT )

global function gtk_progress_bar_get_type()
    return c_func( gtk_progress_bar_get_type_, {} )
end function

----------------------------------------
-- gtk_progress_bar_new
----------------------------------------
constant gtk_progress_bar_new_ = link_c_func( GTK, 
  "gtk_progress_bar_new", {}, C_POINTER )

global function gtk_progress_bar_new()
    return c_func( gtk_progress_bar_new_, {} )
end function

----------------------------------------
-- gtk_progress_bar_new_with_adjustment
----------------------------------------
constant gtk_progress_bar_new_with_adjustment_ = link_c_func( GTK, 
  "gtk_progress_bar_new_with_adjustment", {C_POINTER}, C_POINTER )

global function gtk_progress_bar_new_with_adjustment(atom adjustment_)
    return c_func( gtk_progress_bar_new_with_adjustment_, {adjustment_} )
end function

----------------------------------------
-- gtk_progress_bar_set_bar_style
----------------------------------------
constant gtk_progress_bar_set_bar_style_ = link_c_proc( GTK, 
  "gtk_progress_bar_set_bar_style", {C_POINTER,C_POINTER} )

global procedure gtk_progress_bar_set_bar_style(atom pbar_, atom style_)
    c_proc( gtk_progress_bar_set_bar_style_, {pbar_,style_} )
end procedure

----------------------------------------
-- gtk_progress_bar_set_discrete_blocks
----------------------------------------
constant gtk_progress_bar_set_discrete_blocks_ = link_c_proc( GTK, 
  "gtk_progress_bar_set_discrete_blocks", {C_POINTER,C_UINT} )

global procedure gtk_progress_bar_set_discrete_blocks(atom pbar_, integer blocks_)
    c_proc( gtk_progress_bar_set_discrete_blocks_, {pbar_,blocks_} )
end procedure

----------------------------------------
-- gtk_progress_bar_set_activity_step
----------------------------------------
constant gtk_progress_bar_set_activity_step_ = link_c_proc( GTK, 
  "gtk_progress_bar_set_activity_step", {C_POINTER,C_UINT} )

global procedure gtk_progress_bar_set_activity_step(atom pbar_, integer step_)
    c_proc( gtk_progress_bar_set_activity_step_, {pbar_,step_} )
end procedure

----------------------------------------
-- gtk_progress_bar_set_activity_blocks
----------------------------------------
constant gtk_progress_bar_set_activity_blocks_ = link_c_proc( GTK, 
  "gtk_progress_bar_set_activity_blocks", {C_POINTER,C_UINT} )

global procedure gtk_progress_bar_set_activity_blocks(atom pbar_, integer blocks_)
    c_proc( gtk_progress_bar_set_activity_blocks_, {pbar_,blocks_} )
end procedure

----------------------------------------
-- gtk_progress_bar_set_orientation
----------------------------------------
constant gtk_progress_bar_set_orientation_ = link_c_proc( GTK, 
  "gtk_progress_bar_set_orientation", {C_POINTER,C_POINTER} )

global procedure gtk_progress_bar_set_orientation(atom pbar_, atom orientation_)
    c_proc( gtk_progress_bar_set_orientation_, {pbar_,orientation_} )
end procedure

----------------------------------------
-- gtk_progress_bar_update
----------------------------------------
constant gtk_progress_bar_update_ = link_c_proc( GTK, 
  "gtk_progress_bar_update", {C_POINTER,C_LONG} )

global procedure gtk_progress_bar_update(atom pbar_, integer percentage_)
    c_proc( gtk_progress_bar_update_, {pbar_,percentage_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKRADIOBUTTON.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkRadioButton
----------------------------------------
global constant
    GtkRadioButton_check_button         = allot(SIZEOF_GtkCheckButton),
    GtkRadioButton_group                = allot(TYPE_POINTER),
    SIZEOF_GtkRadioButton               = allotted_size()

----------------------------------------
-- GtkRadioButtonClass
----------------------------------------
global constant
    GtkRadioButtonClass_parent_class    = allot(SIZEOF_GtkCheckButtonClass),
    SIZEOF_GtkRadioButtonClass          = allotted_size()
----------------------------------------
-- gtk_radio_button_get_type
----------------------------------------
constant gtk_radio_button_get_type_ = link_c_func( GTK, 
  "gtk_radio_button_get_type", {}, C_UINT )

global function gtk_radio_button_get_type()
    return c_func( gtk_radio_button_get_type_, {} )
end function

----------------------------------------
-- gtk_radio_button_new
----------------------------------------
constant gtk_radio_button_new_ = link_c_func( GTK, 
  "gtk_radio_button_new", {C_POINTER}, C_POINTER )

global function gtk_radio_button_new(atom group_)
    return c_func( gtk_radio_button_new_, {group_} )
end function

----------------------------------------
-- gtk_radio_button_new_from_widget
----------------------------------------
constant gtk_radio_button_new_from_widget_ = link_c_func( GTK, 
  "gtk_radio_button_new_from_widget", {C_POINTER}, C_POINTER )

global function gtk_radio_button_new_from_widget(atom group_)
    return c_func( gtk_radio_button_new_from_widget_, {group_} )
end function

----------------------------------------
-- gtk_radio_button_new_with_label
----------------------------------------
constant gtk_radio_button_new_with_label_ = link_c_func( GTK, 
  "gtk_radio_button_new_with_label", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_radio_button_new_with_label(atom group_, sequence label_)
    atom result
    atom string1
    string1 = allocate_string( label_ )
    result = c_func( gtk_radio_button_new_with_label_, {group_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_radio_button_new_with_label_from_widget
----------------------------------------
constant gtk_radio_button_new_with_label_from_widget_ = link_c_func( GTK, 
  "gtk_radio_button_new_with_label_from_widget", 
 {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_radio_button_new_with_label_from_widget(atom group_, sequence label_)
    atom result
    atom string1
    string1 = allocate_string( label_ )
    result = c_func( gtk_radio_button_new_with_label_from_widget_, {group_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_radio_button_group
----------------------------------------
constant gtk_radio_button_group_ = link_c_func( GTK, 
  "gtk_radio_button_group", {C_POINTER}, C_POINTER )

global function gtk_radio_button_group(atom radio_button_)
    return c_func( gtk_radio_button_group_, {radio_button_} )
end function

----------------------------------------
-- gtk_radio_button_set_group
----------------------------------------
constant gtk_radio_button_set_group_ = link_c_proc( GTK, 
  "gtk_radio_button_set_group", {C_POINTER,C_POINTER} )

global procedure gtk_radio_button_set_group(atom radio_button_, atom group_)
    c_proc( gtk_radio_button_set_group_, {radio_button_,group_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKRADIOMENUITEM.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkRadioMenuItem
----------------------------------------
global constant
    GtkRadioMenuItem_check_menu_item    = allot(SIZEOF_GtkCheckMenuItem),
    GtkRadioMenuItem_group              = allot(TYPE_POINTER),
    SIZEOF_GtkRadioMenuItem             = allotted_size()

----------------------------------------
-- GtkRadioMenuItemClass
----------------------------------------
global constant
    GtkRadioMenuItemClass_parent_class  = allot(SIZEOF_GtkCheckMenuItemClass),
    SIZEOF_GtkRadioMenuItemClass        = allotted_size()
----------------------------------------
-- gtk_radio_menu_item_get_type
----------------------------------------
constant gtk_radio_menu_item_get_type_ = link_c_func( GTK, 
  "gtk_radio_menu_item_get_type", {}, C_UINT )

global function gtk_radio_menu_item_get_type()
    return c_func( gtk_radio_menu_item_get_type_, {} )
end function

----------------------------------------
-- gtk_radio_menu_item_new
----------------------------------------
constant gtk_radio_menu_item_new_ = link_c_func( GTK, 
  "gtk_radio_menu_item_new", {C_POINTER}, C_POINTER )

global function gtk_radio_menu_item_new(atom group_)
    return c_func( gtk_radio_menu_item_new_, {group_} )
end function

----------------------------------------
-- gtk_radio_menu_item_new_with_label
----------------------------------------
constant gtk_radio_menu_item_new_with_label_ = link_c_func( GTK, 
  "gtk_radio_menu_item_new_with_label", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_radio_menu_item_new_with_label(atom group_, sequence label_)
    atom result
    atom string1
    string1 = allocate_string( label_ )
    result = c_func( gtk_radio_menu_item_new_with_label_, {group_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_radio_menu_item_group
----------------------------------------
constant gtk_radio_menu_item_group_ = link_c_func( GTK, 
  "gtk_radio_menu_item_group", {C_POINTER}, C_POINTER )

global function gtk_radio_menu_item_group(atom radio_menu_item_)
    return c_func( gtk_radio_menu_item_group_, {radio_menu_item_} )
end function

----------------------------------------
-- gtk_radio_menu_item_set_group
----------------------------------------
constant gtk_radio_menu_item_set_group_ = link_c_proc( GTK, 
  "gtk_radio_menu_item_set_group", {C_POINTER,C_POINTER} )

global procedure gtk_radio_menu_item_set_group(atom radio_menu_item_, atom group_)
    c_proc( gtk_radio_menu_item_set_group_, {radio_menu_item_,group_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKRC.H
----------------------------------------
----------------------------------------


global constant
    GTK_RC_FG                           = power(2,0),
    GTK_RC_BG                           = power(2,1),
    GTK_RC_TEXT                         = power(2,2),
    GTK_RC_BASE                         = power(2,3)
global constant SIZEOF_GtkRcFlags = SIZEOF_ENUM


----------------------------------------
-- GtkRcStyle
----------------------------------------
-- manually corrected:
-- bg_pixmap_name[5], color_flags[5], fg[5], bg[5], text[5], base[5]
global constant
    GtkRcStyle_name                     = allot(TYPE_POINTER),
    GtkRcStyle_font_name                = allot(TYPE_POINTER),
    GtkRcStyle_fontset_name             = allot(TYPE_POINTER),
    GtkRcStyle_bg_pixmap_name           = allot(5*LONG_BYTES),
    GtkRcStyle_color_flags              = allot(5*SIZEOF_GtkRcFlags),
    GtkRcStyle_fg                       = allot(5*SIZEOF_GdkColor),
    GtkRcStyle_bg                       = allot(5*SIZEOF_GdkColor),
    GtkRcStyle_text                     = allot(5*SIZEOF_GdkColor),
    GtkRcStyle_base                     = allot(5*SIZEOF_GdkColor),
    GtkRcStyle_engine                   = allot(TYPE_POINTER),
    GtkRcStyle_engine_data              = allot(TYPE_GPOINTER),
    GtkRcStyle_ref_count                = allot(TYPE_GUINT),
    SIZEOF_GtkRcStyle                   = allotted_size()
----------------------------------------
-- gtk_rc_init
----------------------------------------
constant gtk_rc_init_ = link_c_proc( GTK, 
  "gtk_rc_init", {} )

global procedure gtk_rc_init()
    c_proc( gtk_rc_init_, {} )
end procedure

----------------------------------------
-- gtk_rc_add_default_file
----------------------------------------
constant gtk_rc_add_default_file_ = link_c_proc( GTK, 
  "gtk_rc_add_default_file", {C_POINTER} )

global procedure gtk_rc_add_default_file(sequence const_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_rc_add_default_file_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_rc_set_default_files
----------------------------------------
constant gtk_rc_set_default_files_ = link_c_proc( GTK, 
  "gtk_rc_set_default_files", {C_POINTER} )

global procedure gtk_rc_set_default_files(sequence filenames_)
    atom string1
    string1 = allocate_string( filenames_ )
    c_proc( gtk_rc_set_default_files_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_rc_get_default_files
----------------------------------------
constant gtk_rc_get_default_files_ = link_c_func( GTK, 
  "gtk_rc_get_default_files", {}, C_POINTER )

global function gtk_rc_get_default_files()
    return peek_string( c_func( gtk_rc_get_default_files_, {} ) )
end function

----------------------------------------
-- gtk_rc_parse
----------------------------------------
constant gtk_rc_parse_ = link_c_proc( GTK, 
  "gtk_rc_parse", {C_POINTER} )

global procedure gtk_rc_parse(sequence const_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_rc_parse_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_rc_parse_string
----------------------------------------
constant gtk_rc_parse_string_ = link_c_proc( GTK, 
  "gtk_rc_parse_string", {C_POINTER} )

global procedure gtk_rc_parse_string(sequence const_)
    atom string1
    string1 = allocate_string( const_ )
    c_proc( gtk_rc_parse_string_, {string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_rc_reparse_all
----------------------------------------
constant gtk_rc_reparse_all_ = link_c_func( GTK, 
  "gtk_rc_reparse_all", {}, C_INT )

global function gtk_rc_reparse_all()
    return c_func( gtk_rc_reparse_all_, {} )
end function

----------------------------------------
-- gtk_rc_get_style
----------------------------------------
constant gtk_rc_get_style_ = link_c_func( GTK, 
  "gtk_rc_get_style", {C_POINTER}, C_POINTER )

global function gtk_rc_get_style(atom widget_)
    return c_func( gtk_rc_get_style_, {widget_} )
end function

----------------------------------------
-- gtk_rc_add_widget_name_style
----------------------------------------
constant gtk_rc_add_widget_name_style_ = link_c_proc( GTK, 
  "gtk_rc_add_widget_name_style", {C_POINTER,C_POINTER} )

global procedure gtk_rc_add_widget_name_style(atom rc_style_, sequence pattern_)
    atom string1
    string1 = allocate_string( pattern_ )
    c_proc( gtk_rc_add_widget_name_style_, {rc_style_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_rc_add_widget_class_style
----------------------------------------
constant gtk_rc_add_widget_class_style_ = link_c_proc( GTK, 
  "gtk_rc_add_widget_class_style", {C_POINTER,C_POINTER} )

global procedure gtk_rc_add_widget_class_style(atom rc_style_, sequence pattern_)
    atom string1
    string1 = allocate_string( pattern_ )
    c_proc( gtk_rc_add_widget_class_style_, {rc_style_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_rc_add_class_style
----------------------------------------
constant gtk_rc_add_class_style_ = link_c_proc( GTK, 
  "gtk_rc_add_class_style", {C_POINTER,C_POINTER} )

global procedure gtk_rc_add_class_style(atom rc_style_, sequence pattern_)
    atom string1
    string1 = allocate_string( pattern_ )
    c_proc( gtk_rc_add_class_style_, {rc_style_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_rc_style_new
----------------------------------------
constant gtk_rc_style_new_ = link_c_func( GTK, 
  "gtk_rc_style_new", {}, C_POINTER )

global function gtk_rc_style_new()
    return c_func( gtk_rc_style_new_, {} )
end function

----------------------------------------
-- gtk_rc_style_ref
----------------------------------------
constant gtk_rc_style_ref_ = link_c_proc( GTK, 
  "gtk_rc_style_ref", {C_POINTER} )

global procedure gtk_rc_style_ref(atom rc_style_)
    c_proc( gtk_rc_style_ref_, {rc_style_} )
end procedure

----------------------------------------
-- gtk_rc_style_unref
----------------------------------------
constant gtk_rc_style_unref_ = link_c_proc( GTK, 
  "gtk_rc_style_unref", {C_POINTER} )

global procedure gtk_rc_style_unref(atom rc_style_)
    c_proc( gtk_rc_style_unref_, {rc_style_} )
end procedure

----------------------------------------
-- GtkImageLoader
----------------------------------------
constant GtkImageLoader_ = link_c_func( GTK, 
  "GtkImageLoader", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function GtkImageLoader(atom window_, atom colormap_, atom mask_, atom transparent_color_, sequence filename_)
    atom result
    atom string1
    string1 = allocate_string( filename_ )
    result = c_func( GtkImageLoader_, {window_,colormap_,mask_,transparent_color_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_rc_set_image_loader
----------------------------------------
constant gtk_rc_set_image_loader_ = link_c_proc( GTK, 
  "gtk_rc_set_image_loader", {C_POINTER} )

global procedure gtk_rc_set_image_loader(atom loader_)
    c_proc( gtk_rc_set_image_loader_, {loader_} )
end procedure

----------------------------------------
-- gtk_rc_load_image
----------------------------------------
constant gtk_rc_load_image_ = link_c_func( GTK, 
  "gtk_rc_load_image", {C_POINTER,C_POINTER,C_POINTER}, C_POINTER )

global function gtk_rc_load_image(atom colormap_, atom transparent_color_, sequence filename_)
    atom result
    atom string1
    string1 = allocate_string( filename_ )
    result = c_func( gtk_rc_load_image_, {colormap_,transparent_color_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_rc_find_pixmap_in_path
----------------------------------------
constant gtk_rc_find_pixmap_in_path_ = link_c_func( GTK, 
  "gtk_rc_find_pixmap_in_path", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_rc_find_pixmap_in_path(atom scanner_, sequence pixmap_file_)
    atom result
    atom string1
    string1 = allocate_string( pixmap_file_ )
    result = c_func( gtk_rc_find_pixmap_in_path_, {scanner_,string1} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_rc_find_module_in_path
----------------------------------------
constant gtk_rc_find_module_in_path_ = link_c_func( GTK, 
  "gtk_rc_find_module_in_path", {C_POINTER}, C_POINTER )

global function gtk_rc_find_module_in_path(sequence const_)
    atom result
    atom string1
    string1 = allocate_string( const_ )
    result = c_func( gtk_rc_find_module_in_path_, {string1} )
    free( string1 )
    return peek_string( result )
end function

----------------------------------------
-- gtk_rc_get_theme_dir
----------------------------------------
constant gtk_rc_get_theme_dir_ = link_c_func( GTK, 
  "gtk_rc_get_theme_dir", {}, C_POINTER )

global function gtk_rc_get_theme_dir()
    return peek_string( c_func( gtk_rc_get_theme_dir_, {} ) )
end function

----------------------------------------
-- gtk_rc_get_module_dir
----------------------------------------
constant gtk_rc_get_module_dir_ = link_c_func( GTK, 
  "gtk_rc_get_module_dir", {}, C_POINTER )

global function gtk_rc_get_module_dir()
    return peek_string( c_func( gtk_rc_get_module_dir_, {} ) )
end function

-- ERROR: Don't know the value of G_TOKEN_LAST
-- global constant
--     GTK_RC_TOKEN_INVALID                = G_TOKEN_LAST,
--     GTK_RC_TOKEN_INCLUDE                = G_TOKEN_LAST + 1,
--     GTK_RC_TOKEN_NORMAL                 = G_TOKEN_LAST + 2,
--     GTK_RC_TOKEN_ACTIVE                 = G_TOKEN_LAST + 3,
--     GTK_RC_TOKEN_PRELIGHT               = G_TOKEN_LAST + 4,
--     GTK_RC_TOKEN_SELECTED               = G_TOKEN_LAST + 5,
--     GTK_RC_TOKEN_INSENSITIVE            = G_TOKEN_LAST + 6,
--     GTK_RC_TOKEN_FG                     = G_TOKEN_LAST + 7,
--     GTK_RC_TOKEN_BG                     = G_TOKEN_LAST + 8,
--     GTK_RC_TOKEN_BASE                   = G_TOKEN_LAST + 9,
--     GTK_RC_TOKEN_TEXT                   = G_TOKEN_LAST + 10,
--     GTK_RC_TOKEN_FONT                   = G_TOKEN_LAST + 11,
--     GTK_RC_TOKEN_FONTSET                = G_TOKEN_LAST + 12,
--     GTK_RC_TOKEN_BG_PIXMAP              = G_TOKEN_LAST + 13,
--     GTK_RC_TOKEN_PIXMAP_PATH            = G_TOKEN_LAST + 14,
--     GTK_RC_TOKEN_STYLE                  = G_TOKEN_LAST + 15,
--     GTK_RC_TOKEN_BINDING                = G_TOKEN_LAST + 16,
--     GTK_RC_TOKEN_BIND                   = G_TOKEN_LAST + 17,
--     GTK_RC_TOKEN_WIDGET                 = G_TOKEN_LAST + 18,
--     GTK_RC_TOKEN_WIDGET_CLASS           = G_TOKEN_LAST + 19,
--     GTK_RC_TOKEN_CLASS                  = G_TOKEN_LAST + 20,
--     GTK_RC_TOKEN_LOWEST                 = G_TOKEN_LAST + 21,
--     GTK_RC_TOKEN_GTK                    = G_TOKEN_LAST + 22,
--     GTK_RC_TOKEN_APPLICATION            = G_TOKEN_LAST + 23,
--     GTK_RC_TOKEN_RC                     = G_TOKEN_LAST + 24,
--     GTK_RC_TOKEN_HIGHEST                = G_TOKEN_LAST + 25,
--     GTK_RC_TOKEN_ENGINE                 = G_TOKEN_LAST + 26,
--     GTK_RC_TOKEN_MODULE_PATH            = G_TOKEN_LAST + 27,
--     GTK_RC_TOKEN_LAST                   = G_TOKEN_LAST + 28
-- global constant SIZEOF_GtkRcTokenType = SIZEOF_ENUM

----------------------------------------
-- gtk_rc_parse_color
----------------------------------------
constant gtk_rc_parse_color_ = link_c_func( GTK, 
  "gtk_rc_parse_color", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_rc_parse_color(atom scanner_, atom color_)
    return c_func( gtk_rc_parse_color_, {scanner_,color_} )
end function

----------------------------------------
-- gtk_rc_parse_state
----------------------------------------
constant gtk_rc_parse_state_ = link_c_func( GTK, 
  "gtk_rc_parse_state", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_rc_parse_state(atom scanner_, atom state_)
    return c_func( gtk_rc_parse_state_, {scanner_,state_} )
end function

----------------------------------------
-- gtk_rc_parse_priority
----------------------------------------
constant gtk_rc_parse_priority_ = link_c_func( GTK, 
  "gtk_rc_parse_priority", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_rc_parse_priority(atom scanner_, atom priority_)
    return c_func( gtk_rc_parse_priority_, {scanner_,priority_} )
end function



----------------------------------------
----------------------------------------
-- GTKSCROLLEDWINDOW.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkScrolledWindow
----------------------------------------
global constant
    GtkScrolledWindow_container         = allot(SIZEOF_GtkBin),
    GtkScrolledWindow_hscrollbar        = allot(TYPE_POINTER),
    GtkScrolledWindow_vscrollbar        = allot(TYPE_POINTER),
    GtkScrolledWindow_hscrollbar_policy = allot(TYPE_GUINT),
    GtkScrolledWindow_vscrollbar_policy = allot(TYPE_GUINT),
    GtkScrolledWindow_hscrollbar_visible= allot(TYPE_GUINT),
    GtkScrolledWindow_vscrollbar_visible= allot(TYPE_GUINT),
    GtkScrolledWindow_window_placement  = allot(TYPE_GUINT),
    SIZEOF_GtkScrolledWindow            = allotted_size()

----------------------------------------
-- GtkScrolledWindowClass
----------------------------------------
global constant
    GtkScrolledWindowClass_parent_class = allot(SIZEOF_GtkBinClass),
    GtkScrolledWindowClass_scrollbar_spacing= allot(TYPE_GINT),
    SIZEOF_GtkScrolledWindowClass       = allotted_size()
----------------------------------------
-- gtk_scrolled_window_get_type
----------------------------------------
constant gtk_scrolled_window_get_type_ = link_c_func( GTK, 
  "gtk_scrolled_window_get_type", {}, C_UINT )

global function gtk_scrolled_window_get_type()
    return c_func( gtk_scrolled_window_get_type_, {} )
end function

----------------------------------------
-- gtk_scrolled_window_new
----------------------------------------
constant gtk_scrolled_window_new_ = link_c_func( GTK, 
  "gtk_scrolled_window_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_scrolled_window_new(atom hadjustment_, atom vadjustment_)
    return c_func( gtk_scrolled_window_new_, {hadjustment_,vadjustment_} )
end function

----------------------------------------
-- gtk_scrolled_window_set_hadjustment
----------------------------------------
constant gtk_scrolled_window_set_hadjustment_ = link_c_proc( GTK, 
  "gtk_scrolled_window_set_hadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_scrolled_window_set_hadjustment(atom scrolled_window_, atom hadjustment_)
    c_proc( gtk_scrolled_window_set_hadjustment_, {scrolled_window_,hadjustment_} )
end procedure

----------------------------------------
-- gtk_scrolled_window_set_vadjustment
----------------------------------------
constant gtk_scrolled_window_set_vadjustment_ = link_c_proc( GTK, 
  "gtk_scrolled_window_set_vadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_scrolled_window_set_vadjustment(atom scrolled_window_, atom hadjustment_)
    c_proc( gtk_scrolled_window_set_vadjustment_, {scrolled_window_,hadjustment_} )
end procedure

----------------------------------------
-- gtk_scrolled_window_get_hadjustment
----------------------------------------
constant gtk_scrolled_window_get_hadjustment_ = link_c_func( GTK, 
  "gtk_scrolled_window_get_hadjustment", {C_POINTER}, C_POINTER )

global function gtk_scrolled_window_get_hadjustment(atom scrolled_window_)
    return c_func( gtk_scrolled_window_get_hadjustment_, {scrolled_window_} )
end function

----------------------------------------
-- gtk_scrolled_window_get_vadjustment
----------------------------------------
constant gtk_scrolled_window_get_vadjustment_ = link_c_func( GTK, 
  "gtk_scrolled_window_get_vadjustment", {C_POINTER}, C_POINTER )

global function gtk_scrolled_window_get_vadjustment(atom scrolled_window_)
    return c_func( gtk_scrolled_window_get_vadjustment_, {scrolled_window_} )
end function

----------------------------------------
-- gtk_scrolled_window_set_policy
----------------------------------------
constant gtk_scrolled_window_set_policy_ = link_c_proc( GTK, 
  "gtk_scrolled_window_set_policy", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_scrolled_window_set_policy(atom scrolled_window_, atom hscrollbar_policy_, atom vscrollbar_policy_)
    c_proc( gtk_scrolled_window_set_policy_, {scrolled_window_,hscrollbar_policy_,vscrollbar_policy_} )
end procedure

----------------------------------------
-- gtk_scrolled_window_set_placement
----------------------------------------
constant gtk_scrolled_window_set_placement_ = link_c_proc( GTK, 
  "gtk_scrolled_window_set_placement", {C_POINTER,C_POINTER} )

global procedure gtk_scrolled_window_set_placement(atom scrolled_window_, atom window_placement_)
    c_proc( gtk_scrolled_window_set_placement_, {scrolled_window_,window_placement_} )
end procedure

----------------------------------------
-- gtk_scrolled_window_add_with_viewport
----------------------------------------
constant gtk_scrolled_window_add_with_viewport_ = link_c_proc( GTK, 
  "gtk_scrolled_window_add_with_viewport", {C_POINTER,C_POINTER} )

global procedure gtk_scrolled_window_add_with_viewport(atom scrolled_window_, atom child_)
    c_proc( gtk_scrolled_window_add_with_viewport_, {scrolled_window_,child_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKVIEWPORT.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkViewport
----------------------------------------
global constant
    GtkViewport_bin                     = allot(SIZEOF_GtkBin),
    GtkViewport_shadow_type             = allot(SIZEOF_GtkShadowType),
    GtkViewport_view_window             = allot(TYPE_POINTER),
    GtkViewport_bin_window              = allot(TYPE_POINTER),
    GtkViewport_hadjustment             = allot(TYPE_POINTER),
    GtkViewport_vadjustment             = allot(TYPE_POINTER),
    SIZEOF_GtkViewport                  = allotted_size()

----------------------------------------
-- GtkViewportClass
----------------------------------------
global constant
    GtkViewportClass_parent_class       = allot(SIZEOF_GtkBinClass),
    GtkViewportClass_set_scroll_adjustments= allot(TYPE_GPOINTER),
    SIZEOF_GtkViewportClass             = allotted_size()
----------------------------------------
-- gtk_viewport_get_type
----------------------------------------
constant gtk_viewport_get_type_ = link_c_func( GTK, 
  "gtk_viewport_get_type", {}, C_UINT )

global function gtk_viewport_get_type()
    return c_func( gtk_viewport_get_type_, {} )
end function

----------------------------------------
-- gtk_viewport_new
----------------------------------------
constant gtk_viewport_new_ = link_c_func( GTK, 
  "gtk_viewport_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_viewport_new(atom hadjustment_, atom vadjustment_)
    return c_func( gtk_viewport_new_, {hadjustment_,vadjustment_} )
end function

----------------------------------------
-- gtk_viewport_get_hadjustment
----------------------------------------
constant gtk_viewport_get_hadjustment_ = link_c_func( GTK, 
  "gtk_viewport_get_hadjustment", {C_POINTER}, C_POINTER )

global function gtk_viewport_get_hadjustment(atom viewport_)
    return c_func( gtk_viewport_get_hadjustment_, {viewport_} )
end function

----------------------------------------
-- gtk_viewport_get_vadjustment
----------------------------------------
constant gtk_viewport_get_vadjustment_ = link_c_func( GTK, 
  "gtk_viewport_get_vadjustment", {C_POINTER}, C_POINTER )

global function gtk_viewport_get_vadjustment(atom viewport_)
    return c_func( gtk_viewport_get_vadjustment_, {viewport_} )
end function

----------------------------------------
-- gtk_viewport_set_hadjustment
----------------------------------------
constant gtk_viewport_set_hadjustment_ = link_c_proc( GTK, 
  "gtk_viewport_set_hadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_viewport_set_hadjustment(atom viewport_, atom adjustment_)
    c_proc( gtk_viewport_set_hadjustment_, {viewport_,adjustment_} )
end procedure

----------------------------------------
-- gtk_viewport_set_vadjustment
----------------------------------------
constant gtk_viewport_set_vadjustment_ = link_c_proc( GTK, 
  "gtk_viewport_set_vadjustment", {C_POINTER,C_POINTER} )

global procedure gtk_viewport_set_vadjustment(atom viewport_, atom adjustment_)
    c_proc( gtk_viewport_set_vadjustment_, {viewport_,adjustment_} )
end procedure

----------------------------------------
-- gtk_viewport_set_shadow_type
----------------------------------------
constant gtk_viewport_set_shadow_type_ = link_c_proc( GTK, 
  "gtk_viewport_set_shadow_type", {C_POINTER,C_POINTER} )

global procedure gtk_viewport_set_shadow_type(atom viewport_, atom type_)
    c_proc( gtk_viewport_set_shadow_type_, {viewport_,type_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKSOCKET.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkSocket
----------------------------------------
global constant
    GtkSocket_container                 = allot(SIZEOF_GtkContainer),
    GtkSocket_request_width             = allot(TYPE_GUINT16),
    GtkSocket_request_height            = allot(TYPE_GUINT16),
    GtkSocket_current_width             = allot(TYPE_GUINT16),
    GtkSocket_current_height            = allot(TYPE_GUINT16),
    GtkSocket_plug_window               = allot(TYPE_POINTER),
    GtkSocket_same_app                  = allot(TYPE_GUINT),
    GtkSocket_focus_in                  = allot(TYPE_GUINT),
    GtkSocket_have_size                 = allot(TYPE_GUINT),
    GtkSocket_need_map                  = allot(TYPE_GUINT),
    SIZEOF_GtkSocket                    = allotted_size()

----------------------------------------
-- GtkSocketClass
----------------------------------------
global constant
    GtkSocketClass_parent_class         = allot(SIZEOF_GtkContainerClass),
    SIZEOF_GtkSocketClass               = allotted_size()
----------------------------------------
-- gtk_socket_new
----------------------------------------
constant gtk_socket_new_ = link_c_func( GTK, 
  "gtk_socket_new", {}, C_POINTER )

global function gtk_socket_new()
    return c_func( gtk_socket_new_, {} )
end function

----------------------------------------
-- gtk_socket_get_type
----------------------------------------
constant gtk_socket_get_type_ = link_c_func( GTK, 
  "gtk_socket_get_type", {}, C_UINT )

global function gtk_socket_get_type()
    return c_func( gtk_socket_get_type_, {} )
end function

----------------------------------------
-- gtk_socket_steal
----------------------------------------
constant gtk_socket_steal_ = link_c_proc( GTK, 
  "gtk_socket_steal", {C_POINTER,C_UINT} )

global procedure gtk_socket_steal(atom socket_, atom wid_)
    c_proc( gtk_socket_steal_, {socket_,wid_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKSPINBUTTON.H
----------------------------------------
----------------------------------------


global constant
    GTK_UPDATE_ALWAYS                   = 1,
    GTK_UPDATE_IF_VALID                 = 2
global constant SIZEOF_GtkSpinButtonUpdatePolicy = SIZEOF_ENUM

global constant
    GTK_SPIN_STEP_FORWARD               = 1,
    GTK_SPIN_STEP_BACKWARD              = 2,
    GTK_SPIN_PAGE_FORWARD               = 3,
    GTK_SPIN_PAGE_BACKWARD              = 4,
    GTK_SPIN_HOME                       = 5,
    GTK_SPIN_END                        = 6,
    GTK_SPIN_USER_DEFINED               = 7
global constant SIZEOF_GtkSpinType = SIZEOF_ENUM


----------------------------------------
-- GtkSpinButton
----------------------------------------
global constant
    GtkSpinButton_entry                 = allot(SIZEOF_GtkEntry),
    GtkSpinButton_adjustment            = allot(TYPE_POINTER),
    GtkSpinButton_panel                 = allot(TYPE_POINTER),
    GtkSpinButton_shadow_type           = allot(SIZEOF_GtkShadowType),
    GtkSpinButton_timer                 = allot(TYPE_GUINT32),
    GtkSpinButton_ev_time               = allot(TYPE_GUINT32),
    GtkSpinButton_climb_rate            = allot(TYPE_GFLOAT),
    GtkSpinButton_timer_step            = allot(TYPE_GFLOAT),
    GtkSpinButton_update_policy         = allot(SIZEOF_GtkSpinButtonUpdatePolicy),
    GtkSpinButton_in_child              = allot(TYPE_GUINT),
    GtkSpinButton_click_child           = allot(TYPE_GUINT),
    GtkSpinButton_button                = allot(TYPE_GUINT),
    GtkSpinButton_need_timer            = allot(TYPE_GUINT),
    GtkSpinButton_timer_calls           = allot(TYPE_GUINT),
    GtkSpinButton_digits                = allot(TYPE_GUINT),
    GtkSpinButton_numeric               = allot(TYPE_GUINT),
    GtkSpinButton_wrap                  = allot(TYPE_GUINT),
    GtkSpinButton_snap_to_ticks         = allot(TYPE_GUINT),
    SIZEOF_GtkSpinButton                = allotted_size()

----------------------------------------
-- GtkSpinButtonClass
----------------------------------------
global constant
    GtkSpinButtonClass_parent_class     = allot(SIZEOF_GtkEntryClass),
    GtkSpinButtonClass_input            = allot(TYPE_GPOINTER),
    GtkSpinButtonClass_output           = allot(TYPE_GPOINTER),
    SIZEOF_GtkSpinButtonClass           = allotted_size()
----------------------------------------
-- gtk_spin_button_get_type
----------------------------------------
constant gtk_spin_button_get_type_ = link_c_func( GTK, 
  "gtk_spin_button_get_type", {}, C_UINT )

global function gtk_spin_button_get_type()
    return c_func( gtk_spin_button_get_type_, {} )
end function

----------------------------------------
-- gtk_spin_button_configure
----------------------------------------
constant gtk_spin_button_configure_ = link_c_proc( GTK, 
  "gtk_spin_button_configure", {C_POINTER,C_POINTER,C_LONG,C_UINT} )

global procedure gtk_spin_button_configure(atom spin_button_, atom adjustment_, integer climb_rate_, integer digits_)
    c_proc( gtk_spin_button_configure_, {spin_button_,adjustment_,climb_rate_,digits_} )
end procedure

----------------------------------------
-- gtk_spin_button_new
----------------------------------------
constant gtk_spin_button_new_ = link_c_func( GTK, 
  "gtk_spin_button_new", {C_POINTER,C_LONG,C_UINT}, C_POINTER )

global function gtk_spin_button_new(atom adjustment_, integer climb_rate_, integer digits_)
    return c_func( gtk_spin_button_new_, {adjustment_,climb_rate_,digits_} )
end function

----------------------------------------
-- gtk_spin_button_set_adjustment
----------------------------------------
constant gtk_spin_button_set_adjustment_ = link_c_proc( GTK, 
  "gtk_spin_button_set_adjustment", {C_POINTER,C_POINTER} )

global procedure gtk_spin_button_set_adjustment(atom spin_button_, atom adjustment_)
    c_proc( gtk_spin_button_set_adjustment_, {spin_button_,adjustment_} )
end procedure

----------------------------------------
-- gtk_spin_button_get_adjustment
----------------------------------------
constant gtk_spin_button_get_adjustment_ = link_c_func( GTK, 
  "gtk_spin_button_get_adjustment", {C_POINTER}, C_POINTER )

global function gtk_spin_button_get_adjustment(atom spin_button_)
    return c_func( gtk_spin_button_get_adjustment_, {spin_button_} )
end function

----------------------------------------
-- gtk_spin_button_set_digits
----------------------------------------
constant gtk_spin_button_set_digits_ = link_c_proc( GTK, 
  "gtk_spin_button_set_digits", {C_POINTER,C_UINT} )

global procedure gtk_spin_button_set_digits(atom spin_button_, integer digits_)
    c_proc( gtk_spin_button_set_digits_, {spin_button_,digits_} )
end procedure

----------------------------------------
-- gtk_spin_button_get_value_as_float
----------------------------------------
constant gtk_spin_button_get_value_as_float_ = link_c_func( GTK, 
  "gtk_spin_button_get_value_as_float", {C_POINTER}, C_LONG )

global function gtk_spin_button_get_value_as_float(atom spin_button_)
    return c_func( gtk_spin_button_get_value_as_float_, {spin_button_} )
end function

----------------------------------------
-- gtk_spin_button_get_value_as_int
----------------------------------------
constant gtk_spin_button_get_value_as_int_ = link_c_func( GTK, 
  "gtk_spin_button_get_value_as_int", {C_POINTER}, C_INT )

global function gtk_spin_button_get_value_as_int(atom spin_button_)
    return c_func( gtk_spin_button_get_value_as_int_, {spin_button_} )
end function

----------------------------------------
-- gtk_spin_button_set_value
----------------------------------------
constant gtk_spin_button_set_value_ = link_c_proc( GTK, 
  "gtk_spin_button_set_value", {C_POINTER,C_LONG} )

global procedure gtk_spin_button_set_value(atom spin_button_, integer value_)
    c_proc( gtk_spin_button_set_value_, {spin_button_,value_} )
end procedure

----------------------------------------
-- gtk_spin_button_set_update_policy
----------------------------------------
constant gtk_spin_button_set_update_policy_ = link_c_proc( GTK, 
  "gtk_spin_button_set_update_policy", {C_POINTER,C_POINTER} )

global procedure gtk_spin_button_set_update_policy(atom spin_button_, atom policy_)
    c_proc( gtk_spin_button_set_update_policy_, {spin_button_,policy_} )
end procedure

----------------------------------------
-- gtk_spin_button_set_numeric
----------------------------------------
constant gtk_spin_button_set_numeric_ = link_c_proc( GTK, 
  "gtk_spin_button_set_numeric", {C_POINTER,C_INT} )

global procedure gtk_spin_button_set_numeric(atom spin_button_, integer numeric_)
    c_proc( gtk_spin_button_set_numeric_, {spin_button_,numeric_} )
end procedure

----------------------------------------
-- gtk_spin_button_spin
----------------------------------------
constant gtk_spin_button_spin_ = link_c_proc( GTK, 
  "gtk_spin_button_spin", {C_POINTER,C_POINTER,C_LONG} )

global procedure gtk_spin_button_spin(atom spin_button_, atom direction_, integer increment_)
    c_proc( gtk_spin_button_spin_, {spin_button_,direction_,increment_} )
end procedure

----------------------------------------
-- gtk_spin_button_set_wrap
----------------------------------------
constant gtk_spin_button_set_wrap_ = link_c_proc( GTK, 
  "gtk_spin_button_set_wrap", {C_POINTER,C_INT} )

global procedure gtk_spin_button_set_wrap(atom spin_button_, integer wrap_)
    c_proc( gtk_spin_button_set_wrap_, {spin_button_,wrap_} )
end procedure

----------------------------------------
-- gtk_spin_button_set_shadow_type
----------------------------------------
constant gtk_spin_button_set_shadow_type_ = link_c_proc( GTK, 
  "gtk_spin_button_set_shadow_type", {C_POINTER,C_POINTER} )

global procedure gtk_spin_button_set_shadow_type(atom spin_button_, atom shadow_type_)
    c_proc( gtk_spin_button_set_shadow_type_, {spin_button_,shadow_type_} )
end procedure

----------------------------------------
-- gtk_spin_button_set_snap_to_ticks
----------------------------------------
constant gtk_spin_button_set_snap_to_ticks_ = link_c_proc( GTK, 
  "gtk_spin_button_set_snap_to_ticks", {C_POINTER,C_INT} )

global procedure gtk_spin_button_set_snap_to_ticks(atom spin_button_, integer snap_to_ticks_)
    c_proc( gtk_spin_button_set_snap_to_ticks_, {spin_button_,snap_to_ticks_} )
end procedure

----------------------------------------
-- gtk_spin_button_update
----------------------------------------
constant gtk_spin_button_update_ = link_c_proc( GTK, 
  "gtk_spin_button_update", {C_POINTER} )

global procedure gtk_spin_button_update(atom spin_button_)
    c_proc( gtk_spin_button_update_, {spin_button_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKSTATUSBAR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkStatusbar
----------------------------------------
global constant
    GtkStatusbar_parent_widget          = allot(SIZEOF_GtkHBox),
    GtkStatusbar_frame                  = allot(TYPE_POINTER),
    GtkStatusbar_label                  = allot(TYPE_POINTER),
    GtkStatusbar_messages               = allot(TYPE_POINTER),
    GtkStatusbar_keys                   = allot(TYPE_POINTER),
    GtkStatusbar_seq_context_id         = allot(TYPE_GUINT),
    GtkStatusbar_seq_message_id         = allot(TYPE_GUINT),
    SIZEOF_GtkStatusbar                 = allotted_size()

----------------------------------------
-- GtkStatusbarClass
----------------------------------------
global constant
    GtkStatusbarClass_parent_class      = allot(SIZEOF_GtkHBoxClass),
    GtkStatusbarClass_messages_mem_chunk= allot(TYPE_POINTER),
    GtkStatusbarClass_text_pushed       = allot(TYPE_GPOINTER),
    GtkStatusbarClass_text_popped       = allot(TYPE_GPOINTER),
    SIZEOF_GtkStatusbarClass            = allotted_size()

----------------------------------------
-- GtkStatusbarMsg
----------------------------------------
global constant
    GtkStatusbarMsg_text                = allot(TYPE_POINTER),
    GtkStatusbarMsg_context_id          = allot(TYPE_GUINT),
    GtkStatusbarMsg_message_id          = allot(TYPE_GUINT),
    SIZEOF_GtkStatusbarMsg              = allotted_size()
----------------------------------------
-- gtk_statusbar_get_type
----------------------------------------
constant gtk_statusbar_get_type_ = link_c_func( GTK, 
  "gtk_statusbar_get_type", {}, C_UINT )

global function gtk_statusbar_get_type()
    return c_func( gtk_statusbar_get_type_, {} )
end function

----------------------------------------
-- gtk_statusbar_new
----------------------------------------
constant gtk_statusbar_new_ = link_c_func( GTK, 
  "gtk_statusbar_new", {}, C_POINTER )

global function gtk_statusbar_new()
    return c_func( gtk_statusbar_new_, {} )
end function

----------------------------------------
-- gtk_statusbar_get_context_id
----------------------------------------
constant gtk_statusbar_get_context_id_ = link_c_func( GTK, 
  "gtk_statusbar_get_context_id", {C_POINTER,C_POINTER}, C_UINT )

global function gtk_statusbar_get_context_id(atom statusbar_, sequence context_description_)
    integer result
    atom string1
    string1 = allocate_string( context_description_ )
    result = c_func( gtk_statusbar_get_context_id_, {statusbar_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_statusbar_push
----------------------------------------
constant gtk_statusbar_push_ = link_c_func( GTK, 
  "gtk_statusbar_push", {C_POINTER,C_UINT,C_POINTER}, C_UINT )

global function gtk_statusbar_push(atom statusbar_, integer context_id_, sequence text_)
    integer result
    atom string1
    string1 = allocate_string( text_ )
    result = c_func( gtk_statusbar_push_, {statusbar_,context_id_,string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_statusbar_pop
----------------------------------------
constant gtk_statusbar_pop_ = link_c_proc( GTK, 
  "gtk_statusbar_pop", {C_POINTER,C_UINT} )

global procedure gtk_statusbar_pop(atom statusbar_, integer context_id_)
    c_proc( gtk_statusbar_pop_, {statusbar_,context_id_} )
end procedure

----------------------------------------
-- gtk_statusbar_remove
----------------------------------------
constant gtk_statusbar_remove_ = link_c_proc( GTK, 
  "gtk_statusbar_remove", {C_POINTER,C_UINT,C_UINT} )

global procedure gtk_statusbar_remove(atom statusbar_, integer context_id_, integer message_id_)
    c_proc( gtk_statusbar_remove_, {statusbar_,context_id_,message_id_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKTEAROFFMENUITEM.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkTearoffMenuItem
----------------------------------------
global constant
    GtkTearoffMenuItem_menu_item        = allot(SIZEOF_GtkMenuItem),
    GtkTearoffMenuItem_torn_off         = allot(TYPE_GUINT),
    SIZEOF_GtkTearoffMenuItem           = allotted_size()

----------------------------------------
-- GtkTearoffMenuItemClass
----------------------------------------
global constant
    GtkTearoffMenuItemClass_parent_class= allot(SIZEOF_GtkMenuItemClass),
    SIZEOF_GtkTearoffMenuItemClass      = allotted_size()
----------------------------------------
-- gtk_tearoff_menu_item_get_type
----------------------------------------
constant gtk_tearoff_menu_item_get_type_ = link_c_func( GTK, 
  "gtk_tearoff_menu_item_get_type", {}, C_UINT )

global function gtk_tearoff_menu_item_get_type()
    return c_func( gtk_tearoff_menu_item_get_type_, {} )
end function

----------------------------------------
-- gtk_tearoff_menu_item_new
----------------------------------------
constant gtk_tearoff_menu_item_new_ = link_c_func( GTK, 
  "gtk_tearoff_menu_item_new", {}, C_POINTER )

global function gtk_tearoff_menu_item_new()
    return c_func( gtk_tearoff_menu_item_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKTEXT.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkPropertyMark
----------------------------------------
global constant
    GtkPropertyMark_property            = allot(TYPE_POINTER),
    GtkPropertyMark_offset              = allot(TYPE_GUINT),
    GtkPropertyMark_index               = allot(TYPE_GUINT),
    SIZEOF_GtkPropertyMark              = allotted_size()

----------------------------------------
-- GtkText
----------------------------------------
global constant
    GtkText_editable                    = allot(SIZEOF_GtkEditable),
    GtkText_text_area                   = allot(TYPE_POINTER),
    GtkText_hadj                        = allot(TYPE_POINTER),
    GtkText_vadj                        = allot(TYPE_POINTER),
    GtkText_gc                          = allot(TYPE_POINTER),
    GtkText_line_wrap_bitmap            = allot(TYPE_POINTER),
    GtkText_line_arrow_bitmap           = allot(TYPE_POINTER),
    GtkText_text                        = allot(TYPE_LONG), -- union,
    GtkText_text_len                    = allot(TYPE_GUINT),
    GtkText_gap_position                = allot(TYPE_GUINT),
    GtkText_gap_size                    = allot(TYPE_GUINT),
    GtkText_text_end                    = allot(TYPE_GUINT),
    GtkText_line_start_cache            = allot(TYPE_POINTER),
    GtkText_first_line_start_index      = allot(TYPE_GUINT),
    GtkText_first_cut_pixels            = allot(TYPE_GUINT),
    GtkText_first_onscreen_hor_pixel    = allot(TYPE_GUINT),
    GtkText_first_onscreen_ver_pixel    = allot(TYPE_GUINT),
    GtkText_line_wrap                   = allot(TYPE_GUINT),
    GtkText_word_wrap                   = allot(TYPE_GUINT),
    GtkText_use_wchar                   = allot(TYPE_GUINT),
    GtkText_freeze_count                = allot(TYPE_GUINT),
    GtkText_text_properties             = allot(TYPE_POINTER),
    GtkText_text_properties_end         = allot(TYPE_POINTER),
    GtkText_point                       = allot(SIZEOF_GtkPropertyMark),
    GtkText_scratch_buffer              = allot(TYPE_LONG), -- union,
    GtkText_scratch_buffer_len          = allot(TYPE_GUINT),
    GtkText_last_ver_value              = allot(TYPE_GINT),
    GtkText_cursor_pos_x                = allot(TYPE_GINT),
    GtkText_cursor_pos_y                = allot(TYPE_GINT),
    GtkText_cursor_mark                 = allot(SIZEOF_GtkPropertyMark),
    GtkText_cursor_char                 = allot(TYPE_GUINT32),
    GtkText_cursor_char_offset          = allot(TYPE_GCHAR),
    GtkText_cursor_virtual_x            = allot(TYPE_GINT),
    GtkText_cursor_drawn_level          = allot(TYPE_GINT),
    GtkText_current_line                = allot(TYPE_POINTER),
    GtkText_tab_stops                   = allot(TYPE_POINTER),
    GtkText_default_tab_width           = allot(TYPE_GINT),
    GtkText_current_font                = allot(TYPE_POINTER),
    GtkText_timer                       = allot(TYPE_GINT),
    GtkText_button                      = allot(TYPE_GUINT),
    GtkText_bg_gc                       = allot(TYPE_POINTER),
    SIZEOF_GtkText                      = allotted_size()

----------------------------------------
-- GtkTextClass
----------------------------------------
global constant
    GtkTextClass_parent_class           = allot(SIZEOF_GtkEditableClass),
    GtkTextClass_set_scroll_adjustments = allot(TYPE_GPOINTER),
    SIZEOF_GtkTextClass                 = allotted_size()
----------------------------------------
-- gtk_text_get_type
----------------------------------------
constant gtk_text_get_type_ = link_c_func( GTK, 
  "gtk_text_get_type", {}, C_UINT )

global function gtk_text_get_type()
    return c_func( gtk_text_get_type_, {} )
end function

----------------------------------------
-- gtk_text_new
----------------------------------------
constant gtk_text_new_ = link_c_func( GTK, 
  "gtk_text_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_text_new(atom hadj_, atom vadj_)
    return c_func( gtk_text_new_, {hadj_,vadj_} )
end function

----------------------------------------
-- gtk_text_set_editable
----------------------------------------
constant gtk_text_set_editable_ = link_c_proc( GTK, 
  "gtk_text_set_editable", {C_POINTER,C_INT} )

global procedure gtk_text_set_editable(atom text_, integer editable_)
    c_proc( gtk_text_set_editable_, {text_,editable_} )
end procedure

----------------------------------------
-- gtk_text_set_word_wrap
----------------------------------------
constant gtk_text_set_word_wrap_ = link_c_proc( GTK, 
  "gtk_text_set_word_wrap", {C_POINTER,C_INT} )

global procedure gtk_text_set_word_wrap(atom text_, integer word_wrap_)
    c_proc( gtk_text_set_word_wrap_, {text_,word_wrap_} )
end procedure

----------------------------------------
-- gtk_text_set_line_wrap
----------------------------------------
constant gtk_text_set_line_wrap_ = link_c_proc( GTK, 
  "gtk_text_set_line_wrap", {C_POINTER,C_INT} )

global procedure gtk_text_set_line_wrap(atom text_, integer line_wrap_)
    c_proc( gtk_text_set_line_wrap_, {text_,line_wrap_} )
end procedure

----------------------------------------
-- gtk_text_set_adjustments
----------------------------------------
constant gtk_text_set_adjustments_ = link_c_proc( GTK, 
  "gtk_text_set_adjustments", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_text_set_adjustments(atom text_, atom hadj_, atom vadj_)
    c_proc( gtk_text_set_adjustments_, {text_,hadj_,vadj_} )
end procedure

----------------------------------------
-- gtk_text_set_point
----------------------------------------
constant gtk_text_set_point_ = link_c_proc( GTK, 
  "gtk_text_set_point", {C_POINTER,C_UINT} )

global procedure gtk_text_set_point(atom text_, integer index_)
    c_proc( gtk_text_set_point_, {text_,index_} )
end procedure

----------------------------------------
-- gtk_text_get_point
----------------------------------------
constant gtk_text_get_point_ = link_c_func( GTK, 
  "gtk_text_get_point", {C_POINTER}, C_UINT )

global function gtk_text_get_point(atom text_)
    return c_func( gtk_text_get_point_, {text_} )
end function

----------------------------------------
-- gtk_text_get_length
----------------------------------------
constant gtk_text_get_length_ = link_c_func( GTK, 
  "gtk_text_get_length", {C_POINTER}, C_UINT )

global function gtk_text_get_length(atom text_)
    return c_func( gtk_text_get_length_, {text_} )
end function

----------------------------------------
-- gtk_text_freeze
----------------------------------------
constant gtk_text_freeze_ = link_c_proc( GTK, 
  "gtk_text_freeze", {C_POINTER} )

global procedure gtk_text_freeze(atom text_)
    c_proc( gtk_text_freeze_, {text_} )
end procedure

----------------------------------------
-- gtk_text_thaw
----------------------------------------
constant gtk_text_thaw_ = link_c_proc( GTK, 
  "gtk_text_thaw", {C_POINTER} )

global procedure gtk_text_thaw(atom text_)
    c_proc( gtk_text_thaw_, {text_} )
end procedure

----------------------------------------
-- gtk_text_insert
----------------------------------------
constant gtk_text_insert_ = link_c_proc( GTK, 
  "gtk_text_insert", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT} )

global procedure gtk_text_insert(atom text_, atom font_, atom fore_, atom back_, sequence chars_, integer length_)
    atom string1
    string1 = allocate_string( chars_ )
    c_proc( gtk_text_insert_, {text_,font_,fore_,back_,string1,length_} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_text_backward_delete
----------------------------------------
constant gtk_text_backward_delete_ = link_c_func( GTK, 
  "gtk_text_backward_delete", {C_POINTER,C_UINT}, C_INT )

global function gtk_text_backward_delete(atom text_, integer nchars_)
    return c_func( gtk_text_backward_delete_, {text_,nchars_} )
end function

----------------------------------------
-- gtk_text_forward_delete
----------------------------------------
constant gtk_text_forward_delete_ = link_c_func( GTK, 
  "gtk_text_forward_delete", {C_POINTER,C_UINT}, C_INT )

global function gtk_text_forward_delete(atom text_, integer nchars_)
    return c_func( gtk_text_forward_delete_, {text_,nchars_} )
end function



----------------------------------------
----------------------------------------
-- GTKTHEMES.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkThemeEngine
----------------------------------------
global constant
    GtkThemeEngine_parse_rc_style       = allot(TYPE_GPOINTER),
    GtkThemeEngine_merge_rc_style       = allot(TYPE_GPOINTER),
    GtkThemeEngine_rc_style_to_style    = allot(TYPE_GPOINTER),
    GtkThemeEngine_duplicate_style      = allot(TYPE_GPOINTER),
    GtkThemeEngine_realize_style        = allot(TYPE_GPOINTER),
    GtkThemeEngine_unrealize_style      = allot(TYPE_GPOINTER),
    GtkThemeEngine_destroy_rc_style     = allot(TYPE_GPOINTER),
    GtkThemeEngine_destroy_style        = allot(TYPE_GPOINTER),
    GtkThemeEngine_set_background       = allot(TYPE_GPOINTER),
    SIZEOF_GtkThemeEngine               = allotted_size()
----------------------------------------
-- gtk_theme_engine_get
----------------------------------------
constant gtk_theme_engine_get_ = link_c_func( GTK, 
  "gtk_theme_engine_get", {C_POINTER}, C_POINTER )

global function gtk_theme_engine_get(sequence name_)
    atom result
    atom string1
    string1 = allocate_string( name_ )
    result = c_func( gtk_theme_engine_get_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_theme_engine_ref
----------------------------------------
constant gtk_theme_engine_ref_ = link_c_proc( GTK, 
  "gtk_theme_engine_ref", {C_POINTER} )

global procedure gtk_theme_engine_ref(atom engine_)
    c_proc( gtk_theme_engine_ref_, {engine_} )
end procedure

----------------------------------------
-- gtk_theme_engine_unref
----------------------------------------
constant gtk_theme_engine_unref_ = link_c_proc( GTK, 
  "gtk_theme_engine_unref", {C_POINTER} )

global procedure gtk_theme_engine_unref(atom engine_)
    c_proc( gtk_theme_engine_unref_, {engine_} )
end procedure

----------------------------------------
-- gtk_themes_init
----------------------------------------
constant gtk_themes_init_ = link_c_proc( GTK, 
  "gtk_themes_init", {C_INT,C_POINTER} )

global procedure gtk_themes_init(integer argc_, sequence argv_)
    atom string1
    string1 = allocate_string( argv_ )
    c_proc( gtk_themes_init_, {argc_,string1} )
    free( string1 )
end procedure

----------------------------------------
-- gtk_themes_exit
----------------------------------------
constant gtk_themes_exit_ = link_c_proc( GTK, 
  "gtk_themes_exit", {C_INT} )

global procedure gtk_themes_exit(integer error_code_)
    c_proc( gtk_themes_exit_, {error_code_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKTIPSQUERY.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkTipsQuery
----------------------------------------
global constant
    GtkTipsQuery_label                  = allot(SIZEOF_GtkLabel),
    GtkTipsQuery_emit_always            = allot(TYPE_GUINT),
    GtkTipsQuery_in_query               = allot(TYPE_GUINT),
    GtkTipsQuery_label_inactive         = allot(TYPE_POINTER),
    GtkTipsQuery_label_no_tip           = allot(TYPE_POINTER),
    GtkTipsQuery_caller                 = allot(TYPE_POINTER),
    GtkTipsQuery_last_crossed           = allot(TYPE_POINTER),
    GtkTipsQuery_query_cursor           = allot(TYPE_POINTER),
    SIZEOF_GtkTipsQuery                 = allotted_size()

----------------------------------------
-- GtkTipsQueryClass
----------------------------------------
global constant
    GtkTipsQueryClass_parent_class      = allot(SIZEOF_GtkLabelClass),
    GtkTipsQueryClass_start_query       = allot(TYPE_GPOINTER),
    GtkTipsQueryClass_stop_query        = allot(TYPE_GPOINTER),
    GtkTipsQueryClass_widget_entered    = allot(TYPE_GPOINTER),
    GtkTipsQueryClass_widget_selected   = allot(TYPE_GPOINTER),
    SIZEOF_GtkTipsQueryClass            = allotted_size()
----------------------------------------
-- gtk_tips_query_get_type
----------------------------------------
constant gtk_tips_query_get_type_ = link_c_func( GTK, 
  "gtk_tips_query_get_type", {}, C_UINT )

global function gtk_tips_query_get_type()
    return c_func( gtk_tips_query_get_type_, {} )
end function

----------------------------------------
-- gtk_tips_query_new
----------------------------------------
constant gtk_tips_query_new_ = link_c_func( GTK, 
  "gtk_tips_query_new", {}, C_POINTER )

global function gtk_tips_query_new()
    return c_func( gtk_tips_query_new_, {} )
end function

----------------------------------------
-- gtk_tips_query_start_query
----------------------------------------
constant gtk_tips_query_start_query_ = link_c_proc( GTK, 
  "gtk_tips_query_start_query", {C_POINTER} )

global procedure gtk_tips_query_start_query(atom tips_query_)
    c_proc( gtk_tips_query_start_query_, {tips_query_} )
end procedure

----------------------------------------
-- gtk_tips_query_stop_query
----------------------------------------
constant gtk_tips_query_stop_query_ = link_c_proc( GTK, 
  "gtk_tips_query_stop_query", {C_POINTER} )

global procedure gtk_tips_query_stop_query(atom tips_query_)
    c_proc( gtk_tips_query_stop_query_, {tips_query_} )
end procedure

----------------------------------------
-- gtk_tips_query_set_caller
----------------------------------------
constant gtk_tips_query_set_caller_ = link_c_proc( GTK, 
  "gtk_tips_query_set_caller", {C_POINTER,C_POINTER} )

global procedure gtk_tips_query_set_caller(atom tips_query_, atom caller_)
    c_proc( gtk_tips_query_set_caller_, {tips_query_,caller_} )
end procedure

----------------------------------------
-- gtk_tips_query_set_labels
----------------------------------------
constant gtk_tips_query_set_labels_ = link_c_proc( GTK, 
  "gtk_tips_query_set_labels", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_tips_query_set_labels(atom tips_query_, sequence label_inactive_, sequence label_no_tip_)
    atom string1, string2
    string1 = allocate_string( label_inactive_ )
    string2 = allocate_string( label_no_tip_ )
    c_proc( gtk_tips_query_set_labels_, {tips_query_,string1,string2} )
    free( string1 )
    free( string2 )
end procedure



----------------------------------------
----------------------------------------
-- GTKTOOLBAR.H
----------------------------------------
----------------------------------------


global constant
    GTK_TOOLBAR_CHILD_SPACE             = 1,
    GTK_TOOLBAR_CHILD_BUTTON            = 2,
    GTK_TOOLBAR_CHILD_TOGGLEBUTTON      = 3,
    GTK_TOOLBAR_CHILD_RADIOBUTTON       = 4,
    GTK_TOOLBAR_CHILD_WIDGET            = 5
global constant SIZEOF_GtkToolbarChildType = SIZEOF_ENUM

global constant
    GTK_TOOLBAR_SPACE_EMPTY             = 1,
    GTK_TOOLBAR_SPACE_LINE              = 2
global constant SIZEOF_GtkToolbarSpaceStyle = SIZEOF_ENUM


----------------------------------------
-- GtkToolbarChild
----------------------------------------
global constant
    GtkToolbarChild_type                = allot(SIZEOF_GtkToolbarChildType),
    GtkToolbarChild_widget              = allot(TYPE_POINTER),
    GtkToolbarChild_icon                = allot(TYPE_POINTER),
    GtkToolbarChild_label               = allot(TYPE_POINTER),
    SIZEOF_GtkToolbarChild              = allotted_size()

----------------------------------------
-- GtkToolbar
----------------------------------------
global constant
    GtkToolbar_container                = allot(SIZEOF_GtkContainer),
    GtkToolbar_num_children             = allot(TYPE_GINT),
    GtkToolbar_children                 = allot(TYPE_POINTER),
    GtkToolbar_orientation              = allot(SIZEOF_GtkOrientation),
    GtkToolbar_style                    = allot(SIZEOF_GtkToolbarStyle),
    GtkToolbar_space_size               = allot(TYPE_GINT),
    GtkToolbar_space_style              = allot(SIZEOF_GtkToolbarSpaceStyle),
    GtkToolbar_tooltips                 = allot(TYPE_POINTER),
    GtkToolbar_button_maxw              = allot(TYPE_GINT),
    GtkToolbar_button_maxh              = allot(TYPE_GINT),
    GtkToolbar_relief                   = allot(SIZEOF_GtkReliefStyle),
    SIZEOF_GtkToolbar                   = allotted_size()

----------------------------------------
-- GtkToolbarClass
----------------------------------------
global constant
    GtkToolbarClass_parent_class        = allot(SIZEOF_GtkContainerClass),
    GtkToolbarClass_orientation_changed = allot(TYPE_GPOINTER),
    GtkToolbarClass_style_changed       = allot(TYPE_GPOINTER),
    SIZEOF_GtkToolbarClass              = allotted_size()
----------------------------------------
-- gtk_toolbar_get_type
----------------------------------------
constant gtk_toolbar_get_type_ = link_c_func( GTK, 
  "gtk_toolbar_get_type", {}, C_UINT )

global function gtk_toolbar_get_type()
    return c_func( gtk_toolbar_get_type_, {} )
end function

----------------------------------------
-- gtk_toolbar_new
----------------------------------------
constant gtk_toolbar_new_ = link_c_func( GTK, 
  "gtk_toolbar_new", {C_POINTER,C_POINTER}, C_POINTER )

global function gtk_toolbar_new(atom orientation_, atom style_)
    return c_func( gtk_toolbar_new_, {orientation_,style_} )
end function

----------------------------------------
-- gtk_toolbar_append_item
----------------------------------------
constant gtk_toolbar_append_item_ = link_c_func( GTK, 
  "gtk_toolbar_append_item", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, 
 C_POINTER )

global function gtk_toolbar_append_item(atom toolbar_, sequence text_, sequence tooltip_text_, sequence tooltip_private_text_, 
 atom icon_, atom callback_, atom user_data_)
    atom result
    atom string1, string2, string3
    string1 = allocate_string( text_ )
    string2 = allocate_string( tooltip_text_ )
    string3 = allocate_string( tooltip_private_text_ )
    result = c_func( gtk_toolbar_append_item_, {toolbar_,string1,string2,string3,icon_,callback_,user_data_} )
    free( string1 )
    free( string2 )
    free( string3 )
    return result
end function

----------------------------------------
-- gtk_toolbar_prepend_item
----------------------------------------
constant gtk_toolbar_prepend_item_ = link_c_func( GTK, 
  "gtk_toolbar_prepend_item", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, 
 C_POINTER )

global function gtk_toolbar_prepend_item(atom toolbar_, sequence text_, sequence tooltip_text_, sequence tooltip_private_text_, 
 atom icon_, atom callback_, atom user_data_)
    atom result
    atom string1, string2, string3
    string1 = allocate_string( text_ )
    string2 = allocate_string( tooltip_text_ )
    string3 = allocate_string( tooltip_private_text_ )
    result = c_func( gtk_toolbar_prepend_item_, {toolbar_,string1,string2,string3,icon_,callback_,user_data_} )
    free( string1 )
    free( string2 )
    free( string3 )
    return result
end function

----------------------------------------
-- gtk_toolbar_insert_item
----------------------------------------
constant gtk_toolbar_insert_item_ = link_c_func( GTK, 
  "gtk_toolbar_insert_item", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT}, 
 C_POINTER )

global function gtk_toolbar_insert_item(atom toolbar_, sequence text_, sequence tooltip_text_, sequence tooltip_private_text_, 
 atom icon_, atom callback_, atom user_data_, integer position_)
    atom result
    atom string1, string2, string3
    string1 = allocate_string( text_ )
    string2 = allocate_string( tooltip_text_ )
    string3 = allocate_string( tooltip_private_text_ )
    result = c_func( gtk_toolbar_insert_item_, {toolbar_,string1,string2,string3,icon_,callback_,user_data_,position_} )
    free( string1 )
    free( string2 )
    free( string3 )
    return result
end function

----------------------------------------
-- gtk_toolbar_append_space
----------------------------------------
constant gtk_toolbar_append_space_ = link_c_proc( GTK, 
  "gtk_toolbar_append_space", {C_POINTER} )

global procedure gtk_toolbar_append_space(atom toolbar_)
    c_proc( gtk_toolbar_append_space_, {toolbar_} )
end procedure

----------------------------------------
-- gtk_toolbar_prepend_space
----------------------------------------
constant gtk_toolbar_prepend_space_ = link_c_proc( GTK, 
  "gtk_toolbar_prepend_space", {C_POINTER} )

global procedure gtk_toolbar_prepend_space(atom toolbar_)
    c_proc( gtk_toolbar_prepend_space_, {toolbar_} )
end procedure

----------------------------------------
-- gtk_toolbar_insert_space
----------------------------------------
constant gtk_toolbar_insert_space_ = link_c_proc( GTK, 
  "gtk_toolbar_insert_space", {C_POINTER,C_INT} )

global procedure gtk_toolbar_insert_space(atom toolbar_, integer position_)
    c_proc( gtk_toolbar_insert_space_, {toolbar_,position_} )
end procedure

----------------------------------------
-- gtk_toolbar_append_element
----------------------------------------
constant gtk_toolbar_append_element_ = link_c_func( GTK, 
  "gtk_toolbar_append_element", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, 
 C_POINTER )

global function gtk_toolbar_append_element(atom toolbar_, atom type_, atom widget_, sequence text_, sequence tooltip_text_, 
 sequence tooltip_private_text_, atom icon_, atom callback_, atom user_data_)
    atom result
    atom string1, string2, string3
    string1 = allocate_string( text_ )
    string2 = allocate_string( tooltip_text_ )
    string3 = allocate_string( tooltip_private_text_ )
    result = c_func( gtk_toolbar_append_element_, {toolbar_,type_,widget_,string1,string2,string3,icon_,callback_,user_data_} )
    free( string1 )
    free( string2 )
    free( string3 )
    return result
end function

----------------------------------------
-- gtk_toolbar_prepend_element
----------------------------------------
constant gtk_toolbar_prepend_element_ = link_c_func( GTK, 
  "gtk_toolbar_prepend_element", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER}, 
 C_POINTER )

global function gtk_toolbar_prepend_element(atom toolbar_, atom type_, atom widget_, sequence text_, sequence 
 tooltip_text_, sequence tooltip_private_text_, atom icon_, atom callback_, atom user_data_)
    atom result
    atom string1, string2, string3
    string1 = allocate_string( text_ )
    string2 = allocate_string( tooltip_text_ )
    string3 = allocate_string( tooltip_private_text_ )
    result = c_func( gtk_toolbar_prepend_element_, {toolbar_,type_,widget_,string1,string2,string3,icon_,callback_,user_data_} )
    free( string1 )
    free( string2 )
    free( string3 )
    return result
end function

----------------------------------------
-- gtk_toolbar_insert_element
----------------------------------------
constant gtk_toolbar_insert_element_ = link_c_func( GTK, 
  "gtk_toolbar_insert_element", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT}, 
 C_POINTER )

global function gtk_toolbar_insert_element(atom toolbar_, atom type_, atom widget_, sequence text_, sequence tooltip_text_, 
 sequence tooltip_private_text_, atom icon_, atom callback_, atom user_data_, integer position_)
    atom result
    atom string1, string2, string3
    string1 = allocate_string( text_ )
    string2 = allocate_string( tooltip_text_ )
    string3 = allocate_string( tooltip_private_text_ )
    result = c_func( gtk_toolbar_insert_element_, {toolbar_,type_,widget_,string1,string2,string3,icon_,callback_,user_data_,position_} )
    free( string1 )
    free( string2 )
    free( string3 )
    return result
end function

----------------------------------------
-- gtk_toolbar_append_widget
----------------------------------------
constant gtk_toolbar_append_widget_ = link_c_proc( GTK, 
  "gtk_toolbar_append_widget", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_toolbar_append_widget(atom toolbar_, atom widget_, sequence tooltip_text_, sequence tooltip_private_text_)
    atom string1, string2
    string1 = allocate_string( tooltip_text_ )
    string2 = allocate_string( tooltip_private_text_ )
    c_proc( gtk_toolbar_append_widget_, {toolbar_,widget_,string1,string2} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- gtk_toolbar_prepend_widget
----------------------------------------
constant gtk_toolbar_prepend_widget_ = link_c_proc( GTK, 
  "gtk_toolbar_prepend_widget", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_toolbar_prepend_widget(atom toolbar_, atom widget_, sequence tooltip_text_, sequence tooltip_private_text_)
    atom string1, string2
    string1 = allocate_string( tooltip_text_ )
    string2 = allocate_string( tooltip_private_text_ )
    c_proc( gtk_toolbar_prepend_widget_, {toolbar_,widget_,string1,string2} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- gtk_toolbar_insert_widget
----------------------------------------
constant gtk_toolbar_insert_widget_ = link_c_proc( GTK, 
  "gtk_toolbar_insert_widget", {C_POINTER,C_POINTER,C_POINTER,C_POINTER,C_INT} )

global procedure gtk_toolbar_insert_widget(atom toolbar_, atom widget_, sequence tooltip_text_, sequence tooltip_private_text_, integer position_)
    atom string1, string2
    string1 = allocate_string( tooltip_text_ )
    string2 = allocate_string( tooltip_private_text_ )
    c_proc( gtk_toolbar_insert_widget_, {toolbar_,widget_,string1,string2,position_} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- gtk_toolbar_set_orientation
----------------------------------------
constant gtk_toolbar_set_orientation_ = link_c_proc( GTK, 
  "gtk_toolbar_set_orientation", {C_POINTER,C_POINTER} )

global procedure gtk_toolbar_set_orientation(atom toolbar_, atom orientation_)
    c_proc( gtk_toolbar_set_orientation_, {toolbar_,orientation_} )
end procedure

----------------------------------------
-- gtk_toolbar_set_style
----------------------------------------
constant gtk_toolbar_set_style_ = link_c_proc( GTK, 
  "gtk_toolbar_set_style", {C_POINTER,C_POINTER} )

global procedure gtk_toolbar_set_style(atom toolbar_, atom style_)
    c_proc( gtk_toolbar_set_style_, {toolbar_,style_} )
end procedure

----------------------------------------
-- gtk_toolbar_set_space_size
----------------------------------------
constant gtk_toolbar_set_space_size_ = link_c_proc( GTK, 
  "gtk_toolbar_set_space_size", {C_POINTER,C_INT} )

global procedure gtk_toolbar_set_space_size(atom toolbar_, integer space_size_)
    c_proc( gtk_toolbar_set_space_size_, {toolbar_,space_size_} )
end procedure

----------------------------------------
-- gtk_toolbar_set_space_style
----------------------------------------
constant gtk_toolbar_set_space_style_ = link_c_proc( GTK, 
  "gtk_toolbar_set_space_style", {C_POINTER,C_POINTER} )

global procedure gtk_toolbar_set_space_style(atom toolbar_, atom space_style_)
    c_proc( gtk_toolbar_set_space_style_, {toolbar_,space_style_} )
end procedure

----------------------------------------
-- gtk_toolbar_set_tooltips
----------------------------------------
constant gtk_toolbar_set_tooltips_ = link_c_proc( GTK, 
  "gtk_toolbar_set_tooltips", {C_POINTER,C_INT} )

global procedure gtk_toolbar_set_tooltips(atom toolbar_, integer enable_)
    c_proc( gtk_toolbar_set_tooltips_, {toolbar_,enable_} )
end procedure

----------------------------------------
-- gtk_toolbar_set_button_relief
----------------------------------------
constant gtk_toolbar_set_button_relief_ = link_c_proc( GTK, 
  "gtk_toolbar_set_button_relief", {C_POINTER,C_POINTER} )

global procedure gtk_toolbar_set_button_relief(atom toolbar_, atom relief_)
    c_proc( gtk_toolbar_set_button_relief_, {toolbar_,relief_} )
end procedure

----------------------------------------
-- gtk_toolbar_get_button_relief
----------------------------------------
constant gtk_toolbar_get_button_relief_ = link_c_func( GTK, 
  "gtk_toolbar_get_button_relief", {C_POINTER}, C_POINTER )

global function gtk_toolbar_get_button_relief(atom toolbar_)
    return c_func( gtk_toolbar_get_button_relief_, {toolbar_} )
end function



----------------------------------------
----------------------------------------
-- GTKTOOLTIPS.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkTooltipsData
----------------------------------------
global constant
    GtkTooltipsData_tooltips            = allot(TYPE_POINTER),
    GtkTooltipsData_widget              = allot(TYPE_POINTER),
    GtkTooltipsData_tip_text            = allot(TYPE_POINTER),
    GtkTooltipsData_tip_private         = allot(TYPE_POINTER),
    GtkTooltipsData_font                = allot(TYPE_POINTER),
    GtkTooltipsData_width               = allot(TYPE_GINT),
    GtkTooltipsData_row                 = allot(TYPE_POINTER),
    SIZEOF_GtkTooltipsData              = allotted_size()

----------------------------------------
-- GtkTooltips
----------------------------------------
global constant
    GtkTooltips_data                    = allot(SIZEOF_GtkData),
    GtkTooltips_tip_window              = allot(TYPE_POINTER),
    GtkTooltips_active_tips_data        = allot(TYPE_POINTER),
    GtkTooltips_tips_data_list          = allot(TYPE_POINTER),
    GtkTooltips_gc                      = allot(TYPE_POINTER),
    GtkTooltips_foreground              = allot(TYPE_POINTER),
    GtkTooltips_background              = allot(TYPE_POINTER),
    GtkTooltips_delay                   = allot(TYPE_GUINT),
    GtkTooltips_enabled                 = allot(TYPE_GUINT),
    GtkTooltips_timer_tag               = allot(TYPE_GINT),
    SIZEOF_GtkTooltips                  = allotted_size()

----------------------------------------
-- GtkTooltipsClass
----------------------------------------
global constant
    GtkTooltipsClass_parent_class       = allot(SIZEOF_GtkDataClass),
    SIZEOF_GtkTooltipsClass             = allotted_size()
----------------------------------------
-- gtk_tooltips_get_type
----------------------------------------
constant gtk_tooltips_get_type_ = link_c_func( GTK, 
  "gtk_tooltips_get_type", {}, C_UINT )

global function gtk_tooltips_get_type()
    return c_func( gtk_tooltips_get_type_, {} )
end function

----------------------------------------
-- gtk_tooltips_new
----------------------------------------
constant gtk_tooltips_new_ = link_c_func( GTK, 
  "gtk_tooltips_new", {}, C_POINTER )

global function gtk_tooltips_new()
    return c_func( gtk_tooltips_new_, {} )
end function

----------------------------------------
-- gtk_tooltips_enable
----------------------------------------
constant gtk_tooltips_enable_ = link_c_proc( GTK, 
  "gtk_tooltips_enable", {C_POINTER} )

global procedure gtk_tooltips_enable(atom tooltips_)
    c_proc( gtk_tooltips_enable_, {tooltips_} )
end procedure

----------------------------------------
-- gtk_tooltips_disable
----------------------------------------
constant gtk_tooltips_disable_ = link_c_proc( GTK, 
  "gtk_tooltips_disable", {C_POINTER} )

global procedure gtk_tooltips_disable(atom tooltips_)
    c_proc( gtk_tooltips_disable_, {tooltips_} )
end procedure

----------------------------------------
-- gtk_tooltips_set_delay
----------------------------------------
constant gtk_tooltips_set_delay_ = link_c_proc( GTK, 
  "gtk_tooltips_set_delay", {C_POINTER,C_UINT} )

global procedure gtk_tooltips_set_delay(atom tooltips_, integer delay_)
    c_proc( gtk_tooltips_set_delay_, {tooltips_,delay_} )
end procedure

----------------------------------------
-- gtk_tooltips_set_tip
----------------------------------------
constant gtk_tooltips_set_tip_ = link_c_proc( GTK, 
  "gtk_tooltips_set_tip", {C_POINTER,C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_tooltips_set_tip(atom tooltips_, atom widget_, sequence tip_text_, sequence tip_private_)
    atom string1, string2
    string1 = allocate_string( tip_text_ )
    string2 = allocate_string( tip_private_ )
    c_proc( gtk_tooltips_set_tip_, {tooltips_,widget_,string1,string2} )
    free( string1 )
    free( string2 )
end procedure

----------------------------------------
-- gtk_tooltips_set_colors
----------------------------------------
constant gtk_tooltips_set_colors_ = link_c_proc( GTK, 
  "gtk_tooltips_set_colors", {C_POINTER,C_POINTER,C_POINTER} )

global procedure gtk_tooltips_set_colors(atom tooltips_, atom background_, atom foreground_)
    c_proc( gtk_tooltips_set_colors_, {tooltips_,background_,foreground_} )
end procedure

----------------------------------------
-- gtk_tooltips_data_get
----------------------------------------
constant gtk_tooltips_data_get_ = link_c_func( GTK, 
  "gtk_tooltips_data_get", {C_POINTER}, C_POINTER )

global function gtk_tooltips_data_get(atom widget_)
    return c_func( gtk_tooltips_data_get_, {widget_} )
end function

----------------------------------------
-- gtk_tooltips_force_window
----------------------------------------
constant gtk_tooltips_force_window_ = link_c_proc( GTK, 
  "gtk_tooltips_force_window", {C_POINTER} )

global procedure gtk_tooltips_force_window(atom tooltips_)
    c_proc( gtk_tooltips_force_window_, {tooltips_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKTREE.H
----------------------------------------
----------------------------------------


global constant
    GTK_TREE_VIEW_LINE                  = 1,
    GTK_TREE_VIEW_ITEM                  = 2
global constant SIZEOF_GtkTreeViewMode = SIZEOF_ENUM


----------------------------------------
-- GtkTree
----------------------------------------
global constant
    GtkTree_container                   = allot(SIZEOF_GtkContainer),
    GtkTree_children                    = allot(TYPE_POINTER),
    GtkTree_root_tree                   = allot(TYPE_POINTER),
    GtkTree_tree_owner                  = allot(TYPE_POINTER),
    GtkTree_selection                   = allot(TYPE_POINTER),
    GtkTree_level                       = allot(TYPE_GUINT),
    GtkTree_indent_value                = allot(TYPE_GUINT),
    GtkTree_current_indent              = allot(TYPE_GUINT),
    GtkTree_selection_mode              = allot(TYPE_GUINT),
    GtkTree_view_mode                   = allot(TYPE_GUINT),
    GtkTree_view_line                   = allot(TYPE_GUINT),
    SIZEOF_GtkTree                      = allotted_size()

----------------------------------------
-- GtkTreeClass
----------------------------------------
global constant
    GtkTreeClass_parent_class           = allot(SIZEOF_GtkContainerClass),
    GtkTreeClass_selection_changed      = allot(TYPE_GPOINTER),
    GtkTreeClass_select_child           = allot(TYPE_GPOINTER),
    GtkTreeClass_unselect_child         = allot(TYPE_GPOINTER),
    SIZEOF_GtkTreeClass                 = allotted_size()
----------------------------------------
-- gtk_tree_get_type
----------------------------------------
constant gtk_tree_get_type_ = link_c_func( GTK, 
  "gtk_tree_get_type", {}, C_UINT )

global function gtk_tree_get_type()
    return c_func( gtk_tree_get_type_, {} )
end function

----------------------------------------
-- gtk_tree_new
----------------------------------------
constant gtk_tree_new_ = link_c_func( GTK, 
  "gtk_tree_new", {}, C_POINTER )

global function gtk_tree_new()
    return c_func( gtk_tree_new_, {} )
end function

----------------------------------------
-- gtk_tree_append
----------------------------------------
constant gtk_tree_append_ = link_c_proc( GTK, 
  "gtk_tree_append", {C_POINTER,C_POINTER} )

global procedure gtk_tree_append(atom tree_, atom tree_item_)
    c_proc( gtk_tree_append_, {tree_,tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_prepend
----------------------------------------
constant gtk_tree_prepend_ = link_c_proc( GTK, 
  "gtk_tree_prepend", {C_POINTER,C_POINTER} )

global procedure gtk_tree_prepend(atom tree_, atom tree_item_)
    c_proc( gtk_tree_prepend_, {tree_,tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_insert
----------------------------------------
constant gtk_tree_insert_ = link_c_proc( GTK, 
  "gtk_tree_insert", {C_POINTER,C_POINTER,C_INT} )

global procedure gtk_tree_insert(atom tree_, atom tree_item_, integer position_)
    c_proc( gtk_tree_insert_, {tree_,tree_item_,position_} )
end procedure

----------------------------------------
-- gtk_tree_remove_items
----------------------------------------
constant gtk_tree_remove_items_ = link_c_proc( GTK, 
  "gtk_tree_remove_items", {C_POINTER,C_POINTER} )

global procedure gtk_tree_remove_items(atom tree_, atom items_)
    c_proc( gtk_tree_remove_items_, {tree_,items_} )
end procedure

----------------------------------------
-- gtk_tree_clear_items
----------------------------------------
constant gtk_tree_clear_items_ = link_c_proc( GTK, 
  "gtk_tree_clear_items", {C_POINTER,C_INT,C_INT} )

global procedure gtk_tree_clear_items(atom tree_, integer start_, integer end_)
    c_proc( gtk_tree_clear_items_, {tree_,start_,end_} )
end procedure

----------------------------------------
-- gtk_tree_select_item
----------------------------------------
constant gtk_tree_select_item_ = link_c_proc( GTK, 
  "gtk_tree_select_item", {C_POINTER,C_INT} )

global procedure gtk_tree_select_item(atom tree_, integer item_)
    c_proc( gtk_tree_select_item_, {tree_,item_} )
end procedure

----------------------------------------
-- gtk_tree_unselect_item
----------------------------------------
constant gtk_tree_unselect_item_ = link_c_proc( GTK, 
  "gtk_tree_unselect_item", {C_POINTER,C_INT} )

global procedure gtk_tree_unselect_item(atom tree_, integer item_)
    c_proc( gtk_tree_unselect_item_, {tree_,item_} )
end procedure

----------------------------------------
-- gtk_tree_select_child
----------------------------------------
constant gtk_tree_select_child_ = link_c_proc( GTK, 
  "gtk_tree_select_child", {C_POINTER,C_POINTER} )

global procedure gtk_tree_select_child(atom tree_, atom tree_item_)
    c_proc( gtk_tree_select_child_, {tree_,tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_unselect_child
----------------------------------------
constant gtk_tree_unselect_child_ = link_c_proc( GTK, 
  "gtk_tree_unselect_child", {C_POINTER,C_POINTER} )

global procedure gtk_tree_unselect_child(atom tree_, atom tree_item_)
    c_proc( gtk_tree_unselect_child_, {tree_,tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_child_position
----------------------------------------
constant gtk_tree_child_position_ = link_c_func( GTK, 
  "gtk_tree_child_position", {C_POINTER,C_POINTER}, C_INT )

global function gtk_tree_child_position(atom tree_, atom child_)
    return c_func( gtk_tree_child_position_, {tree_,child_} )
end function

----------------------------------------
-- gtk_tree_set_selection_mode
----------------------------------------
constant gtk_tree_set_selection_mode_ = link_c_proc( GTK, 
  "gtk_tree_set_selection_mode", {C_POINTER,C_POINTER} )

global procedure gtk_tree_set_selection_mode(atom tree_, atom mode_)
    c_proc( gtk_tree_set_selection_mode_, {tree_,mode_} )
end procedure

----------------------------------------
-- gtk_tree_set_view_mode
----------------------------------------
constant gtk_tree_set_view_mode_ = link_c_proc( GTK, 
  "gtk_tree_set_view_mode", {C_POINTER,C_POINTER} )

global procedure gtk_tree_set_view_mode(atom tree_, atom mode_)
    c_proc( gtk_tree_set_view_mode_, {tree_,mode_} )
end procedure

----------------------------------------
-- gtk_tree_set_view_lines
----------------------------------------
constant gtk_tree_set_view_lines_ = link_c_proc( GTK, 
  "gtk_tree_set_view_lines", {C_POINTER,C_UINT} )

global procedure gtk_tree_set_view_lines(atom tree_, integer flag_)
    c_proc( gtk_tree_set_view_lines_, {tree_,flag_} )
end procedure

----------------------------------------
-- gtk_tree_remove_item
----------------------------------------
constant gtk_tree_remove_item_ = link_c_proc( GTK, 
  "gtk_tree_remove_item", {C_POINTER,C_POINTER} )

global procedure gtk_tree_remove_item(atom tree_, atom child_)
    c_proc( gtk_tree_remove_item_, {tree_,child_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKTREEITEM.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkTreeItem
----------------------------------------
global constant
    GtkTreeItem_item                    = allot(SIZEOF_GtkItem),
    GtkTreeItem_subtree                 = allot(TYPE_POINTER),
    GtkTreeItem_pixmaps_box             = allot(TYPE_POINTER),
    GtkTreeItem_plus_pix_widget         = allot(TYPE_POINTER),
    GtkTreeItem_minus_pix_widget        = allot(TYPE_POINTER),
    GtkTreeItem_pixmaps                 = allot(TYPE_POINTER),
    GtkTreeItem_expanded                = allot(TYPE_GUINT),
    SIZEOF_GtkTreeItem                  = allotted_size()

----------------------------------------
-- GtkTreeItemClass
----------------------------------------
global constant
    GtkTreeItemClass_parent_class       = allot(SIZEOF_GtkItemClass),
    GtkTreeItemClass_expand             = allot(TYPE_GPOINTER),
    GtkTreeItemClass_collapse           = allot(TYPE_GPOINTER),
    SIZEOF_GtkTreeItemClass             = allotted_size()
----------------------------------------
-- gtk_tree_item_get_type
----------------------------------------
constant gtk_tree_item_get_type_ = link_c_func( GTK, 
  "gtk_tree_item_get_type", {}, C_UINT )

global function gtk_tree_item_get_type()
    return c_func( gtk_tree_item_get_type_, {} )
end function

----------------------------------------
-- gtk_tree_item_new
----------------------------------------
constant gtk_tree_item_new_ = link_c_func( GTK, 
  "gtk_tree_item_new", {}, C_POINTER )

global function gtk_tree_item_new()
    return c_func( gtk_tree_item_new_, {} )
end function

----------------------------------------
-- gtk_tree_item_new_with_label
----------------------------------------
constant gtk_tree_item_new_with_label_ = link_c_func( GTK, 
  "gtk_tree_item_new_with_label", {C_POINTER}, C_POINTER )

global function gtk_tree_item_new_with_label(sequence label_)
    atom result
    atom string1
    string1 = allocate_string( label_ )
    result = c_func( gtk_tree_item_new_with_label_, {string1} )
    free( string1 )
    return result
end function

----------------------------------------
-- gtk_tree_item_set_subtree
----------------------------------------
constant gtk_tree_item_set_subtree_ = link_c_proc( GTK, 
  "gtk_tree_item_set_subtree", {C_POINTER,C_POINTER} )

global procedure gtk_tree_item_set_subtree(atom tree_item_, atom subtree_)
    c_proc( gtk_tree_item_set_subtree_, {tree_item_,subtree_} )
end procedure

----------------------------------------
-- gtk_tree_item_remove_subtree
----------------------------------------
constant gtk_tree_item_remove_subtree_ = link_c_proc( GTK, 
  "gtk_tree_item_remove_subtree", {C_POINTER} )

global procedure gtk_tree_item_remove_subtree(atom tree_item_)
    c_proc( gtk_tree_item_remove_subtree_, {tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_item_select
----------------------------------------
constant gtk_tree_item_select_ = link_c_proc( GTK, 
  "gtk_tree_item_select", {C_POINTER} )

global procedure gtk_tree_item_select(atom tree_item_)
    c_proc( gtk_tree_item_select_, {tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_item_deselect
----------------------------------------
constant gtk_tree_item_deselect_ = link_c_proc( GTK, 
  "gtk_tree_item_deselect", {C_POINTER} )

global procedure gtk_tree_item_deselect(atom tree_item_)
    c_proc( gtk_tree_item_deselect_, {tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_item_expand
----------------------------------------
constant gtk_tree_item_expand_ = link_c_proc( GTK, 
  "gtk_tree_item_expand", {C_POINTER} )

global procedure gtk_tree_item_expand(atom tree_item_)
    c_proc( gtk_tree_item_expand_, {tree_item_} )
end procedure

----------------------------------------
-- gtk_tree_item_collapse
----------------------------------------
constant gtk_tree_item_collapse_ = link_c_proc( GTK, 
  "gtk_tree_item_collapse", {C_POINTER} )

global procedure gtk_tree_item_collapse(atom tree_item_)
    c_proc( gtk_tree_item_collapse_, {tree_item_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKVBBOX.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkVButtonBox
----------------------------------------
global constant
    GtkVButtonBox_button_box            = allot(SIZEOF_GtkButtonBox),
    SIZEOF_GtkVButtonBox                = allotted_size()

----------------------------------------
-- GtkVButtonBoxClass
----------------------------------------
global constant
    GtkVButtonBoxClass_parent_class     = allot(SIZEOF_GtkButtonBoxClass),
    SIZEOF_GtkVButtonBoxClass           = allotted_size()
----------------------------------------
-- gtk_vbutton_box_get_type
----------------------------------------
constant gtk_vbutton_box_get_type_ = link_c_func( GTK, 
  "gtk_vbutton_box_get_type", {}, C_UINT )

global function gtk_vbutton_box_get_type()
    return c_func( gtk_vbutton_box_get_type_, {} )
end function

----------------------------------------
-- gtk_vbutton_box_new
----------------------------------------
constant gtk_vbutton_box_new_ = link_c_func( GTK, 
  "gtk_vbutton_box_new", {}, C_POINTER )

global function gtk_vbutton_box_new()
    return c_func( gtk_vbutton_box_new_, {} )
end function

----------------------------------------
-- gtk_vbutton_box_get_spacing_default
----------------------------------------
constant gtk_vbutton_box_get_spacing_default_ = link_c_func( GTK, 
  "gtk_vbutton_box_get_spacing_default", {}, C_INT )

global function gtk_vbutton_box_get_spacing_default()
    return c_func( gtk_vbutton_box_get_spacing_default_, {} )
end function

----------------------------------------
-- gtk_vbutton_box_set_spacing_default
----------------------------------------
constant gtk_vbutton_box_set_spacing_default_ = link_c_proc( GTK, 
  "gtk_vbutton_box_set_spacing_default", {C_INT} )

global procedure gtk_vbutton_box_set_spacing_default(integer spacing_)
    c_proc( gtk_vbutton_box_set_spacing_default_, {spacing_} )
end procedure

----------------------------------------
-- gtk_vbutton_box_get_layout_default
----------------------------------------
constant gtk_vbutton_box_get_layout_default_ = link_c_func( GTK, 
  "gtk_vbutton_box_get_layout_default", {}, C_POINTER )

global function gtk_vbutton_box_get_layout_default()
    return c_func( gtk_vbutton_box_get_layout_default_, {} )
end function

----------------------------------------
-- gtk_vbutton_box_set_layout_default
----------------------------------------
constant gtk_vbutton_box_set_layout_default_ = link_c_proc( GTK, 
  "gtk_vbutton_box_set_layout_default", {C_POINTER} )

global procedure gtk_vbutton_box_set_layout_default(atom layout_)
    c_proc( gtk_vbutton_box_set_layout_default_, {layout_} )
end procedure



----------------------------------------
----------------------------------------
-- GTKVPANED.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkVPaned
----------------------------------------
global constant
    GtkVPaned_paned                     = allot(SIZEOF_GtkPaned),
    SIZEOF_GtkVPaned                    = allotted_size()

----------------------------------------
-- GtkVPanedClass
----------------------------------------
global constant
    GtkVPanedClass_parent_class         = allot(SIZEOF_GtkPanedClass),
    SIZEOF_GtkVPanedClass               = allotted_size()
----------------------------------------
-- gtk_vpaned_get_type
----------------------------------------
constant gtk_vpaned_get_type_ = link_c_func( GTK, 
  "gtk_vpaned_get_type", {}, C_UINT )

global function gtk_vpaned_get_type()
    return c_func( gtk_vpaned_get_type_, {} )
end function

----------------------------------------
-- gtk_vpaned_new
----------------------------------------
constant gtk_vpaned_new_ = link_c_func( GTK, 
  "gtk_vpaned_new", {}, C_POINTER )

global function gtk_vpaned_new()
    return c_func( gtk_vpaned_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKVRULER.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkVRuler
----------------------------------------
global constant
    GtkVRuler_ruler                     = allot(SIZEOF_GtkRuler),
    SIZEOF_GtkVRuler                    = allotted_size()

----------------------------------------
-- GtkVRulerClass
----------------------------------------
global constant
    GtkVRulerClass_parent_class         = allot(SIZEOF_GtkRulerClass),
    SIZEOF_GtkVRulerClass               = allotted_size()
----------------------------------------
-- gtk_vruler_get_type
----------------------------------------
constant gtk_vruler_get_type_ = link_c_func( GTK, 
  "gtk_vruler_get_type", {}, C_UINT )

global function gtk_vruler_get_type()
    return c_func( gtk_vruler_get_type_, {} )
end function

----------------------------------------
-- gtk_vruler_new
----------------------------------------
constant gtk_vruler_new_ = link_c_func( GTK, 
  "gtk_vruler_new", {}, C_POINTER )

global function gtk_vruler_new()
    return c_func( gtk_vruler_new_, {} )
end function



----------------------------------------
----------------------------------------
-- GTKVSCALE.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkVScale
----------------------------------------
global constant
    GtkVScale_scale                     = allot(SIZEOF_GtkScale),
    SIZEOF_GtkVScale                    = allotted_size()

----------------------------------------
-- GtkVScaleClass
----------------------------------------
global constant
    GtkVScaleClass_parent_class         = allot(SIZEOF_GtkScaleClass),
    SIZEOF_GtkVScaleClass               = allotted_size()
----------------------------------------
-- gtk_vscale_get_type
----------------------------------------
constant gtk_vscale_get_type_ = link_c_func( GTK, 
  "gtk_vscale_get_type", {}, C_UINT )

global function gtk_vscale_get_type()
    return c_func( gtk_vscale_get_type_, {} )
end function

----------------------------------------
-- gtk_vscale_new
----------------------------------------
constant gtk_vscale_new_ = link_c_func( GTK, 
  "gtk_vscale_new", {C_POINTER}, C_POINTER )

global function gtk_vscale_new(atom adjustment_)
    return c_func( gtk_vscale_new_, {adjustment_} )
end function



----------------------------------------
----------------------------------------
-- GTKVSEPARATOR.H
----------------------------------------
----------------------------------------



----------------------------------------
-- GtkVSeparator
----------------------------------------
global constant
    GtkVSeparator_separator             = allot(SIZEOF_GtkSeparator),
    SIZEOF_GtkVSeparator                = allotted_size()

----------------------------------------
-- GtkVSeparatorClass
----------------------------------------
global constant
    GtkVSeparatorClass_parent_class     = allot(SIZEOF_GtkSeparatorClass),
    SIZEOF_GtkVSeparatorClass           = allotted_size()
----------------------------------------
-- gtk_vseparator_get_type
----------------------------------------
constant gtk_vseparator_get_type_ = link_c_func( GTK, 
  "gtk_vseparator_get_type", {}, C_UINT )

global function gtk_vseparator_get_type()
    return c_func( gtk_vseparator_get_type_, {} )
end function

----------------------------------------
-- gtk_vseparator_new
----------------------------------------
constant gtk_vseparator_new_ = link_c_func( GTK, 
  "gtk_vseparator_new", {}, C_POINTER )

global function gtk_vseparator_new()
    return c_func( gtk_vseparator_new_, {} )
end function

